
#include "rtapi.h"		/* RTAPI realtime OS API */
#include "dynamic_6dof.h"
#include "rtapi_math.h"
#include "rtapi_app.h"		/* RTAPI realtime module decls */
#include "rtapi_string.h"
#include "hal.h"		/* HAL public API decls */
#include "sys/time.h"
/* module information */
MODULE_AUTHOR("le thang");
MODULE_DESCRIPTION("PD Loop dynamic torque control Component for EMC HAL");
MODULE_LICENSE("GPL");

/***********************************************************************
*                STRUCTURES AND GLOBAL VARIABLES                       *
************************************************************************/
typedef struct {
    hal_float_t *joint1_cmd;		
    hal_float_t *joint2_cmd;	
    hal_float_t *joint3_cmd;		
    hal_float_t *joint4_cmd;		
    hal_float_t *joint5_cmd;	
    hal_float_t *joint6_cmd;	
    hal_float_t *joint1_fb;		
    hal_float_t *joint2_fb;	
    hal_float_t *joint3_fb;		
    hal_float_t *joint4_fb;		
    hal_float_t *joint5_fb;	
    hal_float_t *joint6_fb;
    hal_float_t *vel1_cmd;		
    hal_float_t *vel2_cmd;	
    hal_float_t *vel3_cmd;		
    hal_float_t *vel4_cmd;		
    hal_float_t *vel5_cmd;	
    hal_float_t *vel6_cmd;
    hal_float_t *vel1_fb;		
    hal_float_t *vel2_fb;	
    hal_float_t *vel3_fb;		
    hal_float_t *vel4_fb;		
    hal_float_t *vel5_fb;	
    hal_float_t *vel6_fb;
    hal_float_t *acc1;		
    hal_float_t *acc2;	
    hal_float_t *acc3;		
    hal_float_t *acc4;		
    hal_float_t *acc5;	
    hal_float_t *acc6;
	hal_float_t 	*torq1;
	hal_float_t 	*torq2;
	hal_float_t 	*torq3;
	hal_float_t 	*torq4;
	hal_float_t 	*torq5;
	hal_float_t	*torq6;
    	hal_float_t   	*Kp1;
    	hal_float_t   	*Kd1;
   	hal_float_t   	*Kp2;
    	hal_float_t   	*Kd2;
   	hal_float_t   	*Kp3;
    	hal_float_t   	*Kd3;
   	hal_float_t   	*Kp4;
    	hal_float_t   	*Kd4;
   	hal_float_t   	*Kp5;
    	hal_float_t   	*Kd5;
   	hal_float_t   	*Kp6;
	hal_float_t   	*Kd6;
	hal_float_t   	*timecal;
} hal_pd_t;
typedef struct struct_dynamic {
	float array2d[10][10];
} darray;
static darray cal_inertia(float *joint);
static darray cal_coriolis(float *joint,float *dq);
static darray cal_gravity(float *joint);
static darray rne(float *joint, float *dq, float *ddq);
static int comp_id;
static hal_pd_t *dyn_pd_array;
static void rne_export(void *arg,long period);
static int export_pd(hal_pd_t *addr);
/***********************************************************************
*                       INIT AND EXIT CODE                             *
************************************************************************/

int rtapi_app_main(void)
{
    int retval;

    comp_id = hal_init("PDdyn");
    if (comp_id < 0) {
	rtapi_print_msg(RTAPI_MSG_ERR, "PDdyn: ERROR: hal_init() failed\n");
	return -EINVAL;
    }

    dyn_pd_array = hal_malloc(sizeof(hal_pd_t));
    /* validate config info */
	if (dyn_pd_array == 0) {
	rtapi_print_msg(RTAPI_MSG_ERR, "PDdyn: ERROR: hal_malloc() failed\n");
	hal_exit(comp_id);
	return -1;
    }
	retval = export_pd(dyn_pd_array);
	if (retval != 0) {
	    rtapi_print_msg(RTAPI_MSG_ERR,
		"PD: ERROR: loop var export failed\n");
	    hal_exit(comp_id);
	    return -1;
	}
    hal_ready(comp_id);
    return 0;
  
}

static int export_pd(hal_pd_t *addr)
{
	int retval, msg;
	msg = rtapi_get_msg_level();
    rtapi_set_msg_level(RTAPI_MSG_WARN);
	retval = hal_pin_float_new("J1cmd",HAL_IN,&(addr->joint1_cmd),comp_id);
    if (retval != 0) {
	return retval;
    }
	retval = hal_pin_float_new("J2cmd",HAL_IN,&(addr->joint2_cmd),comp_id);
    if (retval != 0) {
	return retval;
    }
	retval = hal_pin_float_new("J3cmd",HAL_IN,&(addr->joint3_cmd),comp_id);
    if (retval != 0) {
	return retval;
    }
	retval = hal_pin_float_new("J4cmd",HAL_IN,&(addr->joint4_cmd),comp_id);
    if (retval != 0) {
	return retval;
    }
	retval = hal_pin_float_new("J5cmd",HAL_IN,&(addr->joint5_cmd),comp_id);
    if (retval != 0) {
	return retval;
    }
	retval = hal_pin_float_new("J6cmd",HAL_IN,&(addr->joint6_cmd),comp_id);
    if (retval != 0) {
	return retval;
    }
//------------------------------	
	 retval = hal_pin_float_new("J1fb",HAL_IN,&(addr->joint1_fb),comp_id);
    if (retval != 0) {
	return retval;
    }
	retval = hal_pin_float_new("J2fb",HAL_IN,&(addr->joint2_fb),comp_id);
    if (retval != 0) {
	return retval;
    }
	retval = hal_pin_float_new("J3fb",HAL_IN,&(addr->joint3_fb),comp_id);
    if (retval != 0) {
	return retval;
    }
	retval = hal_pin_float_new("J4fb",HAL_IN,&(addr->joint4_fb),comp_id);
    if (retval != 0) {
	return retval;
    }
	retval = hal_pin_float_new("J5fb",HAL_IN,&(addr->joint5_fb),comp_id);
    if (retval != 0) {
	return retval;
    }
	retval = hal_pin_float_new("J6fb",HAL_IN,&(addr->joint6_fb),comp_id);
    if (retval != 0) {
	return retval;
    }
//---------------------------------------
	retval = hal_pin_float_new("vel1cmd",HAL_IN,&(addr->vel1_cmd),comp_id);
    if (retval != 0) {
	return retval;
    }
	retval = hal_pin_float_new("vel2cmd",HAL_IN,&(addr->vel2_cmd),comp_id);
    if (retval != 0) {
	return retval;
    }
	retval = hal_pin_float_new("vel3cmd",HAL_IN,&(addr->vel3_cmd),comp_id);
    if (retval != 0) {
	return retval;
    }
	retval = hal_pin_float_new("vel4cmd",HAL_IN,&(addr->vel4_cmd),comp_id);
    if (retval != 0) {
	return retval;
    }
	retval = hal_pin_float_new("vel5cmd",HAL_IN,&(addr->vel5_cmd),comp_id);
    if (retval != 0) {
	return retval;
    }
	retval = hal_pin_float_new("vel6cmd",HAL_IN,&(addr->vel6_cmd),comp_id);
    if (retval != 0) {
	return retval;
    }	
//----------------------------------------
	retval = hal_pin_float_new("vel1fb",HAL_IN,&(addr->vel1_fb),comp_id);
    if (retval != 0) {
	return retval;
    }
	retval = hal_pin_float_new("vel2fb",HAL_IN,&(addr->vel2_fb),comp_id);
    if (retval != 0) {
	return retval;
    }
	retval = hal_pin_float_new("vel3fb",HAL_IN,&(addr->vel3_fb),comp_id);
    if (retval != 0) {
	return retval;
    }
	retval = hal_pin_float_new("vel4fb",HAL_IN,&(addr->vel4_fb),comp_id);
    if (retval != 0) {
	return retval;
    }
	retval = hal_pin_float_new("vel5fb",HAL_IN,&(addr->vel5_fb),comp_id);
    if (retval != 0) {
	return retval;
    }
	retval = hal_pin_float_new("vel6fb",HAL_IN,&(addr->vel6_fb),comp_id);
    if (retval != 0) {
	return retval;
    }		
//--------------------------------------------
 retval = hal_pin_float_new("acc1",HAL_IN,&(addr->acc1),comp_id);
    if (retval != 0) {
	return retval;
    }
	retval = hal_pin_float_new("acc2",HAL_IN,&(addr->acc2),comp_id);
    if (retval != 0) {
	return retval;
    }
	retval = hal_pin_float_new("acc3",HAL_IN,&(addr->acc3),comp_id);
    if (retval != 0) {
	return retval;
    }
	retval = hal_pin_float_new("acc4",HAL_IN,&(addr->acc4),comp_id);
    if (retval != 0) {
	return retval;
    }
	retval = hal_pin_float_new("acc5",HAL_IN,&(addr->acc5),comp_id);
    if (retval != 0) {
	return retval;
    }
	retval = hal_pin_float_new("acc6",HAL_IN,&(addr->acc6),comp_id);
    if (retval != 0) {
	return retval;
    }
//-------------------------------------
	retval = hal_pin_float_new("PDdyn.Kp1",HAL_IN,&(addr->Kp1),comp_id);
    if (retval != 0) {
	return retval;
    }
	retval = hal_pin_float_new("PDdyn.Kd1",HAL_IN,&(addr->Kd1),comp_id);
    if (retval != 0) {
	return retval;
    }
	retval = hal_pin_float_new("PDdyn.Kp2",HAL_IN,&(addr->Kp2),comp_id);
    if (retval != 0) {
	return retval;
    }
	retval = hal_pin_float_new("PDdyn.Kd2",HAL_IN,&(addr->Kd2),comp_id);
    if (retval != 0) {
	return retval;
    }
	retval = hal_pin_float_new("PDdyn.Kp3",HAL_IN,&(addr->Kp3),comp_id);
    if (retval != 0) {
	return retval;
    }
	retval = hal_pin_float_new("PDdyn.Kd3",HAL_IN,&(addr->Kd3),comp_id);
    if (retval != 0) {
	return retval;
    }
	retval = hal_pin_float_new("PDdyn.Kp4",HAL_IN,&(addr->Kp4),comp_id);
    if (retval != 0) {
	return retval;
    }
	retval = hal_pin_float_new("PDdyn.Kd4",HAL_IN,&(addr->Kd4),comp_id);
    if (retval != 0) {
	return retval;
    }
	retval = hal_pin_float_new("PDdyn.Kp5",HAL_IN,&(addr->Kp5),comp_id);
    if (retval != 0) {
	return retval;
    }
	retval = hal_pin_float_new("PDdyn.Kd5",HAL_IN,&(addr->Kd5),comp_id);
    if (retval != 0) {
	return retval;
    }
	retval = hal_pin_float_new("PDdyn.Kp6",HAL_IN,&(addr->Kp6),comp_id);
    if (retval != 0) {
	return retval;
    }
	retval = hal_pin_float_new("PDdyn.Kd6",HAL_IN,&(addr->Kd6),comp_id);
    if (retval != 0) {
	return retval;
    }
//-------------------------------------------------------
	retval = hal_pin_float_new("torq1",HAL_OUT,&(addr->torq1),comp_id);
    if (retval != 0) {
	return retval;
    }
	retval = hal_pin_float_new("torq2",HAL_OUT,&(addr->torq2),comp_id);
    if (retval != 0) {
	return retval;
    }
	retval = hal_pin_float_new("torq3",HAL_OUT,&(addr->torq3),comp_id);
    if (retval != 0) {
	return retval;
    }
	retval = hal_pin_float_new("torq4",HAL_OUT,&(addr->torq4),comp_id);
    if (retval != 0) {
	return retval;
    }
	retval = hal_pin_float_new("torq5",HAL_OUT,&(addr->torq5),comp_id);
    if (retval != 0) {
	return retval;
    }
	retval = hal_pin_float_new("torq6",HAL_OUT,&(addr->torq6),comp_id);
    if (retval != 0) {
	return retval;
    }	
	retval = hal_pin_float_new("timecal",HAL_OUT,&(addr->timecal),comp_id);
    if (retval != 0) {
	return retval;
    }	
	
		*(addr->joint1_cmd) = 0;
		*(addr->joint2_cmd) = 0;
		*(addr->joint3_cmd) = 0;
		*(addr->joint4_cmd) = 0;
		*(addr->joint5_cmd) = 0;
		*(addr->joint6_cmd) = 0;
		*(addr->joint1_fb) = 0;
		*(addr->joint2_fb) = 0;
		*(addr->joint3_fb) = 0;
		*(addr->joint4_fb) = 0;
		*(addr->joint5_fb) = 0;
		*(addr->joint6_fb) = 0;
		*(addr->vel1_cmd) = 0;
		*(addr->vel2_cmd) = 0;
		*(addr->vel3_cmd) = 0;
		*(addr->vel4_cmd) = 0;
		*(addr->vel5_cmd) = 0;
		*(addr->vel6_cmd) = 0;
		*(addr->vel1_fb) = 0;
		*(addr->vel2_fb) = 0;
		*(addr->vel3_fb) = 0;
		*(addr->vel4_fb) = 0;
		*(addr->vel5_fb) = 0;
		*(addr->vel6_fb) = 0;
		*(addr->Kp1) = 0;
		*(addr->Kp2) = 0;
		*(addr->Kp3) = 0;
		*(addr->Kp4) = 0;
		*(addr->Kp5) = 0;
		*(addr->Kp6) = 0;
		*(addr->Kd1) = 0;
		*(addr->Kd2) = 0;
		*(addr->Kd3) = 0;
		*(addr->Kd4) = 0;
		*(addr->Kd5) = 0;
		*(addr->Kd6) = 0;
		*(addr->acc1) = 0;
		*(addr->acc2) = 0;
		*(addr->acc3) = 0;
		*(addr->acc4) = 0;
		*(addr->acc5) = 0;
		*(addr->acc6) = 0;
	retval = hal_export_funct("cal-PDdyn", rne_export, addr, 1, 0, comp_id);
    if (retval != 0) {
	rtapi_print_msg(RTAPI_MSG_ERR,"PDdyn: ERROR: rne funct export failed\n");
	hal_exit(comp_id);
	return -1;
    }
	return 0;
}	
		
void rtapi_app_exit(void)
{
    hal_exit(comp_id);
}


static void rne_export(void *arg,long period)
{
	float joint[6],dq[6],ddq[6],Kp[6],Kd[6],dq_fb[6],joint_fb[6];
	float timecal;
	clock_t lastime;
	hal_pd_t *PDdyn;
	darray torque;
	PDdyn = arg;
	lastime = clock();
	joint[0] =*(PDdyn->joint1_cmd);
	joint[1]= *(PDdyn->joint2_cmd);
	joint[2] =*(PDdyn->joint3_cmd);
	joint[3]= *(PDdyn->joint4_cmd);
	joint[4] =*(PDdyn->joint5_cmd);
	joint[5]= *(PDdyn->joint6_cmd);
	joint_fb[0] =*(PDdyn->joint1_fb);
	joint_fb[1]= *(PDdyn->joint2_fb);
	joint_fb[2] =*(PDdyn->joint3_fb);
	joint_fb[3]= *(PDdyn->joint4_fb);
	joint_fb[4] =*(PDdyn->joint5_fb);
	joint_fb[5]= *(PDdyn->joint6_fb);
	dq[0] =*(PDdyn->vel1_cmd);
	dq[1]= *(PDdyn->vel2_cmd);
	dq[2] =*(PDdyn->vel3_cmd);
	dq[3]= *(PDdyn->vel4_cmd);
	dq[4] =*(PDdyn->vel5_cmd);
	dq[5]= *(PDdyn->vel6_cmd);
	dq_fb[0] =*(PDdyn->vel1_fb);
	dq_fb[1] =*(PDdyn->vel2_fb);
	dq_fb[2] =*(PDdyn->vel3_fb);
	dq_fb[3] =*(PDdyn->vel4_fb);
	dq_fb[4] =*(PDdyn->vel5_fb);
	dq_fb[5] =*(PDdyn->vel6_fb);
	Kp[0] = *(PDdyn->Kp1);
	Kp[1] = *(PDdyn->Kp2);
	Kp[2] = *(PDdyn->Kp3);
	Kp[3] = *(PDdyn->Kp4);
	Kp[4] = *(PDdyn->Kp5);
	Kp[5] = *(PDdyn->Kp6);
	Kd[0] = *(PDdyn->Kd1);
	Kd[1] = *(PDdyn->Kd2);
	Kd[2] = *(PDdyn->Kd3);
	Kd[3] = *(PDdyn->Kd4);
	Kd[4] = *(PDdyn->Kd5);
	Kd[5] = *(PDdyn->Kd6);
	ddq[0] =*(PDdyn->acc1)+Kd[0]*(dq_fb[0]-dq[0])+Kp[0]*(joint_fb[0]-joint[0]);
	ddq[1]= *(PDdyn->acc2)+Kd[1]*(dq_fb[1]-dq[1])+Kp[1]*(joint_fb[1]-joint[1]);
	ddq[2] =*(PDdyn->acc3)+Kd[2]*(dq_fb[2]-dq[2])+Kp[2]*(joint_fb[2]-joint[2]);
	ddq[3]= *(PDdyn->acc4)+Kd[3]*(dq_fb[3]-dq[3])+Kp[3]*(joint_fb[3]-joint[3]);
	ddq[4] =*(PDdyn->acc5)+Kd[4]*(dq_fb[4]-dq[4])+Kp[4]*(joint_fb[4]-joint[4]);
	ddq[5]= *(PDdyn->acc6)+Kd[5]*(dq_fb[5]-dq[5])+Kp[5]*(joint_fb[5]-joint[5]);
	torque = rne(joint,dq,ddq);	

	*(PDdyn->torq1)= torque.array2d[0][0];
	*(PDdyn->torq2)= torque.array2d[1][0];
	*(PDdyn->torq3)= torque.array2d[2][0];
	*(PDdyn->torq4)= torque.array2d[3][0];
	*(PDdyn->torq5)= torque.array2d[4][0];
	*(PDdyn->torq6)= torque.array2d[5][0];
	*(PDdyn->timecal) = clock()-lastime;
}
static darray cal_gravity(float *joint)
{
darray gravity;
float q1,q2,q3,q4,q5,q6;
float S1,S2,S3,S4,S5,S6,C1,C2,C3,C4,C5,C6;
float C23,S23, S4_6,C4_6,S4_5,C4_5,S45,C45,S46,C46;

//-----------------------------------------------------------------------
q1 = joint[0]*PM_PI/180;
q2 = joint[1]*PM_PI/180;
q3 = joint[2]*PM_PI/180;
q4 = joint[3]*PM_PI/180;
q5 = joint[4]*PM_PI/180;
q6 = joint[5]*PM_PI/180;
S1 = sin(q1);
S2 = sin(q2);
S3 = sin(q3);
S4 = sin(q4);
S5 = sin(q5);
S6 = sin(q6);
C1 = cos(q1);
C2 = cos(q2);
C3 = cos(q3);
C4 = cos(q4);
C5 = cos(q5);
C6 = cos(q6);
C23 = cos(q2 + q3);
S23 = sin(q2 + q3);
S45 = sin(q4 + q5);
C45 = cos(q4 + q5);
S46 = sin(q4 + q6);
C46 = cos(q4 + q6);
S4_5 = sin(q4-q5);
S4_6 = sin(q4-q6);
C4_5 = cos(q4-q5);
C4_6 = cos(q4-q6);


//----------------------------------------------------------------------------
gravity.array2d[0][0] = 0;
 
gravity.array2d[1][0] =(grav*(2*a2*m_2*C2 + 2*a2*m_3*C2 + 2*a2*m_4*C2 + 2*a2*m_5*C2 + 2*a2*m_6*C2 - 2*Y2*m_2*S2 + 2*X3*m_3*C23 + 2*a3*m_3*C23 + 2*a3*m_4*C23 + 2*a3*m_5*C23 + 2*a3*m_6*C23 - 2*Y4*m_4*S23 + 2*Z3*m_3*S23 + 2*d4*m_4*S23 + 2*d4*m_5*S23 + 2*d4*m_6*S23 + 2*X2*m_2*C2 + X5*m_5*C23*C45 + X6*m_6*C23*C46 - Y6*m_6*C23*S46 + Z5*m_5*C23*S45 + Z6*m_6*C23*S45 + d6*m_6*C23*S45 + 2*X4*m_4*C23*C4 - 2*Y5*m_5*C23*S4 - 2*Z4*m_4*C23*S4 + 2*Z5*m_5*S23*C5 + 2*Z6*m_6*S23*C5 + 2*d6*m_6*S23*C5 - 2*X5*m_5*S23*S5 + X5*m_5*C4_5*C23 - X6*m_6*C4_6*C23 - Y6*m_6*S4_6*C23 - Z5*m_5*S4_5*C23 - Z6*m_6*S4_5*C23 - d6*m_6*S4_5*C23 + X6*m_6*C23*C45*C6 - Y6*m_6*C23*C45*S6 - 2*X6*m_6*S23*C6*S5 + X6*m_6*C4_5*C23*C6 + 2*Y6*m_6*S23*S5*S6 - Y6*m_6*C4_5*C23*S6))/2;
 
gravity.array2d[2][0] = X3*grav*m_3*C23 + a3*grav*m_3*C23 + a3*grav*m_4*C23 + a3*grav*m_5*C23 + a3*grav*m_6*C23 - Y4*grav*m_4*S23 + Z3*grav*m_3*S23 + d4*grav*m_4*S23 + d4*grav*m_5*S23 + d4*grav*m_6*S23 + X4*grav*m_4*C23*C4 - Y5*grav*m_5*C23*S4 - Z4*grav*m_4*C23*S4 + Z5*grav*m_5*S23*C5 + Z6*grav*m_6*S23*C5 + d6*grav*m_6*S23*C5 - X5*grav*m_5*S23*S5 + Y6*grav*m_6*S23*S5*S6 + X5*grav*m_5*C23*C4*C5 - Y6*grav*m_6*C23*C6*S4 + Z5*grav*m_5*C23*C4*S5 + Z6*grav*m_6*C23*C4*S5 + d6*grav*m_6*C23*C4*S5 - X6*grav*m_6*C23*S4*S6 - X6*grav*m_6*S23*C6*S5 + X6*grav*m_6*C23*C4*C5*C6 - Y6*grav*m_6*C23*C4*C5*S6;
 
gravity.array2d[3][0] = -grav*S23*(X4*m_4*S4 + Y5*m_5*C4 + Z4*m_4*C4 + Y6*m_6*C4*C6 + X5*m_5*C5*S4 + X6*m_6*C4*S6 + Z5*m_5*S4*S5 + Z6*m_6*S4*S5 + d6*m_6*S4*S5 + X6*m_6*C5*C6*S4 - Y6*m_6*C5*S4*S6);
 
gravity.array2d[4][0] = grav*m_5*(X5*C23*C5 + Z5*C23*S5 + Z5*S23*C4*C5 - X5*S23*C4*S5) + grav*m_6*(Z6*C23*S5 + d6*C23*S5 + X6*C23*C5*C6 - Y6*C23*C5*S6 + Z6*S23*C4*C5 + d6*S23*C4*C5 + Y6*S23*C4*S5*S6 - X6*S23*C4*C6*S5);
 
gravity.array2d[5][0] = -grav*m_6*(Y6*(C23*C6*S5 - S23*S4*S6 + S23*C4*C5*C6) + X6*(S23*C6*S4 + C23*S5*S6 + S23*C4*C5*S6));


return(gravity);
} 

//--------------------------------------------------------------------------------
static darray rne(float *joint, float *dq, float *ddq)
{	
	int i,k;
// tinh toan cac tham so cua phuong trinh rne
	darray torque;
	darray masseffect;
	darray gravity = cal_gravity(joint);
	darray coriolis = cal_coriolis(joint,dq);
	darray inertiamatrix = cal_inertia(joint);
	for (i = 0; i<6; i++)
	{
		masseffect.array2d[i][0] = 0;
		for (k=0;k<6;k++)
		{
		masseffect.array2d[i][0] += inertiamatrix.array2d[i][k]*ddq[k];
		}
	}
// tinh torque
	for (i = 0; i<6; i++)
	{
		torque.array2d[i][0] = masseffect.array2d[i][0]+gravity.array2d[i][0]+coriolis.array2d[i][0];
	}
	
	return torque;
}	

//--------------------------------------------------------------------------------
static darray cal_inertia(float *joint)
{
darray inertiamatrix; 
//int 	row,column;
float S1,S2,S3,S4,S5,S6,C1,C2,C3,C4,C5,C6;
float C23,S23,S22,C22,S34,C34,S3_4,C3_4,S44,C44,S55,S66;
float S223,C223,S234,C234,C23_4,S23_4;
float S2233,C2233,S223_4,C223_4,S2234,C2234;
float S22334,C22334,S2233_4,C2233_4;
float S223344,C223344,S2233_44,C2233_44;
float t1,t2,t3,t4;
float q1,q2,q3,q4,q5,q6;
float XX2,XX3,XX4,XX5,XX6,YY2,YY3,YY4,YY5,YY6,ZZ1,ZZ2,ZZ3,ZZ4,ZZ5,ZZ6;
float CC4,CC5,CC6,aa1,aa2,aa3,dd4,dd6;


//-------------------------------------------------------------------------

q1 = joint[0]*PM_PI/180;
q2 = joint[1]*PM_PI/180;
q3 = joint[2]*PM_PI/180;
q4 = joint[3]*PM_PI/180;
q5 = joint[4]*PM_PI/180;
q6 = joint[5]*PM_PI/180;
S1 = sin(q1);
S2 = sin(q2);
S3 = sin(q3);
S4 = sin(q4);
S5 = sin(q5);
S6 = sin(q6);
C1 = cos(q1);
C2 = cos(q2);
C3 = cos(q3);
C4 = cos(q4);
C5 = cos(q5);
C6 = cos(q6);
C23 = cos(q2 + q3);
S23 = sin(q2 + q3);
S22 = sin(2*q2);
C22 = cos(2*q2);
S34 = sin(q3+q4);
C34 = cos(q3+q4);
S3_4 = sin(q3 - q4);
C3_4 = cos(q3 - q4);
S44 = sin(2*q4);
C44 = cos(2*q4);
S55 = sin(2*q5);
S66 = sin(2*q6);

S223 = sin(2*q2+q3);
C223 = cos(2*q2+q3);
C234 = cos(q2+q3+q4);
S234 = sin(q2+q3+q4);
C23_4= cos(q2+q3-q4);
S23_4 = sin(q2+q3-q4);
S2234= sin(2*q2+q3+q4);
C2234= cos(2*q2+q3+q4);

S2233 = sin(2*q2+2*q3);
C2233 = cos(2*q2+2*q3);
S223_4 = sin(2*q2+q3-q4);
C223_4 = cos(2*q2+q3-q4);
S22334 = sin(2*q2+2*q3+q4);
C22334 = cos(2*q2+2*q3+q4);

S2233_4 = sin(2*q2+2*q3-q4);
C2233_4 = cos(2*q2+2*q3-q4);
S223344= sin(2*q2+2*q3+2*q4);
C223344= cos(2*q2+2*q3+2*q4);
S2233_44 = sin(2*q2+2*q3-2*q4);
C2233_44 = cos(2*q2+2*q3-2*q4);
//----------------------------------------------------------------------
XX2 = X2*X2;
XX3 = X3*X3;
XX4 = X4*X4;
XX5 = X5*X5;
XX6 = X6*X6;
YY2 = Y2*Y2;
YY3 = Y3*Y3;
YY4 = Y4*Y4;
YY5 = Y5*Y5;
YY6 = Y6*Y6;
ZZ1 = Z1*Z1;
ZZ2 = Z2*Z2;
ZZ3 = Z3*Z3;
ZZ4 = Z4*Z4;
ZZ5 = Z5*Z5;
ZZ6 = Z6*Z6;

aa1 = a1*a1;
aa2 = a2*a2;
aa3 = a3*a3;
dd4 = d4*d4;
dd6 = d6*d6; 

CC4 = C4*C4;
CC5 = C5*C5;
CC6 = C6*C6;

//----------------------------------------------------------------------------------
t1 = a1*C1 + d4*S23*C1 + a2*C1*C2 + Y5*C4*S1 + Z5*S23*C1*C5 - X5*S23*C1*S5 + a3*C1*C2*C3 + X5*C5*S1*S4 - a3*C1*S2*S3 + Z5*S1*S4*S5 - Y5*C1*C2*C3*S4 + Y5*C1*S2*S3*S4 - Z5*C1*C4*S2*S3*S5 + X5*C1*C2*C3*C4*C5 + Z5*C1*C2*C3*C4*S5 - X5*C1*C4*C5*S2*S3;
t2 = a1*S1 + d4*S23*S1 - Y5*C1*C4 + a2*C2*S1 + Z5*S23*C5*S1 - X5*S23*S1*S5 - X5*C1*C5*S4 + a3*C2*C3*S1 - Z5*C1*S4*S5 - a3*S1*S2*S3 - Y5*C2*C3*S1*S4 + Y5*S1*S2*S3*S4 - X5*C4*C5*S1*S2*S3 - Z5*C4*S1*S2*S3*S5 + X5*C2*C3*C4*C5*S1 + Z5*C2*C3*C4*S1*S5;
t3 = a1*S1 + d4*S23*S1 + a2*C2*S1 + Z6*S23*C5*S1 + d6*S23*C5*S1 - Y6*C1*C4*C6 - X6*C1*C4*S6 + a3*C2*C3*S1 - Z6*C1*S4*S5 - d6*C1*S4*S5 - a3*S1*S2*S3 - X6*S23*C6*S1*S5 - X6*C1*C5*C6*S4 + Y6*S23*S1*S5*S6 + Y6*C1*C5*S4*S6 + d6*C2*C3*C4*S1*S5 - X6*C2*C3*S1*S4*S6 + Y6*C6*S1*S2*S3*S4 - Z6*C4*S1*S2*S3*S5 - d6*C4*S1*S2*S3*S5 + X6*S1*S2*S3*S4*S6 - Y6*C2*C3*C6*S1*S4 + Z6*C2*C3*C4*S1*S5 + X6*C2*C3*C4*C5*C6*S1 - Y6*C2*C3*C4*C5*S1*S6 - X6*C4*C5*C6*S1*S2*S3 + Y6*C4*C5*S1*S2*S3*S6;
t4 = a1*C1 + d4*S23*C1 + a2*C1*C2 + Z6*S23*C1*C5 + d6*S23*C1*C5 + a3*C1*C2*C3 + Y6*C4*C6*S1 + X6*C4*S1*S6 - a3*C1*S2*S3 + Z6*S1*S4*S5 + d6*S1*S4*S5 + Y6*S23*C1*S5*S6 + X6*C5*C6*S1*S4 - Y6*C5*S1*S4*S6 - X6*S23*C1*C6*S5 + Y6*C1*C6*S2*S3*S4 - Z6*C1*C4*S2*S3*S5 - d6*C1*C4*S2*S3*S5 + X6*C1*S2*S3*S4*S6 - Y6*C1*C2*C3*C6*S4 + Z6*C1*C2*C3*C4*S5 + d6*C1*C2*C3*C4*S5 - X6*C1*C2*C3*S4*S6 + X6*C1*C2*C3*C4*C5*C6 - Y6*C1*C2*C3*C4*C5*S6 - X6*C1*C4*C5*C6*S2*S3 + Y6*C1*C4*C5*S2*S3*S6;

//=======================================================================================================================================================================================================
inertiamatrix.array2d[0][0]=Ixx2/2 + Ixx3/2 + Ixx4/4 + Iyy1 + Iyy2/2 + Iyy4/2 + Izz3/2 + Izz4/4 + m_5*t1*t1 - (Ixx3*C2233)/2 - (Ixx4*C2233)/4 + (Iyy4*C2233)/2 + (Izz3*C2233)/2 - (Izz4*C2233)/4 - Ixz3*S2233 + (C23*C5 - S23*C4*S5)*(Izz6*C23*C5 - Ixz6*C23*C6*S5 + Iyz6*S23*C6*S4 + Iyz6*C23*S5*S6 - Izz6*S23*C4*S5 + Ixz6*S23*S4*S6 - Ixz6*S23*C4*C5*C6 + Iyz6*S23*C4*C5*S6) + (C23*S5 + S23*C4*C5)*(Ixx5*C23*S5 - Ixz5*C23*C5 - Ixy5*S23*S4 + Ixx5*S23*C4*C5 + Ixz5*S23*C4*S5) - (C23*C5 - S23*C4*S5)*(Ixz5*C23*S5 - Izz5*C23*C5 - Iyz5*S23*S4 + Ixz5*S23*C4*C5 + Izz5*S23*C4*S5) + (Iyz4*C22334)/2 + X1*X1*m_1 + (XX2*m_2)/2 + (XX3*m_3)/2 + (3*XX4*m_4)/4 + (YY2*m_2)/2 + YY3*m_3 + (YY4*m_4)/2 + ZZ1*m_1 + ZZ2*m_2 + (ZZ3*m_3)/2 + (3*ZZ4*m_4)/4 + aa1*m_1 + aa1*m_2 + aa1*m_3 + (aa2*m_2)/2 + aa1*m_4 + (aa2*m_3)/2 + (aa2*m_4)/2 + (aa3*m_3)/2 + (aa3*m_4)/2 + (Ixy4*S22334)/2 + (dd4*m_4)/2 - (C23*C6*S5 - S23*S4*S6 + S23*C4*C5*C6)*(Ixz6*C23*C5 - Ixx6*C23*C6*S5 + Ixy6*S23*C6*S4 + Ixy6*C23*S5*S6 - Ixz6*S23*C4*S5 + Ixx6*S23*S4*S6 - Ixx6*S23*C4*C5*C6 + Ixy6*S23*C4*C5*S6) + m_5*t2*t2 + (S23*C6*S4 + C23*S5*S6 + S23*C4*C5*S6)*(Iyz6*C23*C5 - Ixy6*C23*C6*S5 + Iyy6*S23*C6*S4 + Iyy6*C23*S5*S6 - Iyz6*S23*C4*S5 + Ixy6*S23*S4*S6 - Ixy6*S23*C4*C5*C6 + Iyy6*S23*C4*C5*S6) + m_6*t3*t3 + m_6*t4*t4 - (Ixx2*C22)/2 + (Ixx4*C44)/4 + (Iyy2*C22)/2 - (Izz4*C44)/4 - (Ixx4*C2233_44)/8 - (Ixx4*C223344)/8 - (Iyz4*C2233_4)/2 + (Izz4*C2233_44)/8 + (Izz4*C223344)/8 + Ixy2*S22 - (Ixz4*S44)/2 + (Ixy4*S2233_4)/2 - (Ixz4*S2233_44)/4 + (Ixz4*S223344)/4 - S23*S4*(Ixy5*C23*S5 - Iyz5*C23*C5 - Iyy5*S23*S4 + Ixy5*S23*C4*C5 + Iyz5*S23*C4*S5) + 2*X1*a1*m_1 + X2*a2*m_2 + X3*a3*m_3 - Y4*d4*m_4 + (XX2*m_2*C22)/2 - (XX4*m_4*C44)/4 + (XX4*m_4*C2233_44)/8 + (XX4*m_4*C223344)/8 - (YY2*m_2*C22)/2 + (ZZ4*m_4*C44)/4 - (ZZ4*m_4*C2233_44)/8 - (ZZ4*m_4*C223344)/8 + (aa2*m_2*C22)/2 + (aa2*m_3*C22)/2 + (aa2*m_4*C22)/2 + (XX3*m_3*C2233)/2 + (XX4*m_4*C2233)/4 - (YY4*m_4*C2233)/2 - (ZZ3*m_3*C2233)/2 + (ZZ4*m_4*C2233)/4 + (aa3*m_3*C2233)/2 + (aa3*m_4*C2233)/2 - (dd4*m_4*C2233)/2 + a3*d4*m_4*S2233 + Z4*a1*m_4*S23_4 - (Z4*a2*m_4*S2234)/2 + 2*X3*a1*m_3*C23 + (X4*a2*m_4*C34)/2 + 2*a1*a3*m_3*C23 + 2*a1*a3*m_4*C23 - 2*Y4*a1*m_4*S23 + 2*Z3*a1*m_3*S23 - (Z4*a2*m_4*S34)/2 + 2*a1*d4*m_4*S23 - (Y4*Z4*m_4*C22334)/2 + 2*X2*a1*m_2*C2 + X3*a2*m_3*C3 + X4*a3*m_4*C4 + (X4*a2*m_4*C223_4)/2 + (X4*a3*m_4*C22334)/2 + (Z4*d4*m_4*C22334)/2 - (X4*Y4*m_4*S22334)/2 + 2*a1*a2*m_2*C2 + 2*a1*a2*m_3*C2 + 2*a1*a2*m_4*C2 + a2*a3*m_3*C3 + a2*a3*m_4*C3 - 2*Y2*a1*m_2*S2 - Y4*a2*m_4*S3 + Z3*a2*m_3*S3 - Z4*a3*m_4*S4 + (Z4*a2*m_4*S223_4)/2 - (Z4*a3*m_4*S22334)/2 + (X4*d4*m_4*S22334)/2 + a2*d4*m_4*S3 + X3*a2*m_3*C223 + (X4*a2*m_4*C3_4)/2 + a2*a3*m_3*C223 + a2*a3*m_4*C223 - Y4*a2*m_4*S223 + X4*a1*m_4*C234 + Z3*a2*m_3*S223 + (Z4*a2*m_4*S3_4)/2 + a2*d4*m_4*S223 - Z4*a1*m_4*S234 + (Y4*Z4*m_4*C2233_4)/2 + X2*a2*m_2*C22 + (X4*a3*m_4*C2233_4)/2 - (Z4*d4*m_4*C2233_4)/2 - X2*Y2*m_2*S22 - (X4*Y4*m_4*S2233_4)/2 + (X4*Z4*m_4*S44)/2 + (X4*Z4*m_4*S2233_44)/4 - (X4*Z4*m_4*S223344)/4 - Y2*a2*m_2*S22 + (Z4*a3*m_4*S2233_4)/2 + (X4*d4*m_4*S2233_4)/2 + X3*a3*m_3*C2233 + Y4*d4*m_4*C2233 + X3*Z3*m_3*S2233 - Y4*a3*m_4*S2233 + X4*a1*m_4*C23_4 + (X4*a2*m_4*C2234)/2 + Z3*a3*m_3*S2233;
 
inertiamatrix.array2d[0][1] = Iyz2*C2 + Ixz2*S2 - Iyz3*C2*C3 + Ixy3*C2*S3 + Ixy3*C3*S2 - Ixz4*C2*S3 - Ixz4*C3*S2 + Iyz3*S2*S3 + Iyz4*C2*C3*C4 + Ixy4*C2*C3*S4 - Ixy5*C2*C5*S3 - Ixy5*C3*C5*S2 + Ixy6*C2*C5*S3 + Ixy6*C3*C5*S2 + Ixz5*C2*C3*S4 - Iyz4*C4*S2*S3 - Iyz5*C2*S3*S5 - Iyz5*C3*S2*S5 - Y2*Z2*m_2*C2 - Ixy4*S2*S3*S4 - Ixz5*S2*S3*S4 - X2*Z2*m_2*S2 - Y3*a2*m_3*S2 - Z2*a2*m_2*S2 + 2*Ixz4*C2*CC4*S3 + 2*Ixz4*C3*CC4*S2 + Ixy5*C2*C3*C4*S5 - Ixy6*C2*C3*C4*S5 + Ixz6*C2*C3*C6*S4 + Ixx4*C2*C4*S3*S4 + Ixx4*C3*C4*S2*S4 - Ixx6*C2*C4*S3*S4 - Ixx6*C3*C4*S2*S4 - Iyy5*C2*C4*S3*S4 - Iyy5*C3*C4*S2*S4 + Iyz5*C4*C5*S2*S3 - Iyz6*C2*C3*S4*S6 - Iyz6*C2*C6*S3*S5 - Iyz6*C3*C6*S2*S5 - Izz4*C2*C4*S3*S4 - Izz4*C3*C4*S2*S4 + Izz5*C2*C4*S3*S4 + Izz5*C3*C4*S2*S4 + Izz6*C2*C4*S3*S4 + Izz6*C3*C4*S2*S4 + Y3*Z3*m_3*C2*C3 - Ixy5*C4*S2*S3*S5 + Ixy6*C4*S2*S3*S5 - Ixz6*C6*S2*S3*S4 - Ixz6*C2*S3*S5*S6 - Ixz6*C3*S2*S5*S6 - X3*Y3*m_3*C2*S3 - X3*Y3*m_3*C3*S2 + X4*Z4*m_4*C2*S3 + X4*Z4*m_4*C3*S2 + Iyz6*S2*S3*S4*S6 - Y3*a3*m_3*C2*S3 - Y3*a3*m_3*C3*S2 - Y5*a2*m_5*C4*S2 - Z4*a2*m_4*C4*S2 - Y3*Z3*m_3*S2*S3 - X4*a2*m_4*S2*S4 + 2*Ixy5*C2*CC4*C5*S3 + 2*Ixy5*C3*CC4*C5*S2 - 2*Ixy6*C2*CC4*C5*S3 - 2*Ixy6*C3*CC4*C5*S2 - 2*Ixy6*C2*C5*CC6*S3 - 2*Ixy6*C3*C5*CC6*S2 - 2*Ixz5*C2*C3*CC5*S4 + 2*Iyz5*C2*CC4*S3*S5 + 2*Iyz5*C3*CC4*S2*S5 + 2*Ixz5*CC5*S2*S3*S4 - Iyz5*C2*C3*C4*C5 - dd6*m_6*C2*C4*S3*S4 - dd6*m_6*C3*C4*S2*S4 + Y5*d4*m_5*C2*C3*C4 + Z4*d4*m_4*C2*C3*C4 - X4*Y4*m_4*C2*C3*S4 + X5*Y5*m_5*C2*C5*S3 + X5*Y5*m_5*C3*C5*S2 - X6*Y6*m_6*C2*C5*S3 - X6*Y6*m_6*C3*C5*S2 - X5*Z5*m_5*C2*C3*S4 - Ixx5*C5*S2*S3*S4*S5 - Iyy6*C5*S2*S3*S4*S5 + Izz5*C5*S2*S3*S4*S5 + Izz6*C5*S2*S3*S4*S5 - Y5*a3*m_5*C2*C4*S3 - Y5*a3*m_5*C3*C4*S2 - Y6*a2*m_6*C4*C6*S2 - Z4*a3*m_4*C2*C4*S3 - Z4*a3*m_4*C3*C4*S2 + X4*d4*m_4*C2*C3*S4 + Y4*Z4*m_4*C4*S2*S3 + Y5*Z5*m_5*C2*S3*S5 + Y5*Z5*m_5*C3*S2*S5 - X4*a3*m_4*C2*S3*S4 - X4*a3*m_4*C3*S2*S4 - X5*a2*m_5*C5*S2*S4 - X6*a2*m_6*C4*S2*S6 - Y5*d4*m_5*C4*S2*S3 - Z4*d4*m_4*C4*S2*S3 + X4*Y4*m_4*S2*S3*S4 + X5*Z5*m_5*S2*S3*S4 - Z5*a2*m_5*S2*S4*S5 - Z6*a2*m_6*S2*S4*S5 - X4*d4*m_4*S2*S3*S4 + 2*Ixy6*C2*C3*C4*CC6*S5 - 2*Ixz6*C2*C3*CC5*C6*S4 - a2*d6*m_6*S2*S4*S5 + Ixx5*C2*C4*CC5*S3*S4 + Ixx5*C3*C4*CC5*S2*S4 + Ixx6*C2*C4*CC6*S3*S4 + Ixx6*C3*C4*CC6*S2*S4 + Iyy6*C2*C4*CC5*S3*S4 + Iyy6*C3*C4*CC5*S2*S4 - Iyy6*C2*C4*CC6*S3*S4 - Iyy6*C3*C4*CC6*S2*S4 + 2*Iyz6*C2*C3*CC5*S4*S6 + 2*Iyz6*C2*CC4*C6*S3*S5 + 2*Iyz6*C3*CC4*C6*S2*S5 - Izz5*C2*C4*CC5*S3*S4 - Izz5*C3*C4*CC5*S2*S4 - Izz6*C2*C4*CC5*S3*S4 - Izz6*C3*C4*CC5*S2*S4 - 2*Ixy6*C4*CC6*S2*S3*S5 + 2*Ixz6*C2*CC4*S3*S5*S6 + 2*Ixz6*C3*CC4*S2*S5*S6 + 2*Ixz6*CC5*C6*S2*S3*S4 - 2*X4*Z4*m_4*C2*CC4*S3 - 2*X4*Z4*m_4*C3*CC4*S2 - 2*Iyz6*CC5*S2*S3*S4*S6 + 4*Ixy6*C2*CC4*C5*CC6*S3 + 4*Ixy6*C3*CC4*C5*CC6*S2 - Iyz6*C2*C3*C4*C5*C6 - Ixz6*C2*C3*C4*C5*S6 + Ixx5*C2*C3*C5*S4*S5 - Ixx6*C2*C5*C6*S3*S6 - Ixx6*C3*C5*C6*S2*S6 + Iyy6*C2*C3*C5*S4*S5 + Iyy6*C2*C5*C6*S3*S6 + Iyy6*C3*C5*C6*S2*S6 + Iyz6*C4*C5*C6*S2*S3 - Izz5*C2*C3*C5*S4*S5 - Izz6*C2*C3*C5*S4*S5 - XX4*m_4*C2*C4*S3*S4 - XX4*m_4*C3*C4*S2*S4 + XX6*m_6*C2*C4*S3*S4 + XX6*m_6*C3*C4*S2*S4 + YY5*m_5*C2*C4*S3*S4 + YY5*m_5*C3*C4*S2*S4 + ZZ4*m_4*C2*C4*S3*S4 + ZZ4*m_4*C3*C4*S2*S4 - ZZ5*m_5*C2*C4*S3*S4 - ZZ5*m_5*C3*C4*S2*S4 - ZZ6*m_6*C2*C4*S3*S4 - ZZ6*m_6*C3*C4*S2*S4 - Y4*Z4*m_4*C2*C3*C4 + Ixz6*C4*C5*S2*S3*S6 + X6*Z6*m_6*C6*S2*S3*S4 + X6*Z6*m_6*C2*S3*S5*S6 + X6*Z6*m_6*C3*S2*S5*S6 + d4*d6*m_6*C2*C3*S4*S5 + Y6*a2*m_6*C5*S2*S4*S6 - Z5*a3*m_5*C2*S3*S4*S5 - Z5*a3*m_5*C3*S2*S4*S5 - Z6*a3*m_6*C2*S3*S4*S5 - Z6*a3*m_6*C3*S2*S4*S5 - X5*d4*m_5*C5*S2*S3*S4 - X6*d4*m_6*C4*S2*S3*S6 + X6*d6*m_6*C6*S2*S3*S4 + X6*d6*m_6*C2*S3*S5*S6 + X6*d6*m_6*C3*S2*S5*S6 - Y6*Z6*m_6*S2*S3*S4*S6 - a3*d6*m_6*C2*S3*S4*S5 - a3*d6*m_6*C3*S2*S4*S5 - Y6*d6*m_6*S2*S3*S4*S6 - Z5*d4*m_5*S2*S3*S4*S5 - Z6*d4*m_6*S2*S3*S4*S5 + Ixx6*C2*C3*C5*CC6*S4*S5 + 2*Ixx6*C2*CC4*C5*C6*S3*S6 + 2*Ixx6*C3*CC4*C5*C6*S2*S6 - Iyy6*C2*C3*C5*CC6*S4*S5 - 2*Iyy6*C2*CC4*C5*C6*S3*S6 - 2*Iyy6*C3*CC4*C5*C6*S2*S6 - d4*d6*m_6*S2*S3*S4*S5 - XX5*m_5*C2*C4*CC5*S3*S4 - XX5*m_5*C3*C4*CC5*S2*S4 - XX6*m_6*C2*C4*CC6*S3*S4 - XX6*m_6*C3*C4*CC6*S2*S4 - YY6*m_6*C2*C4*CC5*S3*S4 - YY6*m_6*C3*C4*CC5*S2*S4 + YY6*m_6*C2*C4*CC6*S3*S4 + YY6*m_6*C3*C4*CC6*S2*S4 + ZZ5*m_5*C2*C4*CC5*S3*S4 + ZZ5*m_5*C3*C4*CC5*S2*S4 + ZZ6*m_6*C2*C4*CC5*S3*S4 + ZZ6*m_6*C3*C4*CC5*S2*S4 + dd6*m_6*C2*C4*CC5*S3*S4 + dd6*m_6*C3*C4*CC5*S2*S4 - 2*X5*Y5*m_5*C2*CC4*C5*S3 - 2*X5*Y5*m_5*C3*CC4*C5*S2 + 2*X6*Y6*m_6*C2*CC4*C5*S3 + 2*X6*Y6*m_6*C3*CC4*C5*S2 + 2*X6*Y6*m_6*C2*C5*CC6*S3 + 2*X6*Y6*m_6*C3*C5*CC6*S2 + 2*X5*Z5*m_5*C2*C3*CC5*S4 - Ixx6*C5*CC6*S2*S3*S4*S5 + Iyy6*C5*CC6*S2*S3*S4*S5 - 2*Y5*Z5*m_5*C2*CC4*S3*S5 - 2*Y5*Z5*m_5*C3*CC4*S2*S5 - 2*X5*Z5*m_5*CC5*S2*S3*S4 + Ixx6*C2*C4*CC5*CC6*S3*S4 + Ixx6*C3*C4*CC5*CC6*S2*S4 - Iyy6*C2*C4*CC5*CC6*S3*S4 - Iyy6*C3*C4*CC5*CC6*S2*S4 + Ixx6*C2*C3*C4*C6*S5*S6 - Iyy6*C2*C3*C4*C6*S5*S6 - XX5*m_5*C2*C3*C5*S4*S5 + XX6*m_6*C2*C5*C6*S3*S6 + XX6*m_6*C3*C5*C6*S2*S6 - YY6*m_6*C2*C3*C5*S4*S5 - YY6*m_6*C2*C5*C6*S3*S6 - YY6*m_6*C3*C5*C6*S2*S6 + ZZ5*m_5*C2*C3*C5*S4*S5 + ZZ6*m_6*C2*C3*C5*S4*S5 + Y5*Z5*m_5*C2*C3*C4*C5 - 2*Ixy6*C2*C4*C6*S3*S4*S6 - 2*Ixy6*C3*C4*C6*S2*S4*S6 + 2*Ixz5*C2*C4*C5*S3*S4*S5 + 2*Ixz5*C3*C4*C5*S2*S4*S5 + dd6*m_6*C2*C3*C5*S4*S5 + Y6*d4*m_6*C2*C3*C4*C6 - X5*Y5*m_5*C2*C3*C4*S5 + X6*Y6*m_6*C2*C3*C4*S5 - X6*Z6*m_6*C2*C3*C6*S4 - Ixx6*C4*C6*S2*S3*S5*S6 + Iyy6*C4*C6*S2*S3*S5*S6 - Y6*a3*m_6*C2*C4*C6*S3 - Y6*a3*m_6*C3*C4*C6*S2 + XX5*m_5*C5*S2*S3*S4*S5 + X5*d4*m_5*C2*C3*C5*S4 + X6*d4*m_6*C2*C3*C4*S6 - X6*d6*m_6*C2*C3*C6*S4 + YY6*m_6*C5*S2*S3*S4*S5 - ZZ5*m_5*C5*S2*S3*S4*S5 - ZZ6*m_6*C5*S2*S3*S4*S5 - Y5*Z5*m_5*C4*C5*S2*S3 + Y6*Z6*m_6*C2*C3*S4*S6 + Y6*Z6*m_6*C2*C6*S3*S5 + Y6*Z6*m_6*C3*C6*S2*S5 - dd6*m_6*C5*S2*S3*S4*S5 - X5*a3*m_5*C2*C5*S3*S4 - X5*a3*m_5*C3*C5*S2*S4 - X6*a3*m_6*C2*C4*S3*S6 - X6*a3*m_6*C3*C4*S2*S6 - X6*a2*m_6*C5*C6*S2*S4 - Y6*d4*m_6*C4*C6*S2*S3 + Y6*d6*m_6*C2*C3*S4*S6 + Y6*d6*m_6*C2*C6*S3*S5 + Y6*d6*m_6*C3*C6*S2*S5 + Z5*d4*m_5*C2*C3*S4*S5 + Z6*d4*m_6*C2*C3*S4*S5 - 2*Z6*d6*m_6*C2*C4*S3*S4 - 2*Z6*d6*m_6*C3*C4*S2*S4 + X5*Y5*m_5*C4*S2*S3*S5 - X6*Y6*m_6*C4*S2*S3*S5 - 2*Ixy6*C2*C4*CC5*C6*S3*S4*S6 - 2*Ixy6*C3*C4*CC5*C6*S2*S4*S6 - 2*X6*Y6*m_6*C2*C3*C4*CC6*S5 + 2*X6*Z6*m_6*C2*C3*CC5*C6*S4 + XX6*m_6*C5*CC6*S2*S3*S4*S5 + 2*X6*d6*m_6*C2*C3*CC5*C6*S4 - YY6*m_6*C5*CC6*S2*S3*S4*S5 - 2*Y6*Z6*m_6*C2*C3*CC5*S4*S6 - 2*Y6*Z6*m_6*C2*CC4*C6*S3*S5 - 2*Y6*Z6*m_6*C3*CC4*C6*S2*S5 - 2*Y6*d6*m_6*C2*C3*CC5*S4*S6 - 2*Y6*d6*m_6*C2*CC4*C6*S3*S5 - 2*Y6*d6*m_6*C3*CC4*C6*S2*S5 + 2*Z6*d6*m_6*C2*C4*CC5*S3*S4 + 2*Z6*d6*m_6*C3*C4*CC5*S2*S4 + 2*X6*Y6*m_6*C4*CC6*S2*S3*S5 - 2*X6*Z6*m_6*C2*CC4*S3*S5*S6 - 2*X6*Z6*m_6*C3*CC4*S2*S5*S6 - 2*X6*Z6*m_6*CC5*C6*S2*S3*S4 - 2*X6*d6*m_6*C2*CC4*S3*S5*S6 - 2*X6*d6*m_6*C3*CC4*S2*S5*S6 - 2*X6*d6*m_6*CC5*C6*S2*S3*S4 + 2*Y6*Z6*m_6*CC5*S2*S3*S4*S6 + 2*Y6*d6*m_6*CC5*S2*S3*S4*S6 - XX6*m_6*C2*C4*CC5*CC6*S3*S4 - XX6*m_6*C3*C4*CC5*CC6*S2*S4 + YY6*m_6*C2*C4*CC5*CC6*S3*S4 + YY6*m_6*C3*C4*CC5*CC6*S2*S4 - 4*X6*Y6*m_6*C2*CC4*C5*CC6*S3 - 4*X6*Y6*m_6*C3*CC4*C5*CC6*S2 - XX6*m_6*C2*C3*C4*C6*S5*S6 + YY6*m_6*C2*C3*C4*C6*S5*S6 + Y6*Z6*m_6*C2*C3*C4*C5*C6 - 2*Ixy6*C2*C3*C5*C6*S4*S5*S6 + 2*Ixz6*C2*C4*C5*C6*S3*S4*S5 + 2*Ixz6*C3*C4*C5*C6*S2*S4*S5 + Y6*d6*m_6*C2*C3*C4*C5*C6 + X6*Z6*m_6*C2*C3*C4*C5*S6 - 2*Iyz6*C2*C4*C5*S3*S4*S5*S6 - 2*Iyz6*C3*C4*C5*S2*S4*S5*S6 + XX6*m_6*C4*C6*S2*S3*S5*S6 + X6*d4*m_6*C2*C3*C5*C6*S4 + X6*d6*m_6*C2*C3*C4*C5*S6 - YY6*m_6*C4*C6*S2*S3*S5*S6 - Y6*Z6*m_6*C4*C5*C6*S2*S3 + 2*Ixy6*C5*C6*S2*S3*S4*S5*S6 - X6*a3*m_6*C2*C5*C6*S3*S4 - X6*a3*m_6*C3*C5*C6*S2*S4 - Y6*d4*m_6*C2*C3*C5*S4*S6 - Y6*d6*m_6*C4*C5*C6*S2*S3 + 2*Z6*d6*m_6*C2*C3*C5*S4*S5 - X6*Z6*m_6*C4*C5*S2*S3*S6 + Y6*a3*m_6*C2*C5*S3*S4*S6 + Y6*a3*m_6*C3*C5*S2*S4*S6 - X6*d4*m_6*C5*C6*S2*S3*S4 - X6*d6*m_6*C4*C5*S2*S3*S6 + Y6*d4*m_6*C5*S2*S3*S4*S6 - 2*Z6*d6*m_6*C5*S2*S3*S4*S5 - XX6*m_6*C2*C3*C5*CC6*S4*S5 - 2*XX6*m_6*C2*CC4*C5*C6*S3*S6 - 2*XX6*m_6*C3*CC4*C5*C6*S2*S6 + YY6*m_6*C2*C3*C5*CC6*S4*S5 + 2*YY6*m_6*C2*CC4*C5*C6*S3*S6 + 2*YY6*m_6*C3*CC4*C5*C6*S2*S6 + 2*X6*Y6*m_6*C2*C4*C6*S3*S4*S6 + 2*X6*Y6*m_6*C3*C4*C6*S2*S4*S6 - 2*X5*Z5*m_5*C2*C4*C5*S3*S4*S5 - 2*X5*Z5*m_5*C3*C4*C5*S2*S4*S5 + 2*X6*Y6*m_6*C2*C3*C5*C6*S4*S5*S6 - 2*X6*Z6*m_6*C2*C4*C5*C6*S3*S4*S5 - 2*X6*Z6*m_6*C3*C4*C5*C6*S2*S4*S5 - 2*X6*d6*m_6*C2*C4*C5*C6*S3*S4*S5 - 2*X6*d6*m_6*C3*C4*C5*C6*S2*S4*S5 + 2*Y6*Z6*m_6*C2*C4*C5*S3*S4*S5*S6 + 2*Y6*Z6*m_6*C3*C4*C5*S2*S4*S5*S6 + 2*Y6*d6*m_6*C2*C4*C5*S3*S4*S5*S6 + 2*Y6*d6*m_6*C3*C4*C5*S2*S4*S5*S6 - 2*X6*Y6*m_6*C5*C6*S2*S3*S4*S5*S6 + 2*X6*Y6*m_6*C2*C4*CC5*C6*S3*S4*S6 + 2*X6*Y6*m_6*C3*C4*CC5*C6*S2*S4*S6;
inertiamatrix.array2d[0][2] = Ixy3*C2*S3 - Iyz3*C2*C3 + Ixy3*C3*S2 - Ixz4*C2*S3 - Ixz4*C3*S2 + Iyz3*S2*S3 + Iyz4*C2*C3*C4 + Ixy4*C2*C3*S4 - Ixy5*C2*C5*S3 - Ixy5*C3*C5*S2 + Ixy6*C2*C5*S3 + Ixy6*C3*C5*S2 + Ixz5*C2*C3*S4 - Iyz4*C4*S2*S3 - Iyz5*C2*S3*S5 - Iyz5*C3*S2*S5 - Ixy4*S2*S3*S4 - Ixz5*S2*S3*S4 + 2*Ixz4*C2*CC4*S3 + 2*Ixz4*C3*CC4*S2 + Ixy5*C2*C3*C4*S5 - Ixy6*C2*C3*C4*S5 + Ixz6*C2*C3*C6*S4 + Ixx4*C2*C4*S3*S4 + Ixx4*C3*C4*S2*S4 - Ixx6*C2*C4*S3*S4 - Ixx6*C3*C4*S2*S4 - Iyy5*C2*C4*S3*S4 - Iyy5*C3*C4*S2*S4 + Iyz5*C4*C5*S2*S3 - Iyz6*C2*C3*S4*S6 - Iyz6*C2*C6*S3*S5 - Iyz6*C3*C6*S2*S5 - Izz4*C2*C4*S3*S4 - Izz4*C3*C4*S2*S4 + Izz5*C2*C4*S3*S4 + Izz5*C3*C4*S2*S4 + Izz6*C2*C4*S3*S4 + Izz6*C3*C4*S2*S4 + Y3*Z3*m_3*C2*C3 - Ixy5*C4*S2*S3*S5 + Ixy6*C4*S2*S3*S5 - Ixz6*C6*S2*S3*S4 - Ixz6*C2*S3*S5*S6 - Ixz6*C3*S2*S5*S6 - X3*Y3*m_3*C2*S3 - X3*Y3*m_3*C3*S2 + X4*Z4*m_4*C2*S3 + X4*Z4*m_4*C3*S2 + Iyz6*S2*S3*S4*S6 - Y3*a3*m_3*C2*S3 - Y3*a3*m_3*C3*S2 - Y3*Z3*m_3*S2*S3 + 2*Ixy5*C2*CC4*C5*S3 + 2*Ixy5*C3*CC4*C5*S2 - 2*Ixy6*C2*CC4*C5*S3 - 2*Ixy6*C3*CC4*C5*S2 - 2*Ixy6*C2*C5*CC6*S3 - 2*Ixy6*C3*C5*CC6*S2 - 2*Ixz5*C2*C3*CC5*S4 + 2*Iyz5*C2*CC4*S3*S5 + 2*Iyz5*C3*CC4*S2*S5 + 2*Ixz5*CC5*S2*S3*S4 - Iyz5*C2*C3*C4*C5 - dd6*m_6*C2*C4*S3*S4 - dd6*m_6*C3*C4*S2*S4 + Y5*d4*m_5*C2*C3*C4 + Z4*d4*m_4*C2*C3*C4 - X4*Y4*m_4*C2*C3*S4 + X5*Y5*m_5*C2*C5*S3 + X5*Y5*m_5*C3*C5*S2 - X6*Y6*m_6*C2*C5*S3 - X6*Y6*m_6*C3*C5*S2 - X5*Z5*m_5*C2*C3*S4 - Ixx5*C5*S2*S3*S4*S5 - Iyy6*C5*S2*S3*S4*S5 + Izz5*C5*S2*S3*S4*S5 + Izz6*C5*S2*S3*S4*S5 - Y5*a3*m_5*C2*C4*S3 - Y5*a3*m_5*C3*C4*S2 - Z4*a3*m_4*C2*C4*S3 - Z4*a3*m_4*C3*C4*S2 + X4*d4*m_4*C2*C3*S4 + Y4*Z4*m_4*C4*S2*S3 + Y5*Z5*m_5*C2*S3*S5 + Y5*Z5*m_5*C3*S2*S5 - X4*a3*m_4*C2*S3*S4 - X4*a3*m_4*C3*S2*S4 - Y5*d4*m_5*C4*S2*S3 - Z4*d4*m_4*C4*S2*S3 + X4*Y4*m_4*S2*S3*S4 + X5*Z5*m_5*S2*S3*S4 - X4*d4*m_4*S2*S3*S4 + 2*Ixy6*C2*C3*C4*CC6*S5 - 2*Ixz6*C2*C3*CC5*C6*S4 + Ixx5*C2*C4*CC5*S3*S4 + Ixx5*C3*C4*CC5*S2*S4 + Ixx6*C2*C4*CC6*S3*S4 + Ixx6*C3*C4*CC6*S2*S4 + Iyy6*C2*C4*CC5*S3*S4 + Iyy6*C3*C4*CC5*S2*S4 - Iyy6*C2*C4*CC6*S3*S4 - Iyy6*C3*C4*CC6*S2*S4 + 2*Iyz6*C2*C3*CC5*S4*S6 + 2*Iyz6*C2*CC4*C6*S3*S5 + 2*Iyz6*C3*CC4*C6*S2*S5 - Izz5*C2*C4*CC5*S3*S4 - Izz5*C3*C4*CC5*S2*S4 - Izz6*C2*C4*CC5*S3*S4 - Izz6*C3*C4*CC5*S2*S4 - 2*Ixy6*C4*CC6*S2*S3*S5 + 2*Ixz6*C2*CC4*S3*S5*S6 + 2*Ixz6*C3*CC4*S2*S5*S6 + 2*Ixz6*CC5*C6*S2*S3*S4 - 2*X4*Z4*m_4*C2*CC4*S3 - 2*X4*Z4*m_4*C3*CC4*S2 - 2*Iyz6*CC5*S2*S3*S4*S6 + 4*Ixy6*C2*CC4*C5*CC6*S3 + 4*Ixy6*C3*CC4*C5*CC6*S2 - Iyz6*C2*C3*C4*C5*C6 - Ixz6*C2*C3*C4*C5*S6 + Ixx5*C2*C3*C5*S4*S5 - Ixx6*C2*C5*C6*S3*S6 - Ixx6*C3*C5*C6*S2*S6 + Iyy6*C2*C3*C5*S4*S5 + Iyy6*C2*C5*C6*S3*S6 + Iyy6*C3*C5*C6*S2*S6 + Iyz6*C4*C5*C6*S2*S3 - Izz5*C2*C3*C5*S4*S5 - Izz6*C2*C3*C5*S4*S5 - XX4*m_4*C2*C4*S3*S4 - XX4*m_4*C3*C4*S2*S4 + XX6*m_6*C2*C4*S3*S4 + XX6*m_6*C3*C4*S2*S4 + YY5*m_5*C2*C4*S3*S4 + YY5*m_5*C3*C4*S2*S4 + ZZ4*m_4*C2*C4*S3*S4 + ZZ4*m_4*C3*C4*S2*S4 - ZZ5*m_5*C2*C4*S3*S4 - ZZ5*m_5*C3*C4*S2*S4 - ZZ6*m_6*C2*C4*S3*S4 - ZZ6*m_6*C3*C4*S2*S4 - Y4*Z4*m_4*C2*C3*C4 + Ixz6*C4*C5*S2*S3*S6 + X6*Z6*m_6*C6*S2*S3*S4 + X6*Z6*m_6*C2*S3*S5*S6 + X6*Z6*m_6*C3*S2*S5*S6 + d4*d6*m_6*C2*C3*S4*S5 - Z5*a3*m_5*C2*S3*S4*S5 - Z5*a3*m_5*C3*S2*S4*S5 - Z6*a3*m_6*C2*S3*S4*S5 - Z6*a3*m_6*C3*S2*S4*S5 - X5*d4*m_5*C5*S2*S3*S4 - X6*d4*m_6*C4*S2*S3*S6 + X6*d6*m_6*C6*S2*S3*S4 + X6*d6*m_6*C2*S3*S5*S6 + X6*d6*m_6*C3*S2*S5*S6 - Y6*Z6*m_6*S2*S3*S4*S6 - a3*d6*m_6*C2*S3*S4*S5 - a3*d6*m_6*C3*S2*S4*S5 - Y6*d6*m_6*S2*S3*S4*S6 - Z5*d4*m_5*S2*S3*S4*S5 - Z6*d4*m_6*S2*S3*S4*S5 + Ixx6*C2*C3*C5*CC6*S4*S5 + 2*Ixx6*C2*CC4*C5*C6*S3*S6 + 2*Ixx6*C3*CC4*C5*C6*S2*S6 - Iyy6*C2*C3*C5*CC6*S4*S5 - 2*Iyy6*C2*CC4*C5*C6*S3*S6 - 2*Iyy6*C3*CC4*C5*C6*S2*S6 - d4*d6*m_6*S2*S3*S4*S5 - XX5*m_5*C2*C4*CC5*S3*S4 - XX5*m_5*C3*C4*CC5*S2*S4 - XX6*m_6*C2*C4*CC6*S3*S4 - XX6*m_6*C3*C4*CC6*S2*S4 - YY6*m_6*C2*C4*CC5*S3*S4 - YY6*m_6*C3*C4*CC5*S2*S4 + YY6*m_6*C2*C4*CC6*S3*S4 + YY6*m_6*C3*C4*CC6*S2*S4 + ZZ5*m_5*C2*C4*CC5*S3*S4 + ZZ5*m_5*C3*C4*CC5*S2*S4 + ZZ6*m_6*C2*C4*CC5*S3*S4 + ZZ6*m_6*C3*C4*CC5*S2*S4 + dd6*m_6*C2*C4*CC5*S3*S4 + dd6*m_6*C3*C4*CC5*S2*S4 - 2*X5*Y5*m_5*C2*CC4*C5*S3 - 2*X5*Y5*m_5*C3*CC4*C5*S2 + 2*X6*Y6*m_6*C2*CC4*C5*S3 + 2*X6*Y6*m_6*C3*CC4*C5*S2 + 2*X6*Y6*m_6*C2*C5*CC6*S3 + 2*X6*Y6*m_6*C3*C5*CC6*S2 + 2*X5*Z5*m_5*C2*C3*CC5*S4 - Ixx6*C5*CC6*S2*S3*S4*S5 + Iyy6*C5*CC6*S2*S3*S4*S5 - 2*Y5*Z5*m_5*C2*CC4*S3*S5 - 2*Y5*Z5*m_5*C3*CC4*S2*S5 - 2*X5*Z5*m_5*CC5*S2*S3*S4 + Ixx6*C2*C4*CC5*CC6*S3*S4 + Ixx6*C3*C4*CC5*CC6*S2*S4 - Iyy6*C2*C4*CC5*CC6*S3*S4 - Iyy6*C3*C4*CC5*CC6*S2*S4 + Ixx6*C2*C3*C4*C6*S5*S6 - Iyy6*C2*C3*C4*C6*S5*S6 - XX5*m_5*C2*C3*C5*S4*S5 + XX6*m_6*C2*C5*C6*S3*S6 + XX6*m_6*C3*C5*C6*S2*S6 - YY6*m_6*C2*C3*C5*S4*S5 - YY6*m_6*C2*C5*C6*S3*S6 - YY6*m_6*C3*C5*C6*S2*S6 + ZZ5*m_5*C2*C3*C5*S4*S5 + ZZ6*m_6*C2*C3*C5*S4*S5 + Y5*Z5*m_5*C2*C3*C4*C5 - 2*Ixy6*C2*C4*C6*S3*S4*S6 - 2*Ixy6*C3*C4*C6*S2*S4*S6 + 2*Ixz5*C2*C4*C5*S3*S4*S5 + 2*Ixz5*C3*C4*C5*S2*S4*S5 + dd6*m_6*C2*C3*C5*S4*S5 + Y6*d4*m_6*C2*C3*C4*C6 - X5*Y5*m_5*C2*C3*C4*S5 + X6*Y6*m_6*C2*C3*C4*S5 - X6*Z6*m_6*C2*C3*C6*S4 - Ixx6*C4*C6*S2*S3*S5*S6 + Iyy6*C4*C6*S2*S3*S5*S6 - Y6*a3*m_6*C2*C4*C6*S3 - Y6*a3*m_6*C3*C4*C6*S2 + XX5*m_5*C5*S2*S3*S4*S5 + X5*d4*m_5*C2*C3*C5*S4 + X6*d4*m_6*C2*C3*C4*S6 - X6*d6*m_6*C2*C3*C6*S4 + YY6*m_6*C5*S2*S3*S4*S5 - ZZ5*m_5*C5*S2*S3*S4*S5 - ZZ6*m_6*C5*S2*S3*S4*S5 - Y5*Z5*m_5*C4*C5*S2*S3 + Y6*Z6*m_6*C2*C3*S4*S6 + Y6*Z6*m_6*C2*C6*S3*S5 + Y6*Z6*m_6*C3*C6*S2*S5 - dd6*m_6*C5*S2*S3*S4*S5 - X5*a3*m_5*C2*C5*S3*S4 - X5*a3*m_5*C3*C5*S2*S4 - X6*a3*m_6*C2*C4*S3*S6 - X6*a3*m_6*C3*C4*S2*S6 - Y6*d4*m_6*C4*C6*S2*S3 + Y6*d6*m_6*C2*C3*S4*S6 + Y6*d6*m_6*C2*C6*S3*S5 + Y6*d6*m_6*C3*C6*S2*S5 + Z5*d4*m_5*C2*C3*S4*S5 + Z6*d4*m_6*C2*C3*S4*S5 - 2*Z6*d6*m_6*C2*C4*S3*S4 - 2*Z6*d6*m_6*C3*C4*S2*S4 + X5*Y5*m_5*C4*S2*S3*S5 - X6*Y6*m_6*C4*S2*S3*S5 - 2*Ixy6*C2*C4*CC5*C6*S3*S4*S6 - 2*Ixy6*C3*C4*CC5*C6*S2*S4*S6 - 2*X6*Y6*m_6*C2*C3*C4*CC6*S5 + 2*X6*Z6*m_6*C2*C3*CC5*C6*S4 + XX6*m_6*C5*CC6*S2*S3*S4*S5 + 2*X6*d6*m_6*C2*C3*CC5*C6*S4 - YY6*m_6*C5*CC6*S2*S3*S4*S5 - 2*Y6*Z6*m_6*C2*C3*CC5*S4*S6 - 2*Y6*Z6*m_6*C2*CC4*C6*S3*S5 - 2*Y6*Z6*m_6*C3*CC4*C6*S2*S5 - 2*Y6*d6*m_6*C2*C3*CC5*S4*S6 - 2*Y6*d6*m_6*C2*CC4*C6*S3*S5 - 2*Y6*d6*m_6*C3*CC4*C6*S2*S5 + 2*Z6*d6*m_6*C2*C4*CC5*S3*S4 + 2*Z6*d6*m_6*C3*C4*CC5*S2*S4 + 2*X6*Y6*m_6*C4*CC6*S2*S3*S5 - 2*X6*Z6*m_6*C2*CC4*S3*S5*S6 - 2*X6*Z6*m_6*C3*CC4*S2*S5*S6 - 2*X6*Z6*m_6*CC5*C6*S2*S3*S4 - 2*X6*d6*m_6*C2*CC4*S3*S5*S6 - 2*X6*d6*m_6*C3*CC4*S2*S5*S6 - 2*X6*d6*m_6*CC5*C6*S2*S3*S4 + 2*Y6*Z6*m_6*CC5*S2*S3*S4*S6 + 2*Y6*d6*m_6*CC5*S2*S3*S4*S6 - XX6*m_6*C2*C4*CC5*CC6*S3*S4 - XX6*m_6*C3*C4*CC5*CC6*S2*S4 + YY6*m_6*C2*C4*CC5*CC6*S3*S4 + YY6*m_6*C3*C4*CC5*CC6*S2*S4 - 4*X6*Y6*m_6*C2*CC4*C5*CC6*S3 - 4*X6*Y6*m_6*C3*CC4*C5*CC6*S2 - XX6*m_6*C2*C3*C4*C6*S5*S6 + YY6*m_6*C2*C3*C4*C6*S5*S6 + Y6*Z6*m_6*C2*C3*C4*C5*C6 - 2*Ixy6*C2*C3*C5*C6*S4*S5*S6 + 2*Ixz6*C2*C4*C5*C6*S3*S4*S5 + 2*Ixz6*C3*C4*C5*C6*S2*S4*S5 + Y6*d6*m_6*C2*C3*C4*C5*C6 + X6*Z6*m_6*C2*C3*C4*C5*S6 - 2*Iyz6*C2*C4*C5*S3*S4*S5*S6 - 2*Iyz6*C3*C4*C5*S2*S4*S5*S6 + XX6*m_6*C4*C6*S2*S3*S5*S6 + X6*d4*m_6*C2*C3*C5*C6*S4 + X6*d6*m_6*C2*C3*C4*C5*S6 - YY6*m_6*C4*C6*S2*S3*S5*S6 - Y6*Z6*m_6*C4*C5*C6*S2*S3 + 2*Ixy6*C5*C6*S2*S3*S4*S5*S6 - X6*a3*m_6*C2*C5*C6*S3*S4 - X6*a3*m_6*C3*C5*C6*S2*S4 - Y6*d4*m_6*C2*C3*C5*S4*S6 - Y6*d6*m_6*C4*C5*C6*S2*S3 + 2*Z6*d6*m_6*C2*C3*C5*S4*S5 - X6*Z6*m_6*C4*C5*S2*S3*S6 + Y6*a3*m_6*C2*C5*S3*S4*S6 + Y6*a3*m_6*C3*C5*S2*S4*S6 - X6*d4*m_6*C5*C6*S2*S3*S4 - X6*d6*m_6*C4*C5*S2*S3*S6 + Y6*d4*m_6*C5*S2*S3*S4*S6 - 2*Z6*d6*m_6*C5*S2*S3*S4*S5 - XX6*m_6*C2*C3*C5*CC6*S4*S5 - 2*XX6*m_6*C2*CC4*C5*C6*S3*S6 - 2*XX6*m_6*C3*CC4*C5*C6*S2*S6 + YY6*m_6*C2*C3*C5*CC6*S4*S5 + 2*YY6*m_6*C2*CC4*C5*C6*S3*S6 + 2*YY6*m_6*C3*CC4*C5*C6*S2*S6 + 2*X6*Y6*m_6*C2*C4*C6*S3*S4*S6 + 2*X6*Y6*m_6*C3*C4*C6*S2*S4*S6 - 2*X5*Z5*m_5*C2*C4*C5*S3*S4*S5 - 2*X5*Z5*m_5*C3*C4*C5*S2*S4*S5 + 2*X6*Y6*m_6*C2*C3*C5*C6*S4*S5*S6 - 2*X6*Z6*m_6*C2*C4*C5*C6*S3*S4*S5 - 2*X6*Z6*m_6*C3*C4*C5*C6*S2*S4*S5 - 2*X6*d6*m_6*C2*C4*C5*C6*S3*S4*S5 - 2*X6*d6*m_6*C3*C4*C5*C6*S2*S4*S5 + 2*Y6*Z6*m_6*C2*C4*C5*S3*S4*S5*S6 + 2*Y6*Z6*m_6*C3*C4*C5*S2*S4*S5*S6 + 2*Y6*d6*m_6*C2*C4*C5*S3*S4*S5*S6 + 2*Y6*d6*m_6*C3*C4*C5*S2*S4*S5*S6 - 2*X6*Y6*m_6*C5*C6*S2*S3*S4*S5*S6 + 2*X6*Y6*m_6*C2*C4*CC5*C6*S3*S4*S6 + 2*X6*Y6*m_6*C3*C4*CC5*C6*S2*S4*S6;
inertiamatrix.array2d[0][3] = Ixx5*S2*S3 - Iyy4*C2*C3 - Iyy6*C2*C3 - Ixx5*C2*C3 + Iyy4*S2*S3 + Iyy6*S2*S3 - XX4*m_4*C2*C3 - XX6*m_6*C2*C3 - YY5*m_5*C2*C3 - ZZ4*m_4*C2*C3 - ZZ5*m_5*C2*C3 - ZZ6*m_6*C2*C3 - Ixy4*C2*C4*S3 - Ixy4*C3*C4*S2 - Ixz5*C2*C4*S3 - Ixz5*C3*C4*S2 - dd6*m_6*C2*C3 + Iyz4*C2*S3*S4 + Iyz4*C3*S2*S4 + XX4*m_4*S2*S3 + XX6*m_6*S2*S3 + YY5*m_5*S2*S3 + ZZ4*m_4*S2*S3 + ZZ5*m_5*S2*S3 + ZZ6*m_6*S2*S3 + dd6*m_6*S2*S3 - X4*a1*m_4*C4 + Y5*a1*m_5*S4 + Z4*a1*m_4*S4 + Ixx5*C2*C3*CC5 - Ixx6*C2*C3*CC6 + Iyy6*C2*C3*CC5 + Iyy6*C2*C3*CC6 - Izz5*C2*C3*CC5 - Izz6*C2*C3*CC5 - Ixx5*CC5*S2*S3 + Ixx6*CC6*S2*S3 - Iyy6*CC5*S2*S3 - Iyy6*CC6*S2*S3 + Izz5*CC5*S2*S3 + Izz6*CC5*S2*S3 + 2*Ixy6*C2*C3*C6*S6 + 2*Ixz5*C2*C3*C5*S5 - Ixz6*C2*C4*C6*S3 - Ixz6*C3*C4*C6*S2 - Iyz5*C2*C5*S3*S4 - Iyz5*C3*C5*S2*S4 + Iyz6*C2*C4*S3*S6 + Iyz6*C3*C4*S2*S6 + Ixy5*C2*S3*S4*S5 + Ixy5*C3*S2*S4*S5 - Ixy6*C2*S3*S4*S5 - Ixy6*C3*S2*S4*S5 - 2*Ixy6*C6*S2*S3*S6 - 2*Ixz5*C5*S2*S3*S5 - X4*a2*m_4*C2*C4 - X5*a1*m_5*C4*C5 - 2*Z6*d6*m_6*C2*C3 + Y5*a2*m_5*C2*S4 + Y6*a1*m_6*C6*S4 + Z4*a2*m_4*C2*S4 - Z5*a1*m_5*C4*S5 - Z6*a1*m_6*C4*S5 - a1*d6*m_6*C4*S5 + X6*a1*m_6*S4*S6 + 2*Z6*d6*m_6*S2*S3 - XX5*m_5*C2*C3*CC5 + XX6*m_6*C2*C3*CC6 - YY6*m_6*C2*C3*CC5 - YY6*m_6*C2*C3*CC6 + ZZ5*m_5*C2*C3*CC5 + ZZ6*m_6*C2*C3*CC5 + 2*Ixz5*C2*C4*CC5*S3 + 2*Ixz5*C3*C4*CC5*S2 + dd6*m_6*C2*C3*CC5 + XX5*m_5*CC5*S2*S3 - XX6*m_6*CC6*S2*S3 + YY6*m_6*CC5*S2*S3 + YY6*m_6*CC6*S2*S3 - ZZ5*m_5*CC5*S2*S3 - ZZ6*m_6*CC5*S2*S3 - dd6*m_6*CC5*S2*S3 + Ixx6*C2*C3*CC5*CC6 - Iyy6*C2*C3*CC5*CC6 - Ixx6*CC5*CC6*S2*S3 + Iyy6*CC5*CC6*S2*S3 - X4*a3*m_4*C2*C3*C4 - X5*a2*m_5*C2*C4*C5 - X6*a1*m_6*C4*C5*C6 + X4*Y4*m_4*C2*C4*S3 + X4*Y4*m_4*C3*C4*S2 + X5*Z5*m_5*C2*C4*S3 + X5*Z5*m_5*C3*C4*S2 + 2*Iyz6*C5*S2*S3*S5*S6 + Y5*a3*m_5*C2*C3*S4 + Y6*a2*m_6*C2*C6*S4 + Y6*a1*m_6*C4*C5*S6 + Z4*a3*m_4*C2*C3*S4 - Z5*a2*m_5*C2*C4*S5 - Z6*a2*m_6*C2*C4*S5 - X4*d4*m_4*C2*C4*S3 - X4*d4*m_4*C3*C4*S2 - Y4*Z4*m_4*C2*S3*S4 - Y4*Z4*m_4*C3*S2*S4 - a2*d6*m_6*C2*C4*S5 + X4*a3*m_4*C4*S2*S3 + X6*a2*m_6*C2*S4*S6 + Y5*d4*m_5*C2*S3*S4 + Y5*d4*m_5*C3*S2*S4 + Z4*d4*m_4*C2*S3*S4 + Z4*d4*m_4*C3*S2*S4 - Y5*a3*m_5*S2*S3*S4 - Z4*a3*m_4*S2*S3*S4 - 2*Ixy6*C2*C3*CC5*C6*S6 + 2*Ixz6*C2*C4*CC5*C6*S3 + 2*Ixz6*C3*C4*CC5*C6*S2 - 2*Iyz6*C2*C4*CC5*S3*S6 - 2*Iyz6*C3*C4*CC5*S2*S6 + 2*Ixy6*C2*CC6*S3*S4*S5 + 2*Ixy6*C3*CC6*S2*S4*S5 + 2*Ixy6*CC5*C6*S2*S3*S6 + 2*Z6*d6*m_6*C2*C3*CC5 - 2*Z6*d6*m_6*CC5*S2*S3 - XX6*m_6*C2*C3*CC5*CC6 + YY6*m_6*C2*C3*CC5*CC6 + XX6*m_6*CC5*CC6*S2*S3 - YY6*m_6*CC5*CC6*S2*S3 + 2*Ixz6*C2*C3*C5*C6*S5 - Ixx5*C2*C4*C5*S3*S5 - Ixx5*C3*C4*C5*S2*S5 - Iyy6*C2*C4*C5*S3*S5 - Iyy6*C3*C4*C5*S2*S5 - Iyz6*C2*C5*C6*S3*S4 - Iyz6*C3*C5*C6*S2*S4 - 2*Iyz6*C2*C3*C5*S5*S6 + Izz5*C2*C4*C5*S3*S5 + Izz5*C3*C4*C5*S2*S5 + Izz6*C2*C4*C5*S3*S5 + Izz6*C3*C4*C5*S2*S5 - Ixz6*C2*C5*S3*S4*S6 - Ixz6*C3*C5*S2*S4*S6 - 2*Ixz6*C5*C6*S2*S3*S5 + 2*X5*Z5*m_5*C5*S2*S3*S5 - d4*d6*m_6*C2*C4*S3*S5 - d4*d6*m_6*C3*C4*S2*S5 - Y6*a3*m_6*C6*S2*S3*S4 + Z5*a3*m_5*C4*S2*S3*S5 + Z6*a3*m_6*C4*S2*S3*S5 + X6*d4*m_6*C2*S3*S4*S6 + X6*d4*m_6*C3*S2*S4*S6 + a3*d6*m_6*C4*S2*S3*S5 - X6*a3*m_6*S2*S3*S4*S6 - Ixx6*C2*C4*C5*CC6*S3*S5 - Ixx6*C3*C4*C5*CC6*S2*S5 + Iyy6*C2*C4*C5*CC6*S3*S5 + Iyy6*C3*C4*C5*CC6*S2*S5 - 2*X5*Z5*m_5*C2*C4*CC5*S3 - 2*X5*Z5*m_5*C3*C4*CC5*S2 + XX5*m_5*C2*C4*C5*S3*S5 + XX5*m_5*C3*C4*C5*S2*S5 + YY6*m_6*C2*C4*C5*S3*S5 + YY6*m_6*C3*C4*C5*S2*S5 - ZZ5*m_5*C2*C4*C5*S3*S5 - ZZ5*m_5*C3*C4*C5*S2*S5 - ZZ6*m_6*C2*C4*C5*S3*S5 - ZZ6*m_6*C3*C4*C5*S2*S5 - dd6*m_6*C2*C4*C5*S3*S5 - dd6*m_6*C3*C4*C5*S2*S5 - X5*a3*m_5*C2*C3*C4*C5 - X6*a2*m_6*C2*C4*C5*C6 - 2*X6*Y6*m_6*C2*C3*C6*S6 - 2*X5*Z5*m_5*C2*C3*C5*S5 + X6*Z6*m_6*C2*C4*C6*S3 + X6*Z6*m_6*C3*C4*C6*S2 + Ixx6*C2*C6*S3*S4*S5*S6 + Ixx6*C3*C6*S2*S4*S5*S6 - Iyy6*C2*C6*S3*S4*S5*S6 - Iyy6*C3*C6*S2*S4*S5*S6 + Y6*a3*m_6*C2*C3*C6*S4 + Y6*a2*m_6*C2*C4*C5*S6 - Z5*a3*m_5*C2*C3*C4*S5 - Z6*a3*m_6*C2*C3*C4*S5 - X5*d4*m_5*C2*C4*C5*S3 - X5*d4*m_5*C3*C4*C5*S2 + X6*d6*m_6*C2*C4*C6*S3 + X6*d6*m_6*C3*C4*C6*S2 + Y5*Z5*m_5*C2*C5*S3*S4 + Y5*Z5*m_5*C3*C5*S2*S4 - Y6*Z6*m_6*C2*C4*S3*S6 - Y6*Z6*m_6*C3*C4*S2*S6 - a3*d6*m_6*C2*C3*C4*S5 + X5*a3*m_5*C4*C5*S2*S3 + X6*a3*m_6*C2*C3*S4*S6 + Y6*d4*m_6*C2*C6*S3*S4 + Y6*d4*m_6*C3*C6*S2*S4 - Y6*d6*m_6*C2*C4*S3*S6 - Y6*d6*m_6*C3*C4*S2*S6 - Z5*d4*m_5*C2*C4*S3*S5 - Z5*d4*m_5*C3*C4*S2*S5 - Z6*d4*m_6*C2*C4*S3*S5 - Z6*d4*m_6*C3*C4*S2*S5 - X5*Y5*m_5*C2*S3*S4*S5 - X5*Y5*m_5*C3*S2*S4*S5 + X6*Y6*m_6*C2*S3*S4*S5 + X6*Y6*m_6*C3*S2*S4*S5 + 2*X6*Y6*m_6*C6*S2*S3*S6 + 2*X6*Y6*m_6*C2*C3*CC5*C6*S6 - 2*X6*Z6*m_6*C2*C4*CC5*C6*S3 - 2*X6*Z6*m_6*C3*C4*CC5*C6*S2 - 2*X6*d6*m_6*C2*C4*CC5*C6*S3 - 2*X6*d6*m_6*C3*C4*CC5*C6*S2 + 2*Y6*Z6*m_6*C2*C4*CC5*S3*S6 + 2*Y6*Z6*m_6*C3*C4*CC5*S2*S6 + 2*Y6*d6*m_6*C2*C4*CC5*S3*S6 + 2*Y6*d6*m_6*C3*C4*CC5*S2*S6 - 2*X6*Y6*m_6*C2*CC6*S3*S4*S5 - 2*X6*Y6*m_6*C3*CC6*S2*S4*S5 - 2*X6*Y6*m_6*CC5*C6*S2*S3*S6 + 2*Ixy6*C2*C4*C5*C6*S3*S5*S6 + 2*Ixy6*C3*C4*C5*C6*S2*S5*S6 - X6*a3*m_6*C2*C3*C4*C5*C6 - 2*X6*Z6*m_6*C2*C3*C5*C6*S5 + Y6*a3*m_6*C2*C3*C4*C5*S6 - XX6*m_6*C2*C6*S3*S4*S5*S6 - XX6*m_6*C3*C6*S2*S4*S5*S6 - X6*d4*m_6*C2*C4*C5*C6*S3 - X6*d4*m_6*C3*C4*C5*C6*S2 - 2*X6*d6*m_6*C2*C3*C5*C6*S5 + YY6*m_6*C2*C6*S3*S4*S5*S6 + YY6*m_6*C3*C6*S2*S4*S5*S6 + Y6*Z6*m_6*C2*C5*C6*S3*S4 + Y6*Z6*m_6*C3*C5*C6*S2*S4 + 2*Y6*Z6*m_6*C2*C3*C5*S5*S6 + X6*a3*m_6*C4*C5*C6*S2*S3 + Y6*d4*m_6*C2*C4*C5*S3*S6 + Y6*d4*m_6*C3*C4*C5*S2*S6 + Y6*d6*m_6*C2*C5*C6*S3*S4 + Y6*d6*m_6*C3*C5*C6*S2*S4 + 2*Y6*d6*m_6*C2*C3*C5*S5*S6 - 2*Z6*d6*m_6*C2*C4*C5*S3*S5 - 2*Z6*d6*m_6*C3*C4*C5*S2*S5 + X6*Z6*m_6*C2*C5*S3*S4*S6 + X6*Z6*m_6*C3*C5*S2*S4*S6 + 2*X6*Z6*m_6*C5*C6*S2*S3*S5 - Y6*a3*m_6*C4*C5*S2*S3*S6 + X6*d6*m_6*C2*C5*S3*S4*S6 + X6*d6*m_6*C3*C5*S2*S4*S6 + 2*X6*d6*m_6*C5*C6*S2*S3*S5 - 2*Y6*Z6*m_6*C5*S2*S3*S5*S6 - 2*Y6*d6*m_6*C5*S2*S3*S5*S6 + XX6*m_6*C2*C4*C5*CC6*S3*S5 + XX6*m_6*C3*C4*C5*CC6*S2*S5 - YY6*m_6*C2*C4*C5*CC6*S3*S5 - YY6*m_6*C3*C4*C5*CC6*S2*S5 - 2*X6*Y6*m_6*C2*C4*C5*C6*S3*S5*S6 - 2*X6*Y6*m_6*C3*C4*C5*C6*S2*S5*S6;
inertiamatrix.array2d[0][4] = Ixy5*C2*C3*S5 - Iyz5*C2*C3*C5 - Ixy6*C2*C3*S5 - Ixx6*C2*S3*S4 - Ixx6*C3*S2*S4 - Iyy5*C2*S3*S4 - Iyy5*C3*S2*S4 + Iyz5*C5*S2*S3 - Ixy5*S2*S3*S5 + Ixy6*S2*S3*S5 + Ixy5*C2*C4*C5*S3 + Ixy5*C3*C4*C5*S2 - Ixy6*C2*C4*C5*S3 - Ixy6*C3*C4*C5*S2 - Ixz6*C2*C3*C5*S6 + Iyz5*C2*C4*S3*S5 + Iyz5*C3*C4*S2*S5 + Iyz6*C5*C6*S2*S3 - XX5*m_5*C2*S3*S4 - XX5*m_5*C3*S2*S4 - YY6*m_6*C2*S3*S4 - YY6*m_6*C3*S2*S4 - ZZ5*m_5*C2*S3*S4 - ZZ5*m_5*C3*S2*S4 - ZZ6*m_6*C2*S3*S4 - ZZ6*m_6*C3*S2*S4 + Ixz6*C5*S2*S3*S6 - dd6*m_6*C2*S3*S4 - dd6*m_6*C3*S2*S4 - Z5*a1*m_5*C5*S4 - Z6*a1*m_6*C5*S4 - a1*d6*m_6*C5*S4 + X5*a1*m_5*S4*S5 + 2*Ixy6*C2*C3*CC6*S5 + Ixx6*C2*CC6*S3*S4 + Ixx6*C3*CC6*S2*S4 - Iyy6*C2*CC6*S3*S4 - Iyy6*C3*CC6*S2*S4 - 2*Ixy6*CC6*S2*S3*S5 - Iyz6*C2*C3*C5*C6 - X5*Y5*m_5*C2*C3*S5 + X6*Y6*m_6*C2*C3*S5 - Ixx6*C6*S2*S3*S5*S6 + Iyy6*C6*S2*S3*S5*S6 - Z5*a2*m_5*C2*C5*S4 - Z6*a2*m_6*C2*C5*S4 - Y5*Z5*m_5*C5*S2*S3 - a2*d6*m_6*C2*C5*S4 + X5*a2*m_5*C2*S4*S5 + X6*a1*m_6*C6*S4*S5 - 2*Z6*d6*m_6*C2*S3*S4 - 2*Z6*d6*m_6*C3*S2*S4 + X5*Y5*m_5*S2*S3*S5 - X6*Y6*m_6*S2*S3*S5 - Y6*a1*m_6*S4*S5*S6 + 2*Ixy6*C2*C4*C5*CC6*S3 + 2*Ixy6*C3*C4*C5*CC6*S2 - XX6*m_6*C2*CC6*S3*S4 - XX6*m_6*C3*CC6*S2*S4 + YY6*m_6*C2*CC6*S3*S4 + YY6*m_6*C3*CC6*S2*S4 + Ixx6*C2*C3*C6*S5*S6 - Iyy6*C2*C3*C6*S5*S6 + Iyz6*C2*C4*C6*S3*S5 + Iyz6*C3*C4*C6*S2*S5 + Y5*Z5*m_5*C2*C3*C5 - 2*Ixy6*C2*C6*S3*S4*S6 - 2*Ixy6*C3*C6*S2*S4*S6 + Ixz6*C2*C4*S3*S5*S6 + Ixz6*C3*C4*S2*S5*S6 - X6*Z6*m_6*C5*S2*S3*S6 - d4*d6*m_6*C2*C5*S3*S4 - d4*d6*m_6*C3*C5*S2*S4 - Y6*a2*m_6*C2*S4*S5*S6 + Z5*a3*m_5*C5*S2*S3*S4 + Z6*a3*m_6*C5*S2*S3*S4 + X5*d4*m_5*C2*S3*S4*S5 + X5*d4*m_5*C3*S2*S4*S5 - X6*d6*m_6*C5*S2*S3*S6 + a3*d6*m_6*C5*S2*S3*S4 - X5*a3*m_5*S2*S3*S4*S5 - 2*X6*Y6*m_6*C2*C3*CC6*S5 + 2*X6*Y6*m_6*CC6*S2*S3*S5 + Ixx6*C2*C4*C5*C6*S3*S6 + Ixx6*C3*C4*C5*C6*S2*S6 - Iyy6*C2*C4*C5*C6*S3*S6 - Iyy6*C3*C4*C5*C6*S2*S6 - XX6*m_6*C2*C3*C6*S5*S6 + YY6*m_6*C2*C3*C6*S5*S6 + Y6*Z6*m_6*C2*C3*C5*C6 + Y6*d6*m_6*C2*C3*C5*C6 - X5*Y5*m_5*C2*C4*C5*S3 - X5*Y5*m_5*C3*C4*C5*S2 + X6*Y6*m_6*C2*C4*C5*S3 + X6*Y6*m_6*C3*C4*C5*S2 + X6*Z6*m_6*C2*C3*C5*S6 - Z5*a3*m_5*C2*C3*C5*S4 - Z6*a3*m_6*C2*C3*C5*S4 + XX6*m_6*C6*S2*S3*S5*S6 + X6*d6*m_6*C2*C3*C5*S6 - YY6*m_6*C6*S2*S3*S5*S6 - Y5*Z5*m_5*C2*C4*S3*S5 - Y5*Z5*m_5*C3*C4*S2*S5 - Y6*Z6*m_6*C5*C6*S2*S3 - a3*d6*m_6*C2*C3*C5*S4 + X5*a3*m_5*C2*C3*S4*S5 + X6*a2*m_6*C2*C6*S4*S5 - Y6*d6*m_6*C5*C6*S2*S3 - Z5*d4*m_5*C2*C5*S3*S4 - Z5*d4*m_5*C3*C5*S2*S4 - Z6*d4*m_6*C2*C5*S3*S4 - Z6*d4*m_6*C3*C5*S2*S4 - 2*X6*Y6*m_6*C2*C4*C5*CC6*S3 - 2*X6*Y6*m_6*C3*C4*C5*CC6*S2 - XX6*m_6*C2*C4*C5*C6*S3*S6 - XX6*m_6*C3*C4*C5*C6*S2*S6 + YY6*m_6*C2*C4*C5*C6*S3*S6 + YY6*m_6*C3*C4*C5*C6*S2*S6 - Y6*Z6*m_6*C2*C4*C6*S3*S5 - Y6*Z6*m_6*C3*C4*C6*S2*S5 + X6*a3*m_6*C2*C3*C6*S4*S5 - Y6*d6*m_6*C2*C4*C6*S3*S5 - Y6*d6*m_6*C3*C4*C6*S2*S5 + 2*X6*Y6*m_6*C2*C6*S3*S4*S6 + 2*X6*Y6*m_6*C3*C6*S2*S4*S6 - X6*Z6*m_6*C2*C4*S3*S5*S6 - X6*Z6*m_6*C3*C4*S2*S5*S6 - Y6*a3*m_6*C2*C3*S4*S5*S6 + X6*d4*m_6*C2*C6*S3*S4*S5 + X6*d4*m_6*C3*C6*S2*S4*S5 - X6*d6*m_6*C2*C4*S3*S5*S6 - X6*d6*m_6*C3*C4*S2*S5*S6 - X6*a3*m_6*C6*S2*S3*S4*S5 - Y6*d4*m_6*C2*S3*S4*S5*S6 - Y6*d4*m_6*C3*S2*S4*S5*S6 + Y6*a3*m_6*S2*S3*S4*S5*S6;
inertiamatrix.array2d[0][5] = Izz6*C5*S2*S3 - Izz6*C2*C3*C5 - XX6*m_6*C2*C3*C5 - YY6*m_6*C2*C3*C5 + Ixz6*C2*C3*C6*S5 - Iyz6*C2*C6*S3*S4 - Iyz6*C3*C6*S2*S4 - Iyz6*C2*C3*S5*S6 + Izz6*C2*C4*S3*S5 + Izz6*C3*C4*S2*S5 + XX6*m_6*C5*S2*S3 + YY6*m_6*C5*S2*S3 - Ixz6*C2*S3*S4*S6 - Ixz6*C3*S2*S4*S6 - Ixz6*C6*S2*S3*S5 - X6*a1*m_6*C4*C6 + Iyz6*S2*S3*S5*S6 + Y6*a1*m_6*C4*S6 - X6*a2*m_6*C2*C4*C6 + Y6*a2*m_6*C2*C4*S6 + Y6*a1*m_6*C5*C6*S4 + X6*a1*m_6*C5*S4*S6 + Ixz6*C2*C4*C5*C6*S3 + Ixz6*C3*C4*C5*C6*S2 - Iyz6*C2*C4*C5*S3*S6 - Iyz6*C3*C4*C5*S2*S6 + XX6*m_6*C2*C4*S3*S5 + XX6*m_6*C3*C4*S2*S5 + YY6*m_6*C2*C4*S3*S5 + YY6*m_6*C3*C4*S2*S5 + X6*Z6*m_6*C2*S3*S4*S6 + X6*Z6*m_6*C3*S2*S4*S6 + X6*Z6*m_6*C6*S2*S3*S5 - Y6*a3*m_6*C4*S2*S3*S6 + X6*d6*m_6*C2*S3*S4*S6 + X6*d6*m_6*C3*S2*S4*S6 + X6*d6*m_6*C6*S2*S3*S5 - Y6*Z6*m_6*S2*S3*S5*S6 - Y6*d6*m_6*S2*S3*S5*S6 - X6*a3*m_6*C2*C3*C4*C6 - X6*Z6*m_6*C2*C3*C6*S5 + Y6*a3*m_6*C2*C3*C4*S6 + Y6*a2*m_6*C2*C5*C6*S4 - X6*d4*m_6*C2*C4*C6*S3 - X6*d4*m_6*C3*C4*C6*S2 - X6*d6*m_6*C2*C3*C6*S5 + Y6*Z6*m_6*C2*C6*S3*S4 + Y6*Z6*m_6*C3*C6*S2*S4 + Y6*Z6*m_6*C2*C3*S5*S6 + X6*a3*m_6*C4*C6*S2*S3 + X6*a2*m_6*C2*C5*S4*S6 + Y6*d4*m_6*C2*C4*S3*S6 + Y6*d4*m_6*C3*C4*S2*S6 + Y6*d6*m_6*C2*C6*S3*S4 + Y6*d6*m_6*C3*C6*S2*S4 + Y6*d6*m_6*C2*C3*S5*S6 - X6*Z6*m_6*C2*C4*C5*C6*S3 - X6*Z6*m_6*C3*C4*C5*C6*S2 + Y6*a3*m_6*C2*C3*C5*C6*S4 - X6*d6*m_6*C2*C4*C5*C6*S3 - X6*d6*m_6*C3*C4*C5*C6*S2 + Y6*Z6*m_6*C2*C4*C5*S3*S6 + Y6*Z6*m_6*C3*C4*C5*S2*S6 + X6*a3*m_6*C2*C3*C5*S4*S6 + Y6*d4*m_6*C2*C5*C6*S3*S4 + Y6*d4*m_6*C3*C5*C6*S2*S4 + Y6*d6*m_6*C2*C4*C5*S3*S6 + Y6*d6*m_6*C3*C4*C5*S2*S6 - Y6*a3*m_6*C5*C6*S2*S3*S4 + X6*d4*m_6*C2*C5*S3*S4*S6 + X6*d4*m_6*C3*C5*S2*S4*S6 - X6*a3*m_6*C5*S2*S3*S4*S6;
inertiamatrix.array2d[1][0] = inertiamatrix.array2d[0][1]; 
inertiamatrix.array2d[1][1] = Ixx4 + Iyy3 + Izz2 + Izz5 + Izz6 + XX2*m_2 + XX3*m_3 + XX5*m_5 + XX6*m_6 + YY2*m_2 + YY4*m_4 + YY5*m_5 + YY6*m_6 + ZZ3*m_3 + ZZ4*m_4 + aa2*m_2 + aa2*m_3 + aa2*m_4 + aa3*m_3 + aa2*m_5 + aa3*m_4 + aa2*m_6 + aa3*m_5 + aa3*m_6 + dd4*m_4 + dd4*m_5 + dd4*m_6 - Ixx4*CC4 + Ixx5*CC5 + Ixx6*CC4 + Iyy5*CC4 + Iyy6*CC5 + Izz4*CC4 - Izz5*CC4 - Izz5*CC5 - Izz6*CC4 - Izz6*CC5 + Ixz4*S44 + Ixz5*S55 - Ixx5*CC4*CC5 - Ixx6*CC4*CC6 + Ixx6*CC5*CC6 - Iyy6*CC4*CC5 + Iyy6*CC4*CC6 - Iyy6*CC5*CC6 + Izz5*CC4*CC5 + Izz6*CC4*CC5 + 2*X2*a2*m_2 + 2*X3*a3*m_3 - 2*Y4*d4*m_4 + XX4*m_4*CC4 - XX5*m_5*CC5 - XX6*m_6*CC4 - YY5*m_5*CC4 - YY6*m_6*CC5 - ZZ4*m_4*CC4 + ZZ5*m_5*CC4 + ZZ5*m_5*CC5 + ZZ6*m_6*CC4 + ZZ6*m_6*CC5 + dd6*m_6*CC4 + dd6*m_6*CC5 + 2*Ixy5*C4*C5*S4 - 2*Ixy6*C4*C5*S4 + 2*Ixz6*C5*C6*S5 - Ixx6*CC4*CC5*CC6 + Iyy6*CC4*CC5*CC6 + 2*Iyz5*C4*S4*S5 - 2*Iyz6*C5*S5*S6 + 2*X3*a2*m_3*C3 + 2*X4*a3*m_4*C4 + 2*Z5*d4*m_5*C5 + 2*Z6*d4*m_6*C5 + 2*a2*a3*m_3*C3 + 2*a2*a3*m_4*C3 + 2*a2*a3*m_5*C3 + 2*a2*a3*m_6*C3 + 2*d4*d6*m_6*C5 - 2*Y4*a2*m_4*S3 - 2*Y5*a3*m_5*S4 + 2*Z3*a2*m_3*S3 - 2*Z4*a3*m_4*S4 - 2*X5*d4*m_5*S5 + 2*a2*d4*m_4*S3 + 2*a2*d4*m_5*S3 + 2*a2*d4*m_6*S3 + 2*Ixy6*CC4*C6*S6 - 2*Ixy6*CC5*C6*S6 - 2*Ixz5*CC4*C5*S5 + 2*Z6*d6*m_6*CC4 + 2*Z6*d6*m_6*CC5 - X4*Z4*m_4*S44 - X5*Z5*m_5*S55 + XX5*m_5*CC4*CC5 + XX6*m_6*CC4*CC6 - XX6*m_6*CC5*CC6 + YY6*m_6*CC4*CC5 - YY6*m_6*CC4*CC6 + YY6*m_6*CC5*CC6 - ZZ5*m_5*CC4*CC5 - ZZ6*m_6*CC4*CC5 - dd6*m_6*CC4*CC5 + 2*Iyz6*C4*C6*S4*S5 + XX6*m_6*CC4*CC5*CC6 - YY6*m_6*CC4*CC5*CC6 + 2*Ixz6*C4*S4*S5*S6 + 2*X4*a2*m_4*C3*C4 + 2*X5*a3*m_5*C4*C5 - 2*Y5*a2*m_5*C3*S4 - 2*Y6*a3*m_6*C6*S4 - 2*Z4*a2*m_4*C3*S4 + 2*Z5*a2*m_5*C5*S3 + 2*Z5*a3*m_5*C4*S5 + 2*Z6*a2*m_6*C5*S3 + 2*Z6*a3*m_6*C4*S5 - 2*X6*d4*m_6*C6*S5 + 2*a2*d6*m_6*C5*S3 + 2*a3*d6*m_6*C4*S5 - 2*X5*a2*m_5*S3*S5 - 2*X6*a3*m_6*S4*S6 + 2*Y6*d4*m_6*S5*S6 + 4*Ixy6*C4*C5*CC6*S4 - 2*Ixz6*CC4*C5*C6*S5 + 2*Iyz6*CC4*C5*S5*S6 + 2*Ixy6*CC4*CC5*C6*S6 - 2*Z6*d6*m_6*CC4*CC5 + 2*X5*a2*m_5*C3*C4*C5 + 2*X6*a3*m_6*C4*C5*C6 - 2*X5*Y5*m_5*C4*C5*S4 + 2*X6*Y6*m_6*C4*C5*S4 - 2*X6*Z6*m_6*C5*C6*S5 - 2*Y6*a2*m_6*C3*C6*S4 - 2*Y6*a3*m_6*C4*C5*S6 + 2*Z5*a2*m_5*C3*C4*S5 + 2*Z6*a2*m_6*C3*C4*S5 - 2*X6*d6*m_6*C5*C6*S5 - 2*Y5*Z5*m_5*C4*S4*S5 + 2*Y6*Z6*m_6*C5*S5*S6 + 2*a2*d6*m_6*C3*C4*S5 - 2*X6*a2*m_6*C3*S4*S6 - 2*X6*a2*m_6*C6*S3*S5 + 2*Y6*d6*m_6*C5*S5*S6 + 2*Y6*a2*m_6*S3*S5*S6 - 2*X6*Y6*m_6*CC4*C6*S6 + 2*X6*Y6*m_6*CC5*C6*S6 + 2*X5*Z5*m_5*CC4*C5*S5 + 2*Ixx6*C4*C5*C6*S4*S6 - 2*Iyy6*C4*C5*C6*S4*S6 - 2*X6*Z6*m_6*C4*S4*S5*S6 - 2*X6*d6*m_6*C4*S4*S5*S6 - 4*X6*Y6*m_6*C4*C5*CC6*S4 + 2*X6*Z6*m_6*CC4*C5*C6*S5 + 2*X6*d6*m_6*CC4*C5*C6*S5 - 2*Y6*Z6*m_6*CC4*C5*S5*S6 - 2*Y6*d6*m_6*CC4*C5*S5*S6 - 2*X6*Y6*m_6*CC4*CC5*C6*S6 - 2*XX6*m_6*C4*C5*C6*S4*S6 + 2*YY6*m_6*C4*C5*C6*S4*S6 + 2*X6*a2*m_6*C3*C4*C5*C6 - 2*Y6*a2*m_6*C3*C4*C5*S6 - 2*Y6*Z6*m_6*C4*C6*S4*S5 - 2*Y6*d6*m_6*C4*C6*S4*S5;
inertiamatrix.array2d[1][2] = Ixx4 + Iyy3 + Izz5 + Izz6 + XX3*m_3 + XX5*m_5 + XX6*m_6 + YY4*m_4 + YY5*m_5 + YY6*m_6 + ZZ3*m_3 + ZZ4*m_4 + aa3*m_3 + aa3*m_4 + aa3*m_5 + aa3*m_6 + dd4*m_4 + dd4*m_5 + dd4*m_6 - Ixx4*CC4 + Ixx5*CC5 + Ixx6*CC4 + Iyy5*CC4 + Iyy6*CC5 + Izz4*CC4 - Izz5*CC4 - Izz5*CC5 - Izz6*CC4 - Izz6*CC5 + Ixz4*S44 + Ixz5*S55 - Ixx5*CC4*CC5 - Ixx6*CC4*CC6 + Ixx6*CC5*CC6 - Iyy6*CC4*CC5 + Iyy6*CC4*CC6 - Iyy6*CC5*CC6 + Izz5*CC4*CC5 + Izz6*CC4*CC5 + 2*X3*a3*m_3 - 2*Y4*d4*m_4 + XX4*m_4*CC4 - XX5*m_5*CC5 - XX6*m_6*CC4 - YY5*m_5*CC4 - YY6*m_6*CC5 - ZZ4*m_4*CC4 + ZZ5*m_5*CC4 + ZZ5*m_5*CC5 + ZZ6*m_6*CC4 + ZZ6*m_6*CC5 + dd6*m_6*CC4 + dd6*m_6*CC5 + 2*Ixy5*C4*C5*S4 - 2*Ixy6*C4*C5*S4 + 2*Ixz6*C5*C6*S5 - Ixx6*CC4*CC5*CC6 + Iyy6*CC4*CC5*CC6 + 2*Iyz5*C4*S4*S5 - 2*Iyz6*C5*S5*S6 + X3*a2*m_3*C3 + 2*X4*a3*m_4*C4 + 2*Z5*d4*m_5*C5 + 2*Z6*d4*m_6*C5 + a2*a3*m_3*C3 + a2*a3*m_4*C3 + a2*a3*m_5*C3 + a2*a3*m_6*C3 + 2*d4*d6*m_6*C5 - Y4*a2*m_4*S3 - 2*Y5*a3*m_5*S4 + Z3*a2*m_3*S3 - 2*Z4*a3*m_4*S4 - 2*X5*d4*m_5*S5 + a2*d4*m_4*S3 + a2*d4*m_5*S3 + a2*d4*m_6*S3 + 2*Ixy6*CC4*C6*S6 - 2*Ixy6*CC5*C6*S6 - 2*Ixz5*CC4*C5*S5 + 2*Z6*d6*m_6*CC4 + 2*Z6*d6*m_6*CC5 - X4*Z4*m_4*S44 - X5*Z5*m_5*S55 + XX5*m_5*CC4*CC5 + XX6*m_6*CC4*CC6 - XX6*m_6*CC5*CC6 + YY6*m_6*CC4*CC5 - YY6*m_6*CC4*CC6 + YY6*m_6*CC5*CC6 - ZZ5*m_5*CC4*CC5 - ZZ6*m_6*CC4*CC5 - dd6*m_6*CC4*CC5 + 2*Iyz6*C4*C6*S4*S5 + XX6*m_6*CC4*CC5*CC6 - YY6*m_6*CC4*CC5*CC6 + 2*Ixz6*C4*S4*S5*S6 + X4*a2*m_4*C3*C4 + 2*X5*a3*m_5*C4*C5 - Y5*a2*m_5*C3*S4 - 2*Y6*a3*m_6*C6*S4 - Z4*a2*m_4*C3*S4 + Z5*a2*m_5*C5*S3 + 2*Z5*a3*m_5*C4*S5 + Z6*a2*m_6*C5*S3 + 2*Z6*a3*m_6*C4*S5 - 2*X6*d4*m_6*C6*S5 + a2*d6*m_6*C5*S3 + 2*a3*d6*m_6*C4*S5 - X5*a2*m_5*S3*S5 - 2*X6*a3*m_6*S4*S6 + 2*Y6*d4*m_6*S5*S6 + 4*Ixy6*C4*C5*CC6*S4 - 2*Ixz6*CC4*C5*C6*S5 + 2*Iyz6*CC4*C5*S5*S6 + 2*Ixy6*CC4*CC5*C6*S6 - 2*Z6*d6*m_6*CC4*CC5 + X5*a2*m_5*C3*C4*C5 + 2*X6*a3*m_6*C4*C5*C6 - 2*X5*Y5*m_5*C4*C5*S4 + 2*X6*Y6*m_6*C4*C5*S4 - 2*X6*Z6*m_6*C5*C6*S5 - Y6*a2*m_6*C3*C6*S4 - 2*Y6*a3*m_6*C4*C5*S6 + Z5*a2*m_5*C3*C4*S5 + Z6*a2*m_6*C3*C4*S5 - 2*X6*d6*m_6*C5*C6*S5 - 2*Y5*Z5*m_5*C4*S4*S5 + 2*Y6*Z6*m_6*C5*S5*S6 + a2*d6*m_6*C3*C4*S5 - X6*a2*m_6*C3*S4*S6 - X6*a2*m_6*C6*S3*S5 + 2*Y6*d6*m_6*C5*S5*S6 + Y6*a2*m_6*S3*S5*S6 - 2*X6*Y6*m_6*CC4*C6*S6 + 2*X6*Y6*m_6*CC5*C6*S6 + 2*X5*Z5*m_5*CC4*C5*S5 + 2*Ixx6*C4*C5*C6*S4*S6 - 2*Iyy6*C4*C5*C6*S4*S6 - 2*X6*Z6*m_6*C4*S4*S5*S6 - 2*X6*d6*m_6*C4*S4*S5*S6 - 4*X6*Y6*m_6*C4*C5*CC6*S4 + 2*X6*Z6*m_6*CC4*C5*C6*S5 + 2*X6*d6*m_6*CC4*C5*C6*S5 - 2*Y6*Z6*m_6*CC4*C5*S5*S6 - 2*Y6*d6*m_6*CC4*C5*S5*S6 - 2*X6*Y6*m_6*CC4*CC5*C6*S6 - 2*XX6*m_6*C4*C5*C6*S4*S6 + 2*YY6*m_6*C4*C5*C6*S4*S6 + X6*a2*m_6*C3*C4*C5*C6 - Y6*a2*m_6*C3*C4*C5*S6 - 2*Y6*Z6*m_6*C4*C6*S4*S5 - 2*Y6*d6*m_6*C4*C6*S4*S5;
inertiamatrix.array2d[1][3] = Iyz5*C4*C5 - Ixy4*S4 - Ixz5*S4 - Iyz4*C4 - Ixy5*C4*S5 + Ixy6*C4*S5 - Ixz6*C6*S4 + Iyz6*S4*S6 + 2*Ixz5*CC5*S4 + Iyz6*C4*C5*C6 + Ixz6*C4*C5*S6 - Ixx5*C5*S4*S5 - Iyy6*C5*S4*S5 + Izz5*C5*S4*S5 + Izz6*C5*S4*S5 + Y4*Z4*m_4*C4 - Y5*d4*m_5*C4 - Z4*d4*m_4*C4 + X4*Y4*m_4*S4 + X5*Z5*m_5*S4 - X4*d4*m_4*S4 - 2*Ixy6*C4*CC6*S5 + 2*Ixz6*CC5*C6*S4 - 2*Iyz6*CC5*S4*S6 - Ixx6*C4*C6*S5*S6 + Iyy6*C4*C6*S5*S6 + XX5*m_5*C5*S4*S5 + YY6*m_6*C5*S4*S5 - ZZ5*m_5*C5*S4*S5 - ZZ6*m_6*C5*S4*S5 - Y5*Z5*m_5*C4*C5 - dd6*m_6*C5*S4*S5 - Y6*d4*m_6*C4*C6 + X5*Y5*m_5*C4*S5 - X6*Y6*m_6*C4*S5 + X6*Z6*m_6*C6*S4 - Y5*a2*m_5*C4*S3 - Z4*a2*m_4*C4*S3 - X5*d4*m_5*C5*S4 - X6*d4*m_6*C4*S6 + X6*d6*m_6*C6*S4 - Y6*Z6*m_6*S4*S6 - X4*a2*m_4*S3*S4 - Y6*d6*m_6*S4*S6 - Z5*d4*m_5*S4*S5 - Z6*d4*m_6*S4*S5 - d4*d6*m_6*S4*S5 - Ixx6*C5*CC6*S4*S5 + Iyy6*C5*CC6*S4*S5 - 2*X5*Z5*m_5*CC5*S4 - Y6*d6*m_6*C4*C5*C6 - X6*Z6*m_6*C4*C5*S6 - Y6*a2*m_6*C4*C6*S3 - X6*d4*m_6*C5*C6*S4 - X6*d6*m_6*C4*C5*S6 - X5*a2*m_5*C5*S3*S4 - X6*a2*m_6*C4*S3*S6 + Y6*d4*m_6*C5*S4*S6 - 2*Z6*d6*m_6*C5*S4*S5 - Z5*a2*m_5*S3*S4*S5 - Z6*a2*m_6*S3*S4*S5 - a2*d6*m_6*S3*S4*S5 + XX6*m_6*C5*CC6*S4*S5 - YY6*m_6*C5*CC6*S4*S5 + 2*X6*Y6*m_6*C4*CC6*S5 - 2*X6*Z6*m_6*CC5*C6*S4 - 2*X6*d6*m_6*CC5*C6*S4 + 2*Y6*Z6*m_6*CC5*S4*S6 + 2*Y6*d6*m_6*CC5*S4*S6 + XX6*m_6*C4*C6*S5*S6 - YY6*m_6*C4*C6*S5*S6 - Y6*Z6*m_6*C4*C5*C6 + 2*Ixy6*C5*C6*S4*S5*S6 + Y6*a2*m_6*C5*S3*S4*S6 - X6*a2*m_6*C5*C6*S3*S4 - 2*X6*Y6*m_6*C5*C6*S4*S5*S6;
inertiamatrix.array2d[1][4] = Ixx6*C4 + Iyy5*C4 + XX5*m_5*C4 + YY6*m_6*C4 + ZZ5*m_5*C4 + ZZ6*m_6*C4 + Ixy5*C5*S4 - Ixy6*C5*S4 + dd6*m_6*C4 + Iyz5*S4*S5 - Ixx6*C4*CC6 + Iyy6*C4*CC6 + 2*Ixy6*C4*C6*S6 + Iyz6*C6*S4*S5 + Ixz6*S4*S5*S6 + X5*a3*m_5*C5 + 2*Z6*d6*m_6*C4 + Z5*a3*m_5*S5 + Z6*a3*m_6*S5 + a3*d6*m_6*S5 + XX6*m_6*C4*CC6 - YY6*m_6*C4*CC6 + 2*Ixy6*C5*CC6*S4 + Ixx6*C5*C6*S4*S6 - Iyy6*C5*C6*S4*S6 + X5*a2*m_5*C3*C5 + X6*a3*m_6*C5*C6 + Z5*d4*m_5*C4*C5 + Z6*d4*m_6*C4*C5 - X5*Y5*m_5*C5*S4 + X6*Y6*m_6*C5*S4 + d4*d6*m_6*C4*C5 - Y6*a3*m_6*C5*S6 + Z5*a2*m_5*C3*S5 + Z6*a2*m_6*C3*S5 - X5*d4*m_5*C4*S5 - Y5*Z5*m_5*S4*S5 + a2*d6*m_6*C3*S5 + X6*a2*m_6*C3*C5*C6 - 2*X6*Y6*m_6*C4*C6*S6 - Y6*a2*m_6*C3*C5*S6 + Z5*a2*m_5*C4*C5*S3 + Z6*a2*m_6*C4*C5*S3 - X6*d4*m_6*C4*C6*S5 - Y6*Z6*m_6*C6*S4*S5 + a2*d6*m_6*C4*C5*S3 - X5*a2*m_5*C4*S3*S5 + Y6*d4*m_6*C4*S5*S6 - Y6*d6*m_6*C6*S4*S5 - X6*Z6*m_6*S4*S5*S6 - X6*d6*m_6*S4*S5*S6 - 2*X6*Y6*m_6*C5*CC6*S4 - XX6*m_6*C5*C6*S4*S6 + YY6*m_6*C5*C6*S4*S6 + Y6*a2*m_6*C4*S3*S5*S6 - X6*a2*m_6*C4*C6*S3*S5;
inertiamatrix.array2d[1][5] = Iyz6*C4*C6 + Ixz6*C4*S6 + Izz6*S4*S5 + Ixz6*C5*C6*S4 - Iyz6*C5*S4*S6 + XX6*m_6*S4*S5 + YY6*m_6*S4*S5 - Y6*Z6*m_6*C4*C6 - Y6*d6*m_6*C4*C6 - X6*Z6*m_6*C4*S6 - Y6*a3*m_6*C6*S5 - X6*d4*m_6*C6*S4 - X6*d6*m_6*C4*S6 - X6*a3*m_6*S5*S6 + Y6*d4*m_6*S4*S6 - Y6*d4*m_6*C4*C5*C6 - X6*Z6*m_6*C5*C6*S4 - Y6*a2*m_6*C3*C6*S5 - X6*d4*m_6*C4*C5*S6 - X6*d6*m_6*C5*C6*S4 + Y6*Z6*m_6*C5*S4*S6 - X6*a2*m_6*C6*S3*S4 - X6*a2*m_6*C3*S5*S6 + Y6*d6*m_6*C5*S4*S6 + Y6*a2*m_6*S3*S4*S6 - Y6*a2*m_6*C4*C5*C6*S3 - X6*a2*m_6*C4*C5*S3*S6; 
inertiamatrix.array2d[2][0]= inertiamatrix.array2d[0][2];
inertiamatrix.array2d[2][1] = inertiamatrix.array2d[1][2];
inertiamatrix.array2d[2][2] = Ixx4 + Iyy3 + Izz5 + Izz6 + XX3*m_3 + XX5*m_5 + XX6*m_6 + YY4*m_4 + YY5*m_5 + YY6*m_6 + ZZ3*m_3 + ZZ4*m_4 + aa3*m_3 + aa3*m_4 + aa3*m_5 + aa3*m_6 + dd4*m_4 + dd4*m_5 + dd4*m_6 - Ixx4*CC4 + Ixx5*CC5 + Ixx6*CC4 + Iyy5*CC4 + Iyy6*CC5 + Izz4*CC4 - Izz5*CC4 - Izz5*CC5 - Izz6*CC4 - Izz6*CC5 + Ixz4*S44 + Ixz5*S55 - Ixx5*CC4*CC5 - Ixx6*CC4*CC6 + Ixx6*CC5*CC6 - Iyy6*CC4*CC5 + Iyy6*CC4*CC6 - Iyy6*CC5*CC6 + Izz5*CC4*CC5 + Izz6*CC4*CC5 + 2*X3*a3*m_3 - 2*Y4*d4*m_4 + XX4*m_4*CC4 - XX5*m_5*CC5 - XX6*m_6*CC4 - YY5*m_5*CC4 - YY6*m_6*CC5 - ZZ4*m_4*CC4 + ZZ5*m_5*CC4 + ZZ5*m_5*CC5 + ZZ6*m_6*CC4 + ZZ6*m_6*CC5 + dd6*m_6*CC4 + dd6*m_6*CC5 + 2*Ixy5*C4*C5*S4 - 2*Ixy6*C4*C5*S4 + 2*Ixz6*C5*C6*S5 - Ixx6*CC4*CC5*CC6 + Iyy6*CC4*CC5*CC6 + 2*Iyz5*C4*S4*S5 - 2*Iyz6*C5*S5*S6 + 2*X4*a3*m_4*C4 + 2*Z5*d4*m_5*C5 + 2*Z6*d4*m_6*C5 + 2*d4*d6*m_6*C5 - 2*Y5*a3*m_5*S4 - 2*Z4*a3*m_4*S4 - 2*X5*d4*m_5*S5 + 2*Ixy6*CC4*C6*S6 - 2*Ixy6*CC5*C6*S6 - 2*Ixz5*CC4*C5*S5 + 2*Z6*d6*m_6*CC4 + 2*Z6*d6*m_6*CC5 - X4*Z4*m_4*S44 - X5*Z5*m_5*S55 + XX5*m_5*CC4*CC5 + XX6*m_6*CC4*CC6 - XX6*m_6*CC5*CC6 + YY6*m_6*CC4*CC5 - YY6*m_6*CC4*CC6 + YY6*m_6*CC5*CC6 - ZZ5*m_5*CC4*CC5 - ZZ6*m_6*CC4*CC5 - dd6*m_6*CC4*CC5 + 2*Iyz6*C4*C6*S4*S5 + XX6*m_6*CC4*CC5*CC6 - YY6*m_6*CC4*CC5*CC6 + 2*Ixz6*C4*S4*S5*S6 + 2*X5*a3*m_5*C4*C5 - 2*Y6*a3*m_6*C6*S4 + 2*Z5*a3*m_5*C4*S5 + 2*Z6*a3*m_6*C4*S5 - 2*X6*d4*m_6*C6*S5 + 2*a3*d6*m_6*C4*S5 - 2*X6*a3*m_6*S4*S6 + 2*Y6*d4*m_6*S5*S6 + 4*Ixy6*C4*C5*CC6*S4 - 2*Ixz6*CC4*C5*C6*S5 + 2*Iyz6*CC4*C5*S5*S6 + 2*Ixy6*CC4*CC5*C6*S6 - 2*Z6*d6*m_6*CC4*CC5 + 2*X6*a3*m_6*C4*C5*C6 - 2*X5*Y5*m_5*C4*C5*S4 + 2*X6*Y6*m_6*C4*C5*S4 - 2*X6*Z6*m_6*C5*C6*S5 - 2*Y6*a3*m_6*C4*C5*S6 - 2*X6*d6*m_6*C5*C6*S5 - 2*Y5*Z5*m_5*C4*S4*S5 + 2*Y6*Z6*m_6*C5*S5*S6 + 2*Y6*d6*m_6*C5*S5*S6 - 2*X6*Y6*m_6*CC4*C6*S6 + 2*X6*Y6*m_6*CC5*C6*S6 + 2*X5*Z5*m_5*CC4*C5*S5 + 2*Ixx6*C4*C5*C6*S4*S6 - 2*Iyy6*C4*C5*C6*S4*S6 - 2*X6*Z6*m_6*C4*S4*S5*S6 - 2*X6*d6*m_6*C4*S4*S5*S6 - 4*X6*Y6*m_6*C4*C5*CC6*S4 + 2*X6*Z6*m_6*CC4*C5*C6*S5 + 2*X6*d6*m_6*CC4*C5*C6*S5 - 2*Y6*Z6*m_6*CC4*C5*S5*S6 - 2*Y6*d6*m_6*CC4*C5*S5*S6 - 2*X6*Y6*m_6*CC4*CC5*C6*S6 - 2*XX6*m_6*C4*C5*C6*S4*S6 + 2*YY6*m_6*C4*C5*C6*S4*S6 - 2*Y6*Z6*m_6*C4*C6*S4*S5 - 2*Y6*d6*m_6*C4*C6*S4*S5;
inertiamatrix.array2d[2][3] = Iyz5*C4*C5 - Ixy4*S4 - Ixz5*S4 - Iyz4*C4 - Ixy5*C4*S5 + Ixy6*C4*S5 - Ixz6*C6*S4 + Iyz6*S4*S6 + 2*Ixz5*CC5*S4 + Iyz6*C4*C5*C6 + Ixz6*C4*C5*S6 - Ixx5*C5*S4*S5 - Iyy6*C5*S4*S5 + Izz5*C5*S4*S5 + Izz6*C5*S4*S5 + Y4*Z4*m_4*C4 - Y5*d4*m_5*C4 - Z4*d4*m_4*C4 + X4*Y4*m_4*S4 + X5*Z5*m_5*S4 - X4*d4*m_4*S4 - 2*Ixy6*C4*CC6*S5 + 2*Ixz6*CC5*C6*S4 - 2*Iyz6*CC5*S4*S6 - Ixx6*C4*C6*S5*S6 + Iyy6*C4*C6*S5*S6 + XX5*m_5*C5*S4*S5 + YY6*m_6*C5*S4*S5 - ZZ5*m_5*C5*S4*S5 - ZZ6*m_6*C5*S4*S5 - Y5*Z5*m_5*C4*C5 - dd6*m_6*C5*S4*S5 - Y6*d4*m_6*C4*C6 + X5*Y5*m_5*C4*S5 - X6*Y6*m_6*C4*S5 + X6*Z6*m_6*C6*S4 - X5*d4*m_5*C5*S4 - X6*d4*m_6*C4*S6 + X6*d6*m_6*C6*S4 - Y6*Z6*m_6*S4*S6 - Y6*d6*m_6*S4*S6 - Z5*d4*m_5*S4*S5 - Z6*d4*m_6*S4*S5 - d4*d6*m_6*S4*S5 - Ixx6*C5*CC6*S4*S5 + Iyy6*C5*CC6*S4*S5 - 2*X5*Z5*m_5*CC5*S4 - Y6*d6*m_6*C4*C5*C6 - X6*Z6*m_6*C4*C5*S6 - X6*d4*m_6*C5*C6*S4 - X6*d6*m_6*C4*C5*S6 + Y6*d4*m_6*C5*S4*S6 - 2*Z6*d6*m_6*C5*S4*S5 + XX6*m_6*C5*CC6*S4*S5 - YY6*m_6*C5*CC6*S4*S5 + 2*X6*Y6*m_6*C4*CC6*S5 - 2*X6*Z6*m_6*CC5*C6*S4 - 2*X6*d6*m_6*CC5*C6*S4 + 2*Y6*Z6*m_6*CC5*S4*S6 + 2*Y6*d6*m_6*CC5*S4*S6 + XX6*m_6*C4*C6*S5*S6 - YY6*m_6*C4*C6*S5*S6 - Y6*Z6*m_6*C4*C5*C6 + 2*Ixy6*C5*C6*S4*S5*S6 - 2*X6*Y6*m_6*C5*C6*S4*S5*S6;
inertiamatrix.array2d[2][4] =Ixx6*C4 + Iyy5*C4 + XX5*m_5*C4 + YY6*m_6*C4 + ZZ5*m_5*C4 + ZZ6*m_6*C4 + Ixy5*C5*S4 - Ixy6*C5*S4 + dd6*m_6*C4 + Iyz5*S4*S5 - Ixx6*C4*CC6 + Iyy6*C4*CC6 + 2*Ixy6*C4*C6*S6 + Iyz6*C6*S4*S5 + Ixz6*S4*S5*S6 + X5*a3*m_5*C5 + 2*Z6*d6*m_6*C4 + Z5*a3*m_5*S5 + Z6*a3*m_6*S5 + a3*d6*m_6*S5 + XX6*m_6*C4*CC6 - YY6*m_6*C4*CC6 + 2*Ixy6*C5*CC6*S4 + Ixx6*C5*C6*S4*S6 - Iyy6*C5*C6*S4*S6 + X6*a3*m_6*C5*C6 + Z5*d4*m_5*C4*C5 + Z6*d4*m_6*C4*C5 - X5*Y5*m_5*C5*S4 + X6*Y6*m_6*C5*S4 + d4*d6*m_6*C4*C5 - Y6*a3*m_6*C5*S6 - X5*d4*m_5*C4*S5 - Y5*Z5*m_5*S4*S5 - 2*X6*Y6*m_6*C4*C6*S6 - X6*d4*m_6*C4*C6*S5 - Y6*Z6*m_6*C6*S4*S5 + Y6*d4*m_6*C4*S5*S6 - Y6*d6*m_6*C6*S4*S5 - X6*Z6*m_6*S4*S5*S6 - X6*d6*m_6*S4*S5*S6 - 2*X6*Y6*m_6*C5*CC6*S4 - XX6*m_6*C5*C6*S4*S6 + YY6*m_6*C5*C6*S4*S6; 
inertiamatrix.array2d[2][5] =Iyz6*C4*C6 + Ixz6*C4*S6 + Izz6*S4*S5 + Ixz6*C5*C6*S4 - Iyz6*C5*S4*S6 + XX6*m_6*S4*S5 + YY6*m_6*S4*S5 - Y6*Z6*m_6*C4*C6 - Y6*d6*m_6*C4*C6 - X6*Z6*m_6*C4*S6 - Y6*a3*m_6*C6*S5 - X6*d4*m_6*C6*S4 - X6*d6*m_6*C4*S6 - X6*a3*m_6*S5*S6 + Y6*d4*m_6*S4*S6 - Y6*d4*m_6*C4*C5*C6 - X6*Z6*m_6*C5*C6*S4 - X6*d4*m_6*C4*C5*S6 - X6*d6*m_6*C5*C6*S4 + Y6*Z6*m_6*C5*S4*S6 + Y6*d6*m_6*C5*S4*S6; 
inertiamatrix.array2d[3][0]= inertiamatrix.array2d[0][3]; 
inertiamatrix.array2d[3][1] = inertiamatrix.array2d[1][3];
inertiamatrix.array2d[3][2] = inertiamatrix.array2d[2][3];
inertiamatrix.array2d[3][3] = Ixx5 + Iyy4 + Iyy6 + XX4*m_4 + XX6*m_6 + YY5*m_5 + ZZ4*m_4 + ZZ5*m_5 + ZZ6*m_6 + dd6*m_6 - Ixx5*CC5 + Ixx6*CC6 - Iyy6*CC5 - Iyy6*CC6 + Izz5*CC5 + Izz6*CC5 - Ixy6*S66 - Ixz5*S55 - Ixx6*CC5*CC6 + Iyy6*CC5*CC6 + 2*Z6*d6*m_6 + XX5*m_5*CC5 - XX6*m_6*CC6 + YY6*m_6*CC5 + YY6*m_6*CC6 - ZZ5*m_5*CC5 - ZZ6*m_6*CC5 - dd6*m_6*CC5 - 2*Ixz6*C5*C6*S5 + 2*Iyz6*C5*S5*S6 + 2*Ixy6*CC5*C6*S6 - 2*Z6*d6*m_6*CC5 + X6*Y6*m_6*S66 + X5*Z5*m_5*S55 + XX6*m_6*CC5*CC6 - YY6*m_6*CC5*CC6 + 2*X6*Z6*m_6*C5*C6*S5 + 2*X6*d6*m_6*C5*C6*S5 - 2*Y6*Z6*m_6*C5*S5*S6 - 2*Y6*d6*m_6*C5*S5*S6 - 2*X6*Y6*m_6*CC5*C6*S6;
inertiamatrix.array2d[3][4] = Iyz5*C5 - Ixy5*S5 + Ixy6*S5 + Iyz6*C5*C6 + Ixz6*C5*S6 - 2*Ixy6*CC6*S5 - Ixx6*C6*S5*S6 + Iyy6*C6*S5*S6 - Y5*Z5*m_5*C5 + X5*Y5*m_5*S5 - X6*Y6*m_6*S5 + XX6*m_6*C6*S5*S6 - YY6*m_6*C6*S5*S6 - Y6*Z6*m_6*C5*C6 - Y6*d6*m_6*C5*C6 - X6*Z6*m_6*C5*S6 - X6*d6*m_6*C5*S6 + 2*X6*Y6*m_6*CC6*S5;
inertiamatrix.array2d[3][5] = Izz6*C5 + XX6*m_6*C5 + YY6*m_6*C5 - Ixz6*C6*S5 + Iyz6*S5*S6 + X6*Z6*m_6*C6*S5 + X6*d6*m_6*C6*S5 - Y6*Z6*m_6*S5*S6 - Y6*d6*m_6*S5*S6; 
inertiamatrix.array2d[4][0] = inertiamatrix.array2d[0][4];
inertiamatrix.array2d[4][1] = inertiamatrix.array2d[1][4]; 
inertiamatrix.array2d[4][2] = inertiamatrix.array2d[2][4];
inertiamatrix.array2d[4][3] = inertiamatrix.array2d[3][4];
inertiamatrix.array2d[4][4] = Ixx6 + Iyy5 + XX5*m_5 + YY6*m_6 + ZZ5*m_5 + ZZ6*m_6 + dd6*m_6 - Ixx6*CC6 + Iyy6*CC6 + Ixy6*S66 + 2*Z6*d6*m_6 + XX6*m_6*CC6 - YY6*m_6*CC6 - X6*Y6*m_6*S66; 
inertiamatrix.array2d[4][5] = Iyz6*C6 + Ixz6*S6 - Y6*Z6*m_6*C6 - Y6*d6*m_6*C6 - X6*Z6*m_6*S6 - X6*d6*m_6*S6;
inertiamatrix.array2d[5][0] = inertiamatrix.array2d[0][5];
inertiamatrix.array2d[5][1] = inertiamatrix.array2d[1][5];
inertiamatrix.array2d[5][2] = inertiamatrix.array2d[2][5];  
inertiamatrix.array2d[5][3] = inertiamatrix.array2d[3][5];
inertiamatrix.array2d[5][4] = inertiamatrix.array2d[4][5];  
inertiamatrix.array2d[5][5] = m_6*XX6 + m_6*YY6 + Izz6;


 return inertiamatrix;
}
//---------------------------------------
static darray cal_coriolis(float *joint,float *dq)
{
darray coriolis;
float q1,q2,q3,q4,q5,q6,dq1,dq2,dq3,dq4,dq5,dq6;
float S1,S2,S3,S4,S5,S6,C1,C2,C3,C4,C5,C6;
float S22,S33,S44,S55,S66;
float dq11,dq12,dq13,dq14,dq15,dq16,dq22,dq23,dq24,dq25,dq26,dq33,dq34,dq35,dq36,dq44,dq45,dq46,dq55,dq56,dq66;
float XX2,XX3,XX4,XX5,XX6,YY2,YY3,YY4,YY5,YY6,ZZ1,ZZ2,ZZ3,ZZ4,ZZ5,ZZ6;
float CC2,CC3,CC4,CC5,CC6,aa2,aa3,dd4,dd6;
//-------------------------------------------------------------------
q1 = joint[0]*PM_PI/180;
q2 = joint[1]*PM_PI/180;
q3 = joint[2]*PM_PI/180;
q4 = joint[3]*PM_PI/180;
q5 = joint[4]*PM_PI/180;
q6 = joint[5]*PM_PI/180;
dq1 = dq[0];
dq2 = dq[1];
dq3 = dq[2];
dq4 = dq[3];
dq5 = dq[4];
dq6 = dq[5];
//-------------------------------------------------------------------
S1 = sin(q1);
S2 = sin(q2);
S3 = sin(q3);
S4 = sin(q4);
S5 = sin(q5);
S6 = sin(q6);
C1 = cos(q1);
C2 = cos(q2);
C3 = cos(q3);
C4 = cos(q4);
C5 = cos(q5);
C6 = cos(q6);
//-------------------------------------------------------
S22 = sin(2*q2);
S33 = sin(2*q3);
S44 = sin(2*q4);
S55 = sin(2*q5);
S66 = sin(2*q6);
//-------------------------------------------------------------------
CC2 = C2*C2;
CC3 = C3*C3;
CC4 = C4*C4;
CC5 = C5*C5;
CC6 = C6*C6;

dq11 = dq1*dq1;
dq22 = dq2*dq2;
dq33 = dq3*dq3;
dq44 = dq4*dq4;
dq55 = dq5*dq5;
dq66 = dq6*dq6;
dq12 = dq1*dq2;
dq13 = dq1*dq3;
dq14 = dq1*dq4;
dq15 = dq1*dq5;
dq16 = dq1*dq6;
dq23 = dq2*dq3;
dq24 = dq2*dq4;
dq25 = dq2*dq5;
dq26 = dq2*dq6;
dq34 = dq3*dq4;
dq35 = dq3*dq5;
dq36 = dq3*dq6;
dq45 = dq4*dq5;
dq46 = dq4*dq6;
dq56 = dq5*dq6;

//---------------------------------------------------------------------------------------------------------------
XX2 = X2*X2;
XX3 = X3*X3;
XX4 = X4*X4;
XX5 = X5*X5;
XX6 = X6*X6;
YY2 = Y2*Y2;
YY3 = Y3*Y3;
YY4 = Y4*Y4;
YY5 = Y5*Y5;
YY6 = Y6*Y6;
ZZ1 = Z1*Z1;
ZZ2 = Z2*Z2;
ZZ3 = Z3*Z3;
ZZ4 = Z4*Z4;
ZZ5 = Z5*Z5;
ZZ6 = Z6*Z6;

aa2 = a2*a2;
aa3 = a3*a3;
dd4 = d4*d4;
dd6 = d6*d6; 

coriolis.array2d[0][0] = Ixz2*dq22*C2 - Iyz2*dq22*S2 - 2*Ixy2*dq12 + 2*Ixy6*dq16 - 2*Ixz3*dq12 - 2*Ixz3*dq13 + 2*Ixz5*dq15 + Ixy3*dq22*C2*C3 + Ixy3*dq33*C2*C3 - Ixz4*dq22*C2*C3 - Ixz4*dq33*C2*C3 + Iyz3*dq22*C2*S3 + Iyz3*dq22*C3*S2 + Iyz3*dq33*C2*S3 + Iyz3*dq33*C3*S2 - Ixy3*dq22*S2*S3 - Ixy3*dq33*S2*S3 + Ixz4*dq22*S2*S3 + Ixz4*dq33*S2*S3 + 2*Ixy4*dq12*C4 + 2*Ixy4*dq13*C4 + 2*Ixz5*dq12*C4 + 2*Ixz5*dq13*C4 + 2*Ixz6*dq15*C6 - 2*Iyz4*dq12*S4 - 2*Iyz4*dq13*S4 - 2*Iyz6*dq15*S6 + 4*Ixy2*dq12*CC2 - 4*Ixy6*dq16*CC2 - 4*Ixy6*dq16*CC3 - 2*Ixy6*dq16*CC5 - 4*Ixy6*dq16*CC6 + 4*Ixz3*dq12*CC2 + 4*Ixz3*dq12*CC3 + 4*Ixz3*dq13*CC2 + 4*Ixz3*dq13*CC3 + 2*Ixz4*dq14*CC2 + 2*Ixz4*dq14*CC3 - 2*Ixz5*dq15*CC2 - 2*Ixz5*dq15*CC3 - 4*Ixz5*dq15*CC5 + Ixx2*dq12*S22 - Ixx3*dq12*S22 - Ixx3*dq12*S33 - Ixx3*dq13*S22 - Ixx3*dq13*S33 + Ixx5*dq12*S22 + Ixx5*dq12*S33 + Ixx5*dq13*S22 - Ixx6*dq12*S22 + Ixx5*dq13*S33 - Ixx6*dq12*S33 - Ixx6*dq13*S22 - Ixx6*dq13*S33 + Ixx5*dq15*S55 - Ixx6*dq16*S66 - Iyy2*dq12*S22 + Iyy4*dq12*S22 + Iyy4*dq12*S33 + Iyy4*dq13*S22 - Iyy5*dq12*S22 + Iyy4*dq13*S33 - Iyy5*dq12*S33 - Iyy5*dq13*S22 + Iyy6*dq12*S22 - Iyy5*dq13*S33 + Iyy6*dq12*S33 + Iyy6*dq13*S22 + Iyy6*dq13*S33 + Iyy6*dq15*S55 + Iyy6*dq16*S66 + Izz3*dq12*S22 + Izz3*dq12*S33 + Izz3*dq13*S22 - Izz4*dq12*S22 + Izz3*dq13*S33 - Izz4*dq12*S33 - Izz4*dq13*S22 - Izz4*dq13*S33 - Izz5*dq15*S55 - Izz6*dq15*S55 - Ixy4*dq22*C2*S3*S4 - Ixy4*dq22*C3*S2*S4 - Ixy4*dq33*C2*S3*S4 - Ixy4*dq33*C3*S2*S4 + Ixy4*dq44*C2*S3*S4 + Ixy4*dq44*C3*S2*S4 + Ixy5*dq22*C5*S2*S3 + Ixy5*dq33*C5*S2*S3 - Ixy6*dq22*C5*S2*S3 - Ixy6*dq33*C5*S2*S3 - Ixy5*dq55*C5*S2*S3 + Ixy6*dq55*C5*S2*S3 - Ixz5*dq22*C2*S3*S4 - Ixz5*dq22*C3*S2*S4 - Ixz5*dq33*C2*S3*S4 - Ixz5*dq33*C3*S2*S4 + Ixz5*dq44*C2*S3*S4 + Ixz5*dq44*C3*S2*S4 - X2*Z2*dq22*m_2*C2 + Iyz5*dq22*S2*S3*S5 + Iyz5*dq33*S2*S3*S5 - Iyz5*dq55*S2*S3*S5 + 2*Ixy3*dq23*C2*C3 - 2*Ixy6*dq46*C2*C3 - 2*Ixz4*dq23*C2*C3 - 2*Ixz5*dq45*C2*C3 + 2*Ixz6*dq12*C4*C6 + 2*Ixz6*dq13*C4*C6 - Y3*a2*dq22*m_3*C2 + Y5*a1*dq44*m_5*C4 - Z2*a2*dq22*m_2*C2 + Z4*a1*dq44*m_4*C4 + Y2*Z2*dq22*m_2*S2 - Ixx4*dq24*C2*S3 - Ixx4*dq24*C3*S2 - Ixx4*dq34*C2*S3 - Ixx4*dq34*C3*S2 + Ixx5*dq24*C2*S3 + Ixx5*dq24*C3*S2 + Ixx5*dq34*C2*S3 + Ixx5*dq34*C3*S2 + Ixx6*dq24*C2*S3 + Ixx6*dq24*C3*S2 + Ixx6*dq34*C2*S3 + Ixx6*dq34*C3*S2 + Iyy4*dq24*C2*S3 + Iyy4*dq24*C3*S2 + Iyy4*dq34*C2*S3 + Iyy4*dq34*C3*S2 + Iyy5*dq24*C2*S3 + Iyy5*dq24*C3*S2 + Iyy5*dq34*C2*S3 + Iyy5*dq34*C3*S2 + Iyy6*dq24*C2*S3 + Iyy6*dq24*C3*S2 + Iyy6*dq34*C2*S3 + Iyy6*dq34*C3*S2 + 2*Iyz3*dq23*C2*S3 + 2*Iyz3*dq23*C3*S2 + 2*Iyz5*dq12*C5*S4 + 2*Iyz5*dq13*C5*S4 - 2*Iyz6*dq12*C4*S6 - 2*Iyz6*dq13*C4*S6 + Izz4*dq24*C2*S3 + Izz4*dq24*C3*S2 + Izz4*dq34*C2*S3 + Izz4*dq34*C3*S2 - Izz5*dq24*C2*S3 - Izz5*dq24*C3*S2 - Izz5*dq34*C2*S3 - Izz5*dq34*C3*S2 - Izz6*dq24*C2*S3 - Izz6*dq24*C3*S2 - Izz6*dq34*C2*S3 - Izz6*dq34*C3*S2 + X4*a1*dq44*m_4*S4 - 2*Ixy3*dq23*S2*S3 - 2*Ixy5*dq12*S4*S5 - 2*Ixy5*dq13*S4*S5 + 2*Ixy6*dq12*S4*S5 + 2*Ixy6*dq13*S4*S5 + 2*Ixy6*dq46*S2*S3 + 2*Ixz4*dq23*S2*S3 + 2*Ixz5*dq45*S2*S3 + 2*X2*Y2*dq12*m_2 - 2*X6*Y6*dq16*m_6 + 2*X3*Z3*dq12*m_3 + 2*X3*Z3*dq13*m_3 - 2*X5*Z5*dq15*m_5 + 2*Ixz4*dq22*C2*C3*CC4 + 2*Ixz4*dq33*C2*C3*CC4 + 2*Y2*a2*dq12*m_2 - 2*Y4*a3*dq12*m_4 - 2*Y4*a3*dq13*m_4 + 2*Z3*a3*dq12*m_3 + 2*Z3*a3*dq13*m_3 + 2*a3*d4*dq12*m_4 + 2*a3*d4*dq12*m_5 + 2*a3*d4*dq13*m_4 + 2*a3*d4*dq12*m_6 + 2*a3*d4*dq13*m_5 + 2*a3*d4*dq13*m_6 - 2*Ixz4*dq22*CC4*S2*S3 - 2*Ixz4*dq33*CC4*S2*S3 - 4*Ixy4*dq12*CC2*C4 - 4*Ixy4*dq12*CC3*C4 - 4*Ixy4*dq13*CC2*C4 - 4*Ixy4*dq13*CC3*C4 + 2*Ixy5*dq14*CC2*C5 + 2*Ixy5*dq14*CC3*C5 - 2*Ixy6*dq14*CC2*C5 - 2*Ixy6*dq14*CC3*C5 - 4*Ixz5*dq12*CC2*C4 - 4*Ixz5*dq12*CC3*C4 - 4*Ixz5*dq13*CC2*C4 - 4*Ixz5*dq13*CC3*C4 - 4*Ixz5*dq12*C4*CC5 - 4*Ixz5*dq13*C4*CC5 - 2*Ixz6*dq15*CC2*C6 - 2*Ixz6*dq15*CC3*C6 - 4*Ixz6*dq15*CC5*C6 + 4*Iyz4*dq12*CC2*S4 + 4*Iyz4*dq12*CC3*S4 + 4*Iyz4*dq13*CC2*S4 + 4*Iyz4*dq13*CC3*S4 + 2*Iyz5*dq14*CC2*S5 + 2*Iyz5*dq14*CC3*S5 + 2*Iyz6*dq15*CC2*S6 + 2*Iyz6*dq15*CC3*S6 + 4*Iyz6*dq15*CC5*S6 - XX2*dq12*m_2*S22 + XX3*dq12*m_3*S22 + XX3*dq12*m_3*S33 + XX3*dq13*m_3*S22 + XX3*dq13*m_3*S33 - XX5*dq12*m_5*S22 - XX5*dq12*m_5*S33 - XX5*dq13*m_5*S22 - XX5*dq13*m_5*S33 + XX6*dq12*m_6*S22 + XX6*dq12*m_6*S33 + XX6*dq13*m_6*S22 + XX6*dq13*m_6*S33 - XX5*dq15*m_5*S55 + XX6*dq16*m_6*S66 + YY2*dq12*m_2*S22 - YY4*dq12*m_4*S22 - YY4*dq12*m_4*S33 - YY4*dq13*m_4*S22 - YY4*dq13*m_4*S33 + YY5*dq12*m_5*S22 + YY5*dq12*m_5*S33 + YY5*dq13*m_5*S22 + YY5*dq13*m_5*S33 - YY6*dq12*m_6*S22 - YY6*dq12*m_6*S33 - YY6*dq13*m_6*S22 - YY6*dq13*m_6*S33 - YY6*dq15*m_6*S55 - YY6*dq16*m_6*S66 - ZZ3*dq12*m_3*S22 - ZZ3*dq12*m_3*S33 - ZZ3*dq13*m_3*S22 - ZZ3*dq13*m_3*S33 + ZZ4*dq12*m_4*S22 + ZZ4*dq12*m_4*S33 + ZZ4*dq13*m_4*S22 + ZZ4*dq13*m_4*S33 + ZZ5*dq15*m_5*S55 + ZZ6*dq15*m_6*S55 - aa2*dq12*m_2*S22 - aa2*dq12*m_3*S22 - aa2*dq12*m_4*S22 + aa3*dq12*m_3*S22 - aa2*dq12*m_5*S22 + aa3*dq12*m_3*S33 + aa3*dq12*m_4*S22 + aa3*dq13*m_3*S22 - aa2*dq12*m_6*S22 + aa3*dq12*m_4*S33 + aa3*dq12*m_5*S22 + aa3*dq13*m_3*S33 + aa3*dq13*m_4*S22 + aa3*dq12*m_5*S33 + aa3*dq12*m_6*S22 + aa3*dq13*m_4*S33 + aa3*dq13*m_5*S22 + aa3*dq12*m_6*S33 + aa3*dq13*m_5*S33 + aa3*dq13*m_6*S22 + aa3*dq13*m_6*S33 - dd4*dq12*m_4*S22 - dd4*dq12*m_4*S33 - dd4*dq12*m_5*S22 - dd4*dq13*m_4*S22 - dd4*dq12*m_5*S33 - dd4*dq12*m_6*S22 - dd4*dq13*m_4*S33 - dd4*dq13*m_5*S22 - dd4*dq12*m_6*S33 - dd4*dq13*m_5*S33 - dd4*dq13*m_6*S22 - dd4*dq13*m_6*S33 + dd6*dq15*m_6*S55 + 8*Ixy6*dq16*CC2*CC3 + 2*Ixy6*dq16*CC2*CC4 + 2*Ixy6*dq16*CC2*CC5 + 2*Ixy6*dq16*CC3*CC4 + 8*Ixy6*dq16*CC2*CC6 + 2*Ixy6*dq16*CC3*CC5 + 8*Ixy6*dq16*CC3*CC6 + 4*Ixy6*dq16*CC5*CC6 - 8*Ixz3*dq12*CC2*CC3 - 8*Ixz3*dq13*CC2*CC3 - 4*Ixz4*dq14*CC2*CC3 - 4*Ixz4*dq14*CC2*CC4 - 4*Ixz4*dq14*CC3*CC4 + 4*Ixz5*dq15*CC2*CC3 - 2*Ixz5*dq15*CC2*CC4 + 4*Ixz5*dq15*CC2*CC5 - 2*Ixz5*dq15*CC3*CC4 + 4*Ixz5*dq15*CC3*CC5 - Ixy5*dq22*C2*C3*C5 - Ixy5*dq33*C2*C3*C5 + Ixy6*dq22*C2*C3*C5 + Ixy6*dq33*C2*C3*C5 + Ixy5*dq55*C2*C3*C5 - Ixy6*dq55*C2*C3*C5 - Iyz4*dq22*C2*C4*S3 - Iyz4*dq22*C3*C4*S2 - Iyz4*dq33*C2*C4*S3 - Iyz4*dq33*C3*C4*S2 + Iyz4*dq44*C2*C4*S3 + Iyz4*dq44*C3*C4*S2 - Iyz5*dq22*C2*C3*S5 - Iyz5*dq33*C2*C3*S5 + Iyz5*dq55*C2*C3*S5 - X4*a2*dq22*m_4*C2*S4 + X4*a2*dq44*m_4*C2*S4 + X5*a1*dq44*m_5*C5*S4 + X5*a1*dq55*m_5*C5*S4 + X6*a1*dq44*m_6*C4*S6 + X6*a1*dq66*m_6*C4*S6 + 2*XX4*dq24*m_4*C2*S3 + 2*XX4*dq24*m_4*C3*S2 + 2*XX4*dq34*m_4*C2*S3 + 2*XX4*dq34*m_4*C3*S2 + 2*ZZ5*dq24*m_5*C2*S3 + 2*ZZ5*dq24*m_5*C3*S2 + 2*ZZ5*dq34*m_5*C2*S3 + 2*ZZ5*dq34*m_5*C3*S2 + 2*ZZ6*dq24*m_6*C2*S3 + 2*ZZ6*dq24*m_6*C3*S2 + 2*ZZ6*dq34*m_6*C2*S3 + 2*ZZ6*dq34*m_6*C3*S2 + X3*Y3*dq22*m_3*S2*S3 + X3*Y3*dq33*m_3*S2*S3 - X4*Z4*dq22*m_4*S2*S3 - X4*Z4*dq33*m_4*S2*S3 - 4*Ixy6*dq16*CC2*CC3*CC4 - 4*Ixy6*dq16*CC2*CC3*CC5 - 16*Ixy6*dq16*CC2*CC3*CC6 + 2*Ixy6*dq16*CC2*CC4*CC5 - 4*Ixy6*dq16*CC2*CC4*CC6 + 2*Ixy6*dq16*CC3*CC4*CC5 - 4*Ixy6*dq16*CC2*CC5*CC6 - 4*Ixy6*dq16*CC3*CC4*CC6 - 4*Ixy6*dq16*CC3*CC5*CC6 + 8*Ixz4*dq14*CC2*CC3*CC4 + 4*Ixz5*dq15*CC2*CC3*CC4 - 8*Ixz5*dq15*CC2*CC3*CC5 + 4*Ixz5*dq15*CC2*CC4*CC5 + 4*Ixz5*dq15*CC3*CC4*CC5 + 2*Ixy4*dq14*C2*S2*S4 - 2*Ixy4*dq23*C2*S3*S4 - 2*Ixy4*dq23*C3*S2*S4 + 2*Ixy4*dq14*C3*S3*S4 + 2*Ixy5*dq23*C5*S2*S3 - 2*Ixy6*dq23*C5*S2*S3 + 2*Ixy6*dq56*C2*S3*S4 + 2*Ixy6*dq56*C3*S2*S4 + 2*Ixz5*dq14*C2*S2*S4 - 2*Ixz5*dq23*C2*S3*S4 - 2*Ixz5*dq23*C3*S2*S4 + 2*Ixz5*dq14*C3*S3*S4 + 2*Ixz6*dq12*C5*S4*S6 + 2*Ixz6*dq13*C5*S4*S6 + 2*Ixz6*dq45*C6*S2*S3 + 2*Ixz6*dq16*C5*S5*S6 + 2*dd6*dq24*m_6*C2*S3 + 2*dd6*dq24*m_6*C3*S2 + 2*dd6*dq34*m_6*C2*S3 + 2*dd6*dq34*m_6*C3*S2 + Y3*a3*dq22*m_3*S2*S3 + Y3*a3*dq33*m_3*S2*S3 + Z5*a1*dq44*m_5*S4*S5 + Z5*a1*dq55*m_5*S4*S5 + Z6*a1*dq44*m_6*S4*S5 + Z6*a1*dq55*m_6*S4*S5 - 2*X4*Y4*dq12*m_4*C4 - 2*X4*Y4*dq13*m_4*C4 - 2*X5*Z5*dq12*m_5*C4 - 2*X5*Z5*dq13*m_5*C4 - 2*X6*Z6*dq15*m_6*C6 + 2*Ixy5*dq22*C2*C3*CC4*C5 + 2*Ixy5*dq33*C2*C3*CC4*C5 - 2*Ixy6*dq22*C2*C3*CC4*C5 - 2*Ixy6*dq33*C2*C3*CC4*C5 - 2*Ixy6*dq22*C2*C3*C5*CC6 - 2*Ixy6*dq33*C2*C3*C5*CC6 + 2*Ixy6*dq55*C2*C3*C5*CC6 + a1*d6*dq44*m_6*S4*S5 + a1*d6*dq55*m_6*S4*S5 + Ixx5*dq25*S2*S3*S4 + Ixx5*dq35*S2*S3*S4 + Ixx6*dq25*S2*S3*S4 + Ixx6*dq35*S2*S3*S4 + Ixx6*dq56*S2*S3*S5 + Iyy5*dq25*S2*S3*S4 + Iyy5*dq35*S2*S3*S4 + Iyy6*dq25*S2*S3*S4 + Iyy6*dq35*S2*S3*S4 - Iyy6*dq56*S2*S3*S5 + 2*Iyz5*dq23*S2*S3*S5 - 2*Iyz6*dq45*S2*S3*S6 - Izz5*dq25*S2*S3*S4 - Izz5*dq35*S2*S3*S4 - Izz6*dq25*S2*S3*S4 - Izz6*dq35*S2*S3*S4 - Izz6*dq56*S2*S3*S5 - 2*Y2*a1*dq12*m_2*C2 + 2*Y4*a2*dq12*m_4*C3 - 2*Y5*a3*dq14*m_5*C4 - 2*Z3*a2*dq12*m_3*C3 - 2*Z4*a3*dq14*m_4*C4 + 2*Z5*a3*dq12*m_5*C5 + 2*Z5*a3*dq13*m_5*C5 + 2*Z6*a3*dq12*m_6*C5 + 2*Z6*a3*dq13*m_6*C5 + 2*X4*d4*dq12*m_4*C4 + 2*X4*d4*dq13*m_4*C4 - 2*X6*d6*dq15*m_6*C6 + 2*Y4*Z4*dq12*m_4*S4 + 2*Y4*Z4*dq13*m_4*S4 + 2*Y6*Z6*dq15*m_6*S6 + 2*Iyz5*dq22*C2*C3*CC4*S5 + 2*Iyz5*dq33*C2*C3*CC4*S5 - 2*a2*d4*dq12*m_4*C3 - 2*a2*d4*dq12*m_5*C3 - 2*a2*d4*dq12*m_6*C3 + 2*a3*d6*dq12*m_6*C5 + 2*a3*d6*dq13*m_6*C5 - 2*X2*a1*dq12*m_2*S2 + 2*X3*a2*dq12*m_3*S3 - 2*X4*a3*dq14*m_4*S4 - 2*X5*a3*dq12*m_5*S5 - 2*X5*a3*dq13*m_5*S5 - 2*Y5*d4*dq12*m_5*S4 - 2*Y5*d4*dq13*m_5*S4 + 2*Y6*d6*dq15*m_6*S6 - 2*Z4*d4*dq12*m_4*S4 - 2*Z4*d4*dq13*m_4*S4 - 2*a1*a2*dq12*m_2*S2 - 2*a1*a2*dq12*m_3*S2 - 2*a1*a2*dq12*m_4*S2 - 2*a1*a2*dq12*m_5*S2 - 2*a1*a2*dq12*m_6*S2 + 2*a2*a3*dq12*m_3*S3 + 2*a2*a3*dq12*m_4*S3 + 2*a2*a3*dq12*m_5*S3 + 2*a2*a3*dq12*m_6*S3 - 2*Ixy5*dq22*CC4*C5*S2*S3 - 2*Ixy5*dq33*CC4*C5*S2*S3 + 2*Ixy6*dq22*CC4*C5*S2*S3 + 2*Ixy6*dq33*CC4*C5*S2*S3 + 2*Ixy6*dq22*C5*CC6*S2*S3 + 2*Ixy6*dq33*C5*CC6*S2*S3 - 2*Ixy6*dq55*C5*CC6*S2*S3 + 2*Ixz5*dq22*C2*CC5*S3*S4 + 2*Ixz5*dq22*C3*CC5*S2*S4 + 2*Ixz5*dq33*C2*CC5*S3*S4 + 2*Ixz5*dq33*C3*CC5*S2*S4 - 2*Ixz5*dq44*C2*CC5*S3*S4 - 2*Ixz5*dq44*C3*CC5*S2*S4 - 2*Iyz5*dq22*CC4*S2*S3*S5 - 2*Iyz5*dq33*CC4*S2*S3*S5 + 2*Ixy6*dq46*C2*C3*CC5 + 4*Ixy6*dq46*C2*C3*CC6 + 4*Ixz4*dq23*C2*C3*CC4 - 4*Ixz6*dq12*CC2*C4*C6 - 4*Ixz6*dq12*CC3*C4*C6 - 4*Ixz6*dq13*CC2*C4*C6 - 4*Ixz6*dq13*CC3*C4*C6 + 4*Ixz5*dq45*C2*C3*CC5 - 4*Ixz6*dq12*C4*CC5*C6 - 4*Ixz6*dq13*C4*CC5*C6 + 4*Ixx3*dq12*C2*CC3*S2 + 4*Ixx3*dq12*CC2*C3*S3 + 4*Ixx3*dq13*C2*CC3*S2 + 4*Ixx3*dq13*CC2*C3*S3 - 2*Ixx4*dq12*C2*CC4*S2
 - 4*Ixx5*dq12*C2*CC3*S2 - 2*Ixx4*dq13*C2*CC4*S2 - 4*Ixx5*dq12*CC2*C3*S3 - 4*Ixx5*dq13*C2*CC3*S2 + 4*Ixx6*dq12*C2*CC3*S2 - 2*Ixx4*dq12*C3*CC4*S3 - 2*Ixx5*dq12*C2*CC5*S2 - 4*Ixx5*dq13*CC2*C3*S3 + 2*Ixx6*dq12*C2*CC4*S2 + 4*Ixx6*dq12*CC2*C3*S3 + 4*Ixx6*dq13*C2*CC3*S2 - 2*Ixx4*dq13*C3*CC4*S3 - 2*Ixx5*dq13*C2*CC5*S2 + 2*Ixx6*dq13*C2*CC4*S2 + 4*Ixx6*dq13*CC2*C3*S3 - 2*Ixx4*dq14*CC2*C4*S4 + 2*Ixx4*dq24*C2*CC4*S3 + 2*Ixx4*dq24*C3*CC4*S2 - 2*Ixx5*dq12*C3*CC5*S3 + 4*Ixx6*dq12*C2*CC6*S2 + 2*Ixx6*dq12*C3*CC4*S3 - 2*Ixx4*dq14*CC3*C4*S4 + 2*Ixx4*dq34*C2*CC4*S3 + 2*Ixx4*dq34*C3*CC4*S2 - 2*Ixx5*dq13*C3*CC5*S3 + 4*Ixx6*dq13*C2*CC6*S2 + 2*Ixx6*dq13*C3*CC4*S3 - 2*Ixx5*dq24*C2*CC5*S3 - 2*Ixx5*dq24*C3*CC5*S2 + 4*Ixx6*dq12*C3*CC6*S3 + 2*Ixx6*dq14*CC2*C4*S4 - 2*Ixx6*dq24*C2*CC4*S3 - 2*Ixx6*dq24*C3*CC4*S2 - 2*Ixx5*dq34*C2*CC5*S3 - 2*Ixx5*dq34*C3*CC5*S2 + 4*Ixx6*dq13*C3*CC6*S3 + 2*Ixx6*dq14*CC3*C4*S4 - 2*Ixx6*dq34*C2*CC4*S3 - 2*Ixx6*dq34*C3*CC4*S2 - 2*Ixx5*dq15*CC2*C5*S5 - 2*Ixx5*dq15*CC3*C5*S5 + 4*Ixx6*dq16*CC2*C6*S6 + 2*Ixx6*dq15*C5*CC6*S5 + 4*Ixx6*dq16*CC3*C6*S6 + 2*Ixx6*dq16*CC5*C6*S6 - 4*Iyy4*dq12*C2*CC3*S2 - 4*Iyy4*dq12*CC2*C3*S3 - 4*Iyy4*dq13*C2*CC3*S2 + 4*Iyy5*dq12*C2*CC3*S2 - 4*Iyy4*dq13*CC2*C3*S3 + 2*Iyy5*dq12*C2*CC4*S2 + 4*Iyy5*dq12*CC2*C3*S3 + 4*Iyy5*dq13*C2*CC3*S2 - 4*Iyy6*dq12*C2*CC3*S2 + 2*Iyy5*dq13*C2*CC4*S2 + 4*Iyy5*dq13*CC2*C3*S3 - 4*Iyy6*dq12*CC2*C3*S3 - 4*Iyy6*dq13*C2*CC3*S2 + 2*Iyy5*dq12*C3*CC4*S3 - 2*Iyy6*dq12*C2*CC5*S2 - 4*Iyy6*dq13*CC2*C3*S3 + 2*Iyy5*dq13*C3*CC4*S3 - 4*Iyy6*dq12*C2*CC6*S2 - 2*Iyy6*dq13*C2*CC5*S2 + 2*Iyy5*dq14*CC2*C4*S4 - 2*Iyy5*dq24*C2*CC4*S3 - 2*Iyy5*dq24*C3*CC4*S2 - 2*Iyy6*dq12*C3*CC5*S3 - 4*Iyy6*dq13*C2*CC6*S2 + 2*Iyy5*dq14*CC3*C4*S4 - 2*Iyy5*dq34*C2*CC4*S3 - 2*Iyy5*dq34*C3*CC4*S2 - 4*Iyy6*dq12*C3*CC6*S3 - 2*Iyy6*dq13*C3*CC5*S3 - 4*Iyy6*dq13*C3*CC6*S3 - 2*Iyy6*dq24*C2*CC5*S3 - 2*Iyy6*dq24*C3*CC5*S2 - 2*Iyy6*dq34*C2*CC5*S3 - 2*Iyy6*dq34*C3*CC5*S2 - 2*Iyy6*dq15*CC2*C5*S5 - 2*Iyy6*dq15*CC3*C5*S5 - 4*Iyy6*dq16*CC2*C6*S6 - 2*Iyy6*dq15*C5*CC6*S5 - 4*Iyy6*dq16*CC3*C6*S6 - 2*Iyy6*dq16*CC5*C6*S6 - 4*Iyz5*dq12*CC2*C5*S4 - 4*Iyz5*dq12*CC3*C5*S4 - 4*Iyz5*dq13*CC2*C5*S4 - 4*Iyz5*dq13*CC3*C5*S4 + 4*Iyz6*dq12*CC2*C4*S6 + 4*Iyz6*dq12*CC3*C4*S6 + 4*Iyz6*dq13*CC2*C4*S6 + 4*Iyz6*dq13*CC3*C4*S6 + 4*Iyz6*dq12*C4*CC5*S6 + 2*Iyz6*dq14*CC2*C6*S5 + 4*Iyz6*dq13*C4*CC5*S6 + 2*Iyz6*dq14*CC3*C6*S5 - 4*Izz3*dq12*C2*CC3*S2 - 4*Izz3*dq12*CC2*C3*S3 - 4*Izz3*dq13*C2*CC3*S2 + 4*Izz4*dq12*C2*CC3*S2 - 4*Izz3*dq13*CC2*C3*S3 + 2*Izz4*dq12*C2*CC4*S2 + 4*Izz4*dq12*CC2*C3*S3 + 4*Izz4*dq13*C2*CC3*S2 + 2*Izz4*dq13*C2*CC4*S2 + 4*Izz4*dq13*CC2*C3*S3 - 2*Izz5*dq12*C2*CC4*S2 + 2*Izz4*dq12*C3*CC4*S3 + 2*Izz5*dq12*C2*CC5*S2 - 2*Izz5*dq13*C2*CC4*S2 - 2*Izz6*dq12*C2*CC4*S2 + 2*Izz4*dq13*C3*CC4*S3 - 2*Izz5*dq12*C3*CC4*S3 + 2*Izz5*dq13*C2*CC5*S2 + 2*Izz6*dq12*C2*CC5*S2 - 2*Izz6*dq13*C2*CC4*S2 + 2*Izz4*dq14*CC2*C4*S4 - 2*Izz4*dq24*C2*CC4*S3 - 2*Izz4*dq24*C3*CC4*S2 + 2*Izz5*dq12*C3*CC5*S3 - 2*Izz5*dq13*C3*CC4*S3 - 2*Izz6*dq12*C3*CC4*S3 + 2*Izz6*dq13*C2*CC5*S2 + 2*Izz4*dq14*CC3*C4*S4 - 2*Izz4*dq34*C2*CC4*S3 - 2*Izz4*dq34*C3*CC4*S2 + 2*Izz5*dq13*C3*CC5*S3 - 2*Izz5*dq14*CC2*C4*S4 + 2*Izz5*dq24*C2*CC4*S3 + 2*Izz5*dq24*C3*CC4*S2 + 2*Izz6*dq12*C3*CC5*S3 - 2*Izz6*dq13*C3*CC4*S3 - 2*Izz5*dq14*CC3*C4*S4 + 2*Izz5*dq24*C2*CC5*S3 + 2*Izz5*dq24*C3*CC5*S2 + 2*Izz5*dq34*C2*CC4*S3 + 2*Izz5*dq34*C3*CC4*S2 + 2*Izz6*dq13*C3*CC5*S3 - 2*Izz6*dq14*CC2*C4*S4 + 2*Izz6*dq24*C2*CC4*S3 + 2*Izz6*dq24*C3*CC4*S2 + 2*Izz5*dq34*C2*CC5*S3 + 2*Izz5*dq34*C3*CC5*S2 - 2*Izz6*dq14*CC3*C4*S4 + 2*Izz6*dq24*C2*CC5*S3 + 2*Izz6*dq24*C3*CC5*S2 + 2*Izz6*dq34*C2*CC4*S3 + 2*Izz6*dq34*C3*CC4*S2 + 2*Izz5*dq15*CC2*C5*S5 + 2*Izz6*dq34*C2*CC5*S3 + 2*Izz6*dq34*C3*CC5*S2 + 2*Izz5*dq15*CC3*C5*S5 + 2*Izz6*dq15*CC2*C5*S5 + 2*Izz6*dq15*CC3*C5*S5 + 4*Ixy5*dq12*CC2*S4*S5 + 4*Ixy5*dq12*CC3*S4*S5 + 4*Ixy5*dq13*CC2*S4*S5 - 4*Ixy6*dq12*CC2*S4*S5 + 4*Ixy5*dq13*CC3*S4*S5 - 4*Ixy6*dq12*CC3*S4*S5 - 4*Ixy6*dq13*CC2*S4*S5 - 4*Ixy6*dq13*CC3*S4*S5 - 4*Ixy6*dq12*CC6*S4*S5 - 4*Ixy6*dq13*CC6*S4*S5 - 2*Ixy6*dq46*CC5*S2*S3 - 4*Ixy6*dq46*CC6*S2*S3 - 4*Ixz4*dq23*CC4*S2*S3 - 4*Ixz5*dq45*CC5*S2*S3 + 2*Ixz6*dq14*CC2*S5*S6 + 2*Ixz6*dq14*CC3*S5*S6 - 4*X2*Y2*dq12*m_2*CC2 + 4*X6*Y6*dq16*m_6*CC2 + 4*X6*Y6*dq16*m_6*CC3 + 2*X6*Y6*dq16*m_6*CC5 + 4*X6*Y6*dq16*m_6*CC6 - 4*X3*Z3*dq12*m_3*CC2 - 4*X3*Z3*dq12*m_3*CC3 - 4*X3*Z3*dq13*m_3*CC2 - 4*X3*Z3*dq13*m_3*CC3 - 2*X4*Z4*dq14*m_4*CC2 - 2*X4*Z4*dq14*m_4*CC3 + 2*X5*Z5*dq15*m_5*CC2 + 2*X5*Z5*dq15*m_5*CC3 + 4*X5*Z5*dq15*m_5*CC5 - 4*Y2*a2*dq12*m_2*CC2 + 4*Y4*a3*dq12*m_4*CC2 + 4*Y4*a3*dq12*m_4*CC3 + 4*Y4*a3*dq13*m_4*CC2 + 4*Y4*a3*dq13*m_4*CC3 - 4*Z3*a3*dq12*m_3*CC2 - 4*Z3*a3*dq12*m_3*CC3 - 4*Z3*a3*dq13*m_3*CC2 - 4*Z3*a3*dq13*m_3*CC3 - 4*a3*d4*dq12*m_4*CC2 - 4*a3*d4*dq12*m_4*CC3 - 4*a3*d4*dq12*m_5*CC2 - 4*a3*d4*dq13*m_4*CC2 - 4*a3*d4*dq12*m_5*CC3 - 4*a3*d4*dq12*m_6*CC2 - 4*a3*d4*dq13*m_4*CC3 - 4*a3*d4*dq13*m_5*CC2 - 4*a3*d4*dq12*m_6*CC3 - 4*a3*d4*dq13*m_5*CC3 - 4*a3*d4*dq13*m_6*CC2 - 4*a3*d4*dq13*m_6*CC3 - 2*X2*a2*dq12*m_2*S22 + 2*X3*a3*dq12*m_3*S22 + 2*X3*a3*dq12*m_3*S33 + 2*X3*a3*dq13*m_3*S22 + 2*X3*a3*dq13*m_3*S33 + 2*Y4*d4*dq12*m_4*S22 + 2*Y4*d4*dq12*m_4*S33 + 2*Y4*d4*dq13*m_4*S22 + 2*Y4*d4*dq13*m_4*S33 + 2*Z6*d6*dq15*m_6*S55 + 8*Ixy4*dq12*CC2*CC3*C4 + 8*Ixy4*dq13*CC2*CC3*C4 - 4*Ixy5*dq14*CC2*CC3*C5 - 4*Ixy5*dq14*CC2*CC4*C5 + 4*Ixy6*dq14*CC2*CC3*C5 - 4*Ixy5*dq14*CC3*CC4*C5 + 4*Ixy6*dq14*CC2*CC4*C5 + 4*Ixy6*dq14*CC3*CC4*C5 + 4*Ixy6*dq14*CC2*C5*CC6 + 4*Ixy6*dq14*CC3*C5*CC6 + 8*Ixz5*dq12*CC2*CC3*C4 + 8*Ixz5*dq13*CC2*CC3*C4 + 8*Ixz5*dq12*CC2*C4*CC5 + 8*Ixz5*dq12*CC3*C4*CC5 + 8*Ixz5*dq13*CC2*C4*CC5 + 8*Ixz5*dq13*CC3*C4*CC5 + 4*Ixz6*dq15*CC2*CC3*C6 - 2*Ixz6*dq15*CC2*CC4*C6 + 4*Ixz6*dq15*CC2*CC5*C6 - 2*Ixz6*dq15*CC3*CC4*C6 + 4*Ixz6*dq15*CC3*CC5*C6 - 8*Iyz4*dq12*CC2*CC3*S4 - 8*Iyz4*dq13*CC2*CC3*S4 - 4*Iyz5*dq14*CC2*CC3*S5 - 4*Iyz5*dq14*CC2*CC4*S5 - 4*Iyz5*dq14*CC3*CC4*S5 - 4*Iyz6*dq15*CC2*CC3*S6 + 2*Iyz6*dq15*CC2*CC4*S6 - 4*Iyz6*dq15*CC2*CC5*S6 + 2*Iyz6*dq15*CC3*CC4*S6 - 4*Iyz6*dq15*CC3*CC5*S6 + Ixx4*dq22*C2*C3*C4*S4 + Ixx4*dq33*C2*C3*C4*S4 - Ixx6*dq22*C2*C3*C4*S4 - Ixx6*dq33*C2*C3*C4*S4 - Iyy5*dq22*C2*C3*C4*S4 - Iyy5*dq33*C2*C3*C4*S4 + Iyz5*dq22*C2*C4*C5*S3 + Iyz5*dq22*C3*C4*C5*S2 + Iyz5*dq33*C2*C4*C5*S3 + Iyz5*dq33*C3*C4*C5*S2 - Iyz5*dq44*C2*C4*C5*S3 - Iyz5*dq44*C3*C4*C5*S2 + Iyz5*dq55*C2*C4*C5*S3 + Iyz5*dq55*C3*C4*C5*S2 - Iyz6*dq22*C2*C3*C6*S5 - Iyz6*dq33*C2*C3*C6*S5 + Iyz6*dq55*C2*C3*C6*S5 - Iyz6*dq66*C2*C3*C6*S5 - Izz4*dq22*C2*C3*C4*S4 - Izz4*dq33*C2*C3*C4*S4 + Izz5*dq22*C2*C3*C4*S4 + Izz5*dq33*C2*C3*C4*S4 + Izz6*dq22*C2*C3*C4*S4 + Izz6*dq33*C2*C3*C4*S4 - Ixy5*dq22*C2*C4*S3*S5 - Ixy5*dq22*C3*C4*S2*S5 - Ixy5*dq33*C2*C4*S3*S5 - Ixy5*dq33*C3*C4*S2*S5 + Ixy6*dq22*C2*C4*S3*S5 + Ixy6*dq22*C3*C4*S2*S5 + Ixy5*dq44*C2*C4*S3*S5 + Ixy5*dq44*C3*C4*S2*S5 + Ixy6*dq33*C2*C4*S3*S5 + Ixy6*dq33*C3*C4*S2*S5 - Ixy5*dq55*C2*C4*S3*S5 - Ixy5*dq55*C3*C4*S2*S5 - Ixy6*dq44*C2*C4*S3*S5 - Ixy6*dq44*C3*C4*S2*S5 + Ixy6*dq55*C2*C4*S3*S5 + Ixy6*dq55*C3*C4*S2*S5 - Ixz6*dq22*C2*C6*S3*S4 - Ixz6*dq22*C3*C6*S2*S4 - Ixz6*dq22*C2*C3*S5*S6 - Ixz6*dq33*C2*C6*S3*S4 - Ixz6*dq33*C3*C6*S2*S4 - Ixz6*dq33*C2*C3*S5*S6 + Ixz6*dq44*C2*C6*S3*S4 + Ixz6*dq44*C3*C6*S2*S4 + Ixz6*dq55*C2*C3*S5*S6 - Ixz6*dq66*C2*C6*S3*S4 - Ixz6*dq66*C3*C6*S2*S4 - Ixz6*dq66*C2*C3*S5*S6 - X3*Y3*dq22*m_3*C2*C3 - X3*Y3*dq33*m_3*C2*C3 + X4*Z4*dq22*m_4*C2*C3 + X4*Z4*dq33*m_4*C2*C3 - Ixx4*dq22*C4*S2*S3*S4 - Ixx4*dq33*C4*S2*S3*S4 + Ixx6*dq22*C4*S2*S3*S4 + Ixx6*dq33*C4*S2*S3*S4 + Iyy5*dq22*C4*S2*S3*S4 + Iyy5*dq33*C4*S2*S3*S4 + Iyz6*dq22*C2*S3*S4*S6 + Iyz6*dq22*C3*S2*S4*S6 + Iyz6*dq22*C6*S2*S3*S5 + Iyz6*dq33*C2*S3*S4*S6 + Iyz6*dq33*C3*S2*S4*S6 + Iyz6*dq33*C6*S2*S3*S5 - Iyz6*dq44*C2*S3*S4*S6 - Iyz6*dq44*C3*S2*S4*S6 - Iyz6*dq55*C6*S2*S3*S5 + Iyz6*dq66*C2*S3*S4*S6 + Iyz6*dq66*C3*S2*S4*S6 + Iyz6*dq66*C6*S2*S3*S5 + Izz4*dq22*C4*S2*S3*S4 + Izz4*dq33*C4*S2*S3*S4 - Izz5*dq22*C4*S2*S3*S4 - Izz5*dq33*C4*S2*S3*S4 - Izz6*dq22*C4*S2*S3*S4 - Izz6*dq33*C4*S2*S3*S4 - 2*Ixy5*dq23*C2*C3*C5 + 2*Ixy6*dq23*C2*C3*C5 - 2*Ixz6*dq45*C2*C3*C6 - Y3*a3*dq22*m_3*C2*C3 - Y3*a3*dq33*m_3*C2*C3 - Y5*a2*dq22*m_5*C2*C4 + Y5*a2*dq44*m_5*C2*C4 + Y6*a1*dq44*m_6*C4*C6 + Y6*a1*dq66*m_6*C4*C6 - Z4*a2*dq22*m_4*C2*C4 + Z4*a2*dq44*m_4*C2*C4 - Y3*Z3*dq22*m_3*C2*S3 - Y3*Z3*dq22*m_3*C3*S2 - Y3*Z3*dq33*m_3*C2*S3 - Y3*Z3*dq33*m_3*C3*S2 + Ixz6*dq22*S2*S3*S5*S6 + Ixz6*dq33*S2*S3*S5*S6 - Ixz6*dq55*S2*S3*S5*S6 + Ixz6*dq66*S2*S3*S5*S6 + 2*Ixx5*dq15*C2*C4*S2 + 2*Ixx5*dq15*C3*C4*S3 - Ixx5*dq25*C2*C3*S4 + 2*Ixx5*dq12*C4*C5*S5 - Ixx5*dq35*C2*C3*S4 - Ixx6*dq25*C2*C3*S4 + 2*Ixx5*dq13*C4*C5*S5 + Ixx5*dq45*C2*C4*S3 + Ixx5*dq45*C3*C4*S2 - Ixx6*dq35*C2*C3*S4 + Ixx6*dq26*C2*C5*S3 + Ixx6*dq26*C3*C5*S2 - Ixx6*dq45*C2*C4*S3 - Ixx6*dq45*C3*C4*S2 + Ixx6*dq36*C2*C5*S3 + Ixx6*dq36*C3*C5*S2 - Ixx6*dq56*C2*C3*S5 + 2*Iyy6*dq15*C2*C4*S2 - Iyy5*dq25*C2*C3*S4 - Iyy5*dq35*C2*C3*S4 + 2*Iyy6*dq15*C3*C4*S3 - Iyy6*dq25*C2*C3*S4 - Iyy5*dq45*C2*C4*S3 - Iyy5*dq45*C3*C4*S2 + 2*Iyy6*dq12*C4*C5*S5 - Iyy6*dq35*C2*C3*S4 + 2*Iyy6*dq13*C4*C5*S5 - Iyy6*dq26*C2*C5*S3 - Iyy6*dq26*C3*C5*S2 + Iyy6*dq45*C2*C4*S3 + Iyy6*dq45*C3*C4*S2 - Iyy6*dq36*C2*C5*S3 - Iyy6*dq36*C3*C5*S2 + Iyy6*dq56*C2*C3*S5 + 2*Iyz4*dq14*C2*C4*S2 - 2*Iyz4*dq23*C2*C4*S3 - 2*Iyz4*dq23*C3*C4*S2 + 2*Iyz4*dq14*C3*C4*S3 - 2*Iyz5*dq23*C2*C3*S5 + 2*Iyz6*dq12*C5*C6*S4 + 2*Iyz6*dq13*C5*C6*S4 + 2*Iyz6*dq45*C2*C3*S6 + 2*Iyz6*dq16*C5*C6*S5 - 2*Izz5*dq15*C2*C4*S2 - 2*Izz6*dq15*C2*C4*S2 - 2*Izz5*dq15*C3*C4*S3 + Izz5*dq25*C2*C3*S4 - 2*Izz5*dq12*C4*C5*S5 + Izz5*dq35*C2*C3*S4 - 2*Izz6*dq15*C3*C4*S3 + Izz6*dq25*C2*C3*S4 - 2*Izz5*dq13*C4*C5*S5 - Izz5*dq45*C2*C4*S3 - Izz5*dq45*C3*C4*S2 - 2*Izz6*dq12*C4*C5*S5 + Izz6*dq35*C2*C3*S4 - 2*Izz6*dq13*C4*C5*S5 + Izz6*dq26*C2*C5*S3 + Izz6*dq26*C3*C5*S2 - Izz6*dq45*C2*C4*S3 - Izz6*dq45*C3*C4*S2 + Izz6*dq36*C2*C5*S3 + Izz6*dq36*C3*C5*S2 + Izz6*dq56*C2*C3*S5 - 2*Y3*Z3*dq23*m_3*C2*S3 - 2*Y3*Z3*dq23*m_3*C3*S2 - 2*Y5*Z5*dq12*m_5*C5*S4 - 2*Y5*Z5*dq13*m_5*C5*S4 + 2*Y6*Z6*dq12*m_6*C4*S6 + 2*Y6*Z6*dq13*m_6*C4*S6 + Ixx5*dq22*C2*C3*C4*CC5*S4 + Ixx5*dq33*C2*C3*C4*CC5*S4 + Ixx6*dq22*C2*C3*C4*CC6*S4 +
 Ixx6*dq33*C2*C3*C4*CC6*S4 + Iyy6*dq22*C2*C3*C4*CC5*S4 - Iyy6*dq22*C2*C3*C4*CC6*S4 + Iyy6*dq33*C2*C3*C4*CC5*S4 - Iyy6*dq33*C2*C3*C4*CC6*S4 + 2*Iyz6*dq22*C2*C3*CC4*C6*S5 + 2*Iyz6*dq33*C2*C3*CC4*C6*S5 - Izz5*dq22*C2*C3*C4*CC5*S4 - Izz5*dq33*C2*C3*C4*CC5*S4 - Izz6*dq22*C2*C3*C4*CC5*S4 - Izz6*dq33*C2*C3*C4*CC5*S4 + 2*Ixz6*dq23*S2*S3*S5*S6 + 2*Ixz6*dq26*S2*S3*S4*S6 + 2*Ixz6*dq36*S2*S3*S4*S6 + 2*a1*d4*dq12*m_4*C2*C3 + 2*a1*d4*dq12*m_5*C2*C3 + 2*a1*d4*dq13*m_4*C2*C3 + 2*a1*d4*dq12*m_6*C2*C3 + 2*a1*d4*dq13*m_5*C2*C3 + 2*a1*d4*dq13*m_6*C2*C3 - 2*a2*d6*dq12*m_6*C3*C5 + 2*a3*d6*dq15*m_6*C4*C5 - 2*a1*d6*dq45*m_6*C4*C5 + 2*dd6*dq25*m_6*S2*S3*S4 + 2*dd6*dq35*m_6*S2*S3*S4 - 2*X3*a1*dq12*m_3*C2*S3 - 2*X3*a1*dq12*m_3*C3*S2 - 2*X3*a1*dq13*m_3*C2*S3 - 2*X3*a1*dq13*m_3*C3*S2 + 2*X4*a2*dq12*m_4*C4*S3 + 2*X5*a2*dq12*m_5*C3*S5 - 2*X5*a3*dq14*m_5*C5*S4 - 2*X5*a3*dq15*m_5*C4*S5 + 2*X5*a1*dq45*m_5*C4*S5 - 2*X6*a3*dq12*m_6*C6*S5 - 2*X6*a3*dq13*m_6*C6*S5 - 2*X6*a3*dq14*m_6*C4*S6 - 2*X6*a3*dq16*m_6*C6*S4 + 2*X6*a1*dq46*m_6*C6*S4 - 2*Y6*d4*dq12*m_6*C6*S4 - 2*Y6*d4*dq13*m_6*C6*S4 + 2*Y6*d6*dq12*m_6*C4*S6 + 2*Y6*d6*dq13*m_6*C4*S6 + 2*Z5*d4*dq12*m_5*C4*S5 + 2*Z5*d4*dq13*m_5*C4*S5 + 2*Z6*d4*dq12*m_6*C4*S5 + 2*Z6*d4*dq13*m_6*C4*S5 + 4*Z6*d6*dq24*m_6*C2*S3 + 4*Z6*d6*dq24*m_6*C3*S2 + 4*Z6*d6*dq34*m_6*C2*S3 + 4*Z6*d6*dq34*m_6*C3*S2 + 2*X3*Y3*dq23*m_3*S2*S3 + 2*X5*Y5*dq12*m_5*S4*S5 + 2*X5*Y5*dq13*m_5*S4*S5 - 2*X6*Y6*dq12*m_6*S4*S5 - 2*X6*Y6*dq13*m_6*S4*S5 - 2*X6*Y6*dq46*m_6*S2*S3 - 2*X4*Z4*dq23*m_4*S2*S3 - 2*X5*Z5*dq45*m_5*S2*S3 - 2*a1*a3*dq12*m_3*C2*S3 - 2*a1*a3*dq12*m_3*C3*S2 - 2*a1*a3*dq12*m_4*C2*S3 - 2*a1*a3*dq12*m_4*C3*S2 - 2*a1*a3*dq13*m_3*C2*S3 - 2*a1*a3*dq13*m_3*C3*S2 - 2*a1*a3*dq12*m_5*C2*S3 - 2*a1*a3*dq12*m_5*C3*S2 - 2*a1*a3*dq13*m_4*C2*S3 - 2*a1*a3*dq13*m_4*C3*S2 - 2*a1*a3*dq12*m_6*C2*S3 - 2*a1*a3*dq12*m_6*C3*S2 - 2*a1*a3*dq13*m_5*C2*S3 - 2*a1*a3*dq13*m_5*C3*S2 - 2*a1*a3*dq13*m_6*C2*S3 - 2*a1*a3*dq13*m_6*C3*S2 - 2*Ixy6*dq22*C2*C4*CC6*S3*S5 - 2*Ixy6*dq22*C3*C4*CC6*S2*S5 - 2*Ixy6*dq33*C2*C4*CC6*S3*S5 - 2*Ixy6*dq33*C3*C4*CC6*S2*S5 + 2*Ixy6*dq44*C2*C4*CC6*S3*S5 + 2*Ixy6*dq44*C3*C4*CC6*S2*S5 - 2*Ixy6*dq55*C2*C4*CC6*S3*S5 - 2*Ixy6*dq55*C3*C4*CC6*S2*S5 + 2*Ixz6*dq22*C2*C3*CC4*S5*S6 + 2*Ixz6*dq22*C2*CC5*C6*S3*S4 + 2*Ixz6*dq22*C3*CC5*C6*S2*S4 + 2*Ixz6*dq33*C2*C3*CC4*S5*S6 + 2*Ixz6*dq33*C2*CC5*C6*S3*S4 + 2*Ixz6*dq33*C3*CC5*C6*S2*S4 - 2*Ixz6*dq44*C2*CC5*C6*S3*S4 - 2*Ixz6*dq44*C3*CC5*C6*S2*S4 + 2*d4*d6*dq12*m_6*C4*S5 + 2*d4*d6*dq13*m_6*C4*S5 + 2*Y4*a1*dq12*m_4*S2*S3 + 2*Y4*a1*dq13*m_4*S2*S3 + 2*Y3*a3*dq23*m_3*S2*S3 - 2*Y5*a2*dq12*m_5*S3*S4 + 2*Y6*a3*dq12*m_6*S5*S6 + 2*Y6*a3*dq13*m_6*S5*S6 + 2*Y6*a3*dq16*m_6*S4*S6 - 2*Y6*a1*dq46*m_6*S4*S6 - 2*Z3*a1*dq12*m_3*S2*S3 - 2*Z3*a1*dq13*m_3*S2*S3 - 2*Z4*a2*dq12*m_4*S3*S4 - 2*Z5*a3*dq14*m_5*S4*S5 - 2*Z6*a3*dq14*m_6*S4*S5 - 2*X6*d4*dq12*m_6*S4*S6 - 2*X6*d4*dq13*m_6*S4*S6 - 2*X4*Z4*dq22*m_4*C2*C3*CC4 - 2*X4*Z4*dq33*m_4*C2*C3*CC4 - Ixx5*dq22*C4*CC5*S2*S3*S4 - Ixx5*dq33*C4*CC5*S2*S3*S4 - Ixx6*dq22*C4*CC6*S2*S3*S4 - Ixx6*dq33*C4*CC6*S2*S3*S4 - Iyy6*dq22*C4*CC5*S2*S3*S4 + Iyy6*dq22*C4*CC6*S2*S3*S4 - Iyy6*dq33*C4*CC5*S2*S3*S4 + Iyy6*dq33*C4*CC6*S2*S3*S4 - 2*Iyz6*dq22*C2*CC5*S3*S4*S6 - 2*Iyz6*dq22*C3*CC5*S2*S4*S6 - 2*Iyz6*dq22*CC4*C6*S2*S3*S5 - 2*Iyz6*dq33*C2*CC5*S3*S4*S6 - 2*Iyz6*dq33*C3*CC5*S2*S4*S6 - 2*Iyz6*dq33*CC4*C6*S2*S3*S5 + 2*Iyz6*dq44*C2*CC5*S3*S4*S6 + 2*Iyz6*dq44*C3*CC5*S2*S4*S6 + Izz5*dq22*C4*CC5*S2*S3*S4 + Izz5*dq33*C4*CC5*S2*S3*S4 + Izz6*dq22*C4*CC5*S2*S3*S4 + Izz6*dq33*C4*CC5*S2*S3*S4 + 4*Ixy5*dq23*C2*C3*CC4*C5 - 4*Ixy6*dq23*C2*C3*CC4*C5 - 4*Ixy6*dq23*C2*C3*C5*CC6 + 4*Ixz6*dq45*C2*C3*CC5*C6 - 2*a1*d4*dq12*m_4*S2*S3 - 2*a1*d4*dq12*m_5*S2*S3 - 2*a1*d4*dq13*m_4*S2*S3 - 2*a1*d4*dq12*m_6*S2*S3 - 2*a1*d4*dq13*m_5*S2*S3 - 2*a1*d4*dq13*m_6*S2*S3 - 2*a3*d6*dq14*m_6*S4*S5 - 2*Ixz6*dq22*CC4*S2*S3*S5*S6 - 2*Ixz6*dq33*CC4*S2*S3*S5*S6 - 4*Ixx5*dq15*C2*CC3*C4*S2 - 4*Ixx5*dq15*CC2*C3*C4*S3 - 4*Ixx5*dq12*CC2*C4*C5*S5 - 4*Ixx5*dq15*C2*C4*CC5*S2 - 4*Ixx5*dq12*CC3*C4*C5*S5 - 4*Ixx5*dq13*CC2*C4*C5*S5 - 4*Ixx5*dq13*CC3*C4*C5*S5 - 4*Ixx5*dq15*C3*C4*CC5*S3 + 2*Ixx5*dq25*C2*C3*CC5*S4 + 2*Ixx6*dq15*C2*C4*CC6*S2 + 2*Ixx5*dq35*C2*C3*CC5*S4 - 2*Ixx5*dq45*C2*C4*CC5*S3 - 2*Ixx5*dq45*C3*C4*CC5*S2 + 2*Ixx6*dq15*C3*C4*CC6*S3 + 2*Ixx6*dq16*CC2*C4*C5*S4 - 2*Ixx6*dq26*C2*CC4*C5*S3 - 2*Ixx6*dq26*C3*CC4*C5*S2 + 2*Ixx6*dq12*C4*C5*CC6*S5 + 2*Ixx6*dq16*CC3*C4*C5*S4 - 2*Ixx6*dq36*C2*CC4*C5*S3 - 2*Ixx6*dq36*C3*CC4*C5*S2 + 2*Ixx6*dq13*C4*C5*CC6*S5 + 2*Ixx6*dq14*CC2*C5*C6*S6 - 2*Ixx6*dq26*C2*C5*CC6*S3 - 2*Ixx6*dq26*C3*C5*CC6*S2 + 2*Ixx6*dq45*C2*C4*CC6*S3 + 2*Ixx6*dq45*C3*C4*CC6*S2 + 2*Ixx6*dq14*CC3*C5*C6*S6 - 2*Ixx6*dq36*C2*C5*CC6*S3 - 2*Ixx6*dq36*C3*C5*CC6*S2 + 2*Ixx6*dq56*C2*C3*CC6*S5 - 4*Iyy6*dq15*C2*CC3*C4*S2 - 4*Iyy6*dq15*CC2*C3*C4*S3 - 4*Iyy6*dq12*CC2*C4*C5*S5 - 4*Iyy6*dq15*C2*C4*CC5*S2 - 4*Iyy6*dq12*CC3*C4*C5*S5 - 4*Iyy6*dq13*CC2*C4*C5*S5 - 2*Iyy6*dq15*C2*C4*CC6*S2 - 4*Iyy6*dq13*CC3*C4*C5*S5 - 4*Iyy6*dq15*C3*C4*CC5*S3 + 2*Iyy6*dq25*C2*C3*CC5*S4 - 2*Iyy6*dq15*C3*C4*CC6*S3 - 2*Iyy6*dq16*CC2*C4*C5*S4 + 2*Iyy6*dq26*C2*CC4*C5*S3 + 2*Iyy6*dq26*C3*CC4*C5*S2 + 2*Iyy6*dq35*C2*C3*CC5*S4 - 2*Iyy6*dq12*C4*C5*CC6*S5 - 2*Iyy6*dq16*CC3*C4*C5*S4 + 2*Iyy6*dq36*C2*CC4*C5*S3 + 2*Iyy6*dq36*C3*CC4*C5*S2 - 2*Iyy6*dq45*C2*C4*CC5*S3 - 2*Iyy6*dq45*C3*C4*CC5*S2 - 2*Iyy6*dq13*C4*C5*CC6*S5 - 2*Iyy6*dq14*CC2*C5*C6*S6 + 2*Iyy6*dq26*C2*C5*CC6*S3 + 2*Iyy6*dq26*C3*C5*CC6*S2 - 2*Iyy6*dq45*C2*C4*CC6*S3 - 2*Iyy6*dq45*C3*C4*CC6*S2 - 2*Iyy6*dq14*CC3*C5*C6*S6 + 2*Iyy6*dq36*C2*C5*CC6*S3 + 2*Iyy6*dq36*C3*C5*CC6*S2 - 2*Iyy6*dq56*C2*C3*CC6*S5 - 4*Iyz4*dq14*C2*CC3*C4*S2 - 4*Iyz4*dq14*CC2*C3*C4*S3 + 4*Iyz5*dq23*C2*C3*CC4*S5 - 2*Iyz5*dq15*CC2*C4*C5*S4 + 2*Iyz5*dq25*C2*CC4*C5*S3 + 2*Iyz5*dq25*C3*CC4*C5*S2 - 4*Iyz6*dq12*CC2*C5*C6*S4 - 2*Iyz5*dq15*CC3*C4*C5*S4 + 2*Iyz5*dq35*C2*CC4*C5*S3 + 2*Iyz5*dq35*C3*CC4*C5*S2 - 4*Iyz6*dq12*CC3*C5*C6*S4 - 4*Iyz6*dq13*CC2*C5*C6*S4 - 4*Iyz6*dq13*CC3*C5*C6*S4 - 2*Iyz6*dq16*CC2*C5*C6*S5 - 4*Iyz6*dq45*C2*C3*CC5*S6 - 2*Iyz6*dq16*CC3*C5*C6*S5 + 4*Izz5*dq15*C2*CC3*C4*S2 + 4*Izz5*dq15*CC2*C3*C4*S3 + 4*Izz6*dq15*C2*CC3*C4*S2 + 4*Izz5*dq12*CC2*C4*C5*S5 + 4*Izz5*dq15*C2*C4*CC5*S2 + 4*Izz6*dq15*CC2*C3*C4*S3 + 4*Izz5*dq12*CC3*C4*C5*S5 + 4*Izz5*dq13*CC2*C4*C5*S5 + 4*Izz6*dq12*CC2*C4*C5*S5 + 4*Izz6*dq15*C2*C4*CC5*S2 + 4*Izz5*dq13*CC3*C4*C5*S5 + 4*Izz5*dq15*C3*C4*CC5*S3 - 2*Izz5*dq25*C2*C3*CC5*S4 + 4*Izz6*dq12*CC3*C4*C5*S5 + 4*Izz6*dq13*CC2*C4*C5*S5 - 2*Izz5*dq35*C2*C3*CC5*S4 + 4*Izz6*dq13*CC3*C4*C5*S5 + 4*Izz6*dq15*C3*C4*CC5*S3 - 2*Izz6*dq25*C2*C3*CC5*S4 + 2*Izz5*dq45*C2*C4*CC5*S3 + 2*Izz5*dq45*C3*C4*CC5*S2 - 2*Izz6*dq35*C2*C3*CC5*S4 + 2*Izz6*dq45*C2*C4*CC5*S3 + 2*Izz6*dq45*C3*C4*CC5*S2 - 4*XX3*dq12*m_3*C2*CC3*S2 - 4*XX3*dq12*m_3*CC2*C3*S3 - 4*XX3*dq13*m_3*C2*CC3*S2 - 4*XX3*dq13*m_3*CC2*C3*S3 + 2*XX4*dq12*m_4*C2*CC4*S2 + 2*XX4*dq13*m_4*C2*CC4*S2 + 4*XX5*dq12*m_5*C2*CC3*S2 + 2*XX4*dq12*m_4*C3*CC4*S3 + 4*XX5*dq12*m_5*CC2*C3*S3 + 4*XX5*dq13*m_5*C2*CC3*S2 + 2*XX4*dq13*m_4*C3*CC4*S3 + 2*XX5*dq12*m_5*C2*CC5*S2 + 4*XX5*dq13*m_5*CC2*C3*S3 - 4*XX6*dq12*m_6*C2*CC3*S2 + 2*XX4*dq14*m_4*CC2*C4*S4 - 2*XX4*dq24*m_4*C2*CC4*S3 - 2*XX4*dq24*m_4*C3*CC4*S2 + 2*XX5*dq13*m_5*C2*CC5*S2 - 2*XX6*dq12*m_6*C2*CC4*S2 - 4*XX6*dq12*m_6*CC2*C3*S3 - 4*XX6*dq13*m_6*C2*CC3*S2 + 2*XX4*dq14*m_4*CC3*C4*S4 - 2*XX4*dq34*m_4*C2*CC4*S3 - 2*XX4*dq34*m_4*C3*CC4*S2 + 2*XX5*dq12*m_5*C3*CC5*S3 - 2*XX6*dq13*m_6*C2*CC4*S2 - 4*XX6*dq13*m_6*CC2*C3*S3 + 2*XX5*dq13*m_5*C3*CC5*S3 - 4*XX6*dq12*m_6*C2*CC6*S2 - 2*XX6*dq12*m_6*C3*CC4*S3 + 2*XX5*dq24*m_5*C2*CC5*S3 + 2*XX5*dq24*m_5*C3*CC5*S2 - 4*XX6*dq13*m_6*C2*CC6*S2 - 2*XX6*dq13*m_6*C3*CC4*S3 + 2*XX5*dq34*m_5*C2*CC5*S3 + 2*XX5*dq34*m_5*C3*CC5*S2 - 4*XX6*dq12*m_6*C3*CC6*S3 - 2*XX6*dq14*m_6*CC2*C4*S4 + 2*XX6*dq24*m_6*C2*CC4*S3 + 2*XX6*dq24*m_6*C3*CC4*S2 + 2*XX5*dq15*m_5*CC2*C5*S5 - 4*XX6*dq13*m_6*C3*CC6*S3 - 2*XX6*dq14*m_6*CC3*C4*S4 + 2*XX6*dq34*m_6*C2*CC4*S3 + 2*XX6*dq34*m_6*C3*CC4*S2 + 2*XX5*dq15*m_5*CC3*C5*S5 - 4*XX6*dq16*m_6*CC2*C6*S6 - 2*XX6*dq15*m_6*C5*CC6*S5 - 4*XX6*dq16*m_6*CC3*C6*S6 - 2*XX6*dq16*m_6*CC5*C6*S6 + 4*YY4*dq12*m_4*C2*CC3*S2 + 4*YY4*dq12*m_4*CC2*C3*S3 + 4*YY4*dq13*m_4*C2*CC3*S2 + 4*YY4*dq13*m_4*CC2*C3*S3 - 4*YY5*dq12*m_5*C2*CC3*S2 - 2*YY5*dq12*m_5*C2*CC4*S2 - 4*YY5*dq12*m_5*CC2*C3*S3 - 4*YY5*dq13*m_5*C2*CC3*S2 - 2*YY5*dq13*m_5*C2*CC4*S2 - 4*YY5*dq13*m_5*CC2*C3*S3 + 4*YY6*dq12*m_6*C2*CC3*S2 - 2*YY5*dq12*m_5*C3*CC4*S3 + 4*YY6*dq12*m_6*CC2*C3*S3 + 4*YY6*dq13*m_6*C2*CC3*S2 - 2*YY5*dq13*m_5*C3*CC4*S3 + 2*YY6*dq12*m_6*C2*CC5*S2 + 4*YY6*dq13*m_6*CC2*C3*S3 - 2*YY5*dq14*m_5*CC2*C4*S4 + 2*YY5*dq24*m_5*C2*CC4*S3 + 2*YY5*dq24*m_5*C3*CC4*S2 + 4*YY6*dq12*m_6*C2*CC6*S2 + 2*YY6*dq13*m_6*C2*CC5*S2 - 2*YY5*dq14*m_5*CC3*C4*S4 + 2*YY5*dq34*m_5*C2*CC4*S3 + 2*YY5*dq34*m_5*C3*CC4*S2 + 2*YY6*dq12*m_6*C3*CC5*S3 + 4*YY6*dq13*m_6*C2*CC6*S2 + 4*YY6*dq12*m_6*C3*CC6*S3 + 2*YY6*dq13*m_6*C3*CC5*S3 + 4*YY6*dq13*m_6*C3*CC6*S3 + 2*YY6*dq24*m_6*C2*CC5*S3 + 2*YY6*dq24*m_6*C3*CC5*S2 + 2*YY6*dq34*m_6*C2*CC5*S3 + 2*YY6*dq34*m_6*C3*CC5*S2 + 2*YY6*dq15*m_6*CC2*C5*S5 + 2*YY6*dq15*m_6*CC3*C5*S5 + 4*YY6*dq16*m_6*CC2*C6*S6 + 2*YY6*dq15*m_6*C5*CC6*S5 + 4*YY6*dq16*m_6*CC3*C6*S6 + 2*YY6*dq16*m_6*CC5*C6*S6 + 4*ZZ3*dq12*m_3*C2*CC3*S2 + 4*ZZ3*dq12*m_3*CC2*C3*S3 + 4*ZZ3*dq13*m_3*C2*CC3*S2 + 4*ZZ3*dq13*m_3*CC2*C3*S3 - 4*ZZ4*dq12*m_4*C2*CC3*S2 - 2*ZZ4*dq12*m_4*C2*CC4*S2 - 4*ZZ4*dq12*m_4*CC2*C3*S3 - 4*ZZ4*dq13*m_4*C2*CC3*S2 - 2*ZZ4*dq13*m_4*C2*CC4*S2 - 4*ZZ4*dq13*m_4*CC2*C3*S3 - 2*ZZ4*dq12*m_4*C3*CC4*S3 + 2*ZZ5*dq12*m_5*C2*CC4*S2 - 2*ZZ4*dq13*m_4*C3*CC4*S3 - 2*ZZ5*dq12*m_5*C2*CC5*S2 + 2*ZZ5*dq13*m_5*C2*CC4*S2 - 2*ZZ4*dq14*m_4*CC2*C4*S4 + 2*ZZ4*dq24*m_4*C2*CC4*S3 + 2*ZZ4*dq24*m_4*C3*CC4*S2 + 2*ZZ5*dq12*m_5*C3*CC4*S3 - 2*ZZ5*dq13*m_5*C2*CC5*S2 + 2*ZZ6*dq12*m_6*C2*CC4*S2 - 2*ZZ4*dq14*m_4*CC3*C4*S4 + 2*ZZ4*dq34*m_4*C2*CC4*S3 + 2*ZZ4*dq34*m_4*C3*CC4*S2 - 2*ZZ5*dq12*m_5*C3*CC5*S3 + 2*ZZ5*dq13*m_5*C3*CC4*S3 - 2*ZZ6*dq12*m_6*C2*CC5*S2 + 2*ZZ6*dq13*m_6*C2*CC4*S2 - 2*ZZ5*dq13*m_5*C3*CC5*S3 + 2*ZZ5*dq14*m_5*CC2*C4*S4 - 2*ZZ5*dq24*m_5*C2*CC4*S3 - 2*ZZ5*dq24*m_5*C3*CC4*S2 + 2*ZZ6*dq12*m_6*C3*CC4*S3 - 2*ZZ6*dq13*m_6*C2*CC5*S2 +
 2*ZZ5*dq14*m_5*CC3*C4*S4 - 2*ZZ5*dq24*m_5*C2*CC5*S3 - 2*ZZ5*dq24*m_5*C3*CC5*S2 - 2*ZZ5*dq34*m_5*C2*CC4*S3 - 2*ZZ5*dq34*m_5*C3*CC4*S2 - 2*ZZ6*dq12*m_6*C3*CC5*S3 + 2*ZZ6*dq13*m_6*C3*CC4*S3 - 2*ZZ5*dq34*m_5*C2*CC5*S3 - 2*ZZ5*dq34*m_5*C3*CC5*S2 - 2*ZZ6*dq13*m_6*C3*CC5*S3 + 2*ZZ6*dq14*m_6*CC2*C4*S4 - 2*ZZ6*dq24*m_6*C2*CC4*S3 - 2*ZZ6*dq24*m_6*C3*CC4*S2 - 2*ZZ5*dq15*m_5*CC2*C5*S5 + 2*ZZ6*dq14*m_6*CC3*C4*S4 - 2*ZZ6*dq24*m_6*C2*CC5*S3 - 2*ZZ6*dq24*m_6*C3*CC5*S2 - 2*ZZ6*dq34*m_6*C2*CC4*S3 - 2*ZZ6*dq34*m_6*C3*CC4*S2 - 2*ZZ5*dq15*m_5*CC3*C5*S5 - 2*ZZ6*dq34*m_6*C2*CC5*S3 - 2*ZZ6*dq34*m_6*C3*CC5*S2 - 2*ZZ6*dq15*m_6*CC2*C5*S5 - 2*ZZ6*dq15*m_6*CC3*C5*S5 + 2*X4*Z4*dq22*m_4*CC4*S2*S3 + 2*X4*Z4*dq33*m_4*CC4*S2*S3 - 4*Ixy6*dq16*CC2*CC3*CC4*CC5 + 8*Ixy6*dq16*CC2*CC3*CC4*CC6 + 8*Ixy6*dq16*CC2*CC3*CC5*CC6 - 4*Ixy6*dq16*CC2*CC4*CC5*CC6 - 4*Ixy6*dq16*CC3*CC4*CC5*CC6 - 8*Ixz5*dq15*CC2*CC3*CC4*CC5 - 4*aa3*dq12*m_3*C2*CC3*S2 - 4*aa3*dq12*m_3*CC2*C3*S3 - 4*aa3*dq12*m_4*C2*CC3*S2 - 4*aa3*dq13*m_3*C2*CC3*S2 - 4*aa3*dq12*m_4*CC2*C3*S3 - 4*aa3*dq12*m_5*C2*CC3*S2 - 4*aa3*dq13*m_3*CC2*C3*S3 - 4*aa3*dq13*m_4*C2*CC3*S2 - 4*aa3*dq12*m_5*CC2*C3*S3 - 4*aa3*dq12*m_6*C2*CC3*S2 - 4*aa3*dq13*m_4*CC2*C3*S3 - 4*aa3*dq13*m_5*C2*CC3*S2 - 4*aa3*dq12*m_6*CC2*C3*S3 - 4*aa3*dq13*m_5*CC2*C3*S3 - 4*aa3*dq13*m_6*C2*CC3*S2 - 4*aa3*dq13*m_6*CC2*C3*S3 - 4*Ixy4*dq14*C2*CC3*S2*S4 - 4*Ixy4*dq14*CC2*C3*S3*S4 - 4*Ixy5*dq23*CC4*C5*S2*S3 + 4*Ixy6*dq23*CC4*C5*S2*S3 + 2*Ixy5*dq15*CC2*C4*S4*S5 - 2*Ixy5*dq25*C2*CC4*S3*S5 - 2*Ixy5*dq25*C3*CC4*S2*S5 + 2*Ixy5*dq15*CC3*C4*S4*S5 - 2*Ixy5*dq35*C2*CC4*S3*S5 - 2*Ixy5*dq35*C3*CC4*S2*S5 - 2*Ixy6*dq15*CC2*C4*S4*S5 + 4*Ixy6*dq23*C5*CC6*S2*S3 + 2*Ixy6*dq25*C2*CC4*S3*S5 + 2*Ixy6*dq25*C3*CC4*S2*S5 - 2*Ixy6*dq15*CC3*C4*S4*S5 + 2*Ixy6*dq35*C2*CC4*S3*S5 + 2*Ixy6*dq35*C3*CC4*S2*S5 - 4*Ixy6*dq56*C2*CC6*S3*S4 - 4*Ixy6*dq56*C3*CC6*S2*S4 - 4*Ixz5*dq14*C2*CC3*S2*S4 - 4*Ixz5*dq14*CC2*C3*S3*S4 - 4*Ixz5*dq14*C2*CC5*S2*S4 + 4*Ixz5*dq23*C2*CC5*S3*S4 + 4*Ixz5*dq23*C3*CC5*S2*S4 - 4*Ixz5*dq14*C3*CC5*S3*S4 - 4*Ixz6*dq12*CC2*C5*S4*S6 - 4*Ixz6*dq12*CC3*C5*S4*S6 - 4*Ixz6*dq13*CC2*C5*S4*S6 - 4*Ixz6*dq13*CC3*C5*S4*S6 - 2*Ixz6*dq16*CC2*C5*S5*S6 - 4*Ixz6*dq45*CC5*C6*S2*S3 - 2*Ixz6*dq16*CC3*C5*S5*S6 + 4*dd4*dq12*m_4*C2*CC3*S2 + 4*dd4*dq12*m_4*CC2*C3*S3 + 4*dd4*dq12*m_5*C2*CC3*S2 + 4*dd4*dq13*m_4*C2*CC3*S2 + 4*dd4*dq12*m_5*CC2*C3*S3 + 4*dd4*dq12*m_6*C2*CC3*S2 + 4*dd4*dq13*m_4*CC2*C3*S3 + 4*dd4*dq13*m_5*C2*CC3*S2 + 4*dd4*dq12*m_6*CC2*C3*S3 + 4*dd4*dq13*m_5*CC2*C3*S3 + 4*dd4*dq13*m_6*C2*CC3*S2 + 4*dd4*dq13*m_6*CC2*C3*S3 + 2*dd6*dq12*m_6*C2*CC4*S2 - 2*dd6*dq12*m_6*C2*CC5*S2 + 2*dd6*dq13*m_6*C2*CC4*S2 + 2*dd6*dq12*m_6*C3*CC4*S3 - 2*dd6*dq13*m_6*C2*CC5*S2 - 2*dd6*dq12*m_6*C3*CC5*S3 + 2*dd6*dq13*m_6*C3*CC4*S3 - 2*dd6*dq13*m_6*C3*CC5*S3 + 2*dd6*dq14*m_6*CC2*C4*S4 - 2*dd6*dq24*m_6*C2*CC4*S3 - 2*dd6*dq24*m_6*C3*CC4*S2 + 2*dd6*dq14*m_6*CC3*C4*S4 - 2*dd6*dq24*m_6*C2*CC5*S3 - 2*dd6*dq24*m_6*C3*CC5*S2 - 2*dd6*dq34*m_6*C2*CC4*S3 - 2*dd6*dq34*m_6*C3*CC4*S2 - 2*dd6*dq34*m_6*C2*CC5*S3 - 2*dd6*dq34*m_6*C3*CC5*S2 - 2*dd6*dq15*m_6*CC2*C5*S5 - 2*dd6*dq15*m_6*CC3*C5*S5 + 4*X4*Y4*dq12*m_4*CC2*C4 + 4*X4*Y4*dq12*m_4*CC3*C4 + 4*X4*Y4*dq13*m_4*CC2*C4 + 4*X4*Y4*dq13*m_4*CC3*C4 - 2*X5*Y5*dq14*m_5*CC2*C5 - 2*X5*Y5*dq14*m_5*CC3*C5 + 2*X6*Y6*dq14*m_6*CC2*C5 + 2*X6*Y6*dq14*m_6*CC3*C5 + 4*X5*Z5*dq12*m_5*CC2*C4 + 4*X5*Z5*dq12*m_5*CC3*C4 + 4*X5*Z5*dq13*m_5*CC2*C4 + 4*X5*Z5*dq13*m_5*CC3*C4 + 4*X5*Z5*dq12*m_5*C4*CC5 + 4*X5*Z5*dq13*m_5*C4*CC5 + 2*X6*Z6*dq15*m_6*CC2*C6 + 2*X6*Z6*dq15*m_6*CC3*C6 + 4*X6*Z6*dq15*m_6*CC5*C6 + 4*Ixy6*dq22*C2*C3*CC4*C5*CC6 + 4*Ixy6*dq33*C2*C3*CC4*C5*CC6 - 2*Ixx5*dq25*CC5*S2*S3*S4 - 2*Ixx5*dq35*CC5*S2*S3*S4 - 2*Ixx6*dq56*CC6*S2*S3*S5 - 2*Iyy6*dq25*CC5*S2*S3*S4 - 2*Iyy6*dq35*CC5*S2*S3*S4 + 2*Iyy6*dq56*CC6*S2*S3*S5 - 4*Iyz5*dq23*CC4*S2*S3*S5 + 4*Iyz6*dq45*CC5*S2*S3*S6 + 2*Izz5*dq25*CC5*S2*S3*S4 + 2*Izz5*dq35*CC5*S2*S3*S4 + 2*Izz6*dq25*CC5*S2*S3*S4 + 2*Izz6*dq35*CC5*S2*S3*S4 - 4*Y4*a2*dq12*m_4*CC2*C3 - 2*Y4*a2*dq13*m_4*CC2*C3 + 2*Y5*a3*dq14*m_5*CC2*C4 + 2*Y5*a3*dq14*m_5*CC3*C4 + 4*Z3*a2*dq12*m_3*CC2*C3 + 2*Z3*a2*dq13*m_3*CC2*C3 + 2*Z4*a3*dq14*m_4*CC2*C4 + 2*Z4*a3*dq14*m_4*CC3*C4 - 4*Z5*a3*dq12*m_5*CC2*C5 - 4*Z5*a3*dq12*m_5*CC3*C5 - 4*Z5*a3*dq13*m_5*CC2*C5 - 4*Z5*a3*dq13*m_5*CC3*C5 - 4*Z6*a3*dq12*m_6*CC2*C5 - 4*Z6*a3*dq12*m_6*CC3*C5 - 4*Z6*a3*dq13*m_6*CC2*C5 - 4*Z6*a3*dq13*m_6*CC3*C5 - 4*X4*d4*dq12*m_4*CC2*C4 - 4*X4*d4*dq12*m_4*CC3*C4 - 4*X4*d4*dq13*m_4*CC2*C4 - 4*X4*d4*dq13*m_4*CC3*C4 - 2*X5*d4*dq15*m_5*CC2*C5 - 2*X5*d4*dq15*m_5*CC3*C5 + 2*X6*d6*dq15*m_6*CC2*C6 + 2*X6*d6*dq15*m_6*CC3*C6 + 4*X6*d6*dq15*m_6*CC5*C6 - 4*Y4*Z4*dq12*m_4*CC2*S4 - 4*Y4*Z4*dq12*m_4*CC3*S4 - 4*Y4*Z4*dq13*m_4*CC2*S4 - 4*Y4*Z4*dq13*m_4*CC3*S4 - 2*Y5*Z5*dq14*m_5*CC2*S5 - 2*Y5*Z5*dq14*m_5*CC3*S5 - 2*Y6*Z6*dq15*m_6*CC2*S6 - 2*Y6*Z6*dq15*m_6*CC3*S6 - 4*Y6*Z6*dq15*m_6*CC5*S6 + 4*a2*d4*dq12*m_4*CC2*C3 + 4*a2*d4*dq12*m_5*CC2*C3 + 2*a2*d4*dq13*m_4*CC2*C3 + 4*a2*d4*dq12*m_6*CC2*C3 + 2*a2*d4*dq13*m_5*CC2*C3 + 2*a2*d4*dq13*m_6*CC2*C3 - 4*a3*d6*dq12*m_6*CC2*C5 - 4*a3*d6*dq12*m_6*CC3*C5 - 4*a3*d6*dq13*m_6*CC2*C5 - 4*a3*d6*dq13*m_6*CC3*C5 - 4*X3*a2*dq12*m_3*CC2*S3 - 2*X3*a2*dq13*m_3*CC2*S3 + 2*X4*a3*dq14*m_4*CC2*S4 + 2*X4*a3*dq14*m_4*CC3*S4 + 4*X5*a3*dq12*m_5*CC2*S5 + 4*X5*a3*dq12*m_5*CC3*S5 + 4*X5*a3*dq13*m_5*CC2*S5 + 4*X5*a3*dq13*m_5*CC3*S5 + 4*Y5*d4*dq12*m_5*CC2*S4 + 4*Y5*d4*dq12*m_5*CC3*S4 + 4*Y5*d4*dq13*m_5*CC2*S4 + 4*Y5*d4*dq13*m_5*CC3*S4 - 2*Y6*d6*dq15*m_6*CC2*S6 - 2*Y6*d6*dq15*m_6*CC3*S6 - 4*Y6*d6*dq15*m_6*CC5*S6 + 4*Z4*d4*dq12*m_4*CC2*S4 + 4*Z4*d4*dq12*m_4*CC3*S4 + 4*Z4*d4*dq13*m_4*CC2*S4 + 4*Z4*d4*dq13*m_4*CC3*S4 - 2*Z5*d4*dq15*m_5*CC2*S5 - 2*Z5*d4*dq15*m_5*CC3*S5 - 2*Z6*d4*dq15*m_6*CC2*S5 - 2*Z6*d4*dq15*m_6*CC3*S5 - 4*a2*a3*dq12*m_3*CC2*S3 - 4*a2*a3*dq12*m_4*CC2*S3 - 2*a2*a3*dq13*m_3*CC2*S3 - 4*a2*a3*dq12*m_5*CC2*S3 - 2*a2*a3*dq13*m_4*CC2*S3 - 4*a2*a3*dq12*m_6*CC2*S3 - 2*a2*a3*dq13*m_5*CC2*S3 - 2*a2*a3*dq13*m_6*CC2*S3 - 4*Ixy6*dq22*CC4*C5*CC6*S2*S3 - 4*Ixy6*dq33*CC4*C5*CC6*S2*S3 - 2*d4*d6*dq15*m_6*CC2*S5 - 2*d4*d6*dq15*m_6*CC3*S5 - 4*Ixy6*dq46*C2*C3*CC5*CC6 + 8*Ixz6*dq12*CC2*CC3*C4*C6 + 8*Ixz6*dq13*CC2*CC3*C4*C6 + 8*Ixz6*dq12*CC2*C4*CC5*C6 + 8*Ixz6*dq12*CC3*C4*CC5*C6 + 8*Ixz6*dq13*CC2*C4*CC5*C6 + 8*Ixz6*dq13*CC3*C4*CC5*C6 + 4*Ixx4*dq12*C2*CC3*CC4*S2 + 4*Ixx4*dq12*CC2*C3*CC4*S3 + 4*Ixx4*dq13*C2*CC3*CC4*S2 + 4*Ixx4*dq13*CC2*C3*CC4*S3 + 4*Ixx5*dq12*C2*CC3*CC5*S2 - 4*Ixx6*dq12*C2*CC3*CC4*S2 - 2*Ixx5*dq12*C2*CC4*CC5*S2 + 4*Ixx5*dq12*CC2*C3*CC5*S3 + 4*Ixx5*dq13*C2*CC3*CC5*S2 - 4*Ixx6*dq12*CC2*C3*CC4*S3 - 4*Ixx6*dq13*C2*CC3*CC4*S2 + 4*Ixx4*dq14*CC2*CC3*C4*S4 - 2*Ixx5*dq13*C2*CC4*CC5*S2 + 4*Ixx5*dq13*CC2*C3*CC5*S3 - 8*Ixx6*dq12*C2*CC3*CC6*S2 - 4*Ixx6*dq13*CC2*C3*CC4*S3 - 2*Ixx5*dq12*C3*CC4*CC5*S3 - 2*Ixx6*dq12*C2*CC4*CC6*S2 - 8*Ixx6*dq12*CC2*C3*CC6*S3 - 8*Ixx6*dq13*C2*CC3*CC6*S2 - 2*Ixx5*dq13*C3*CC4*CC5*S3 - 2*Ixx6*dq12*C2*CC5*CC6*S2 - 2*Ixx6*dq13*C2*CC4*CC6*S2 - 8*Ixx6*dq13*CC2*C3*CC6*S3 - 4*Ixx6*dq14*CC2*CC3*C4*S4 - 2*Ixx5*dq14*CC2*C4*CC5*S4 + 2*Ixx5*dq24*C2*CC4*CC5*S3 + 2*Ixx5*dq24*C3*CC4*CC5*S2 - 2*Ixx6*dq12*C3*CC4*CC6*S3 - 2*Ixx6*dq13*C2*CC5*CC6*S2 - 2*Ixx5*dq14*CC3*C4*CC5*S4 + 4*Ixx5*dq15*CC2*CC3*C5*S5 + 2*Ixx5*dq34*C2*CC4*CC5*S3 + 2*Ixx5*dq34*C3*CC4*CC5*S2 - 2*Ixx6*dq12*C3*CC5*CC6*S3 - 2*Ixx6*dq13*C3*CC4*CC6*S3 - 2*Ixx5*dq15*CC2*CC4*C5*S5 - 2*Ixx6*dq13*C3*CC5*CC6*S3 - 2*Ixx6*dq14*CC2*C4*CC6*S4 + 2*Ixx6*dq24*C2*CC4*CC6*S3 + 2*Ixx6*dq24*C3*CC4*CC6*S2 - 2*Ixx5*dq15*CC3*CC4*C5*S5 - 2*Ixx6*dq14*CC3*C4*CC6*S4 - 2*Ixx6*dq24*C2*CC5*CC6*S3 - 2*Ixx6*dq24*C3*CC5*CC6*S2 + 2*Ixx6*dq34*C2*CC4*CC6*S3 + 2*Ixx6*dq34*C3*CC4*CC6*S2 - 2*Ixx6*dq34*C2*CC5*CC6*S3 - 2*Ixx6*dq34*C3*CC5*CC6*S2 - 2*Ixx6*dq15*CC2*C5*CC6*S5 - 8*Ixx6*dq16*CC2*CC3*C6*S6 - 2*Ixx6*dq15*CC3*C5*CC6*S5 - 2*Ixx6*dq16*CC2*CC4*C6*S6 - 2*Ixx6*dq16*CC2*CC5*C6*S6 - 2*Ixx6*dq16*CC3*CC4*C6*S6 - 2*Ixx6*dq16*CC3*CC5*C6*S6 - 4*Iyy5*dq12*C2*CC3*CC4*S2 - 4*Iyy5*dq12*CC2*C3*CC4*S3 - 4*Iyy5*dq13*C2*CC3*CC4*S2 - 4*Iyy5*dq13*CC2*C3*CC4*S3 + 4*Iyy6*dq12*C2*CC3*CC5*S2 + 8*Iyy6*dq12*C2*CC3*CC6*S2 - 2*Iyy6*dq12*C2*CC4*CC5*S2 + 4*Iyy6*dq12*CC2*C3*CC5*S3 + 4*Iyy6*dq13*C2*CC3*CC5*S2 - 4*Iyy5*dq14*CC2*CC3*C4*S4 + 2*Iyy6*dq12*C2*CC4*CC6*S2 + 8*Iyy6*dq12*CC2*C3*CC6*S3 + 8*Iyy6*dq13*C2*CC3*CC6*S2 - 2*Iyy6*dq13*C2*CC4*CC5*S2 + 4*Iyy6*dq13*CC2*C3*CC5*S3 + 2*Iyy6*dq12*C2*CC5*CC6*S2 - 2*Iyy6*dq12*C3*CC4*CC5*S3 + 2*Iyy6*dq13*C2*CC4*CC6*S2 + 8*Iyy6*dq13*CC2*C3*CC6*S3 + 2*Iyy6*dq12*C3*CC4*CC6*S3 + 2*Iyy6*dq13*C2*CC5*CC6*S2 - 2*Iyy6*dq13*C3*CC4*CC5*S3 + 2*Iyy6*dq12*C3*CC5*CC6*S3 + 2*Iyy6*dq13*C3*CC4*CC6*S3 - 2*Iyy6*dq14*CC2*C4*CC5*S4 + 2*Iyy6*dq24*C2*CC4*CC5*S3 + 2*Iyy6*dq24*C3*CC4*CC5*S2 + 2*Iyy6*dq13*C3*CC5*CC6*S3 + 2*Iyy6*dq14*CC2*C4*CC6*S4 - 2*Iyy6*dq14*CC3*C4*CC5*S4 + 4*Iyy6*dq15*CC2*CC3*C5*S5 - 2*Iyy6*dq24*C2*CC4*CC6*S3 - 2*Iyy6*dq24*C3*CC4*CC6*S2 + 2*Iyy6*dq34*C2*CC4*CC5*S3 + 2*Iyy6*dq34*C3*CC4*CC5*S2 + 2*Iyy6*dq14*CC3*C4*CC6*S4 - 2*Iyy6*dq15*CC2*CC4*C5*S5 + 2*Iyy6*dq24*C2*CC5*CC6*S3 + 2*Iyy6*dq24*C3*CC5*CC6*S2 - 2*Iyy6*dq34*C2*CC4*CC6*S3 - 2*Iyy6*dq34*C3*CC4*CC6*S2 - 2*Iyy6*dq15*CC3*CC4*C5*S5 + 2*Iyy6*dq34*C2*CC5*CC6*S3 + 2*Iyy6*dq34*C3*CC5*CC6*S2 + 2*Iyy6*dq15*CC2*C5*CC6*S5 + 8*Iyy6*dq16*CC2*CC3*C6*S6 + 2*Iyy6*dq15*CC3*C5*CC6*S5 + 2*Iyy6*dq16*CC2*CC4*C6*S6 + 2*Iyy6*dq16*CC2*CC5*C6*S6 + 2*Iyy6*dq16*CC3*CC4*C6*S6 + 2*Iyy6*dq16*CC3*CC5*C6*S6 + 8*Iyz5*dq12*CC2*CC3*C5*S4 + 8*Iyz5*dq13*CC2*CC3*C5*S4 - 8*Iyz6*dq12*CC2*CC3*C4*S6 - 8*Iyz6*dq13*CC2*CC3*C4*S6 - 8*Iyz6*dq12*CC2*C4*CC5*S6 - 8*Iyz6*dq12*CC3*C4*CC5*S6 - 8*Iyz6*dq13*CC2*C4*CC5*S6 - 4*Iyz6*dq14*CC2*CC3*C6*S5 - 8*Iyz6*dq13*CC3*C4*CC5*S6 - 4*Iyz6*dq14*CC2*CC4*C6*S5 - 4*Iyz6*dq14*CC3*CC4*C6*S5 - 4*Izz4*dq12*C2*CC3*CC4*S2 - 4*Izz4*dq12*CC2*C3*CC4*S3 - 4*Izz4*dq13*C2*CC3*CC4*S2 + 4*Izz5*dq12*C2*CC3*CC4*S2 - 4*Izz4*dq13*CC2*C3*CC4*S3 - 4*Izz5*dq12*C2*CC3*CC5*S2 + 4*Izz5*dq12*CC2*C3*CC4*S3 + 4*Izz5*dq13*C2*CC3*CC4*S2 + 4*Izz6*dq12*C2*CC3*CC4*S2 + 2*Izz5*dq12*C2*CC4*CC5*S2 - 4*Izz5*dq12*CC2*C3*CC5*S3 - 4*Izz5*dq13*C2*CC3*CC5*S2 + 4*Izz5*dq13*CC2*C3*CC4*S3 - 4*Izz6*dq12*C2*CC3*CC5*S2 + 4*Izz6*dq12*CC2*C3*CC4*S3 + 4*Izz6*dq13*C2*CC3*CC4*S2 - 4*Izz4*dq14*CC2*CC3*C4*S4
 + 2*Izz5*dq13*C2*CC4*CC5*S2 - 4*Izz5*dq13*CC2*C3*CC5*S3 + 2*Izz6*dq12*C2*CC4*CC5*S2 - 4*Izz6*dq12*CC2*C3*CC5*S3 - 4*Izz6*dq13*C2*CC3*CC5*S2 + 4*Izz6*dq13*CC2*C3*CC4*S3 + 2*Izz5*dq12*C3*CC4*CC5*S3 + 4*Izz5*dq14*CC2*CC3*C4*S4 + 2*Izz6*dq13*C2*CC4*CC5*S2 - 4*Izz6*dq13*CC2*C3*CC5*S3 + 2*Izz5*dq13*C3*CC4*CC5*S3 + 2*Izz6*dq12*C3*CC4*CC5*S3 + 4*Izz6*dq14*CC2*CC3*C4*S4 + 2*Izz5*dq14*CC2*C4*CC5*S4 - 2*Izz5*dq24*C2*CC4*CC5*S3 - 2*Izz5*dq24*C3*CC4*CC5*S2 + 2*Izz6*dq13*C3*CC4*CC5*S3 + 2*Izz5*dq14*CC3*C4*CC5*S4 - 4*Izz5*dq15*CC2*CC3*C5*S5 - 2*Izz5*dq34*C2*CC4*CC5*S3 - 2*Izz5*dq34*C3*CC4*CC5*S2 + 2*Izz6*dq14*CC2*C4*CC5*S4 - 2*Izz6*dq24*C2*CC4*CC5*S3 - 2*Izz6*dq24*C3*CC4*CC5*S2 + 2*Izz5*dq15*CC2*CC4*C5*S5 + 2*Izz6*dq14*CC3*C4*CC5*S4 - 4*Izz6*dq15*CC2*CC3*C5*S5 - 2*Izz6*dq34*C2*CC4*CC5*S3 - 2*Izz6*dq34*C3*CC4*CC5*S2 + 2*Izz5*dq15*CC3*CC4*C5*S5 + 2*Izz6*dq15*CC2*CC4*C5*S5 + 2*Izz6*dq15*CC3*CC4*C5*S5 - 8*Ixy5*dq12*CC2*CC3*S4*S5 - 8*Ixy5*dq13*CC2*CC3*S4*S5 + 8*Ixy6*dq12*CC2*CC3*S4*S5 + 8*Ixy6*dq13*CC2*CC3*S4*S5 + 8*Ixy6*dq12*CC2*CC6*S4*S5 + 8*Ixy6*dq12*CC3*CC6*S4*S5 + 8*Ixy6*dq13*CC2*CC6*S4*S5 + 8*Ixy6*dq13*CC3*CC6*S4*S5 + 4*Ixy6*dq46*CC5*CC6*S2*S3 - 4*Ixz6*dq14*CC2*CC3*S5*S6 - 4*Ixz6*dq14*CC2*CC4*S5*S6 - 4*Ixz6*dq14*CC3*CC4*S5*S6 - Ixx6*dq22*C2*C3*C5*C6*S6 - Ixx6*dq33*C2*C3*C5*C6*S6 + Ixx6*dq55*C2*C3*C5*C6*S6 + Iyy6*dq22*C2*C3*C5*C6*S6 + Iyy6*dq33*C2*C3*C5*C6*S6 - Iyy6*dq55*C2*C3*C5*C6*S6 + Iyz6*dq22*C2*C4*C5*C6*S3 + Iyz6*dq22*C3*C4*C5*C6*S2 + Iyz6*dq33*C2*C4*C5*C6*S3 + Iyz6*dq33*C3*C4*C5*C6*S2 - Iyz6*dq44*C2*C4*C5*C6*S3 - Iyz6*dq44*C3*C4*C5*C6*S2 + Iyz6*dq55*C2*C4*C5*C6*S3 + Iyz6*dq55*C3*C4*C5*C6*S2 - Iyz6*dq66*C2*C4*C5*C6*S3 - Iyz6*dq66*C3*C4*C5*C6*S2 - XX4*dq22*m_4*C2*C3*C4*S4 - XX4*dq33*m_4*C2*C3*C4*S4 + XX6*dq22*m_6*C2*C3*C4*S4 + XX6*dq33*m_6*C2*C3*C4*S4 + YY5*dq22*m_5*C2*C3*C4*S4 + YY5*dq33*m_5*C2*C3*C4*S4 + ZZ4*dq22*m_4*C2*C3*C4*S4 + ZZ4*dq33*m_4*C2*C3*C4*S4 - ZZ5*dq22*m_5*C2*C3*C4*S4 - ZZ5*dq33*m_5*C2*C3*C4*S4 - ZZ6*dq22*m_6*C2*C3*C4*S4 - ZZ6*dq33*m_6*C2*C3*C4*S4 - 8*X6*Y6*dq16*m_6*CC2*CC3 - 2*X6*Y6*dq16*m_6*CC2*CC4 - 2*X6*Y6*dq16*m_6*CC2*CC5 - 2*X6*Y6*dq16*m_6*CC3*CC4 - 8*X6*Y6*dq16*m_6*CC2*CC6 - 2*X6*Y6*dq16*m_6*CC3*CC5 - 8*X6*Y6*dq16*m_6*CC3*CC6 - 4*X6*Y6*dq16*m_6*CC5*CC6 + 8*X3*Z3*dq12*m_3*CC2*CC3 + 8*X3*Z3*dq13*m_3*CC2*CC3 + 4*X4*Z4*dq14*m_4*CC2*CC3 + 4*X4*Z4*dq14*m_4*CC2*CC4 + 4*X4*Z4*dq14*m_4*CC3*CC4 - 4*X5*Z5*dq15*m_5*CC2*CC3 + 2*X5*Z5*dq15*m_5*CC2*CC4 - 4*X5*Z5*dq15*m_5*CC2*CC5 + 2*X5*Z5*dq15*m_5*CC3*CC4 - 4*X5*Z5*dq15*m_5*CC3*CC5 + Ixz6*dq22*C2*C4*C5*S3*S6 + Ixz6*dq22*C3*C4*C5*S2*S6 + Ixz6*dq33*C2*C4*C5*S3*S6 + Ixz6*dq33*C3*C4*C5*S2*S6 - Ixz6*dq44*C2*C4*C5*S3*S6 - Ixz6*dq44*C3*C4*C5*S2*S6 + Ixz6*dq55*C2*C4*C5*S3*S6 + Ixz6*dq55*C3*C4*C5*S2*S6 - Ixz6*dq66*C2*C4*C5*S3*S6 - Ixz6*dq66*C3*C4*C5*S2*S6 - dd6*dq22*m_6*C2*C3*C4*S4 - dd6*dq33*m_6*C2*C3*C4*S4 - 8*Y4*a3*dq12*m_4*CC2*CC3 - 8*Y4*a3*dq13*m_4*CC2*CC3 + 8*Z3*a3*dq12*m_3*CC2*CC3 + 8*Z3*a3*dq13*m_3*CC2*CC3 + X5*Y5*dq22*m_5*C2*C3*C5 + X5*Y5*dq33*m_5*C2*C3*C5 - X5*Y5*dq55*m_5*C2*C3*C5 - X6*Y6*dq22*m_6*C2*C3*C5 - X6*Y6*dq33*m_6*C2*C3*C5 + X6*Y6*dq55*m_6*C2*C3*C5 + 8*a3*d4*dq12*m_4*CC2*CC3 + 8*a3*d4*dq12*m_5*CC2*CC3 + 8*a3*d4*dq13*m_4*CC2*CC3 + 8*a3*d4*dq12*m_6*CC2*CC3 + 8*a3*d4*dq13*m_5*CC2*CC3 + 8*a3*d4*dq13*m_6*CC2*CC3 - Ixx5*dq22*C2*C5*S3*S4*S5 - Ixx5*dq22*C3*C5*S2*S4*S5 - Ixx5*dq33*C2*C5*S3*S4*S5 - Ixx5*dq33*C3*C5*S2*S4*S5 + Ixx5*dq44*C2*C5*S3*S4*S5 + Ixx5*dq44*C3*C5*S2*S4*S5 + Ixx6*dq22*C5*C6*S2*S3*S6 + Ixx6*dq33*C5*C6*S2*S3*S6 - Ixx6*dq55*C5*C6*S2*S3*S6 - Iyy6*dq22*C2*C5*S3*S4*S5 - Iyy6*dq22*C3*C5*S2*S4*S5 - Iyy6*dq33*C2*C5*S3*S4*S5 - Iyy6*dq33*C3*C5*S2*S4*S5 + Iyy6*dq44*C2*C5*S3*S4*S5 + Iyy6*dq44*C3*C5*S2*S4*S5 - Iyy6*dq22*C5*C6*S2*S3*S6 - Iyy6*dq33*C5*C6*S2*S3*S6 + Iyy6*dq55*C5*C6*S2*S3*S6 + Izz5*dq22*C2*C5*S3*S4*S5 + Izz5*dq22*C3*C5*S2*S4*S5 + Izz5*dq33*C2*C5*S3*S4*S5 + Izz5*dq33*C3*C5*S2*S4*S5 + Izz6*dq22*C2*C5*S3*S4*S5 + Izz6*dq22*C3*C5*S2*S4*S5 - Izz5*dq44*C2*C5*S3*S4*S5 - Izz5*dq44*C3*C5*S2*S4*S5 + Izz6*dq33*C2*C5*S3*S4*S5 + Izz6*dq33*C3*C5*S2*S4*S5 - Izz6*dq44*C2*C5*S3*S4*S5 - Izz6*dq44*C3*C5*S2*S4*S5 + 2*Ixy5*dq25*C2*C3*C4*C5 + 2*Ixy5*dq35*C2*C3*C4*C5 - 2*Ixy6*dq25*C2*C3*C4*C5 - 2*Ixy6*dq35*C2*C3*C4*C5 - Y5*a3*dq22*m_5*C2*C3*C4 - Y5*a3*dq33*m_5*C2*C3*C4 + Y5*a3*dq44*m_5*C2*C3*C4 - Y6*a2*dq22*m_6*C2*C4*C6 + Y6*a2*dq44*m_6*C2*C4*C6 + Y6*a2*dq66*m_6*C2*C4*C6 - Z4*a3*dq22*m_4*C2*C3*C4 - Z4*a3*dq33*m_4*C2*C3*C4 + Z4*a3*dq44*m_4*C2*C3*C4 + XX4*dq22*m_4*C4*S2*S3*S4 + XX4*dq33*m_4*C4*S2*S3*S4 - XX6*dq22*m_6*C4*S2*S3*S4 - XX6*dq33*m_6*C4*S2*S3*S4 - YY5*dq22*m_5*C4*S2*S3*S4 - YY5*dq33*m_5*C4*S2*S3*S4 - ZZ4*dq22*m_4*C4*S2*S3*S4 - ZZ4*dq33*m_4*C4*S2*S3*S4 + ZZ5*dq22*m_5*C4*S2*S3*S4 + ZZ5*dq33*m_5*C4*S2*S3*S4 + ZZ6*dq22*m_6*C4*S2*S3*S4 + ZZ6*dq33*m_6*C4*S2*S3*S4 + Y4*Z4*dq22*m_4*C2*C4*S3 + Y4*Z4*dq22*m_4*C3*C4*S2 + Y4*Z4*dq33*m_4*C2*C4*S3 + Y4*Z4*dq33*m_4*C3*C4*S2 - Y4*Z4*dq44*m_4*C2*C4*S3 - Y4*Z4*dq44*m_4*C3*C4*S2 + Y5*Z5*dq22*m_5*C2*C3*S5 + Y5*Z5*dq33*m_5*C2*C3*S5 - Y5*Z5*dq55*m_5*C2*C3*S5 + 2*Ixx4*dq23*C2*C3*C4*S4 - 2*Ixx6*dq23*C2*C3*C4*S4 - Ixx6*dq26*C2*C3*C4*S5 - 2*Ixx5*dq45*C2*C3*C5*S5 - Ixx6*dq36*C2*C3*C4*S5 - Ixx6*dq56*C2*C4*C5*S3 - Ixx6*dq56*C3*C4*C5*S2 + 2*Ixx6*dq46*C2*C3*C6*S6 - 2*Iyy5*dq23*C2*C3*C4*S4 + Iyy6*dq26*C2*C3*C4*S5 + Iyy6*dq36*C2*C3*C4*S5 - 2*Iyy6*dq45*C2*C3*C5*S5 + Iyy6*dq56*C2*C4*C5*S3 + Iyy6*dq56*C3*C4*C5*S2 - 2*Iyy6*dq46*C2*C3*C6*S6 - 2*Iyz5*dq14*C2*C4*C5*S2 + 2*Iyz5*dq23*C2*C4*C5*S3 + 2*Iyz5*dq23*C3*C4*C5*S2 - 2*Iyz5*dq14*C3*C4*C5*S3 + 2*Iyz5*dq25*C2*C3*C4*S5 + 2*Iyz5*dq35*C2*C3*C4*S5 + 2*Iyz6*dq16*C2*C4*C6*S2 - 2*Iyz6*dq23*C2*C3*C6*S5 + 2*Iyz6*dq16*C3*C4*C6*S3 - 2*Iyz6*dq26*C2*C3*C6*S4 - 2*Iyz6*dq36*C2*C3*C6*S4 - 2*Izz4*dq23*C2*C3*C4*S4 + 2*Izz5*dq23*C2*C3*C4*S4 + 2*Izz6*dq23*C2*C3*C4*S4 + Izz6*dq26*C2*C3*C4*S5 + 2*Izz5*dq45*C2*C3*C5*S5 + Izz6*dq36*C2*C3*C4*S5 + 2*Izz6*dq45*C2*C3*C5*S5 + Izz6*dq56*C2*C4*C5*S3 + Izz6*dq56*C3*C4*C5*S2 + dd6*dq22*m_6*C4*S2*S3*S4 + dd6*dq33*m_6*C4*S2*S3*S4 - X4*a3*dq22*m_4*C2*C3*S4 - X4*a3*dq33*m_4*C2*C3*S4 + X4*a3*dq44*m_4*C2*C3*S4 - X5*a2*dq22*m_5*C2*C5*S4 + X5*a2*dq44*m_5*C2*C5*S4 + X5*a2*dq55*m_5*C2*C5*S4 - X6*a2*dq22*m_6*C2*C4*S6 + X6*a2*dq44*m_6*C2*C4*S6 + X6*a1*dq44*m_6*C5*C6*S4 + X6*a2*dq66*m_6*C2*C4*S6 + X6*a1*dq55*m_6*C5*C6*S4 + X6*a1*dq66*m_6*C5*C6*S4 - 2*XX5*dq15*m_5*C2*C4*S2 - 2*XX5*dq15*m_5*C3*C4*S3 - 2*XX5*dq12*m_5*C4*C5*S5 - 2*XX5*dq13*m_5*C4*C5*S5 - 2*XX5*dq45*m_5*C2*C4*S3 - 2*XX5*dq45*m_5*C3*C4*S2 + 2*XX6*dq56*m_6*C2*C3*S5 - Y5*d4*dq22*m_5*C2*C4*S3 - Y5*d4*dq22*m_5*C3*C4*S2 - Y5*d4*dq33*m_5*C2*C4*S3 - Y5*d4*dq33*m_5*C3*C4*S2 + Y5*d4*dq44*m_5*C2*C4*S3 + Y5*d4*dq44*m_5*C3*C4*S2 - 2*YY6*dq15*m_6*C2*C4*S2 - 2*YY6*dq15*m_6*C3*C4*S3 - 2*YY6*dq12*m_6*C4*C5*S5 - 2*YY6*dq13*m_6*C4*C5*S5 + 2*YY6*dq26*m_6*C2*C5*S3 + 2*YY6*dq26*m_6*C3*C5*S2 - 2*YY6*dq45*m_6*C2*C4*S3 - 2*YY6*dq45*m_6*C3*C4*S2 + 2*YY6*dq36*m_6*C2*C5*S3 + 2*YY6*dq36*m_6*C3*C5*S2 - Z4*d4*dq22*m_4*C2*C4*S3 - Z4*d4*dq22*m_4*C3*C4*S2 - Z4*d4*dq33*m_4*C2*C4*S3 - Z4*d4*dq33*m_4*C3*C4*S2 + Z4*d4*dq44*m_4*C2*C4*S3 + Z4*d4*dq44*m_4*C3*C4*S2 + 2*ZZ5*dq15*m_5*C2*C4*S2 + 2*ZZ5*dq15*m_5*C3*C4*S3 - 2*ZZ5*dq25*m_5*C2*C3*S4 + 2*ZZ6*dq15*m_6*C2*C4*S2 + 2*ZZ5*dq12*m_5*C4*C5*S5 - 2*ZZ5*dq35*m_5*C2*C3*S4 + 2*ZZ5*dq13*m_5*C4*C5*S5 + 2*ZZ6*dq15*m_6*C3*C4*S3 - 2*ZZ6*dq25*m_6*C2*C3*S4 + 2*ZZ6*dq12*m_6*C4*C5*S5 - 2*ZZ6*dq35*m_6*C2*C3*S4 + 2*ZZ6*dq13*m_6*C4*C5*S5 + X4*Y4*dq22*m_4*C2*S3*S4 + X4*Y4*dq22*m_4*C3*S2*S4 + X4*Y4*dq33*m_4*C2*S3*S4 + X4*Y4*dq33*m_4*C3*S2*S4 - X4*Y4*dq44*m_4*C2*S3*S4 - X4*Y4*dq44*m_4*C3*S2*S4 - X5*Y5*dq22*m_5*C5*S2*S3 - X5*Y5*dq33*m_5*C5*S2*S3 + X5*Y5*dq55*m_5*C5*S2*S3 + X6*Y6*dq22*m_6*C5*S2*S3 + X6*Y6*dq33*m_6*C5*S2*S3 - X6*Y6*dq55*m_6*C5*S2*S3 + X5*Z5*dq22*m_5*C2*S3*S4 + X5*Z5*dq22*m_5*C3*S2*S4 + X5*Z5*dq33*m_5*C2*S3*S4 + X5*Z5*dq33*m_5*C3*S2*S4 - X5*Z5*dq44*m_5*C2*S3*S4 - X5*Z5*dq44*m_5*C3*S2*S4 + 8*Ixy5*dq14*CC2*CC3*CC4*C5 - 8*Ixy6*dq14*CC2*CC3*CC4*C5 - 8*Ixy6*dq14*CC2*CC3*C5*CC6 - 8*Ixy6*dq14*CC2*CC4*C5*CC6 - 8*Ixy6*dq14*CC3*CC4*C5*CC6 - 16*Ixz5*dq12*CC2*CC3*C4*CC5 - 16*Ixz5*dq13*CC2*CC3*C4*CC5 + 4*Ixz6*dq15*CC2*CC3*CC4*C6 - 8*Ixz6*dq15*CC2*CC3*CC5*C6 + 4*Ixz6*dq15*CC2*CC4*CC5*C6 + 4*Ixz6*dq15*CC3*CC4*CC5*C6 + 2*Ixy5*dq14*C2*C4*S2*S5 - 8*Ixy6*dq16*C2*C3*S2*S3 + 2*Ixy5*dq15*C2*C5*S2*S4 - 2*Ixy5*dq23*C2*C4*S3*S5 - 2*Ixy5*dq23*C3*C4*S2*S5 - 2*Ixy6*dq14*C2*C4*S2*S5 + 2*Ixy5*dq14*C3*C4*S3*S5 - 8*Ixy6*dq12*C2*C6*S2*S6 - 2*Ixy6*dq15*C2*C5*S2*S4 + 2*Ixy6*dq23*C2*C4*S3*S5 + 2*Ixy6*dq23*C3*C4*S2*S5 + 2*Ixy5*dq15*C3*C5*S3*S4 - 2*Ixy5*dq25*C4*C5*S2*S3 - 8*Ixy6*dq13*C2*C6*S2*S6 - 2*Ixy6*dq14*C3*C4*S3*S5 - 2*Ixy5*dq35*C4*C5*S2*S3 - 8*Ixy6*dq12*C3*C6*S3*S6 - 2*Ixy6*dq15*C3*C5*S3*S4 + 2*Ixy6*dq25*C4*C5*S2*S3 + 2*Ixy6*dq26*C2*C4*S3*S4 + 2*Ixy6*dq26*C3*C4*S2*S4 - 8*Ixy6*dq13*C3*C6*S3*S6 + 2*Ixy6*dq35*C4*C5*S2*S3 + 2*Ixy6*dq36*C2*C4*S3*S4 + 2*Ixy6*dq36*C3*C4*S2*S4 - 4*Ixy6*dq15*C5*C6*S5*S6 + 8*Ixz3*dq12*C2*C3*S2*S3 + 8*Ixz3*dq13*C2*C3*S2*S3 + 4*Ixz4*dq12*C2*C4*S2*S4 + 4*Ixz4*dq14*C2*C3*S2*S3 + 4*Ixz4*dq13*C2*C4*S2*S4 + 4*Ixz4*dq12*C3*C4*S3*S4 - 4*Ixz5*dq15*C2*C3*S2*S3 + 4*Ixz4*dq13*C3*C4*S3*S4 - 4*Ixz5*dq12*C2*C5*S2*S5 - 4*Ixz4*dq24*C2*C4*S3*S4 - 4*Ixz4*dq24*C3*C4*S2*S4 - 4*Ixz5*dq13*C2*C5*S2*S5 - 4*Ixz4*dq34*C2*C4*S3*S4 - 4*Ixz4*dq34*C3*C4*S2*S4 - 4*Ixz5*dq12*C3*C5*S3*S5 - 4*Ixz5*dq13*C3*C5*S3*S5 - 2*Ixz5*dq25*C2*C4*S3*S4 - 2*Ixz5*dq25*C3*C4*S2*S4 + 2*Ixz6*dq14*C2*C6*S2*S4 - 4*Ixz5*dq24*C2*C5*S3*S5 - 4*Ixz5*dq24*C3*C5*S2*S5 - 2*Ixz5*dq35*C2*C4*S3*S4 - 2*Ixz5*dq35*C3*C4*S2*S4 - 2*Ixz6*dq23*C2*C6*S3*S4 - 2*Ixz6*dq23*C3*C6*S2*S4 - 4*Ixz5*dq34*C2*C5*S3*S5 - 4*Ixz5*dq34*C3*C5*S2*S5 + 2*Ixz6*dq14*C3*C6*S3*S4 + 2*Ixz6*dq16*C2*C4*S2*S6 - 2*Ixz6*dq23*C2*C3*S5*S6 + 2*Ixz6*dq16*C3*C4*S3*S6 - 2*Ixz6*dq26*C2*C3*S4*S6 - 2*Ixz6*dq26*C2*C6*S3*S5 - 2*Ixz6*dq26*C3*C6*S2*S5 - 2*Ixz6*dq36*C2*C3*S4*S6 - 2*Ixz6*dq36*C2*C6*S3*S5 - 2*Ixz6*dq36*C3*C6*S2*S5 + 2*dd6*dq15*m_6*C2*C4*S2 + 2*dd6*dq15*m_6*C3*C4*S3 - 2*dd6*dq25*m_6*C2*C3*S4 + 2*dd6*dq12*m_6*C4*C5*S5 - 2*dd6*dq35*m_6*C2*C3*S4 + 2*dd6*dq13*m_6*C4*C5*S5 + Y5*a3*dq22*m_5*C4*S2*S3 + Y5*a3*dq33*m_5*C4*S2*S3 - Y5*a3*dq44*m_5*C4*S2*S3
 - Y6*a1*dq44*m_6*C5*S4*S6 - Y6*a1*dq55*m_6*C5*S4*S6 - Y6*a1*dq66*m_6*C5*S4*S6 + Z4*a3*dq22*m_4*C4*S2*S3 + Z4*a3*dq33*m_4*C4*S2*S3 - Z4*a3*dq44*m_4*C4*S2*S3 - Z5*a2*dq22*m_5*C2*S4*S5 + Z5*a2*dq44*m_5*C2*S4*S5 - Z6*a2*dq22*m_6*C2*S4*S5 + Z5*a2*dq55*m_5*C2*S4*S5 + Z6*a2*dq44*m_6*C2*S4*S5 + Z6*a2*dq55*m_6*C2*S4*S5 - X4*d4*dq22*m_4*C2*S3*S4 - X4*d4*dq22*m_4*C3*S2*S4 - X4*d4*dq33*m_4*C2*S3*S4 - X4*d4*dq33*m_4*C3*S2*S4 + X4*d4*dq44*m_4*C2*S3*S4 + X4*d4*dq44*m_4*C3*S2*S4 - 2*X3*Y3*dq23*m_3*C2*C3 + 2*X6*Y6*dq46*m_6*C2*C3 + 2*X4*Z4*dq23*m_4*C2*C3 + 2*X5*Z5*dq45*m_5*C2*C3 - 2*X6*Z6*dq12*m_6*C4*C6 - 2*X6*Z6*dq13*m_6*C4*C6 - Y5*Z5*dq22*m_5*S2*S3*S5 - Y5*Z5*dq33*m_5*S2*S3*S5 + Y5*Z5*dq55*m_5*S2*S3*S5 + 8*Iyz5*dq14*CC2*CC3*CC4*S5 - 4*Iyz6*dq15*CC2*CC3*CC4*S6 + 8*Iyz6*dq15*CC2*CC3*CC5*S6 - 4*Iyz6*dq15*CC2*CC4*CC5*S6 - 4*Iyz6*dq15*CC3*CC4*CC5*S6 - a2*d6*dq22*m_6*C2*S4*S5 + a2*d6*dq44*m_6*C2*S4*S5 + a2*d6*dq55*m_6*C2*S4*S5 - 2*Ixx4*dq23*C4*S2*S3*S4 + 2*Ixx6*dq23*C4*S2*S3*S4 - 2*Ixx6*dq16*C2*S2*S4*S5 - 2*Ixx6*dq16*C3*S3*S4*S5 + Ixx6*dq26*C4*S2*S3*S5 + 2*Ixx5*dq45*C5*S2*S3*S5 + Ixx6*dq36*C4*S2*S3*S5 - 2*Ixx6*dq12*C6*S4*S5*S6 - Ixx6*dq46*C2*S3*S4*S5 - Ixx6*dq46*C3*S2*S4*S5 - 2*Ixx6*dq13*C6*S4*S5*S6 - 2*Ixx6*dq46*C6*S2*S3*S6 + 2*Iyy5*dq23*C4*S2*S3*S4 + 2*Iyy6*dq16*C2*S2*S4*S5 + 2*Iyy6*dq16*C3*S3*S4*S5 - Iyy6*dq26*C4*S2*S3*S5 - Iyy6*dq36*C4*S2*S3*S5 + 2*Iyy6*dq12*C6*S4*S5*S6 + 2*Iyy6*dq45*C5*S2*S3*S5 + Iyy6*dq46*C2*S3*S4*S5 + Iyy6*dq46*C3*S2*S4*S5 + 2*Iyy6*dq13*C6*S4*S5*S6 + 2*Iyy6*dq46*C6*S2*S3*S6 + 2*Iyz5*dq15*C2*S2*S4*S5 - 2*Iyz6*dq14*C2*S2*S4*S6 + 2*Iyz5*dq15*C3*S3*S4*S5 - 2*Iyz5*dq25*C4*S2*S3*S5 + 2*Iyz6*dq23*C2*S3*S4*S6 + 2*Iyz6*dq23*C3*S2*S4*S6 - 2*Iyz5*dq35*C4*S2*S3*S5 - 2*Iyz6*dq14*C3*S3*S4*S6 + 2*Iyz6*dq23*C6*S2*S3*S5 + 2*Iyz6*dq26*C6*S2*S3*S4 + 2*Iyz6*dq26*C2*S3*S5*S6 + 2*Iyz6*dq26*C3*S2*S5*S6 + 2*Iyz6*dq36*C6*S2*S3*S4 + 2*Iyz6*dq36*C2*S3*S5*S6 + 2*Iyz6*dq36*C3*S2*S5*S6 + 2*Izz4*dq23*C4*S2*S3*S4 - 2*Izz5*dq23*C4*S2*S3*S4 - 2*Izz6*dq23*C4*S2*S3*S4 - Izz6*dq26*C4*S2*S3*S5 - 2*Izz5*dq45*C5*S2*S3*S5 - Izz6*dq36*C4*S2*S3*S5 - 2*Izz6*dq45*C5*S2*S3*S5 - Izz6*dq46*C2*S3*S4*S5 - Izz6*dq46*C3*S2*S4*S5 + X4*a3*dq22*m_4*S2*S3*S4 + X4*a3*dq33*m_4*S2*S3*S4 - X4*a3*dq44*m_4*S2*S3*S4 - 2*Y4*a1*dq12*m_4*C2*C3 - 2*Y4*a1*dq13*m_4*C2*C3 - 2*Y3*a3*dq23*m_3*C2*C3 - 2*Y6*a3*dq14*m_6*C4*C6 + 2*Z3*a1*dq12*m_3*C2*C3 + 2*Z3*a1*dq13*m_3*C2*C3 - 2*Z5*a2*dq12*m_5*C3*C5 - 2*Z6*a2*dq12*m_6*C3*C5 + 2*Z5*a3*dq15*m_5*C4*C5 - 2*Z5*a1*dq45*m_5*C4*C5 + 2*Z6*a3*dq15*m_6*C4*C5 - 2*Z6*a1*dq45*m_6*C4*C5 - 2*XX6*dq56*m_6*S2*S3*S5 + 2*X5*d4*dq12*m_5*C4*C5 + 2*X5*d4*dq13*m_5*C4*C5 - 2*X6*d6*dq12*m_6*C4*C6 - 2*X6*d6*dq13*m_6*C4*C6 + 2*ZZ5*dq25*m_5*S2*S3*S4 + 2*ZZ5*dq35*m_5*S2*S3*S4 + 2*ZZ6*dq25*m_6*S2*S3*S4 + 2*ZZ6*dq35*m_6*S2*S3*S4 + 4*Z6*d6*dq25*m_6*S2*S3*S4 + 4*Z6*d6*dq35*m_6*S2*S3*S4 - 2*Y5*Z5*dq22*m_5*C2*C3*CC4*S5 - 2*Y5*Z5*dq33*m_5*C2*C3*CC4*S5 + 2*Ixx5*dq23*C2*C3*C4*CC5*S4 + 2*Ixx6*dq23*C2*C3*C4*CC6*S4 + 2*Ixx6*dq26*C2*C3*C4*CC6*S5 + 2*Ixx6*dq36*C2*C3*C4*CC6*S5 - 2*Ixx6*dq45*C2*C3*C5*CC6*S5 + 2*Ixx6*dq56*C2*C4*C5*CC6*S3 + 2*Ixx6*dq56*C3*C4*C5*CC6*S2 - 2*Ixx6*dq46*C2*C3*CC5*C6*S6 + 2*Iyy6*dq23*C2*C3*C4*CC5*S4 - 2*Iyy6*dq23*C2*C3*C4*CC6*S4 - 2*Iyy6*dq26*C2*C3*C4*CC6*S5 - 2*Iyy6*dq36*C2*C3*C4*CC6*S5 + 2*Iyy6*dq45*C2*C3*C5*CC6*S5 - 2*Iyy6*dq56*C2*C4*C5*CC6*S3 - 2*Iyy6*dq56*C3*C4*C5*CC6*S2 + 2*Iyy6*dq46*C2*C3*CC5*C6*S6 + 4*Iyz5*dq14*C2*CC3*C4*C5*S2 + 4*Iyz5*dq14*CC2*C3*C4*C5*S3 - 4*Iyz6*dq16*C2*CC3*C4*C6*S2 - 4*Iyz6*dq16*CC2*C3*C4*C6*S3 + 4*Iyz6*dq23*C2*C3*CC4*C6*S5 - 4*Iyz6*dq16*C2*C4*CC5*C6*S2 - 2*Iyz6*dq15*CC2*C4*C5*C6*S4 + 2*Iyz6*dq25*C2*CC4*C5*C6*S3 + 2*Iyz6*dq25*C3*CC4*C5*C6*S2 - 2*Iyz6*dq15*CC3*C4*C5*C6*S4 - 4*Iyz6*dq16*C3*C4*CC5*C6*S3 + 2*Iyz6*dq26*C2*C3*CC5*C6*S4 + 2*Iyz6*dq35*C2*CC4*C5*C6*S3 + 2*Iyz6*dq35*C3*CC4*C5*C6*S2 + 2*Iyz6*dq36*C2*C3*CC5*C6*S4 - 2*Iyz6*dq46*C2*C4*CC5*C6*S3 - 2*Iyz6*dq46*C3*C4*CC5*C6*S2 - 2*Izz5*dq23*C2*C3*C4*CC5*S4 - 2*Izz6*dq23*C2*C3*C4*CC5*S4 - dd6*dq22*m_6*C4*CC5*S2*S3*S4 - dd6*dq33*m_6*C4*CC5*S2*S3*S4 + 4*XX5*dq15*m_5*C2*CC3*C4*S2 + 4*XX5*dq15*m_5*CC2*C3*C4*S3 + 4*XX5*dq12*m_5*CC2*C4*C5*S5 + 4*XX5*dq15*m_5*C2*C4*CC5*S2 + 4*XX5*dq12*m_5*CC3*C4*C5*S5 + 4*XX5*dq13*m_5*CC2*C4*C5*S5 + 4*XX5*dq13*m_5*CC3*C4*C5*S5 + 4*XX5*dq15*m_5*C3*C4*CC5*S3 - 2*XX5*dq25*m_5*C2*C3*CC5*S4 - 2*XX5*dq35*m_5*C2*C3*CC5*S4 - 2*XX6*dq15*m_6*C2*C4*CC6*S2 + 2*XX5*dq45*m_5*C2*C4*CC5*S3 + 2*XX5*dq45*m_5*C3*C4*CC5*S2 - 2*XX6*dq15*m_6*C3*C4*CC6*S3 - 2*XX6*dq16*m_6*CC2*C4*C5*S4 + 2*XX6*dq26*m_6*C2*CC4*C5*S3 + 2*XX6*dq26*m_6*C3*CC4*C5*S2 - 2*XX6*dq12*m_6*C4*C5*CC6*S5 - 2*XX6*dq16*m_6*CC3*C4*C5*S4 + 2*XX6*dq36*m_6*C2*CC4*C5*S3 + 2*XX6*dq36*m_6*C3*CC4*C5*S2 - 2*XX6*dq13*m_6*C4*C5*CC6*S5 - 2*XX6*dq14*m_6*CC2*C5*C6*S6 + 2*XX6*dq26*m_6*C2*C5*CC6*S3 + 2*XX6*dq26*m_6*C3*C5*CC6*S2 - 2*XX6*dq45*m_6*C2*C4*CC6*S3 - 2*XX6*dq45*m_6*C3*C4*CC6*S2 - 2*XX6*dq14*m_6*CC3*C5*C6*S6 + 2*XX6*dq36*m_6*C2*C5*CC6*S3 + 2*XX6*dq36*m_6*C3*C5*CC6*S2 - 2*XX6*dq56*m_6*C2*C3*CC6*S5 + 4*YY6*dq15*m_6*C2*CC3*C4*S2 + 4*YY6*dq15*m_6*CC2*C3*C4*S3 + 4*YY6*dq12*m_6*CC2*C4*C5*S5 + 4*YY6*dq15*m_6*C2*C4*CC5*S2 + 4*YY6*dq12*m_6*CC3*C4*C5*S5 + 4*YY6*dq13*m_6*CC2*C4*C5*S5 + 2*YY6*dq15*m_6*C2*C4*CC6*S2 + 4*YY6*dq13*m_6*CC3*C4*C5*S5 + 4*YY6*dq15*m_6*C3*C4*CC5*S3 - 2*YY6*dq25*m_6*C2*C3*CC5*S4 + 2*YY6*dq15*m_6*C3*C4*CC6*S3 + 2*YY6*dq16*m_6*CC2*C4*C5*S4 - 2*YY6*dq26*m_6*C2*CC4*C5*S3 - 2*YY6*dq26*m_6*C3*CC4*C5*S2 - 2*YY6*dq35*m_6*C2*C3*CC5*S4 + 2*YY6*dq12*m_6*C4*C5*CC6*S5 + 2*YY6*dq16*m_6*CC3*C4*C5*S4 - 2*YY6*dq36*m_6*C2*CC4*C5*S3 - 2*YY6*dq36*m_6*C3*CC4*C5*S2 + 2*YY6*dq45*m_6*C2*C4*CC5*S3 + 2*YY6*dq45*m_6*C3*C4*CC5*S2 + 2*YY6*dq13*m_6*C4*C5*CC6*S5 + 2*YY6*dq14*m_6*CC2*C5*C6*S6 - 2*YY6*dq26*m_6*C2*C5*CC6*S3 - 2*YY6*dq26*m_6*C3*C5*CC6*S2 + 2*YY6*dq45*m_6*C2*C4*CC6*S3 + 2*YY6*dq45*m_6*C3*C4*CC6*S2 + 2*YY6*dq14*m_6*CC3*C5*C6*S6 - 2*YY6*dq36*m_6*C2*C5*CC6*S3 - 2*YY6*dq36*m_6*C3*C5*CC6*S2 + 2*YY6*dq56*m_6*C2*C3*CC6*S5 - 4*ZZ5*dq15*m_5*C2*CC3*C4*S2 - 4*ZZ5*dq15*m_5*CC2*C3*C4*S3 - 4*ZZ5*dq12*m_5*CC2*C4*C5*S5 - 4*ZZ5*dq15*m_5*C2*C4*CC5*S2 - 4*ZZ6*dq15*m_6*C2*CC3*C4*S2 - 4*ZZ5*dq12*m_5*CC3*C4*C5*S5 - 4*ZZ5*dq13*m_5*CC2*C4*C5*S5 - 4*ZZ6*dq15*m_6*CC2*C3*C4*S3 - 4*ZZ5*dq13*m_5*CC3*C4*C5*S5 - 4*ZZ5*dq15*m_5*C3*C4*CC5*S3 + 2*ZZ5*dq25*m_5*C2*C3*CC5*S4 - 4*ZZ6*dq12*m_6*CC2*C4*C5*S5 - 4*ZZ6*dq15*m_6*C2*C4*CC5*S2 + 2*ZZ5*dq35*m_5*C2*C3*CC5*S4 - 4*ZZ6*dq12*m_6*CC3*C4*C5*S5 - 4*ZZ6*dq13*m_6*CC2*C4*C5*S5 - 2*ZZ5*dq45*m_5*C2*C4*CC5*S3 - 2*ZZ5*dq45*m_5*C3*C4*CC5*S2 - 4*ZZ6*dq13*m_6*CC3*C4*C5*S5 - 4*ZZ6*dq15*m_6*C3*C4*CC5*S3 + 2*ZZ6*dq25*m_6*C2*C3*CC5*S4 + 2*ZZ6*dq35*m_6*C2*C3*CC5*S4 - 2*ZZ6*dq45*m_6*C2*C4*CC5*S3 - 2*ZZ6*dq45*m_6*C3*C4*CC5*S2 + 2*X5*Y5*dq22*m_5*CC4*C5*S2*S3 + 2*X5*Y5*dq33*m_5*CC4*C5*S2*S3 - 2*X6*Y6*dq22*m_6*CC4*C5*S2*S3 - 2*X6*Y6*dq33*m_6*CC4*C5*S2*S3 - 2*X6*Y6*dq22*m_6*C5*CC6*S2*S3 - 2*X6*Y6*dq33*m_6*C5*CC6*S2*S3 + 2*X6*Y6*dq55*m_6*C5*CC6*S2*S3 - 2*X5*Z5*dq22*m_5*C2*CC5*S3*S4 - 2*X5*Z5*dq22*m_5*C3*CC5*S2*S4 - 2*X5*Z5*dq33*m_5*C2*CC5*S3*S4 - 2*X5*Z5*dq33*m_5*C3*CC5*S2*S4 + 2*X5*Z5*dq44*m_5*C2*CC5*S3*S4 + 2*X5*Z5*dq44*m_5*C3*CC5*S2*S4 + 16*Ixy6*dq14*CC2*CC3*CC4*C5*CC6 - 8*Ixz6*dq15*CC2*CC3*CC4*CC5*C6 - 4*Ixy5*dq14*C2*CC3*C4*S2*S5 - 4*Ixy5*dq14*CC2*C3*C4*S3*S5 - 4*Ixy5*dq15*C2*CC3*C5*S2*S4 + 4*Ixy6*dq14*C2*CC3*C4*S2*S5 + 4*Ixy6*dq16*C2*C3*CC4*S2*S3 - 4*Ixy5*dq15*CC2*C3*C5*S3*S4 + 16*Ixy6*dq12*C2*CC3*C6*S2*S6 + 4*Ixy6*dq14*CC2*C3*C4*S3*S5 + 4*Ixy6*dq15*C2*CC3*C5*S2*S4 + 4*Ixy6*dq16*C2*C3*CC5*S2*S3 + 4*Ixy6*dq12*C2*CC4*C6*S2*S6 + 16*Ixy6*dq12*CC2*C3*C6*S3*S6 + 16*Ixy6*dq13*C2*CC3*C6*S2*S6 + 4*Ixy6*dq15*CC2*C3*C5*S3*S4 + 16*Ixy6*dq16*C2*C3*CC6*S2*S3 + 4*Ixy6*dq12*C2*CC5*C6*S2*S6 + 4*Ixy6*dq13*C2*CC4*C6*S2*S6 + 16*Ixy6*dq13*CC2*C3*C6*S3*S6 + 4*Ixy6*dq14*C2*C4*CC6*S2*S5 + 4*Ixy6*dq12*C3*CC4*C6*S3*S6 + 4*Ixy6*dq13*C2*CC5*C6*S2*S6 + 4*Ixy6*dq15*C2*C5*CC6*S2*S4 - 4*Ixy6*dq23*C2*C4*CC6*S3*S5 - 4*Ixy6*dq23*C3*C4*CC6*S2*S5 + 4*Ixy6*dq12*C3*CC5*C6*S3*S6 + 4*Ixy6*dq13*C3*CC4*C6*S3*S6 + 4*Ixy6*dq14*C3*C4*CC6*S3*S5 + 2*Ixy6*dq26*C2*C4*CC5*S3*S4 + 2*Ixy6*dq26*C3*C4*CC5*S2*S4 + 4*Ixy6*dq13*C3*CC5*C6*S3*S6 + 4*Ixy6*dq14*CC2*C4*C6*S4*S6 + 4*Ixy6*dq15*C3*C5*CC6*S3*S4 - 4*Ixy6*dq24*C2*CC4*C6*S3*S6 - 4*Ixy6*dq24*C3*CC4*C6*S2*S6 - 4*Ixy6*dq25*C4*C5*CC6*S2*S3 - 4*Ixy6*dq26*C2*C4*CC6*S3*S4 - 4*Ixy6*dq26*C3*C4*CC6*S2*S4 + 2*Ixy6*dq36*C2*C4*CC5*S3*S4 + 2*Ixy6*dq36*C3*C4*CC5*S2*S4 + 4*Ixy6*dq14*CC3*C4*C6*S4*S6 + 4*Ixy6*dq24*C2*CC5*C6*S3*S6 + 4*Ixy6*dq24*C3*CC5*C6*S2*S6 - 4*Ixy6*dq34*C2*CC4*C6*S3*S6 - 4*Ixy6*dq34*C3*CC4*C6*S2*S6 - 4*Ixy6*dq35*C4*C5*CC6*S2*S3 - 4*Ixy6*dq36*C2*C4*CC6*S3*S4 - 4*Ixy6*dq36*C3*C4*CC6*S2*S4 + 4*Ixy6*dq34*C2*CC5*C6*S3*S6 + 4*Ixy6*dq34*C3*CC5*C6*S2*S6 + 4*Ixy6*dq15*CC2*C5*C6*S5*S6 + 4*Ixy6*dq15*CC3*C5*C6*S5*S6 - 8*Ixz4*dq12*C2*CC3*C4*S2*S4 - 8*Ixz4*dq12*CC2*C3*C4*S3*S4 - 8*Ixz4*dq13*C2*CC3*C4*S2*S4 - 8*Ixz4*dq14*C2*C3*CC4*S2*S3 - 8*Ixz4*dq13*CC2*C3*C4*S3*S4 + 8*Ixz5*dq12*C2*CC3*C5*S2*S5 - 4*Ixz5*dq15*C2*C3*CC4*S2*S3 - 4*Ixz5*dq12*C2*CC4*C5*S2*S5 + 8*Ixz5*dq12*CC2*C3*C5*S3*S5 + 8*Ixz5*dq13*C2*CC3*C5*S2*S5 + 8*Ixz5*dq15*C2*C3*CC5*S2*S3 - 4*Ixz5*dq13*C2*CC4*C5*S2*S5 + 8*Ixz5*dq13*CC2*C3*C5*S3*S5 - 4*Ixz5*dq12*C3*CC4*C5*S3*S5 - 4*Ixz6*dq14*C2*CC3*C6*S2*S4 - 4*Ixz5*dq13*C3*CC4*C5*S3*S5 - 4*Ixz6*dq14*CC2*C3*C6*S3*S4 - 4*Ixz5*dq14*CC2*C4*C5*S4*S5 + 4*Ixz5*dq24*C2*CC4*C5*S3*S5 + 4*Ixz5*dq24*C3*CC4*C5*S2*S5 + 4*Ixz5*dq25*C2*C4*CC5*S3*S4 + 4*Ixz5*dq25*C3*C4*CC5*S2*S4 - 4*Ixz6*dq14*C2*CC5*C6*S2*S4 - 4*Ixz6*dq16*C2*CC3*C4*S2*S6 - 4*Ixz5*dq14*CC3*C4*C5*S4*S5 + 4*Ixz5*dq34*C2*CC4*C5*S3*S5 + 4*Ixz5*dq34*C3*CC4*C5*S2*S5 + 4*Ixz5*dq35*C2*C4*CC5*S3*S4 + 4*Ixz5*dq35*C3*C4*CC5*S2*S4 - 4*Ixz6*dq16*CC2*C3*C4*S3*S6 + 4*Ixz6*dq23*C2*C3*CC4*S5*S6 + 4*Ixz6*dq23*C2*CC5*C6*S3*S4 + 4*Ixz6*dq23*C3*CC5*C6*S2*S4 - 4*Ixz6*dq14*C3*CC5*C6*S3*S4 - 4*Ixz6*dq16*C2*C4*CC5*S2*S6 - 2*Ixz6*dq15*CC2*C4*C5*S4*S6 + 2*Ixz6*dq25*C2*CC4*C5*S3*S6 + 2*Ixz6*dq25*C3*CC4*C5*S2*S6 - 2*Ixz6*dq15*CC3*C4*C5*S4*S6 - 4*Ixz6*dq16*C3*C4*CC5*S3*S6 - 2*Ixz6*dq16*CC2*C4*C6*S4*S5 + 2*Ixz6*dq26*C2*C3*CC5*S4*S6 + 2*Ixz6*dq26*C2*CC4*C6*S3*S5 + 2*Ixz6*dq26*C3*CC4*C6*S2*S5 + 2*Ixz6*dq35*C2*CC4*C5*S3*S6
 + 2*Ixz6*dq35*C3*CC4*C5*S2*S6 - 2*Ixz6*dq16*CC3*C4*C6*S4*S5 + 2*Ixz6*dq36*C2*C3*CC5*S4*S6 + 2*Ixz6*dq36*C2*CC4*C6*S3*S5 + 2*Ixz6*dq36*C3*CC4*C6*S2*S5 - 2*Ixz6*dq46*C2*C4*CC5*S3*S6 - 2*Ixz6*dq46*C3*C4*CC5*S2*S6 - 4*dd6*dq15*m_6*C2*CC3*C4*S2 - 4*dd6*dq15*m_6*CC2*C3*C4*S3 - 4*dd6*dq12*m_6*CC2*C4*C5*S5 - 4*dd6*dq15*m_6*C2*C4*CC5*S2 - 4*dd6*dq12*m_6*CC3*C4*C5*S5 - 4*dd6*dq13*m_6*CC2*C4*C5*S5 - 4*dd6*dq13*m_6*CC3*C4*C5*S5 - 4*dd6*dq15*m_6*C3*C4*CC5*S3 + 2*dd6*dq25*m_6*C2*C3*CC5*S4 + 2*dd6*dq35*m_6*C2*C3*CC5*S4 - 2*dd6*dq45*m_6*C2*C4*CC5*S3 - 2*dd6*dq45*m_6*C3*C4*CC5*S2 - 2*X6*Y6*dq46*m_6*C2*C3*CC5 - 4*X6*Y6*dq46*m_6*C2*C3*CC6 - 4*X4*Z4*dq23*m_4*C2*C3*CC4 + 4*X6*Z6*dq12*m_6*CC2*C4*C6 - 4*X5*Z5*dq45*m_5*C2*C3*CC5 + 4*X6*Z6*dq12*m_6*CC3*C4*C6 + 4*X6*Z6*dq13*m_6*CC2*C4*C6 + 4*X6*Z6*dq13*m_6*CC3*C4*C6 + 4*X6*Z6*dq12*m_6*C4*CC5*C6 + 4*X6*Z6*dq13*m_6*C4*CC5*C6 + 2*Y5*Z5*dq22*m_5*CC4*S2*S3*S5 + 2*Y5*Z5*dq33*m_5*CC4*S2*S3*S5 + 8*Iyz6*dq15*CC2*CC3*CC4*CC5*S6 - 2*Ixx5*dq23*C4*CC5*S2*S3*S4 + 4*Ixx6*dq16*C2*CC3*S2*S4*S5 + 4*Ixx6*dq16*CC2*C3*S3*S4*S5 - 2*Ixx6*dq23*C4*CC6*S2*S3*S4 + 4*Ixx6*dq12*CC2*C6*S4*S5*S6 + 4*Ixx6*dq16*C2*CC6*S2*S4*S5 + 4*Ixx6*dq12*CC3*C6*S4*S5*S6 + 4*Ixx6*dq13*CC2*C6*S4*S5*S6 + 4*Ixx6*dq13*CC3*C6*S4*S5*S6 + 4*Ixx6*dq16*C3*CC6*S3*S4*S5 - 2*Ixx6*dq26*C4*CC6*S2*S3*S5 - 2*Ixx6*dq36*C4*CC6*S2*S3*S5 + 2*Ixx6*dq45*C5*CC6*S2*S3*S5 + 2*Ixx6*dq46*C2*CC6*S3*S4*S5 + 2*Ixx6*dq46*C3*CC6*S2*S4*S5 + 2*Ixx6*dq46*CC5*C6*S2*S3*S6 - 4*Iyy6*dq16*C2*CC3*S2*S4*S5 - 2*Iyy6*dq23*C4*CC5*S2*S3*S4 - 4*Iyy6*dq16*CC2*C3*S3*S4*S5 + 2*Iyy6*dq23*C4*CC6*S2*S3*S4 - 4*Iyy6*dq12*CC2*C6*S4*S5*S6 - 4*Iyy6*dq16*C2*CC6*S2*S4*S5 - 4*Iyy6*dq12*CC3*C6*S4*S5*S6 - 4*Iyy6*dq13*CC2*C6*S4*S5*S6 - 4*Iyy6*dq13*CC3*C6*S4*S5*S6 - 4*Iyy6*dq16*C3*CC6*S3*S4*S5 + 2*Iyy6*dq26*C4*CC6*S2*S3*S5 + 2*Iyy6*dq36*C4*CC6*S2*S3*S5 - 2*Iyy6*dq45*C5*CC6*S2*S3*S5 - 2*Iyy6*dq46*C2*CC6*S3*S4*S5 - 2*Iyy6*dq46*C3*CC6*S2*S4*S5 - 2*Iyy6*dq46*CC5*C6*S2*S3*S6 - 4*Iyz5*dq15*C2*CC3*S2*S4*S5 - 4*Iyz5*dq15*CC2*C3*S3*S4*S5 + 4*Iyz6*dq14*C2*CC3*S2*S4*S6 + 4*Iyz6*dq14*CC2*C3*S3*S4*S6 + 4*Iyz6*dq14*C2*CC5*S2*S4*S6 - 4*Iyz6*dq23*C2*CC5*S3*S4*S6 - 4*Iyz6*dq23*C3*CC5*S2*S4*S6 - 4*Iyz6*dq23*CC4*C6*S2*S3*S5 + 4*Iyz6*dq14*C3*CC5*S3*S4*S6 + 2*Iyz6*dq16*CC2*C4*S4*S5*S6 - 2*Iyz6*dq26*C2*CC4*S3*S5*S6 - 2*Iyz6*dq26*C3*CC4*S2*S5*S6 - 2*Iyz6*dq26*CC5*C6*S2*S3*S4 + 2*Iyz6*dq16*CC3*C4*S4*S5*S6 - 2*Iyz6*dq36*C2*CC4*S3*S5*S6 - 2*Iyz6*dq36*C3*CC4*S2*S5*S6 - 2*Iyz6*dq36*CC5*C6*S2*S3*S4 + 2*Izz5*dq23*C4*CC5*S2*S3*S4 + 2*Izz6*dq23*C4*CC5*S2*S3*S4 - 2*Y5*a2*dq14*m_5*CC2*C3*C4 + 2*Y6*a3*dq14*m_6*CC2*C4*C6 + 2*Y6*a3*dq14*m_6*CC3*C4*C6 - 2*Z4*a2*dq14*m_4*CC2*C3*C4 + 4*Z5*a2*dq12*m_5*CC2*C3*C5 + 2*Z5*a2*dq13*m_5*CC2*C3*C5 + 4*Z6*a2*dq12*m_6*CC2*C3*C5 + 2*Z6*a2*dq13*m_6*CC2*C3*C5 - 2*Z5*a3*dq15*m_5*CC2*C4*C5 - 2*Z5*a3*dq15*m_5*CC3*C4*C5 - 2*Z6*a3*dq15*m_6*CC2*C4*C5 - 2*Z6*a3*dq15*m_6*CC3*C4*C5 + 2*XX5*dq25*m_5*CC5*S2*S3*S4 + 2*XX5*dq35*m_5*CC5*S2*S3*S4 + 2*XX6*dq56*m_6*CC6*S2*S3*S5 - 4*X5*d4*dq12*m_5*CC2*C4*C5 - 4*X5*d4*dq12*m_5*CC3*C4*C5 - 4*X5*d4*dq13*m_5*CC2*C4*C5 - 4*X5*d4*dq13*m_5*CC3*C4*C5 + 4*X6*d6*dq12*m_6*CC2*C4*C6 + 4*X6*d6*dq12*m_6*CC3*C4*C6 + 4*X6*d6*dq13*m_6*CC2*C4*C6 - 2*X6*d4*dq15*m_6*CC2*C5*C6 + 4*X6*d6*dq13*m_6*CC3*C4*C6 - 2*X6*d4*dq15*m_6*CC3*C5*C6 + 4*X6*d6*dq12*m_6*C4*CC5*C6 + 4*X6*d6*dq13*m_6*C4*CC5*C6 + 2*YY6*dq25*m_6*CC5*S2*S3*S4 + 2*YY6*dq35*m_6*CC5*S2*S3*S4 - 2*YY6*dq56*m_6*CC6*S2*S3*S5 - 2*ZZ5*dq25*m_5*CC5*S2*S3*S4 - 2*ZZ5*dq35*m_5*CC5*S2*S3*S4 - 2*ZZ6*dq25*m_6*CC5*S2*S3*S4 - 2*ZZ6*dq35*m_6*CC5*S2*S3*S4 + 4*Y5*Z5*dq12*m_5*CC2*C5*S4 + 4*Y5*Z5*dq12*m_5*CC3*C5*S4 + 4*Y5*Z5*dq13*m_5*CC2*C5*S4 + 4*Y5*Z5*dq13*m_5*CC3*C5*S4 - 4*Y6*Z6*dq12*m_6*CC2*C4*S6 - 4*Y6*Z6*dq12*m_6*CC3*C4*S6 - 4*Y6*Z6*dq13*m_6*CC2*C4*S6 - 4*Y6*Z6*dq13*m_6*CC3*C4*S6 - 4*Y6*Z6*dq12*m_6*C4*CC5*S6 - 2*Y6*Z6*dq14*m_6*CC2*C6*S5 - 4*Y6*Z6*dq13*m_6*C4*CC5*S6 - 2*Y6*Z6*dq14*m_6*CC3*C6*S5 + Ixx6*dq22*C2*C3*C4*CC5*CC6*S4 + Ixx6*dq33*C2*C3*C4*CC5*CC6*S4 - Iyy6*dq22*C2*C3*C4*CC5*CC6*S4 - Iyy6*dq33*C2*C3*C4*CC5*CC6*S4 - 4*Ixz6*dq23*CC4*S2*S3*S5*S6 - 2*Ixz6*dq26*CC5*S2*S3*S4*S6 - 2*Ixz6*dq36*CC5*S2*S3*S4*S6 + 4*a2*d6*dq12*m_6*CC2*C3*C5 + 2*a2*d6*dq13*m_6*CC2*C3*C5 - 2*a3*d6*dq15*m_6*CC2*C4*C5 - 2*a3*d6*dq15*m_6*CC3*C4*C5 - 2*dd6*dq25*m_6*CC5*S2*S3*S4 - 2*dd6*dq35*m_6*CC5*S2*S3*S4 - 8*X3*a3*dq12*m_3*C2*CC3*S2 - 8*X3*a3*dq12*m_3*CC2*C3*S3 - 8*X3*a3*dq13*m_3*C2*CC3*S2 - 8*X3*a3*dq13*m_3*CC2*C3*S3 - 4*X4*a2*dq12*m_4*CC2*C4*S3 - 2*X4*a2*dq13*m_4*CC2*C4*S3 - 2*X4*a2*dq14*m_4*CC2*C3*S4 - 4*X5*a2*dq12*m_5*CC2*C3*S5 - 2*X5*a2*dq13*m_5*CC2*C3*S5 - 2*X5*a2*dq15*m_5*CC2*C5*S3 + 2*X5*a3*dq14*m_5*CC2*C5*S4 + 2*X5*a3*dq14*m_5*CC3*C5*S4 + 2*X5*a3*dq15*m_5*CC2*C4*S5 + 2*X5*a3*dq15*m_5*CC3*C4*S5 + 4*X6*a3*dq12*m_6*CC2*C6*S5 + 4*X6*a3*dq12*m_6*CC3*C6*S5 + 4*X6*a3*dq13*m_6*CC2*C6*S5 + 2*X6*a3*dq14*m_6*CC2*C4*S6 + 4*X6*a3*dq13*m_6*CC3*C6*S5 + 2*X6*a3*dq14*m_6*CC3*C4*S6 + 2*X6*a3*dq16*m_6*CC2*C6*S4 + 2*X6*a3*dq16*m_6*CC3*C6*S4 - 8*Y4*d4*dq12*m_4*C2*CC3*S2 - 8*Y4*d4*dq12*m_4*CC2*C3*S3 - 8*Y4*d4*dq13*m_4*C2*CC3*S2 - 8*Y4*d4*dq13*m_4*CC2*C3*S3 + 4*Y6*d4*dq12*m_6*CC2*C6*S4 + 4*Y6*d4*dq12*m_6*CC3*C6*S4 + 4*Y6*d4*dq13*m_6*CC2*C6*S4 + 4*Y6*d4*dq13*m_6*CC3*C6*S4 - 4*Y6*d6*dq12*m_6*CC2*C4*S6 - 4*Y6*d6*dq12*m_6*CC3*C4*S6 - 4*Y6*d6*dq13*m_6*CC2*C4*S6 + 2*Y6*d4*dq15*m_6*CC2*C5*S6 - 4*Y6*d6*dq13*m_6*CC3*C4*S6 + 2*Y6*d4*dq15*m_6*CC3*C5*S6 + 2*Y6*d4*dq16*m_6*CC2*C6*S5 - 4*Y6*d6*dq12*m_6*C4*CC5*S6 - 2*Y6*d6*dq14*m_6*CC2*C6*S5 + 2*Y6*d4*dq16*m_6*CC3*C6*S5 - 4*Y6*d6*dq13*m_6*C4*CC5*S6 - 2*Y6*d6*dq14*m_6*CC3*C6*S5 - 4*Z5*d4*dq12*m_5*CC2*C4*S5 - 4*Z5*d4*dq12*m_5*CC3*C4*S5 - 4*Z5*d4*dq13*m_5*CC2*C4*S5 + 4*Z6*d6*dq12*m_6*C2*CC4*S2 - 4*Z5*d4*dq13*m_5*CC3*C4*S5 - 4*Z6*d4*dq12*m_6*CC2*C4*S5 - 4*Z6*d6*dq12*m_6*C2*CC5*S2 + 4*Z6*d6*dq13*m_6*C2*CC4*S2 - 4*Z6*d4*dq12*m_6*CC3*C4*S5 - 4*Z6*d4*dq13*m_6*CC2*C4*S5 + 4*Z6*d6*dq12*m_6*C3*CC4*S3 - 4*Z6*d6*dq13*m_6*C2*CC5*S2 - 4*Z6*d4*dq13*m_6*CC3*C4*S5 - 4*Z6*d6*dq12*m_6*C3*CC5*S3 + 4*Z6*d6*dq13*m_6*C3*CC4*S3 - 4*Z6*d6*dq13*m_6*C3*CC5*S3 + 4*Z6*d6*dq14*m_6*CC2*C4*S4 - 4*Z6*d6*dq24*m_6*C2*CC4*S3 - 4*Z6*d6*dq24*m_6*C3*CC4*S2 + 4*Z6*d6*dq14*m_6*CC3*C4*S4 - 4*Z6*d6*dq24*m_6*C2*CC5*S3 - 4*Z6*d6*dq24*m_6*C3*CC5*S2 - 4*Z6*d6*dq34*m_6*C2*CC4*S3 - 4*Z6*d6*dq34*m_6*C3*CC4*S2 - 4*Z6*d6*dq34*m_6*C2*CC5*S3 - 4*Z6*d6*dq34*m_6*C3*CC5*S2 - 4*Z6*d6*dq15*m_6*CC2*C5*S5 - 4*Z6*d6*dq15*m_6*CC3*C5*S5 - 4*X5*Y5*dq12*m_5*CC2*S4*S5 - 4*X5*Y5*dq12*m_5*CC3*S4*S5 - 4*X5*Y5*dq13*m_5*CC2*S4*S5 - 4*X5*Y5*dq13*m_5*CC3*S4*S5 + 4*X6*Y6*dq12*m_6*CC2*S4*S5 + 4*X6*Y6*dq12*m_6*CC3*S4*S5 + 4*X6*Y6*dq13*m_6*CC2*S4*S5 + 4*X6*Y6*dq13*m_6*CC3*S4*S5 + 4*X6*Y6*dq12*m_6*CC6*S4*S5 + 4*X6*Y6*dq13*m_6*CC6*S4*S5 + 2*X6*Y6*dq46*m_6*CC5*S2*S3 + 4*X6*Y6*dq46*m_6*CC6*S2*S3 + 4*X4*Z4*dq23*m_4*CC4*S2*S3 + 4*X5*Z5*dq45*m_5*CC5*S2*S3 - 2*X6*Z6*dq14*m_6*CC2*S5*S6 - 2*X6*Z6*dq14*m_6*CC3*S5*S6 - 4*d4*d6*dq12*m_6*CC2*C4*S5 - 4*d4*d6*dq12*m_6*CC3*C4*S5 - 4*d4*d6*dq13*m_6*CC2*C4*S5 - 4*d4*d6*dq13*m_6*CC3*C4*S5 + 4*Y5*a2*dq12*m_5*CC2*S3*S4 + 2*Y5*a2*dq13*m_5*CC2*S3*S4 - 4*Y6*a3*dq12*m_6*CC2*S5*S6 - 4*Y6*a3*dq12*m_6*CC3*S5*S6 - 4*Y6*a3*dq13*m_6*CC2*S5*S6 - 4*Y6*a3*dq13*m_6*CC3*S5*S6 - 2*Y6*a3*dq16*m_6*CC2*S4*S6 - 2*Y6*a3*dq16*m_6*CC3*S4*S6 + 4*Z4*a2*dq12*m_4*CC2*S3*S4 + 2*Z4*a2*dq13*m_4*CC2*S3*S4 - 2*Z5*a2*dq15*m_5*CC2*S3*S5 + 2*Z5*a3*dq14*m_5*CC2*S4*S5 + 2*Z5*a3*dq14*m_5*CC3*S4*S5 - 2*Z6*a2*dq15*m_6*CC2*S3*S5 + 2*Z6*a3*dq14*m_6*CC2*S4*S5 + 2*Z6*a3*dq14*m_6*CC3*S4*S5 + 4*X6*d4*dq12*m_6*CC2*S4*S6 + 4*X6*d4*dq12*m_6*CC3*S4*S6 + 4*X6*d4*dq13*m_6*CC2*S4*S6 + 4*X6*d4*dq13*m_6*CC3*S4*S6 + 2*X6*d4*dq16*m_6*CC2*S5*S6 - 2*X6*d6*dq14*m_6*CC2*S5*S6 + 2*X6*d4*dq16*m_6*CC3*S5*S6 - 2*X6*d6*dq14*m_6*CC3*S5*S6 - Ixx6*dq22*C4*CC5*CC6*S2*S3*S4 - Ixx6*dq33*C4*CC5*CC6*S2*S3*S4 + Iyy6*dq22*C4*CC5*CC6*S2*S3*S4 + Iyy6*dq33*C4*CC5*CC6*S2*S3*S4 + 8*Ixy6*dq23*C2*C3*CC4*C5*CC6 - 2*a2*d6*dq15*m_6*CC2*S3*S5 + 2*a3*d6*dq14*m_6*CC2*S4*S5 + 2*a3*d6*dq14*m_6*CC3*S4*S5 + 8*Ixx5*dq12*CC2*CC3*C4*C5*S5 + 8*Ixx5*dq15*C2*CC3*C4*CC5*S2 + 8*Ixx5*dq13*CC2*CC3*C4*C5*S5 + 8*Ixx5*dq15*CC2*C3*C4*CC5*S3 - 4*Ixx6*dq15*C2*CC3*C4*CC6*S2 - 4*Ixx6*dq15*CC2*C3*C4*CC6*S3 - 4*Ixx6*dq12*CC2*C4*C5*CC6*S5 - 4*Ixx6*dq15*C2*C4*CC5*CC6*S2 - 4*Ixx6*dq16*CC2*CC3*C4*C5*S4 - 4*Ixx6*dq12*CC3*C4*C5*CC6*S5 - 4*Ixx6*dq13*CC2*C4*C5*CC6*S5 - 4*Ixx6*dq13*CC3*C4*C5*CC6*S5 - 4*Ixx6*dq14*CC2*CC3*C5*C6*S6 - 4*Ixx6*dq15*C3*C4*CC5*CC6*S3 + 2*Ixx6*dq25*C2*C3*CC5*CC6*S4 - 4*Ixx6*dq14*CC2*CC4*C5*C6*S6 - 4*Ixx6*dq16*CC2*C4*C5*CC6*S4 + 4*Ixx6*dq26*C2*CC4*C5*CC6*S3 + 4*Ixx6*dq26*C3*CC4*C5*CC6*S2 + 2*Ixx6*dq35*C2*C3*CC5*CC6*S4 - 4*Ixx6*dq14*CC3*CC4*C5*C6*S6 - 4*Ixx6*dq16*CC3*C4*C5*CC6*S4 + 4*Ixx6*dq36*C2*CC4*C5*CC6*S3 + 4*Ixx6*dq36*C3*CC4*C5*CC6*S2 - 2*Ixx6*dq45*C2*C4*CC5*CC6*S3 - 2*Ixx6*dq45*C3*C4*CC5*CC6*S2 + 8*Iyy6*dq12*CC2*CC3*C4*C5*S5 + 8*Iyy6*dq15*C2*CC3*C4*CC5*S2 + 8*Iyy6*dq13*CC2*CC3*C4*C5*S5 + 4*Iyy6*dq15*C2*CC3*C4*CC6*S2 + 8*Iyy6*dq15*CC2*C3*C4*CC5*S3 + 4*Iyy6*dq15*CC2*C3*C4*CC6*S3 + 4*Iyy6*dq12*CC2*C4*C5*CC6*S5 + 4*Iyy6*dq15*C2*C4*CC5*CC6*S2 + 4*Iyy6*dq16*CC2*CC3*C4*C5*S4 + 4*Iyy6*dq12*CC3*C4*C5*CC6*S5 + 4*Iyy6*dq13*CC2*C4*C5*CC6*S5 + 4*Iyy6*dq13*CC3*C4*C5*CC6*S5 + 4*Iyy6*dq14*CC2*CC3*C5*C6*S6 + 4*Iyy6*dq15*C3*C4*CC5*CC6*S3 - 2*Iyy6*dq25*C2*C3*CC5*CC6*S4 + 4*Iyy6*dq14*CC2*CC4*C5*C6*S6 + 4*Iyy6*dq16*CC2*C4*C5*CC6*S4 - 4*Iyy6*dq26*C2*CC4*C5*CC6*S3 - 4*Iyy6*dq26*C3*CC4*C5*CC6*S2 - 2*Iyy6*dq35*C2*C3*CC5*CC6*S4 + 4*Iyy6*dq14*CC3*CC4*C5*C6*S6 + 4*Iyy6*dq16*CC3*C4*C5*CC6*S4 - 4*Iyy6*dq36*C2*CC4*C5*CC6*S3 - 4*Iyy6*dq36*C3*CC4*C5*CC6*S2 + 2*Iyy6*dq45*C2*C4*CC5*CC6*S3 + 2*Iyy6*dq45*C3*C4*CC5*CC6*S2 + 4*Iyz5*dq15*CC2*CC3*C4*C5*S4 + 8*Iyz6*dq12*CC2*CC3*C5*C6*S4 + 8*Iyz6*dq13*CC2*CC3*C5*C6*S4 + 4*Iyz6*dq16*CC2*CC3*C5*C6*S5 - 2*Iyz6*dq16*CC2*CC4*C5*C6*S5 - 2*Iyz6*dq16*CC3*CC4*C5*C6*S5 - 8*Izz5*dq12*CC2*CC3*C4*C5*S5 - 8*Izz5*dq15*C2*CC3*C4*CC5*S2 - 8*Izz5*dq13*CC2*CC3*C4*C5*S5 - 8*Izz5*dq15*CC2*C3*C4*CC5*S3 - 8*Izz6*dq12*CC2*CC3*C4*C5*S5 - 8*Izz6*dq15*C2*CC3*C4*CC5*S2 - 8*Izz6*dq13*CC2*CC3*C4*C5*S5 - 8*Izz6*dq15*CC2*C3*C4*CC5*S3 - 4*XX4*dq12*m_4*C2*CC3*CC4*S2 - 4*XX4*dq12*m_4*CC2*C3*CC4*S3 - 4*XX4*dq13*m_4*C2*CC3*CC4*S2
 - 4*XX4*dq13*m_4*CC2*C3*CC4*S3 - 4*XX5*dq12*m_5*C2*CC3*CC5*S2 - 4*XX4*dq14*m_4*CC2*CC3*C4*S4 + 2*XX5*dq12*m_5*C2*CC4*CC5*S2 - 4*XX5*dq12*m_5*CC2*C3*CC5*S3 - 4*XX5*dq13*m_5*C2*CC3*CC5*S2 + 4*XX6*dq12*m_6*C2*CC3*CC4*S2 + 2*XX5*dq13*m_5*C2*CC4*CC5*S2 - 4*XX5*dq13*m_5*CC2*C3*CC5*S3 + 4*XX6*dq12*m_6*CC2*C3*CC4*S3 + 4*XX6*dq13*m_6*C2*CC3*CC4*S2 + 2*XX5*dq12*m_5*C3*CC4*CC5*S3 + 8*XX6*dq12*m_6*C2*CC3*CC6*S2 + 4*XX6*dq13*m_6*CC2*C3*CC4*S3 + 2*XX5*dq13*m_5*C3*CC4*CC5*S3 + 2*XX6*dq12*m_6*C2*CC4*CC6*S2 + 8*XX6*dq12*m_6*CC2*C3*CC6*S3 + 8*XX6*dq13*m_6*C2*CC3*CC6*S2 + 2*XX5*dq14*m_5*CC2*C4*CC5*S4 - 2*XX5*dq24*m_5*C2*CC4*CC5*S3 - 2*XX5*dq24*m_5*C3*CC4*CC5*S2 + 2*XX6*dq12*m_6*C2*CC5*CC6*S2 + 2*XX6*dq13*m_6*C2*CC4*CC6*S2 + 8*XX6*dq13*m_6*CC2*C3*CC6*S3 + 4*XX6*dq14*m_6*CC2*CC3*C4*S4 + 2*XX5*dq14*m_5*CC3*C4*CC5*S4 - 4*XX5*dq15*m_5*CC2*CC3*C5*S5 - 2*XX5*dq34*m_5*C2*CC4*CC5*S3 - 2*XX5*dq34*m_5*C3*CC4*CC5*S2 + 2*XX6*dq12*m_6*C3*CC4*CC6*S3 + 2*XX6*dq13*m_6*C2*CC5*CC6*S2 + 2*XX5*dq15*m_5*CC2*CC4*C5*S5 + 2*XX6*dq12*m_6*C3*CC5*CC6*S3 + 2*XX6*dq13*m_6*C3*CC4*CC6*S3 + 2*XX5*dq15*m_5*CC3*CC4*C5*S5 + 2*XX6*dq13*m_6*C3*CC5*CC6*S3 + 2*XX6*dq14*m_6*CC2*C4*CC6*S4 - 2*XX6*dq24*m_6*C2*CC4*CC6*S3 - 2*XX6*dq24*m_6*C3*CC4*CC6*S2 + 2*XX6*dq14*m_6*CC3*C4*CC6*S4 + 2*XX6*dq24*m_6*C2*CC5*CC6*S3 + 2*XX6*dq24*m_6*C3*CC5*CC6*S2 - 2*XX6*dq34*m_6*C2*CC4*CC6*S3 - 2*XX6*dq34*m_6*C3*CC4*CC6*S2 + 2*XX6*dq34*m_6*C2*CC5*CC6*S3 + 2*XX6*dq34*m_6*C3*CC5*CC6*S2 + 2*XX6*dq15*m_6*CC2*C5*CC6*S5 + 8*XX6*dq16*m_6*CC2*CC3*C6*S6 + 2*XX6*dq15*m_6*CC3*C5*CC6*S5 + 2*XX6*dq16*m_6*CC2*CC4*C6*S6 + 2*XX6*dq16*m_6*CC2*CC5*C6*S6 + 2*XX6*dq16*m_6*CC3*CC4*C6*S6 + 2*XX6*dq16*m_6*CC3*CC5*C6*S6 + 4*YY5*dq12*m_5*C2*CC3*CC4*S2 + 4*YY5*dq12*m_5*CC2*C3*CC4*S3 + 4*YY5*dq13*m_5*C2*CC3*CC4*S2 + 4*YY5*dq13*m_5*CC2*C3*CC4*S3 - 4*YY6*dq12*m_6*C2*CC3*CC5*S2 + 4*YY5*dq14*m_5*CC2*CC3*C4*S4 - 8*YY6*dq12*m_6*C2*CC3*CC6*S2 + 2*YY6*dq12*m_6*C2*CC4*CC5*S2 - 4*YY6*dq12*m_6*CC2*C3*CC5*S3 - 4*YY6*dq13*m_6*C2*CC3*CC5*S2 - 2*YY6*dq12*m_6*C2*CC4*CC6*S2 - 8*YY6*dq12*m_6*CC2*C3*CC6*S3 - 8*YY6*dq13*m_6*C2*CC3*CC6*S2 + 2*YY6*dq13*m_6*C2*CC4*CC5*S2 - 4*YY6*dq13*m_6*CC2*C3*CC5*S3 - 2*YY6*dq12*m_6*C2*CC5*CC6*S2 + 2*YY6*dq12*m_6*C3*CC4*CC5*S3 - 2*YY6*dq13*m_6*C2*CC4*CC6*S2 - 8*YY6*dq13*m_6*CC2*C3*CC6*S3 - 2*YY6*dq12*m_6*C3*CC4*CC6*S3 - 2*YY6*dq13*m_6*C2*CC5*CC6*S2 + 2*YY6*dq13*m_6*C3*CC4*CC5*S3 - 2*YY6*dq12*m_6*C3*CC5*CC6*S3 - 2*YY6*dq13*m_6*C3*CC4*CC6*S3 + 2*YY6*dq14*m_6*CC2*C4*CC5*S4 - 2*YY6*dq24*m_6*C2*CC4*CC5*S3 - 2*YY6*dq24*m_6*C3*CC4*CC5*S2 - 2*YY6*dq13*m_6*C3*CC5*CC6*S3 - 2*YY6*dq14*m_6*CC2*C4*CC6*S4 + 2*YY6*dq14*m_6*CC3*C4*CC5*S4 - 4*YY6*dq15*m_6*CC2*CC3*C5*S5 + 2*YY6*dq24*m_6*C2*CC4*CC6*S3 + 2*YY6*dq24*m_6*C3*CC4*CC6*S2 - 2*YY6*dq34*m_6*C2*CC4*CC5*S3 - 2*YY6*dq34*m_6*C3*CC4*CC5*S2 - 2*YY6*dq14*m_6*CC3*C4*CC6*S4 + 2*YY6*dq15*m_6*CC2*CC4*C5*S5 - 2*YY6*dq24*m_6*C2*CC5*CC6*S3 - 2*YY6*dq24*m_6*C3*CC5*CC6*S2 + 2*YY6*dq34*m_6*C2*CC4*CC6*S3 + 2*YY6*dq34*m_6*C3*CC4*CC6*S2 + 2*YY6*dq15*m_6*CC3*CC4*C5*S5 - 2*YY6*dq34*m_6*C2*CC5*CC6*S3 - 2*YY6*dq34*m_6*C3*CC5*CC6*S2 - 2*YY6*dq15*m_6*CC2*C5*CC6*S5 - 8*YY6*dq16*m_6*CC2*CC3*C6*S6 - 2*YY6*dq15*m_6*CC3*C5*CC6*S5 - 2*YY6*dq16*m_6*CC2*CC4*C6*S6 - 2*YY6*dq16*m_6*CC2*CC5*C6*S6 - 2*YY6*dq16*m_6*CC3*CC4*C6*S6 - 2*YY6*dq16*m_6*CC3*CC5*C6*S6 + 4*ZZ4*dq12*m_4*C2*CC3*CC4*S2 + 4*ZZ4*dq12*m_4*CC2*C3*CC4*S3 + 4*ZZ4*dq13*m_4*C2*CC3*CC4*S2 + 4*ZZ4*dq13*m_4*CC2*C3*CC4*S3 - 4*ZZ5*dq12*m_5*C2*CC3*CC4*S2 + 4*ZZ5*dq12*m_5*C2*CC3*CC5*S2 - 4*ZZ5*dq12*m_5*CC2*C3*CC4*S3 - 4*ZZ5*dq13*m_5*C2*CC3*CC4*S2 + 4*ZZ4*dq14*m_4*CC2*CC3*C4*S4 - 2*ZZ5*dq12*m_5*C2*CC4*CC5*S2 + 4*ZZ5*dq12*m_5*CC2*C3*CC5*S3 + 4*ZZ5*dq13*m_5*C2*CC3*CC5*S2 - 4*ZZ5*dq13*m_5*CC2*C3*CC4*S3 - 4*ZZ6*dq12*m_6*C2*CC3*CC4*S2 - 2*ZZ5*dq13*m_5*C2*CC4*CC5*S2 + 4*ZZ5*dq13*m_5*CC2*C3*CC5*S3 + 4*ZZ6*dq12*m_6*C2*CC3*CC5*S2 - 4*ZZ6*dq12*m_6*CC2*C3*CC4*S3 - 4*ZZ6*dq13*m_6*C2*CC3*CC4*S2 - 2*ZZ5*dq12*m_5*C3*CC4*CC5*S3 - 4*ZZ5*dq14*m_5*CC2*CC3*C4*S4 - 2*ZZ6*dq12*m_6*C2*CC4*CC5*S2 + 4*ZZ6*dq12*m_6*CC2*C3*CC5*S3 + 4*ZZ6*dq13*m_6*C2*CC3*CC5*S2 - 4*ZZ6*dq13*m_6*CC2*C3*CC4*S3 - 2*ZZ5*dq13*m_5*C3*CC4*CC5*S3 - 2*ZZ6*dq13*m_6*C2*CC4*CC5*S2 + 4*ZZ6*dq13*m_6*CC2*C3*CC5*S3 - 2*ZZ5*dq14*m_5*CC2*C4*CC5*S4 + 2*ZZ5*dq24*m_5*C2*CC4*CC5*S3 + 2*ZZ5*dq24*m_5*C3*CC4*CC5*S2 - 2*ZZ6*dq12*m_6*C3*CC4*CC5*S3 - 4*ZZ6*dq14*m_6*CC2*CC3*C4*S4 - 2*ZZ5*dq14*m_5*CC3*C4*CC5*S4 + 4*ZZ5*dq15*m_5*CC2*CC3*C5*S5 + 2*ZZ5*dq34*m_5*C2*CC4*CC5*S3 + 2*ZZ5*dq34*m_5*C3*CC4*CC5*S2 - 2*ZZ6*dq13*m_6*C3*CC4*CC5*S3 - 2*ZZ5*dq15*m_5*CC2*CC4*C5*S5 - 2*ZZ6*dq14*m_6*CC2*C4*CC5*S4 + 2*ZZ6*dq24*m_6*C2*CC4*CC5*S3 + 2*ZZ6*dq24*m_6*C3*CC4*CC5*S2 - 2*ZZ5*dq15*m_5*CC3*CC4*C5*S5 - 2*ZZ6*dq14*m_6*CC3*C4*CC5*S4 + 4*ZZ6*dq15*m_6*CC2*CC3*C5*S5 + 2*ZZ6*dq34*m_6*C2*CC4*CC5*S3 + 2*ZZ6*dq34*m_6*C3*CC4*CC5*S2 - 2*ZZ6*dq15*m_6*CC2*CC4*C5*S5 - 2*ZZ6*dq15*m_6*CC3*CC4*C5*S5 + 8*Ixy6*dq16*CC2*CC3*CC4*CC5*CC6 - 4*Ixy5*dq15*CC2*CC3*C4*S4*S5 + 4*Ixy6*dq15*CC2*CC3*C4*S4*S5 - 8*Ixy6*dq23*CC4*C5*CC6*S2*S3 + 4*Ixy6*dq15*CC2*C4*CC6*S4*S5 - 4*Ixy6*dq25*C2*CC4*CC6*S3*S5 - 4*Ixy6*dq25*C3*CC4*CC6*S2*S5 + 4*Ixy6*dq15*CC3*C4*CC6*S4*S5 - 4*Ixy6*dq35*C2*CC4*CC6*S3*S5 - 4*Ixy6*dq35*C3*CC4*CC6*S2*S5 + 8*Ixz5*dq14*C2*CC3*CC5*S2*S4 + 8*Ixz5*dq14*CC2*C3*CC5*S3*S4 + 8*Ixz6*dq12*CC2*CC3*C5*S4*S6 + 8*Ixz6*dq13*CC2*CC3*C5*S4*S6 + 4*Ixz6*dq16*CC2*CC3*C5*S5*S6 - 2*Ixz6*dq16*CC2*CC4*C5*S5*S6 - 2*Ixz6*dq16*CC3*CC4*C5*S5*S6 - 4*dd6*dq12*m_6*C2*CC3*CC4*S2 + 4*dd6*dq12*m_6*C2*CC3*CC5*S2 - 4*dd6*dq12*m_6*CC2*C3*CC4*S3 - 4*dd6*dq13*m_6*C2*CC3*CC4*S2 - 2*dd6*dq12*m_6*C2*CC4*CC5*S2 + 4*dd6*dq12*m_6*CC2*C3*CC5*S3 + 4*dd6*dq13*m_6*C2*CC3*CC5*S2 - 4*dd6*dq13*m_6*CC2*C3*CC4*S3 - 2*dd6*dq13*m_6*C2*CC4*CC5*S2 + 4*dd6*dq13*m_6*CC2*C3*CC5*S3 - 2*dd6*dq12*m_6*C3*CC4*CC5*S3 - 4*dd6*dq14*m_6*CC2*CC3*C4*S4 - 2*dd6*dq13*m_6*C3*CC4*CC5*S3 - 2*dd6*dq14*m_6*CC2*C4*CC5*S4 + 2*dd6*dq24*m_6*C2*CC4*CC5*S3 + 2*dd6*dq24*m_6*C3*CC4*CC5*S2 - 2*dd6*dq14*m_6*CC3*C4*CC5*S4 + 4*dd6*dq15*m_6*CC2*CC3*C5*S5 + 2*dd6*dq34*m_6*C2*CC4*CC5*S3 + 2*dd6*dq34*m_6*C3*CC4*CC5*S2 - 2*dd6*dq15*m_6*CC2*CC4*C5*S5 - 2*dd6*dq15*m_6*CC3*CC4*C5*S5 + XX6*dq22*m_6*C2*C3*C5*C6*S6 + XX6*dq33*m_6*C2*C3*C5*C6*S6 - XX6*dq55*m_6*C2*C3*C5*C6*S6 - YY6*dq22*m_6*C2*C3*C5*C6*S6 - YY6*dq33*m_6*C2*C3*C5*C6*S6 + YY6*dq55*m_6*C2*C3*C5*C6*S6 - 8*X4*Y4*dq12*m_4*CC2*CC3*C4 - 8*X4*Y4*dq13*m_4*CC2*CC3*C4 + 4*X5*Y5*dq14*m_5*CC2*CC3*C5 + 4*X5*Y5*dq14*m_5*CC2*CC4*C5 + 4*X5*Y5*dq14*m_5*CC3*CC4*C5 - 4*X6*Y6*dq14*m_6*CC2*CC3*C5 - 4*X6*Y6*dq14*m_6*CC2*CC4*C5 - 4*X6*Y6*dq14*m_6*CC3*CC4*C5 - 4*X6*Y6*dq14*m_6*CC2*C5*CC6 - 4*X6*Y6*dq14*m_6*CC3*C5*CC6 - 8*X5*Z5*dq12*m_5*CC2*CC3*C4 - 8*X5*Z5*dq13*m_5*CC2*CC3*C4 - 8*X5*Z5*dq12*m_5*CC2*C4*CC5 - 8*X5*Z5*dq12*m_5*CC3*C4*CC5 - 8*X5*Z5*dq13*m_5*CC2*C4*CC5 - 8*X5*Z5*dq13*m_5*CC3*C4*CC5 - 4*X6*Z6*dq15*m_6*CC2*CC3*C6 + 2*X6*Z6*dq15*m_6*CC2*CC4*C6 - 4*X6*Z6*dq15*m_6*CC2*CC5*C6 + 2*X6*Z6*dq15*m_6*CC3*CC4*C6 - 4*X6*Z6*dq15*m_6*CC3*CC5*C6 - 2*Ixx6*dq25*CC5*CC6*S2*S3*S4 - 2*Ixx6*dq35*CC5*CC6*S2*S3*S4 + 2*Iyy6*dq25*CC5*CC6*S2*S3*S4 + 2*Iyy6*dq35*CC5*CC6*S2*S3*S4 - 2*Ixy6*dq22*C2*C3*C4*C6*S4*S6 - 2*Ixy6*dq33*C2*C3*C4*C6*S4*S6 + 2*Ixz5*dq22*C2*C3*C4*C5*S4*S5 + 2*Ixz5*dq33*C2*C3*C4*C5*S4*S5 - 4*Y5*a3*dq14*m_5*CC2*CC3*C4 - 4*Z4*a3*dq14*m_4*CC2*CC3*C4 + 8*Z5*a3*dq12*m_5*CC2*CC3*C5 + 8*Z5*a3*dq13*m_5*CC2*CC3*C5 + 8*Z6*a3*dq12*m_6*CC2*CC3*C5 + 8*Z6*a3*dq13*m_6*CC2*CC3*C5 + 8*X4*d4*dq12*m_4*CC2*CC3*C4 + 8*X4*d4*dq13*m_4*CC2*CC3*C4 + 4*X5*d4*dq15*m_5*CC2*CC3*C5 - 4*X6*d6*dq15*m_6*CC2*CC3*C6 + 2*X6*d6*dq15*m_6*CC2*CC4*C6 - 4*X6*d6*dq15*m_6*CC2*CC5*C6 + 2*X6*d6*dq15*m_6*CC3*CC4*C6 - 4*X6*d6*dq15*m_6*CC3*CC5*C6 + 8*Y4*Z4*dq12*m_4*CC2*CC3*S4 + 8*Y4*Z4*dq13*m_4*CC2*CC3*S4 + 4*Y5*Z5*dq14*m_5*CC2*CC3*S5 + 4*Y5*Z5*dq14*m_5*CC2*CC4*S5 + 4*Y5*Z5*dq14*m_5*CC3*CC4*S5 + 4*Y6*Z6*dq15*m_6*CC2*CC3*S6 - 2*Y6*Z6*dq15*m_6*CC2*CC4*S6 + 4*Y6*Z6*dq15*m_6*CC2*CC5*S6 - 2*Y6*Z6*dq15*m_6*CC3*CC4*S6 + 4*Y6*Z6*dq15*m_6*CC3*CC5*S6 + 8*a3*d6*dq12*m_6*CC2*CC3*C5 + 8*a3*d6*dq13*m_6*CC2*CC3*C5 - Ixx6*dq22*C2*C4*C6*S3*S5*S6 - Ixx6*dq22*C3*C4*C6*S2*S5*S6 - Ixx6*dq33*C2*C4*C6*S3*S5*S6 - Ixx6*dq33*C3*C4*C6*S2*S5*S6 + Ixx6*dq44*C2*C4*C6*S3*S5*S6 + Ixx6*dq44*C3*C4*C6*S2*S5*S6 - Ixx6*dq55*C2*C4*C6*S3*S5*S6 - Ixx6*dq55*C3*C4*C6*S2*S5*S6 + Iyy6*dq22*C2*C4*C6*S3*S5*S6 + Iyy6*dq22*C3*C4*C6*S2*S5*S6 + Iyy6*dq33*C2*C4*C6*S3*S5*S6 + Iyy6*dq33*C3*C4*C6*S2*S5*S6 - Iyy6*dq44*C2*C4*C6*S3*S5*S6 - Iyy6*dq44*C3*C4*C6*S2*S5*S6 + Iyy6*dq55*C2*C4*C6*S3*S5*S6 + Iyy6*dq55*C3*C4*C6*S2*S5*S6 - 4*X4*a3*dq14*m_4*CC2*CC3*S4 - 8*X5*a3*dq12*m_5*CC2*CC3*S5 - 8*X5*a3*dq13*m_5*CC2*CC3*S5 - Y6*a3*dq22*m_6*C2*C3*C4*C6 - Y6*a3*dq33*m_6*C2*C3*C4*C6 + Y6*a3*dq44*m_6*C2*C3*C4*C6 + Y6*a3*dq66*m_6*C2*C3*C4*C6 + XX5*dq22*m_5*C2*C5*S3*S4*S5 + XX5*dq22*m_5*C3*C5*S2*S4*S5 + XX5*dq33*m_5*C2*C5*S3*S4*S5 + XX5*dq33*m_5*C3*C5*S2*S4*S5 - XX5*dq44*m_5*C2*C5*S3*S4*S5 - XX5*dq44*m_5*C3*C5*S2*S4*S5 - XX6*dq22*m_6*C5*C6*S2*S3*S6 - XX6*dq33*m_6*C5*C6*S2*S3*S6 + XX6*dq55*m_6*C5*C6*S2*S3*S6 - 8*Y5*d4*dq12*m_5*CC2*CC3*S4 - 8*Y5*d4*dq13*m_5*CC2*CC3*S4 + 4*Y6*d6*dq15*m_6*CC2*CC3*S6 - 2*Y6*d6*dq15*m_6*CC2*CC4*S6 + 4*Y6*d6*dq15*m_6*CC2*CC5*S6 - 2*Y6*d6*dq15*m_6*CC3*CC4*S6 + 4*Y6*d6*dq15*m_6*CC3*CC5*S6 + YY6*dq22*m_6*C2*C5*S3*S4*S5 + YY6*dq22*m_6*C3*C5*S2*S4*S5 + YY6*dq33*m_6*C2*C5*S3*S4*S5 + YY6*dq33*m_6*C3*C5*S2*S4*S5 - YY6*dq44*m_6*C2*C5*S3*S4*S5 - YY6*dq44*m_6*C3*C5*S2*S4*S5 + YY6*dq22*m_6*C5*C6*S2*S3*S6 + YY6*dq33*m_6*C5*C6*S2*S3*S6 - YY6*dq55*m_6*C5*C6*S2*S3*S6 - 8*Z4*d4*dq12*m_4*CC2*CC3*S4 - 8*Z4*d4*dq13*m_4*CC2*CC3*S4 + 4*Z5*d4*dq15*m_5*CC2*CC3*S5 + 4*Z6*d4*dq15*m_6*CC2*CC3*S5 - ZZ5*dq22*m_5*C2*C5*S3*S4*S5 - ZZ5*dq22*m_5*C3*C5*S2*S4*S5 - ZZ5*dq33*m_5*C2*C5*S3*S4*S5 - ZZ5*dq33*m_5*C3*C5*S2*S4*S5 + ZZ5*dq44*m_5*C2*C5*S3*S4*S5 + ZZ5*dq44*m_5*C3*C5*S2*S4*S5 - ZZ6*dq22*m_6*C2*C5*S3*S4*S5 - ZZ6*dq22*m_6*C3*C5*S2*S4*S5 - ZZ6*dq33*m_6*C2*C5*S3*S4*S5 - ZZ6*dq33*m_6*C3*C5*S2*S4*S5 + ZZ6*dq44*m_6*C2*C5*S3*S4*S5 + ZZ6*dq44*m_6*C3*C5*S2*S4*S5 - Y5*Z5*dq22*m_5*C2*C4*C5*S3 - Y5*Z5*dq22*m_5*C3*C4*C5*S2 - Y5*Z5*dq33*m_5*C2*C4*C5*S3 - Y5*Z5*dq33*m_5*C3*C4*C5*S2 + Y5*Z5*dq44*m_5*C2*C4*C5*S3 + Y5*Z5*dq44*m_5*C3*C4*C5*S2 - Y5*Z5*dq55*m_5*C2*C4*C5*S3
 - Y5*Z5*dq55*m_5*C3*C4*C5*S2 + Y6*Z6*dq22*m_6*C2*C3*C6*S5 + Y6*Z6*dq33*m_6*C2*C3*C6*S5 - Y6*Z6*dq55*m_6*C2*C3*C6*S5 + Y6*Z6*dq66*m_6*C2*C3*C6*S5 + 2*Ixy6*dq22*C4*C6*S2*S3*S4*S6 + 2*Ixy6*dq33*C4*C6*S2*S3*S4*S6 - 2*Ixz5*dq22*C4*C5*S2*S3*S4*S5 - 2*Ixz5*dq33*C4*C5*S2*S3*S4*S5 - 2*Ixx6*dq23*C2*C3*C5*C6*S6 + 2*Iyy6*dq23*C2*C3*C5*C6*S6 - 2*Iyz6*dq14*C2*C4*C5*C6*S2 + 2*Iyz6*dq23*C2*C4*C5*C6*S3 + 2*Iyz6*dq23*C3*C4*C5*C6*S2 - 2*Iyz6*dq14*C3*C4*C5*C6*S3 + 2*Iyz6*dq25*C2*C3*C4*C6*S5 + 2*Iyz6*dq35*C2*C3*C4*C6*S5 - 2*Iyz6*dq46*C2*C3*C5*C6*S5 + 4*d4*d6*dq15*m_6*CC2*CC3*S5 - dd6*dq22*m_6*C2*C5*S3*S4*S5 - dd6*dq22*m_6*C3*C5*S2*S4*S5 - dd6*dq33*m_6*C2*C5*S3*S4*S5 - dd6*dq33*m_6*C3*C5*S2*S4*S5 + dd6*dq44*m_6*C2*C5*S3*S4*S5 + dd6*dq44*m_6*C3*C5*S2*S4*S5 - X5*a3*dq22*m_5*C2*C3*C5*S4 - X5*a3*dq33*m_5*C2*C3*C5*S4 + X5*a3*dq44*m_5*C2*C3*C5*S4 + X5*a3*dq55*m_5*C2*C3*C5*S4 - X6*a3*dq22*m_6*C2*C3*C4*S6 - X6*a2*dq22*m_6*C2*C5*C6*S4 - X6*a3*dq33*m_6*C2*C3*C4*S6 + X6*a3*dq44*m_6*C2*C3*C4*S6 + X6*a2*dq44*m_6*C2*C5*C6*S4 + X6*a2*dq55*m_6*C2*C5*C6*S4 + X6*a3*dq66*m_6*C2*C3*C4*S6 + X6*a2*dq66*m_6*C2*C5*C6*S4 - 2*XX4*dq23*m_4*C2*C3*C4*S4 + 2*XX6*dq23*m_6*C2*C3*C4*S4 + 2*XX5*dq45*m_5*C2*C3*C5*S5 + 2*XX6*dq26*m_6*C2*C3*C4*S5 + 2*XX6*dq36*m_6*C2*C3*C4*S5 + 2*XX6*dq56*m_6*C2*C4*C5*S3 + 2*XX6*dq56*m_6*C3*C4*C5*S2 - 2*XX6*dq46*m_6*C2*C3*C6*S6 - Y6*d4*dq22*m_6*C2*C4*C6*S3 - Y6*d4*dq22*m_6*C3*C4*C6*S2 - Y6*d4*dq33*m_6*C2*C4*C6*S3 - Y6*d4*dq33*m_6*C3*C4*C6*S2 + Y6*d4*dq44*m_6*C2*C4*C6*S3 + Y6*d4*dq44*m_6*C3*C4*C6*S2 + Y6*d6*dq22*m_6*C2*C3*C6*S5 + Y6*d4*dq66*m_6*C2*C4*C6*S3 + Y6*d4*dq66*m_6*C3*C4*C6*S2 + Y6*d6*dq33*m_6*C2*C3*C6*S5 - Y6*d6*dq55*m_6*C2*C3*C6*S5 + Y6*d6*dq66*m_6*C2*C3*C6*S5 + 2*YY5*dq23*m_5*C2*C3*C4*S4 + 2*YY6*dq45*m_6*C2*C3*C5*S5 + 2*YY6*dq46*m_6*C2*C3*C6*S6 - 2*Z6*d6*dq22*m_6*C2*C3*C4*S4 - 2*Z6*d6*dq33*m_6*C2*C3*C4*S4 + 2*ZZ4*dq23*m_4*C2*C3*C4*S4 - 2*ZZ5*dq23*m_5*C2*C3*C4*S4 - 2*ZZ6*dq23*m_6*C2*C3*C4*S4 - 2*ZZ5*dq45*m_5*C2*C3*C5*S5 - 2*ZZ6*dq45*m_6*C2*C3*C5*S5 + X5*Y5*dq22*m_5*C2*C4*S3*S5 + X5*Y5*dq22*m_5*C3*C4*S2*S5 + X5*Y5*dq33*m_5*C2*C4*S3*S5 + X5*Y5*dq33*m_5*C3*C4*S2*S5 - X5*Y5*dq44*m_5*C2*C4*S3*S5 - X5*Y5*dq44*m_5*C3*C4*S2*S5 + X5*Y5*dq55*m_5*C2*C4*S3*S5 + X5*Y5*dq55*m_5*C3*C4*S2*S5 - X6*Y6*dq22*m_6*C2*C4*S3*S5 - X6*Y6*dq22*m_6*C3*C4*S2*S5 - X6*Y6*dq33*m_6*C2*C4*S3*S5 - X6*Y6*dq33*m_6*C3*C4*S2*S5 + X6*Y6*dq44*m_6*C2*C4*S3*S5 + X6*Y6*dq44*m_6*C3*C4*S2*S5 - X6*Y6*dq55*m_6*C2*C4*S3*S5 - X6*Y6*dq55*m_6*C3*C4*S2*S5 + X6*Z6*dq22*m_6*C2*C6*S3*S4 + X6*Z6*dq22*m_6*C3*C6*S2*S4 + X6*Z6*dq22*m_6*C2*C3*S5*S6 + X6*Z6*dq33*m_6*C2*C6*S3*S4 + X6*Z6*dq33*m_6*C3*C6*S2*S4 + X6*Z6*dq33*m_6*C2*C3*S5*S6 - X6*Z6*dq44*m_6*C2*C6*S3*S4 - X6*Z6*dq44*m_6*C3*C6*S2*S4 - X6*Z6*dq55*m_6*C2*C3*S5*S6 + X6*Z6*dq66*m_6*C2*C6*S3*S4 + X6*Z6*dq66*m_6*C3*C6*S2*S4 + X6*Z6*dq66*m_6*C2*C3*S5*S6 - 16*Ixz6*dq12*CC2*CC3*C4*CC5*C6 - 16*Ixz6*dq13*CC2*CC3*C4*CC5*C6 - 8*Ixy4*dq12*C2*C3*C4*S2*S3 - 8*Ixy4*dq13*C2*C3*C4*S2*S3 + 4*Ixy5*dq12*C2*C4*C5*S2*S4 + 4*Ixy5*dq14*C2*C3*C5*S2*S3 + 4*Ixy5*dq13*C2*C4*C5*S2*S4 - 4*Ixy6*dq12*C2*C4*C5*S2*S4 - 4*Ixy6*dq14*C2*C3*C5*S2*S3 + 4*Ixy5*dq12*C3*C4*C5*S3*S4 - 4*Ixy6*dq13*C2*C4*C5*S2*S4 + 4*Ixy5*dq13*C3*C4*C5*S3*S4 - 4*Ixy6*dq12*C3*C4*C5*S3*S4 - 4*Ixy5*dq24*C2*C4*C5*S3*S4 - 4*Ixy5*dq24*C3*C4*C5*S2*S4 - 4*Ixy6*dq13*C3*C4*C5*S3*S4 - 4*Ixy5*dq34*C2*C4*C5*S3*S4 - 4*Ixy5*dq34*C3*C4*C5*S2*S4 + 4*Ixy6*dq24*C2*C4*C5*S3*S4 + 4*Ixy6*dq24*C3*C4*C5*S2*S4 - 4*Ixy6*dq16*C2*C4*C5*S2*S5 + 4*Ixy6*dq34*C2*C4*C5*S3*S4 + 4*Ixy6*dq34*C3*C4*C5*S2*S4 - 4*Ixy6*dq15*C2*C4*C6*S2*S6 - 4*Ixy6*dq16*C3*C4*C5*S3*S5 + 2*Ixy6*dq26*C2*C3*C5*S4*S5 - 4*Ixy6*dq15*C3*C4*C6*S3*S6 + 2*Ixy6*dq36*C2*C3*C5*S4*S5 - 4*Ixy6*dq12*C4*C5*C6*S5*S6 - 2*Ixy6*dq46*C2*C4*C5*S3*S5 - 2*Ixy6*dq46*C3*C4*C5*S2*S5 - 4*Ixy6*dq13*C4*C5*C6*S5*S6 + 4*Ixy6*dq26*C2*C5*C6*S3*S6 + 4*Ixy6*dq26*C3*C5*C6*S2*S6 - 4*Ixy6*dq45*C2*C4*C6*S3*S6 - 4*Ixy6*dq45*C3*C4*C6*S2*S6 + 4*Ixy6*dq36*C2*C5*C6*S3*S6 + 4*Ixy6*dq36*C3*C5*C6*S2*S6 - 4*Ixy6*dq56*C2*C3*C6*S5*S6 - 8*Ixz5*dq12*C2*C3*C4*S2*S3 - 8*Ixz5*dq13*C2*C3*C4*S2*S3 - 4*Ixz6*dq15*C2*C3*C6*S2*S3 - 8*Ixz5*dq15*C2*C4*C5*S2*S5 - 4*Ixz6*dq12*C2*C5*C6*S2*S5 - 4*Ixz6*dq13*C2*C5*C6*S2*S5 - 2*Ixz6*dq14*C2*C4*C5*S2*S6 - 8*Ixz5*dq15*C3*C4*C5*S3*S5 + 4*Ixz5*dq25*C2*C3*C5*S4*S5 - 4*Ixz6*dq12*C3*C5*C6*S3*S5 + 2*Ixz6*dq23*C2*C4*C5*S3*S6 + 2*Ixz6*dq23*C3*C4*C5*S2*S6 + 4*Ixz5*dq35*C2*C3*C5*S4*S5 - 4*Ixz6*dq13*C3*C5*C6*S3*S5 - 2*Ixz6*dq14*C3*C4*C5*S3*S6 - 2*Ixz6*dq16*C2*C5*C6*S2*S4 - 2*Ixz6*dq25*C2*C4*C6*S3*S4 - 2*Ixz6*dq25*C3*C4*C6*S2*S4 - 4*Ixz5*dq45*C2*C4*C5*S3*S5 - 4*Ixz5*dq45*C3*C4*C5*S2*S5 - 4*Ixz6*dq24*C2*C5*C6*S3*S5 - 4*Ixz6*dq24*C3*C5*C6*S2*S5 + 2*Ixz6*dq25*C2*C3*C4*S5*S6 - 2*Ixz6*dq35*C2*C4*C6*S3*S4 - 2*Ixz6*dq35*C3*C4*C6*S2*S4 - 2*Ixz6*dq16*C3*C5*C6*S3*S4 - 4*Ixz6*dq34*C2*C5*C6*S3*S5 - 4*Ixz6*dq34*C3*C5*C6*S2*S5 + 2*Ixz6*dq35*C2*C3*C4*S5*S6 - 2*Ixz6*dq46*C2*C5*C6*S3*S4 - 2*Ixz6*dq46*C3*C5*C6*S2*S4 - 2*Ixz6*dq46*C2*C3*C5*S5*S6 - 2*dd6*dq23*m_6*C2*C3*C4*S4 - 2*dd6*dq45*m_6*C2*C3*C5*S5 + Y6*a3*dq22*m_6*C4*C6*S2*S3 + Y6*a2*dq22*m_6*C2*C5*S4*S6 + Y6*a3*dq33*m_6*C4*C6*S2*S3 - Y6*a3*dq44*m_6*C4*C6*S2*S3 - Y6*a2*dq44*m_6*C2*C5*S4*S6 - Y6*a2*dq55*m_6*C2*C5*S4*S6 - Y6*a3*dq66*m_6*C4*C6*S2*S3 - Y6*a2*dq66*m_6*C2*C5*S4*S6 - Z5*a3*dq22*m_5*C2*C3*S4*S5 - Z5*a3*dq33*m_5*C2*C3*S4*S5 + Z5*a3*dq44*m_5*C2*C3*S4*S5 - Z6*a3*dq22*m_6*C2*C3*S4*S5 + Z5*a3*dq55*m_5*C2*C3*S4*S5 - Z6*a3*dq33*m_6*C2*C3*S4*S5 + Z6*a3*dq44*m_6*C2*C3*S4*S5 + Z6*a3*dq55*m_6*C2*C3*S4*S5 - X5*d4*dq22*m_5*C2*C5*S3*S4 - X5*d4*dq22*m_5*C3*C5*S2*S4 - X5*d4*dq33*m_5*C2*C5*S3*S4 - X5*d4*dq33*m_5*C3*C5*S2*S4 + X5*d4*dq44*m_5*C2*C5*S3*S4 + X5*d4*dq44*m_5*C3*C5*S2*S4 + X5*d4*dq55*m_5*C2*C5*S3*S4 + X5*d4*dq55*m_5*C3*C5*S2*S4 - X6*d4*dq22*m_6*C2*C4*S3*S6 - X6*d4*dq22*m_6*C3*C4*S2*S6 - X6*d4*dq33*m_6*C2*C4*S3*S6 - X6*d4*dq33*m_6*C3*C4*S2*S6 + X6*d4*dq44*m_6*C2*C4*S3*S6 + X6*d4*dq44*m_6*C3*C4*S2*S6 + X6*d6*dq22*m_6*C2*C6*S3*S4 + X6*d6*dq22*m_6*C3*C6*S2*S4 + X6*d6*dq22*m_6*C2*C3*S5*S6 + X6*d6*dq33*m_6*C2*C6*S3*S4 + X6*d6*dq33*m_6*C3*C6*S2*S4 + X6*d4*dq66*m_6*C2*C4*S3*S6 + X6*d4*dq66*m_6*C3*C4*S2*S6 + X6*d6*dq33*m_6*C2*C3*S5*S6 - X6*d6*dq44*m_6*C2*C6*S3*S4 - X6*d6*dq44*m_6*C3*C6*S2*S4 - X6*d6*dq55*m_6*C2*C3*S5*S6 + X6*d6*dq66*m_6*C2*C6*S3*S4 + X6*d6*dq66*m_6*C3*C6*S2*S4 + X6*d6*dq66*m_6*C2*C3*S5*S6 + 2*X5*Y5*dq23*m_5*C2*C3*C5 - 2*X6*Y6*dq23*m_6*C2*C3*C5 + 2*X6*Z6*dq45*m_6*C2*C3*C6 - Y6*Z6*dq22*m_6*C2*S3*S4*S6 - Y6*Z6*dq22*m_6*C3*S2*S4*S6 - Y6*Z6*dq22*m_6*C6*S2*S3*S5 - Y6*Z6*dq33*m_6*C2*S3*S4*S6 - Y6*Z6*dq33*m_6*C3*S2*S4*S6 - Y6*Z6*dq33*m_6*C6*S2*S3*S5 + Y6*Z6*dq44*m_6*C2*S3*S4*S6 + Y6*Z6*dq44*m_6*C3*S2*S4*S6 + Y6*Z6*dq55*m_6*C6*S2*S3*S5 - Y6*Z6*dq66*m_6*C2*S3*S4*S6 - Y6*Z6*dq66*m_6*C3*S2*S4*S6 - Y6*Z6*dq66*m_6*C6*S2*S3*S5 + 4*Ixx5*dq12*C2*CC3*CC4*CC5*S2 + 4*Ixx5*dq12*CC2*C3*CC4*CC5*S3 + 4*Ixx5*dq13*C2*CC3*CC4*CC5*S2 + 4*Ixx5*dq13*CC2*C3*CC4*CC5*S3 + 4*Ixx6*dq12*C2*CC3*CC4*CC6*S2 + 4*Ixx6*dq12*C2*CC3*CC5*CC6*S2 + 4*Ixx6*dq12*CC2*C3*CC4*CC6*S3 + 4*Ixx6*dq13*C2*CC3*CC4*CC6*S2 + 4*Ixx5*dq14*CC2*CC3*C4*CC5*S4 - 2*Ixx6*dq12*C2*CC4*CC5*CC6*S2 + 4*Ixx6*dq12*CC2*C3*CC5*CC6*S3 + 4*Ixx6*dq13*C2*CC3*CC5*CC6*S2 + 4*Ixx6*dq13*CC2*C3*CC4*CC6*S3 - 2*Ixx6*dq13*C2*CC4*CC5*CC6*S2 + 4*Ixx6*dq13*CC2*C3*CC5*CC6*S3 + 4*Ixx5*dq15*CC2*CC3*CC4*C5*S5 - 2*Ixx6*dq12*C3*CC4*CC5*CC6*S3 + 4*Ixx6*dq14*CC2*CC3*C4*CC6*S4 - 2*Ixx6*dq13*C3*CC4*CC5*CC6*S3 - 2*Ixx6*dq14*CC2*C4*CC5*CC6*S4 + 2*Ixx6*dq24*C2*CC4*CC5*CC6*S3 + 2*Ixx6*dq24*C3*CC4*CC5*CC6*S2 - 2*Ixx6*dq14*CC3*C4*CC5*CC6*S4 + 4*Ixx6*dq15*CC2*CC3*C5*CC6*S5 + 2*Ixx6*dq34*C2*CC4*CC5*CC6*S3 + 2*Ixx6*dq34*C3*CC4*CC5*CC6*S2 - 2*Ixx6*dq15*CC2*CC4*C5*CC6*S5 + 4*Ixx6*dq16*CC2*CC3*CC4*C6*S6 - 2*Ixx6*dq15*CC3*CC4*C5*CC6*S5 + 4*Ixx6*dq16*CC2*CC3*CC5*C6*S6 - 2*Ixx6*dq16*CC2*CC4*CC5*C6*S6 - 2*Ixx6*dq16*CC3*CC4*CC5*C6*S6 + 4*Iyy6*dq12*C2*CC3*CC4*CC5*S2 - 4*Iyy6*dq12*C2*CC3*CC4*CC6*S2 + 4*Iyy6*dq12*CC2*C3*CC4*CC5*S3 + 4*Iyy6*dq13*C2*CC3*CC4*CC5*S2 - 4*Iyy6*dq12*C2*CC3*CC5*CC6*S2 - 4*Iyy6*dq12*CC2*C3*CC4*CC6*S3 - 4*Iyy6*dq13*C2*CC3*CC4*CC6*S2 + 4*Iyy6*dq13*CC2*C3*CC4*CC5*S3 + 2*Iyy6*dq12*C2*CC4*CC5*CC6*S2 - 4*Iyy6*dq12*CC2*C3*CC5*CC6*S3 - 4*Iyy6*dq13*C2*CC3*CC5*CC6*S2 - 4*Iyy6*dq13*CC2*C3*CC4*CC6*S3 + 2*Iyy6*dq13*C2*CC4*CC5*CC6*S2 - 4*Iyy6*dq13*CC2*C3*CC5*CC6*S3 + 4*Iyy6*dq14*CC2*CC3*C4*CC5*S4 + 2*Iyy6*dq12*C3*CC4*CC5*CC6*S3 - 4*Iyy6*dq14*CC2*CC3*C4*CC6*S4 + 2*Iyy6*dq13*C3*CC4*CC5*CC6*S3 + 4*Iyy6*dq15*CC2*CC3*CC4*C5*S5 + 2*Iyy6*dq14*CC2*C4*CC5*CC6*S4 - 2*Iyy6*dq24*C2*CC4*CC5*CC6*S3 - 2*Iyy6*dq24*C3*CC4*CC5*CC6*S2 + 2*Iyy6*dq14*CC3*C4*CC5*CC6*S4 - 4*Iyy6*dq15*CC2*CC3*C5*CC6*S5 - 2*Iyy6*dq34*C2*CC4*CC5*CC6*S3 - 2*Iyy6*dq34*C3*CC4*CC5*CC6*S2 + 2*Iyy6*dq15*CC2*CC4*C5*CC6*S5 - 4*Iyy6*dq16*CC2*CC3*CC4*C6*S6 + 2*Iyy6*dq15*CC3*CC4*C5*CC6*S5 - 4*Iyy6*dq16*CC2*CC3*CC5*C6*S6 + 2*Iyy6*dq16*CC2*CC4*CC5*C6*S6 + 2*Iyy6*dq16*CC3*CC4*CC5*C6*S6 + 16*Iyz6*dq12*CC2*CC3*C4*CC5*S6 + 16*Iyz6*dq13*CC2*CC3*C4*CC5*S6 + 8*Iyz6*dq14*CC2*CC3*CC4*C6*S5 - 4*Izz5*dq12*C2*CC3*CC4*CC5*S2 - 4*Izz5*dq12*CC2*C3*CC4*CC5*S3 - 4*Izz5*dq13*C2*CC3*CC4*CC5*S2 - 4*Izz6*dq12*C2*CC3*CC4*CC5*S2 - 4*Izz5*dq13*CC2*C3*CC4*CC5*S3 - 4*Izz6*dq12*CC2*C3*CC4*CC5*S3 - 4*Izz6*dq13*C2*CC3*CC4*CC5*S2 - 4*Izz6*dq13*CC2*C3*CC4*CC5*S3 - 4*Izz5*dq14*CC2*CC3*C4*CC5*S4 - 4*Izz6*dq14*CC2*CC3*C4*CC5*S4 - 4*Izz5*dq15*CC2*CC3*CC4*C5*S5 - 4*Izz6*dq15*CC2*CC3*CC4*C5*S5 - a3*d6*dq22*m_6*C2*C3*S4*S5 - a3*d6*dq33*m_6*C2*C3*S4*S5 + a3*d6*dq44*m_6*C2*C3*S4*S5 + a3*d6*dq55*m_6*C2*C3*S4*S5 + 2*Ixx5*dq14*C2*C5*S2*S4*S5 - 2*Ixx5*dq23*C2*C5*S3*S4*S5 - 2*Ixx5*dq23*C3*C5*S2*S4*S5 + 2*Ixx5*dq14*C3*C5*S3*S4*S5 + 2*Ixx6*dq23*C5*C6*S2*S3*S6 - 2*Ixx6*dq56*C2*C6*S3*S4*S6 - 2*Ixx6*dq56*C3*C6*S2*S4*S6 + 2*Iyy6*dq14*C2*C5*S2*S4*S5 - 2*Iyy6*dq23*C2*C5*S3*S4*S5 - 2*Iyy6*dq23*C3*C5*S2*S4*S5 + 2*Iyy6*dq14*C3*C5*S3*S4*S5 - 2*Iyy6*dq23*C5*C6*S2*S3*S6 + 2*Iyy6*dq56*C2*C6*S3*S4*S6 + 2*Iyy6*dq56*C3*C6*S2*S4*S6 + 8*Iyz4*dq12*C2*C3*S2*S3*S4 + 8*Iyz4*dq13*C2*C3*S2*S3*S4 + 4*Iyz5*dq12*C2*C4*S2*S4*S5 + 4*Iyz5*dq14*C2*C3*S2*S3*S5 + 4*Iyz5*dq13*C2*C4*S2*S4*S5 + 4*Iyz5*dq12*C3*C4*S3*S4*S5 + 4*Iyz5*dq13*C3*C4*S3*S4*S5 + 4*Iyz6*dq15*C2*C3*S2*S3*S6 - 4*Iyz5*dq24*C2*C4*S3*S4*S5
 - 4*Iyz5*dq24*C3*C4*S2*S4*S5 + 4*Iyz6*dq12*C2*C5*S2*S5*S6 - 4*Iyz5*dq34*C2*C4*S3*S4*S5 - 4*Iyz5*dq34*C3*C4*S2*S4*S5 + 4*Iyz6*dq13*C2*C5*S2*S5*S6 + 4*Iyz6*dq12*C3*C5*S3*S5*S6 + 2*Iyz6*dq15*C2*C6*S2*S4*S5 + 4*Iyz6*dq13*C3*C5*S3*S5*S6 + 2*Iyz6*dq16*C2*C5*S2*S4*S6 + 2*Iyz6*dq25*C2*C4*S3*S4*S6 + 2*Iyz6*dq25*C3*C4*S2*S4*S6 + 2*Iyz6*dq15*C3*C6*S3*S4*S5 + 4*Iyz6*dq24*C2*C5*S3*S5*S6 + 4*Iyz6*dq24*C3*C5*S2*S5*S6 - 2*Iyz6*dq25*C4*C6*S2*S3*S5 + 2*Iyz6*dq35*C2*C4*S3*S4*S6 + 2*Iyz6*dq35*C3*C4*S2*S4*S6 + 2*Iyz6*dq16*C3*C5*S3*S4*S6 + 4*Iyz6*dq34*C2*C5*S3*S5*S6 + 4*Iyz6*dq34*C3*C5*S2*S5*S6 - 2*Iyz6*dq35*C4*C6*S2*S3*S5 + 2*Iyz6*dq46*C2*C5*S3*S4*S6 + 2*Iyz6*dq46*C3*C5*S2*S4*S6 + 2*Iyz6*dq46*C5*C6*S2*S3*S5 - 2*Izz5*dq14*C2*C5*S2*S4*S5 + 2*Izz5*dq23*C2*C5*S3*S4*S5 + 2*Izz5*dq23*C3*C5*S2*S4*S5 - 2*Izz6*dq14*C2*C5*S2*S4*S5 - 2*Izz5*dq14*C3*C5*S3*S4*S5 + 2*Izz6*dq23*C2*C5*S3*S4*S5 + 2*Izz6*dq23*C3*C5*S2*S4*S5 - 2*Izz6*dq14*C3*C5*S3*S4*S5 + X5*a3*dq22*m_5*C5*S2*S3*S4 + X5*a3*dq33*m_5*C5*S2*S3*S4 - X5*a3*dq44*m_5*C5*S2*S3*S4 - X5*a3*dq55*m_5*C5*S2*S3*S4 + X6*a3*dq22*m_6*C4*S2*S3*S6 + X6*a3*dq33*m_6*C4*S2*S3*S6 - X6*a3*dq44*m_6*C4*S2*S3*S6 - X6*a3*dq66*m_6*C4*S2*S3*S6 - 2*Y5*a1*dq14*m_5*C2*C3*C4 - 2*Y5*a3*dq23*m_5*C2*C3*C4 - 2*Y6*a3*dq16*m_6*C4*C5*C6 + 2*Y6*a1*dq46*m_6*C4*C5*C6 - 2*Z4*a1*dq14*m_4*C2*C3*C4 + 2*Z5*a1*dq12*m_5*C2*C3*C5 - 2*Z4*a3*dq23*m_4*C2*C3*C4 + 2*Z5*a1*dq13*m_5*C2*C3*C5 + 2*Z6*a1*dq12*m_6*C2*C3*C5 + 2*Z6*a1*dq13*m_6*C2*C3*C5 - 2*Z5*a2*dq45*m_5*C2*C4*C5 - 2*Z6*a2*dq45*m_6*C2*C4*C5 + 2*XX4*dq23*m_4*C4*S2*S3*S4 - 2*XX6*dq23*m_6*C4*S2*S3*S4 + 2*XX6*dq16*m_6*C2*S2*S4*S5 - 2*XX5*dq45*m_5*C5*S2*S3*S5 + 2*XX6*dq16*m_6*C3*S3*S4*S5 - 2*XX6*dq26*m_6*C4*S2*S3*S5 - 2*XX6*dq36*m_6*C4*S2*S3*S5 + 2*XX6*dq12*m_6*C6*S4*S5*S6 + 2*XX6*dq13*m_6*C6*S4*S5*S6 + 2*XX6*dq46*m_6*C6*S2*S3*S6 + 2*X6*d4*dq12*m_6*C4*C5*C6 + 2*X6*d4*dq13*m_6*C4*C5*C6 + 2*X6*d6*dq45*m_6*C2*C3*C6 - Y6*d6*dq22*m_6*C2*S3*S4*S6 - Y6*d6*dq22*m_6*C3*S2*S4*S6 - Y6*d6*dq22*m_6*C6*S2*S3*S5 - Y6*d6*dq33*m_6*C2*S3*S4*S6 - Y6*d6*dq33*m_6*C3*S2*S4*S6 - Y6*d6*dq33*m_6*C6*S2*S3*S5 + Y6*d6*dq44*m_6*C2*S3*S4*S6 + Y6*d6*dq44*m_6*C3*S2*S4*S6 + Y6*d6*dq55*m_6*C6*S2*S3*S5 - Y6*d6*dq66*m_6*C2*S3*S4*S6 - Y6*d6*dq66*m_6*C3*S2*S4*S6 - Y6*d6*dq66*m_6*C6*S2*S3*S5 - 2*YY5*dq23*m_5*C4*S2*S3*S4 - 2*YY6*dq16*m_6*C2*S2*S4*S5 - 2*YY6*dq16*m_6*C3*S3*S4*S5 - 2*YY6*dq12*m_6*C6*S4*S5*S6 - 2*YY6*dq45*m_6*C5*S2*S3*S5 - 2*YY6*dq46*m_6*C2*S3*S4*S5 - 2*YY6*dq46*m_6*C3*S2*S4*S5 - 2*YY6*dq13*m_6*C6*S4*S5*S6 - 2*YY6*dq46*m_6*C6*S2*S3*S6 - Z5*d4*dq22*m_5*C2*S3*S4*S5 - Z5*d4*dq22*m_5*C3*S2*S4*S5 - Z5*d4*dq33*m_5*C2*S3*S4*S5 - Z5*d4*dq33*m_5*C3*S2*S4*S5 + Z5*d4*dq44*m_5*C2*S3*S4*S5 + Z5*d4*dq44*m_5*C3*S2*S4*S5 - Z6*d4*dq22*m_6*C2*S3*S4*S5 - Z6*d4*dq22*m_6*C3*S2*S4*S5 + Z5*d4*dq55*m_5*C2*S3*S4*S5 + Z5*d4*dq55*m_5*C3*S2*S4*S5 - Z6*d4*dq33*m_6*C2*S3*S4*S5 - Z6*d4*dq33*m_6*C3*S2*S4*S5 + 2*Z6*d6*dq22*m_6*C4*S2*S3*S4 + Z6*d4*dq44*m_6*C2*S3*S4*S5 + Z6*d4*dq44*m_6*C3*S2*S4*S5 + 2*Z6*d6*dq33*m_6*C4*S2*S3*S4 + Z6*d4*dq55*m_6*C2*S3*S4*S5 + Z6*d4*dq55*m_6*C3*S2*S4*S5 - 2*ZZ4*dq23*m_4*C4*S2*S3*S4 + 2*ZZ5*dq23*m_5*C4*S2*S3*S4 + 2*ZZ6*dq23*m_6*C4*S2*S3*S4 + 2*ZZ5*dq45*m_5*C5*S2*S3*S5 + 2*ZZ6*dq45*m_6*C5*S2*S3*S5 - X6*Z6*dq22*m_6*S2*S3*S5*S6 - X6*Z6*dq33*m_6*S2*S3*S5*S6 + X6*Z6*dq55*m_6*S2*S3*S5*S6 - X6*Z6*dq66*m_6*S2*S3*S5*S6 - 2*Y4*Z4*dq14*m_4*C2*C4*S2 + 2*Y4*Z4*dq23*m_4*C2*C4*S3 + 2*Y4*Z4*dq23*m_4*C3*C4*S2 - 2*Y4*Z4*dq14*m_4*C3*C4*S3 + 2*Y5*Z5*dq23*m_5*C2*C3*S5 - 2*Y6*Z6*dq12*m_6*C5*C6*S4 - 2*Y6*Z6*dq13*m_6*C5*C6*S4 - 2*Y6*Z6*dq45*m_6*C2*C3*S6 - 2*Y6*Z6*dq16*m_6*C5*C6*S5 - 16*Ixy6*dq12*CC2*CC3*CC6*S4*S5 - 16*Ixy6*dq13*CC2*CC3*CC6*S4*S5 + 8*Ixz6*dq14*CC2*CC3*CC4*S5*S6 + 2*Ixx6*dq22*C2*C3*CC4*C5*C6*S6 + 2*Ixx6*dq33*C2*C3*CC4*C5*C6*S6 - 2*Iyy6*dq22*C2*C3*CC4*C5*C6*S6 - 2*Iyy6*dq33*C2*C3*CC4*C5*C6*S6 - 2*Ixy6*dq26*C5*S2*S3*S4*S5 - 2*Ixy6*dq36*C5*S2*S3*S4*S5 + 4*Ixy6*dq56*C6*S2*S3*S5*S6 - 4*Ixz5*dq25*C5*S2*S3*S4*S5 + 2*Ixz6*dq15*C2*S2*S4*S5*S6 - 4*Ixz5*dq35*C5*S2*S3*S4*S5 + 2*Ixz6*dq15*C3*S3*S4*S5*S6 - 2*Ixz6*dq25*C4*S2*S3*S5*S6 - 2*Ixz6*dq35*C4*S2*S3*S5*S6 + 2*Ixz6*dq46*C5*S2*S3*S5*S6 + 2*a1*d6*dq12*m_6*C2*C3*C5 + 2*a1*d6*dq13*m_6*C2*C3*C5 - 2*a2*d6*dq45*m_6*C2*C4*C5 - d4*d6*dq22*m_6*C2*S3*S4*S5 - d4*d6*dq22*m_6*C3*S2*S4*S5 - d4*d6*dq33*m_6*C2*S3*S4*S5 - d4*d6*dq33*m_6*C3*S2*S4*S5 + d4*d6*dq44*m_6*C2*S3*S4*S5 + d4*d6*dq44*m_6*C3*S2*S4*S5 + d4*d6*dq55*m_6*C2*S3*S4*S5 + d4*d6*dq55*m_6*C3*S2*S4*S5 + 2*dd6*dq23*m_6*C4*S2*S3*S4 + 2*dd6*dq45*m_6*C5*S2*S3*S5 - 4*X3*a2*dq12*m_3*C2*C3*S2 - 2*X3*a2*dq13*m_3*C2*C3*S2 - 2*X4*a1*dq12*m_4*C2*C4*S3 - 2*X4*a1*dq12*m_4*C3*C4*S2 - 2*X4*a1*dq13*m_4*C2*C4*S3 - 2*X4*a1*dq13*m_4*C3*C4*S2 + 4*X4*a3*dq12*m_4*C2*C4*S2 - 2*X4*a1*dq14*m_4*C2*C3*S4 + 4*X4*a3*dq13*m_4*C2*C4*S2 + 4*X4*a3*dq12*m_4*C3*C4*S3 - 2*X5*a1*dq12*m_5*C2*C3*S5 + 4*X4*a3*dq13*m_4*C3*C4*S3 - 2*X4*a3*dq23*m_4*C2*C3*S4 - 2*X5*a1*dq13*m_5*C2*C3*S5 - 2*X5*a1*dq15*m_5*C2*C5*S3 - 2*X5*a1*dq15*m_5*C3*C5*S2 + 2*X5*a2*dq12*m_5*C4*C5*S3 + 2*X5*a3*dq15*m_5*C2*C5*S2 + 2*X5*a3*dq15*m_5*C3*C5*S3 + 2*X6*a2*dq12*m_6*C3*C6*S5 + 2*X5*a2*dq45*m_5*C2*C4*S5 - 2*X6*a3*dq14*m_6*C5*C6*S4 + 2*X6*a2*dq46*m_6*C2*C6*S4 - 2*X6*a3*dq15*m_6*C4*C6*S5 + 2*X6*a1*dq45*m_6*C4*C6*S5 - 2*X6*a3*dq16*m_6*C4*C5*S6 + 2*X6*a1*dq46*m_6*C4*C5*S6 + Z5*a3*dq22*m_5*S2*S3*S4*S5 + Z5*a3*dq33*m_5*S2*S3*S4*S5 - Z5*a3*dq44*m_5*S2*S3*S4*S5 + Z6*a3*dq22*m_6*S2*S3*S4*S5 - Z5*a3*dq55*m_5*S2*S3*S4*S5 + Z6*a3*dq33*m_6*S2*S3*S4*S5 - Z6*a3*dq44*m_6*S2*S3*S4*S5 - Z6*a3*dq55*m_6*S2*S3*S4*S5 - XX5*dq22*m_5*C2*C3*C4*CC5*S4 - XX5*dq33*m_5*C2*C3*C4*CC5*S4 - XX6*dq22*m_6*C2*C3*C4*CC6*S4 - XX6*dq33*m_6*C2*C3*C4*CC6*S4 - X6*d6*dq22*m_6*S2*S3*S5*S6 - X6*d6*dq33*m_6*S2*S3*S5*S6 + X6*d6*dq55*m_6*S2*S3*S5*S6 - X6*d6*dq66*m_6*S2*S3*S5*S6 - YY6*dq22*m_6*C2*C3*C4*CC5*S4 + YY6*dq22*m_6*C2*C3*C4*CC6*S4 - YY6*dq33*m_6*C2*C3*C4*CC5*S4 + YY6*dq33*m_6*C2*C3*C4*CC6*S4 + ZZ5*dq22*m_5*C2*C3*C4*CC5*S4 + ZZ5*dq33*m_5*C2*C3*C4*CC5*S4 + ZZ6*dq22*m_6*C2*C3*C4*CC5*S4 + ZZ6*dq33*m_6*C2*C3*C4*CC5*S4 + 2*Y5*d4*dq14*m_5*C2*C4*S2 - 2*Y5*d4*dq23*m_5*C2*C4*S3 - 2*Y5*d4*dq23*m_5*C3*C4*S2 + 2*Y5*d4*dq14*m_5*C3*C4*S3 - 2*Y6*d4*dq12*m_6*C4*C5*S6 - 2*Y6*d4*dq13*m_6*C4*C5*S6 - 2*Y6*d6*dq12*m_6*C5*C6*S4 - 2*Y6*d6*dq13*m_6*C5*C6*S4 - 2*Y6*d6*dq45*m_6*C2*C3*S6 - 2*Y6*d6*dq16*m_6*C5*C6*S5 + 2*Z4*d4*dq14*m_4*C2*C4*S2 - 2*Z4*d4*dq23*m_4*C2*C4*S3 - 2*Z4*d4*dq23*m_4*C3*C4*S2 - 4*Z5*d4*dq12*m_5*C2*C5*S2 + 2*Z4*d4*dq14*m_4*C3*C4*S3 - 4*Z5*d4*dq13*m_5*C2*C5*S2 - 4*Z5*d4*dq12*m_5*C3*C5*S3 - 4*Z6*d4*dq12*m_6*C2*C5*S2 - 4*Z5*d4*dq13*m_5*C3*C5*S3 - 4*Z6*d4*dq13*m_6*C2*C5*S2 - 4*Z6*d4*dq12*m_6*C3*C5*S3 - 4*Z6*d4*dq13*m_6*C3*C5*S3 + 4*Z6*d6*dq15*m_6*C2*C4*S2 + 4*Z6*d6*dq15*m_6*C3*C4*S3 - 4*Z6*d6*dq25*m_6*C2*C3*S4 + 4*Z6*d6*dq12*m_6*C4*C5*S5 - 4*Z6*d6*dq35*m_6*C2*C3*S4 + 4*Z6*d6*dq13*m_6*C4*C5*S5 + 4*X6*Y6*dq16*m_6*CC2*CC3*CC4 + 4*X6*Y6*dq16*m_6*CC2*CC3*CC5 + 16*X6*Y6*dq16*m_6*CC2*CC3*CC6 - 2*X6*Y6*dq16*m_6*CC2*CC4*CC5 + 4*X6*Y6*dq16*m_6*CC2*CC4*CC6 - 2*X6*Y6*dq16*m_6*CC3*CC4*CC5 + 4*X6*Y6*dq16*m_6*CC2*CC5*CC6 + 4*X6*Y6*dq16*m_6*CC3*CC4*CC6 + 4*X6*Y6*dq16*m_6*CC3*CC5*CC6 - 8*X4*Z4*dq14*m_4*CC2*CC3*CC4 - 4*X5*Z5*dq15*m_5*CC2*CC3*CC4 + 8*X5*Z5*dq15*m_5*CC2*CC3*CC5 - 4*X5*Z5*dq15*m_5*CC2*CC4*CC5 - 4*X5*Z5*dq15*m_5*CC3*CC4*CC5 - 2*X4*Y4*dq14*m_4*C2*S2*S4 + 2*X4*Y4*dq23*m_4*C2*S3*S4 + 2*X4*Y4*dq23*m_4*C3*S2*S4 - 2*X4*Y4*dq14*m_4*C3*S3*S4 - 2*X5*Y5*dq23*m_5*C5*S2*S3 + 2*X6*Y6*dq23*m_6*C5*S2*S3 - 2*X6*Y6*dq56*m_6*C2*S3*S4 - 2*X6*Y6*dq56*m_6*C3*S2*S4 - 2*X5*Z5*dq14*m_5*C2*S2*S4 + 2*X5*Z5*dq23*m_5*C2*S3*S4 + 2*X5*Z5*dq23*m_5*C3*S2*S4 - 2*X5*Z5*dq14*m_5*C3*S3*S4 - 2*X6*Z6*dq12*m_6*C5*S4*S6 - 2*X6*Z6*dq13*m_6*C5*S4*S6 - 2*X6*Z6*dq45*m_6*C6*S2*S3 - 2*X6*Z6*dq16*m_6*C5*S5*S6 - 4*a2*a3*dq12*m_3*C2*C3*S2 - 4*a2*a3*dq12*m_4*C2*C3*S2 - 2*a2*a3*dq13*m_3*C2*C3*S2 - 4*a2*a3*dq12*m_5*C2*C3*S2 - 2*a2*a3*dq13*m_4*C2*C3*S2 - 4*a2*a3*dq12*m_6*C2*C3*S2 - 2*a2*a3*dq13*m_5*C2*C3*S2 - 2*a2*a3*dq13*m_6*C2*C3*S2 + a3*d6*dq22*m_6*S2*S3*S4*S5 + a3*d6*dq33*m_6*S2*S3*S4*S5 - a3*d6*dq44*m_6*S2*S3*S4*S5 - a3*d6*dq55*m_6*S2*S3*S4*S5 + dd6*dq22*m_6*C2*C3*C4*CC5*S4 + dd6*dq33*m_6*C2*C3*C4*CC5*S4 - 4*d4*d6*dq12*m_6*C2*C5*S2 - 4*d4*d6*dq13*m_6*C2*C5*S2 - 4*d4*d6*dq12*m_6*C3*C5*S3 - 4*d4*d6*dq13*m_6*C3*C5*S3 + 4*Y4*a2*dq12*m_4*C2*S2*S3 + 2*Y4*a2*dq13*m_4*C2*S2*S3 + 2*Y5*a1*dq12*m_5*C2*S3*S4 + 2*Y5*a1*dq12*m_5*C3*S2*S4 + 2*Y5*a1*dq13*m_5*C2*S3*S4 + 2*Y5*a1*dq13*m_5*C3*S2*S4 - 4*Y5*a3*dq12*m_5*C2*S2*S4 + 2*Y5*a1*dq14*m_5*C4*S2*S3 - 4*Y5*a3*dq13*m_5*C2*S2*S4 - 4*Y5*a3*dq12*m_5*C3*S3*S4 - 4*Y5*a3*dq13*m_5*C3*S3*S4 + 2*Y5*a3*dq23*m_5*C4*S2*S3 - 2*Y6*a2*dq12*m_6*C6*S3*S4 - 2*Y6*a2*dq12*m_6*C3*S5*S6 + 2*Y6*a3*dq14*m_6*C5*S4*S6 - 2*Y6*a2*dq46*m_6*C2*S4*S6 + 2*Y6*a3*dq15*m_6*C4*S5*S6 - 2*Y6*a1*dq45*m_6*C4*S5*S6 - 2*Y6*a1*dq56*m_6*C6*S4*S5 - 4*Z3*a2*dq12*m_3*C2*S2*S3 - 2*Z3*a2*dq13*m_3*C2*S2*S3 + 2*Z4*a1*dq12*m_4*C2*S3*S4 + 2*Z4*a1*dq12*m_4*C3*S2*S4 + 2*Z4*a1*dq13*m_4*C2*S3*S4 + 2*Z4*a1*dq13*m_4*C3*S2*S4 - 4*Z4*a3*dq12*m_4*C2*S2*S4 + 2*Z4*a1*dq14*m_4*C4*S2*S3 - 4*Z4*a3*dq13*m_4*C2*S2*S4 - 4*Z4*a3*dq12*m_4*C3*S3*S4 - 2*Z5*a1*dq12*m_5*C5*S2*S3 - 4*Z4*a3*dq13*m_4*C3*S3*S4 + 2*Z4*a3*dq23*m_4*C4*S2*S3 - 2*Z5*a1*dq13*m_5*C5*S2*S3 - 2*Z6*a1*dq12*m_6*C5*S2*S3 - 2*Z5*a1*dq15*m_5*C2*S3*S5 - 2*Z5*a1*dq15*m_5*C3*S2*S5 + 2*Z5*a2*dq12*m_5*C4*S3*S5 - 2*Z6*a1*dq13*m_6*C5*S2*S3 + 2*Z5*a3*dq15*m_5*C2*S2*S5 - 2*Z6*a1*dq15*m_6*C2*S3*S5 - 2*Z6*a1*dq15*m_6*C3*S2*S5 + 2*Z6*a2*dq12*m_6*C4*S3*S5 + 2*Z5*a3*dq15*m_5*C3*S3*S5 + 2*Z6*a3*dq15*m_6*C2*S2*S5 + 2*Z6*a3*dq15*m_6*C3*S3*S5 + 2*X4*d4*dq14*m_4*C2*S2*S4 - 2*X4*d4*dq23*m_4*C2*S3*S4 - 2*X4*d4*dq23*m_4*C3*S2*S4 + 4*X5*d4*dq12*m_5*C2*S2*S5 + 2*X4*d4*dq14*m_4*C3*S3*S4 + 4*X5*d4*dq13*m_5*C2*S2*S5 + 4*X5*d4*dq12*m_5*C3*S3*S5 + 4*X5*d4*dq13*m_5*C3*S3*S5 - 2*X6*d6*dq12*m_6*C5*S4*S6 - 2*X6*d6*dq13*m_6*C5*S4*S6 - 2*X6*d6*dq45*m_6*C6*S2*S3 - 2*X6*d6*dq16*m_6*C5*S5*S6 - 2*X5*Y5*dq22*m_5*C2*C3*CC4*C5 - 2*X5*Y5*dq33*m_5*C2*C3*CC4*C5 + 2*X6*Y6*dq22*m_6*C2*C3*CC4*C5 + 2*X6*Y6*dq33*m_6*C2*C3*CC4*C5 + 2*X6*Y6*dq22*m_6*C2*C3*C5*CC6 + 2*X6*Y6*dq33*m_6*C2*C3*C5*CC6 - 2*X6*Y6*dq55*m_6*C2*C3*C5*CC6 - 2*Y5*Z5*dq23*m_5*S2*S3*S5
 + 2*Y6*Z6*dq45*m_6*S2*S3*S6 - Ixx6*dq22*C2*C5*CC6*S3*S4*S5 - Ixx6*dq22*C3*C5*CC6*S2*S4*S5 - 2*Ixx6*dq22*CC4*C5*C6*S2*S3*S6 - Ixx6*dq33*C2*C5*CC6*S3*S4*S5 - Ixx6*dq33*C3*C5*CC6*S2*S4*S5 - 2*Ixx6*dq33*CC4*C5*C6*S2*S3*S6 + Ixx6*dq44*C2*C5*CC6*S3*S4*S5 + Ixx6*dq44*C3*C5*CC6*S2*S4*S5 + Iyy6*dq22*C2*C5*CC6*S3*S4*S5 + Iyy6*dq22*C3*C5*CC6*S2*S4*S5 + 2*Iyy6*dq22*CC4*C5*C6*S2*S3*S6 + Iyy6*dq33*C2*C5*CC6*S3*S4*S5 + Iyy6*dq33*C3*C5*CC6*S2*S4*S5 + 2*Iyy6*dq33*CC4*C5*C6*S2*S3*S6 - Iyy6*dq44*C2*C5*CC6*S3*S4*S5 - Iyy6*dq44*C3*C5*CC6*S2*S4*S5 + 4*Ixy6*dq25*C2*C3*C4*C5*CC6 + 4*Ixy6*dq35*C2*C3*C4*C5*CC6 - 4*a2*d4*dq12*m_4*C2*S2*S3 - 4*a2*d4*dq12*m_5*C2*S2*S3 - 2*a2*d4*dq13*m_4*C2*S2*S3 - 4*a2*d4*dq12*m_6*C2*S2*S3 - 2*a2*d4*dq13*m_5*C2*S2*S3 - 2*a2*d4*dq13*m_6*C2*S2*S3 - 2*a1*d6*dq12*m_6*C5*S2*S3 - 2*a1*d6*dq13*m_6*C5*S2*S3 - 2*a1*d6*dq15*m_6*C2*S3*S5 - 2*a1*d6*dq15*m_6*C3*S2*S5 + 2*a2*d6*dq12*m_6*C4*S3*S5 + 2*a3*d6*dq15*m_6*C2*S2*S5 + 2*a3*d6*dq15*m_6*C3*S3*S5 + 2*X4*a1*dq14*m_4*S2*S3*S4 + 2*X5*a1*dq12*m_5*S2*S3*S5 + 2*X4*a3*dq23*m_4*S2*S3*S4 + 2*X5*a1*dq13*m_5*S2*S3*S5 - 2*X6*a2*dq12*m_6*S3*S4*S6 - 2*X6*a1*dq56*m_6*S4*S5*S6 + XX5*dq22*m_5*C4*CC5*S2*S3*S4 + XX5*dq33*m_5*C4*CC5*S2*S3*S4 + XX6*dq22*m_6*C4*CC6*S2*S3*S4 + XX6*dq33*m_6*C4*CC6*S2*S3*S4 + YY6*dq22*m_6*C4*CC5*S2*S3*S4 - YY6*dq22*m_6*C4*CC6*S2*S3*S4 + YY6*dq33*m_6*C4*CC5*S2*S3*S4 - YY6*dq33*m_6*C4*CC6*S2*S3*S4 - ZZ5*dq22*m_5*C4*CC5*S2*S3*S4 - ZZ5*dq33*m_5*C4*CC5*S2*S3*S4 - ZZ6*dq22*m_6*C4*CC5*S2*S3*S4 - ZZ6*dq33*m_6*C4*CC5*S2*S3*S4 + 2*Y6*d6*dq45*m_6*S2*S3*S6 - 2*Y6*a2*dq14*m_6*CC2*C3*C4*C6 + 2*Y6*a3*dq16*m_6*CC2*C4*C5*C6 + 2*Y6*a3*dq16*m_6*CC3*C4*C5*C6 + 2*Z5*a2*dq15*m_5*CC2*C3*C4*C5 + 2*Z6*a2*dq15*m_6*CC2*C3*C4*C5 + 2*XX5*dq23*m_5*C4*CC5*S2*S3*S4 - 4*XX6*dq16*m_6*C2*CC3*S2*S4*S5 - 4*XX6*dq16*m_6*CC2*C3*S3*S4*S5 + 2*XX6*dq23*m_6*C4*CC6*S2*S3*S4 - 4*XX6*dq12*m_6*CC2*C6*S4*S5*S6 - 4*XX6*dq16*m_6*C2*CC6*S2*S4*S5 - 4*XX6*dq12*m_6*CC3*C6*S4*S5*S6 - 4*XX6*dq13*m_6*CC2*C6*S4*S5*S6 - 4*XX6*dq13*m_6*CC3*C6*S4*S5*S6 - 4*XX6*dq16*m_6*C3*CC6*S3*S4*S5 + 2*XX6*dq26*m_6*C4*CC6*S2*S3*S5 + 2*XX6*dq36*m_6*C4*CC6*S2*S3*S5 - 2*XX6*dq45*m_6*C5*CC6*S2*S3*S5 - 2*XX6*dq46*m_6*C2*CC6*S3*S4*S5 - 2*XX6*dq46*m_6*C3*CC6*S2*S4*S5 - 2*XX6*dq46*m_6*CC5*C6*S2*S3*S6 - 4*X6*d4*dq12*m_6*CC2*C4*C5*C6 - 4*X6*d4*dq12*m_6*CC3*C4*C5*C6 - 4*X6*d4*dq13*m_6*CC2*C4*C5*C6 - 4*X6*d4*dq13*m_6*CC3*C4*C5*C6 - 4*X6*d6*dq45*m_6*C2*C3*CC5*C6 + 2*Y6*d6*dq22*m_6*C2*CC5*S3*S4*S6 + 2*Y6*d6*dq22*m_6*C3*CC5*S2*S4*S6 + 2*Y6*d6*dq22*m_6*CC4*C6*S2*S3*S5 + 2*Y6*d6*dq33*m_6*C2*CC5*S3*S4*S6 + 2*Y6*d6*dq33*m_6*C3*CC5*S2*S4*S6 + 2*Y6*d6*dq33*m_6*CC4*C6*S2*S3*S5 - 2*Y6*d6*dq44*m_6*C2*CC5*S3*S4*S6 - 2*Y6*d6*dq44*m_6*C3*CC5*S2*S4*S6 + 4*YY6*dq16*m_6*C2*CC3*S2*S4*S5 + 2*YY6*dq23*m_6*C4*CC5*S2*S3*S4 + 4*YY6*dq16*m_6*CC2*C3*S3*S4*S5 - 2*YY6*dq23*m_6*C4*CC6*S2*S3*S4 + 4*YY6*dq12*m_6*CC2*C6*S4*S5*S6 + 4*YY6*dq16*m_6*C2*CC6*S2*S4*S5 + 4*YY6*dq12*m_6*CC3*C6*S4*S5*S6 + 4*YY6*dq13*m_6*CC2*C6*S4*S5*S6 + 4*YY6*dq13*m_6*CC3*C6*S4*S5*S6 + 4*YY6*dq16*m_6*C3*CC6*S3*S4*S5 - 2*YY6*dq26*m_6*C4*CC6*S2*S3*S5 - 2*YY6*dq36*m_6*C4*CC6*S2*S3*S5 + 2*YY6*dq45*m_6*C5*CC6*S2*S3*S5 + 2*YY6*dq46*m_6*C2*CC6*S3*S4*S5 + 2*YY6*dq46*m_6*C3*CC6*S2*S4*S5 + 2*YY6*dq46*m_6*CC5*C6*S2*S3*S6 - 2*Z6*d6*dq22*m_6*C4*CC5*S2*S3*S4 - 2*Z6*d6*dq33*m_6*C4*CC5*S2*S3*S4 - 2*ZZ5*dq23*m_5*C4*CC5*S2*S3*S4 - 2*ZZ6*dq23*m_6*C4*CC5*S2*S3*S4 + 2*X6*Z6*dq22*m_6*CC4*S2*S3*S5*S6 + 2*X6*Z6*dq33*m_6*CC4*S2*S3*S5*S6 + 4*Y4*Z4*dq14*m_4*C2*CC3*C4*S2 + 4*Y4*Z4*dq14*m_4*CC2*C3*C4*S3 - 4*Y5*Z5*dq23*m_5*C2*C3*CC4*S5 + 2*Y5*Z5*dq15*m_5*CC2*C4*C5*S4 - 2*Y5*Z5*dq25*m_5*C2*CC4*C5*S3 - 2*Y5*Z5*dq25*m_5*C3*CC4*C5*S2 + 2*Y5*Z5*dq15*m_5*CC3*C4*C5*S4 - 2*Y5*Z5*dq35*m_5*C2*CC4*C5*S3 - 2*Y5*Z5*dq35*m_5*C3*CC4*C5*S2 + 4*Y6*Z6*dq12*m_6*CC2*C5*C6*S4 + 4*Y6*Z6*dq12*m_6*CC3*C5*C6*S4 + 4*Y6*Z6*dq13*m_6*CC2*C5*C6*S4 + 4*Y6*Z6*dq13*m_6*CC3*C5*C6*S4 + 2*Y6*Z6*dq16*m_6*CC2*C5*C6*S5 + 4*Y6*Z6*dq45*m_6*C2*C3*CC5*S6 + 2*Y6*Z6*dq16*m_6*CC3*C5*C6*S5 + 4*Ixy6*dq25*CC5*C6*S2*S3*S4*S6 + 4*Ixy6*dq26*C5*CC6*S2*S3*S4*S5 + 4*Ixy6*dq35*CC5*C6*S2*S3*S4*S6 + 4*Ixy6*dq36*C5*CC6*S2*S3*S4*S5 - 4*Ixz6*dq15*C2*CC3*S2*S4*S5*S6 - 4*Ixz6*dq15*CC2*C3*S3*S4*S5*S6 + 2*a2*d6*dq15*m_6*CC2*C3*C4*C5 - 2*dd6*dq23*m_6*C4*CC5*S2*S3*S4 - 8*X4*a3*dq12*m_4*C2*CC3*C4*S2 - 8*X4*a3*dq12*m_4*CC2*C3*C4*S3 - 8*X4*a3*dq13*m_4*C2*CC3*C4*S2 - 8*X4*a3*dq13*m_4*CC2*C3*C4*S3 - 4*X5*a2*dq12*m_5*CC2*C4*C5*S3 - 2*X5*a2*dq13*m_5*CC2*C4*C5*S3 - 2*X5*a2*dq14*m_5*CC2*C3*C5*S4 - 4*X5*a3*dq15*m_5*C2*CC3*C5*S2 - 2*X5*a2*dq15*m_5*CC2*C3*C4*S5 - 4*X5*a3*dq15*m_5*CC2*C3*C5*S3 - 4*X6*a2*dq12*m_6*CC2*C3*C6*S5 - 2*X6*a2*dq13*m_6*CC2*C3*C6*S5 - 2*X6*a2*dq14*m_6*CC2*C3*C4*S6 - 2*X6*a2*dq15*m_6*CC2*C5*C6*S3 - 2*X6*a2*dq16*m_6*CC2*C3*C6*S4 + 2*X6*a3*dq14*m_6*CC2*C5*C6*S4 + 2*X6*a3*dq14*m_6*CC3*C5*C6*S4 + 2*X6*a3*dq15*m_6*CC2*C4*C6*S5 + 2*X6*a3*dq15*m_6*CC3*C4*C6*S5 + 2*X6*a3*dq16*m_6*CC2*C4*C5*S6 + 2*X6*a3*dq16*m_6*CC3*C4*C5*S6 - XX6*dq22*m_6*C2*C3*C4*CC5*CC6*S4 - XX6*dq33*m_6*C2*C3*C4*CC5*CC6*S4 + 2*X6*d6*dq22*m_6*CC4*S2*S3*S5*S6 + 2*X6*d6*dq33*m_6*CC4*S2*S3*S5*S6 + YY6*dq22*m_6*C2*C3*C4*CC5*CC6*S4 + YY6*dq33*m_6*C2*C3*C4*CC5*CC6*S4 - 4*Y5*d4*dq14*m_5*C2*CC3*C4*S2 - 4*Y5*d4*dq14*m_5*CC2*C3*C4*S3 + 4*Y6*d4*dq12*m_6*CC2*C4*C5*S6 + 4*Y6*d4*dq12*m_6*CC3*C4*C5*S6 + 4*Y6*d4*dq13*m_6*CC2*C4*C5*S6 + 4*Y6*d4*dq13*m_6*CC3*C4*C5*S6 + 4*Y6*d6*dq12*m_6*CC2*C5*C6*S4 + 4*Y6*d6*dq12*m_6*CC3*C5*C6*S4 + 4*Y6*d6*dq13*m_6*CC2*C5*C6*S4 + 4*Y6*d6*dq13*m_6*CC3*C5*C6*S4 + 2*Y6*d6*dq16*m_6*CC2*C5*C6*S5 + 4*Y6*d6*dq45*m_6*C2*C3*CC5*S6 + 2*Y6*d6*dq16*m_6*CC3*C5*C6*S5 - 4*Z4*d4*dq14*m_4*C2*CC3*C4*S2 - 4*Z4*d4*dq14*m_4*CC2*C3*C4*S3 + 8*Z5*d4*dq12*m_5*C2*CC3*C5*S2 + 8*Z5*d4*dq12*m_5*CC2*C3*C5*S3 + 8*Z5*d4*dq13*m_5*C2*CC3*C5*S2 + 8*Z5*d4*dq13*m_5*CC2*C3*C5*S3 + 8*Z6*d4*dq12*m_6*C2*CC3*C5*S2 + 8*Z6*d4*dq12*m_6*CC2*C3*C5*S3 + 8*Z6*d4*dq13*m_6*C2*CC3*C5*S2 + 8*Z6*d4*dq13*m_6*CC2*C3*C5*S3 - 8*Z6*d6*dq15*m_6*C2*CC3*C4*S2 - 8*Z6*d6*dq15*m_6*CC2*C3*C4*S3 - 8*Z6*d6*dq12*m_6*CC2*C4*C5*S5 - 8*Z6*d6*dq15*m_6*C2*C4*CC5*S2 - 8*Z6*d6*dq12*m_6*CC3*C4*C5*S5 - 8*Z6*d6*dq13*m_6*CC2*C4*C5*S5 - 8*Z6*d6*dq13*m_6*CC3*C4*C5*S5 - 8*Z6*d6*dq15*m_6*C3*C4*CC5*S3 + 4*Z6*d6*dq25*m_6*C2*C3*CC5*S4 + 4*Z6*d6*dq35*m_6*C2*C3*CC5*S4 - 4*Z6*d6*dq45*m_6*C2*C4*CC5*S3 - 4*Z6*d6*dq45*m_6*C3*C4*CC5*S2 + 4*X6*Y6*dq16*m_6*CC2*CC3*CC4*CC5 - 8*X6*Y6*dq16*m_6*CC2*CC3*CC4*CC6 - 8*X6*Y6*dq16*m_6*CC2*CC3*CC5*CC6 + 4*X6*Y6*dq16*m_6*CC2*CC4*CC5*CC6 + 4*X6*Y6*dq16*m_6*CC3*CC4*CC5*CC6 + 8*X5*Z5*dq15*m_5*CC2*CC3*CC4*CC5 + 4*X4*Y4*dq14*m_4*C2*CC3*S2*S4 + 4*X4*Y4*dq14*m_4*CC2*C3*S3*S4 + 4*X5*Y5*dq23*m_5*CC4*C5*S2*S3 - 2*X5*Y5*dq15*m_5*CC2*C4*S4*S5 + 2*X5*Y5*dq25*m_5*C2*CC4*S3*S5 + 2*X5*Y5*dq25*m_5*C3*CC4*S2*S5 - 2*X5*Y5*dq15*m_5*CC3*C4*S4*S5 + 2*X5*Y5*dq35*m_5*C2*CC4*S3*S5 + 2*X5*Y5*dq35*m_5*C3*CC4*S2*S5 - 4*X6*Y6*dq23*m_6*CC4*C5*S2*S3 + 2*X6*Y6*dq15*m_6*CC2*C4*S4*S5 - 4*X6*Y6*dq23*m_6*C5*CC6*S2*S3 - 2*X6*Y6*dq25*m_6*C2*CC4*S3*S5 - 2*X6*Y6*dq25*m_6*C3*CC4*S2*S5 + 2*X6*Y6*dq15*m_6*CC3*C4*S4*S5 - 2*X6*Y6*dq35*m_6*C2*CC4*S3*S5 - 2*X6*Y6*dq35*m_6*C3*CC4*S2*S5 + 4*X6*Y6*dq56*m_6*C2*CC6*S3*S4 + 4*X6*Y6*dq56*m_6*C3*CC6*S2*S4 + 4*X5*Z5*dq14*m_5*C2*CC3*S2*S4 + 4*X5*Z5*dq14*m_5*CC2*C3*S3*S4 + 4*X5*Z5*dq14*m_5*C2*CC5*S2*S4 - 4*X5*Z5*dq23*m_5*C2*CC5*S3*S4 - 4*X5*Z5*dq23*m_5*C3*CC5*S2*S4 + 4*X5*Z5*dq14*m_5*C3*CC5*S3*S4 + 4*X6*Z6*dq12*m_6*CC2*C5*S4*S6 + 4*X6*Z6*dq12*m_6*CC3*C5*S4*S6 + 4*X6*Z6*dq13*m_6*CC2*C5*S4*S6 + 4*X6*Z6*dq13*m_6*CC3*C5*S4*S6 + 2*X6*Z6*dq16*m_6*CC2*C5*S5*S6 + 4*X6*Z6*dq45*m_6*CC5*C6*S2*S3 + 2*X6*Z6*dq16*m_6*CC3*C5*S5*S6 + 8*d4*d6*dq12*m_6*C2*CC3*C5*S2 + 8*d4*d6*dq12*m_6*CC2*C3*C5*S3 + 8*d4*d6*dq13*m_6*C2*CC3*C5*S2 + 8*d4*d6*dq13*m_6*CC2*C3*C5*S3 + 8*Y5*a3*dq12*m_5*C2*CC3*S2*S4 + 8*Y5*a3*dq12*m_5*CC2*C3*S3*S4 + 8*Y5*a3*dq13*m_5*C2*CC3*S2*S4 + 8*Y5*a3*dq13*m_5*CC2*C3*S3*S4 + 4*Y6*a2*dq12*m_6*CC2*C6*S3*S4 + 4*Y6*a2*dq12*m_6*CC2*C3*S5*S6 + 2*Y6*a2*dq13*m_6*CC2*C6*S3*S4 + 2*Y6*a2*dq13*m_6*CC2*C3*S5*S6 + 2*Y6*a2*dq15*m_6*CC2*C5*S3*S6 + 2*Y6*a2*dq16*m_6*CC2*C3*S4*S6 + 2*Y6*a2*dq16*m_6*CC2*C6*S3*S5 - 2*Y6*a3*dq14*m_6*CC2*C5*S4*S6 - 2*Y6*a3*dq14*m_6*CC3*C5*S4*S6 - 2*Y6*a3*dq15*m_6*CC2*C4*S5*S6 - 2*Y6*a3*dq15*m_6*CC3*C4*S5*S6 + 8*Z4*a3*dq12*m_4*C2*CC3*S2*S4 + 8*Z4*a3*dq12*m_4*CC2*C3*S3*S4 + 8*Z4*a3*dq13*m_4*C2*CC3*S2*S4 + 8*Z4*a3*dq13*m_4*CC2*C3*S3*S4 - 4*Z5*a2*dq12*m_5*CC2*C4*S3*S5 - 2*Z5*a2*dq13*m_5*CC2*C4*S3*S5 - 2*Z5*a2*dq14*m_5*CC2*C3*S4*S5 - 4*Z5*a3*dq15*m_5*C2*CC3*S2*S5 - 4*Z6*a2*dq12*m_6*CC2*C4*S3*S5 - 4*Z5*a3*dq15*m_5*CC2*C3*S3*S5 - 2*Z6*a2*dq13*m_6*CC2*C4*S3*S5 - 2*Z6*a2*dq14*m_6*CC2*C3*S4*S5 - 4*Z6*a3*dq15*m_6*C2*CC3*S2*S5 - 4*Z6*a3*dq15*m_6*CC2*C3*S3*S5 - 4*X4*d4*dq14*m_4*C2*CC3*S2*S4 - 4*X4*d4*dq14*m_4*CC2*C3*S3*S4 - 8*X5*d4*dq12*m_5*C2*CC3*S2*S5 - 8*X5*d4*dq12*m_5*CC2*C3*S3*S5 - 8*X5*d4*dq13*m_5*C2*CC3*S2*S5 - 8*X5*d4*dq13*m_5*CC2*C3*S3*S5 + 4*X6*d6*dq12*m_6*CC2*C5*S4*S6 + 4*X6*d6*dq12*m_6*CC3*C5*S4*S6 + 4*X6*d6*dq13*m_6*CC2*C5*S4*S6 + 4*X6*d6*dq13*m_6*CC3*C5*S4*S6 + 2*X6*d6*dq16*m_6*CC2*C5*S5*S6 + 4*X6*d6*dq45*m_6*CC5*C6*S2*S3 + 2*X6*d6*dq16*m_6*CC3*C5*S5*S6 - 4*X6*Y6*dq22*m_6*C2*C3*CC4*C5*CC6 - 4*X6*Y6*dq33*m_6*C2*C3*CC4*C5*CC6 + 4*Y5*Z5*dq23*m_5*CC4*S2*S3*S5 - 4*Y6*Z6*dq45*m_6*CC5*S2*S3*S6 - 4*a2*d6*dq12*m_6*CC2*C4*S3*S5 - 2*a2*d6*dq13*m_6*CC2*C4*S3*S5 - 2*a2*d6*dq14*m_6*CC2*C3*S4*S5 - 4*a3*d6*dq15*m_6*C2*CC3*S2*S5 - 4*a3*d6*dq15*m_6*CC2*C3*S3*S5 + 4*X6*a2*dq12*m_6*CC2*S3*S4*S6 + 2*X6*a2*dq13*m_6*CC2*S3*S4*S6 + 2*X6*a2*dq16*m_6*CC2*S3*S5*S6 + XX6*dq22*m_6*C4*CC5*CC6*S2*S3*S4 + XX6*dq33*m_6*C4*CC5*CC6*S2*S3*S4 - YY6*dq22*m_6*C4*CC5*CC6*S2*S3*S4 - YY6*dq33*m_6*C4*CC5*CC6*S2*S3*S4 - 4*Y6*d6*dq45*m_6*CC5*S2*S3*S6 - 4*Z6*d6*dq25*m_6*CC5*S2*S3*S4 - 4*Z6*d6*dq35*m_6*CC5*S2*S3*S4 + 2*Ixx6*dq23*C2*C3*C4*CC5*CC6*S4 - 2*Iyy6*dq23*C2*C3*C4*CC5*CC6*S4 + 8*Iyz6*dq16*C2*CC3*C4*CC5*C6*S2 + 4*Iyz6*dq15*CC2*CC3*C4*C5*C6*S4 + 8*Iyz6*dq16*CC2*C3*C4*CC5*C6*S3 - 8*XX5*dq12*m_5*CC2*CC3*C4*C5*S5 - 8*XX5*dq15*m_5*C2*CC3*C4*CC5*S2 - 8*XX5*dq13*m_5*CC2*CC3*C4*C5*S5 - 8*XX5*dq15*m_5*CC2*C3*C4*CC5*S3 + 4*XX6*dq15*m_6*C2*CC3*C4*CC6*S2 + 4*XX6*dq15*m_6*CC2*C3*C4*CC6*S3 + 4*XX6*dq12*m_6*CC2*C4*C5*CC6*S5
 + 4*XX6*dq15*m_6*C2*C4*CC5*CC6*S2 + 4*XX6*dq16*m_6*CC2*CC3*C4*C5*S4 + 4*XX6*dq12*m_6*CC3*C4*C5*CC6*S5 + 4*XX6*dq13*m_6*CC2*C4*C5*CC6*S5 + 4*XX6*dq13*m_6*CC3*C4*C5*CC6*S5 + 4*XX6*dq14*m_6*CC2*CC3*C5*C6*S6 + 4*XX6*dq15*m_6*C3*C4*CC5*CC6*S3 - 2*XX6*dq25*m_6*C2*C3*CC5*CC6*S4 + 4*XX6*dq14*m_6*CC2*CC4*C5*C6*S6 + 4*XX6*dq16*m_6*CC2*C4*C5*CC6*S4 - 4*XX6*dq26*m_6*C2*CC4*C5*CC6*S3 - 4*XX6*dq26*m_6*C3*CC4*C5*CC6*S2 - 2*XX6*dq35*m_6*C2*C3*CC5*CC6*S4 + 4*XX6*dq14*m_6*CC3*CC4*C5*C6*S6 + 4*XX6*dq16*m_6*CC3*C4*C5*CC6*S4 - 4*XX6*dq36*m_6*C2*CC4*C5*CC6*S3 - 4*XX6*dq36*m_6*C3*CC4*C5*CC6*S2 + 2*XX6*dq45*m_6*C2*C4*CC5*CC6*S3 + 2*XX6*dq45*m_6*C3*C4*CC5*CC6*S2 - 8*YY6*dq12*m_6*CC2*CC3*C4*C5*S5 - 8*YY6*dq15*m_6*C2*CC3*C4*CC5*S2 - 8*YY6*dq13*m_6*CC2*CC3*C4*C5*S5 - 4*YY6*dq15*m_6*C2*CC3*C4*CC6*S2 - 8*YY6*dq15*m_6*CC2*C3*C4*CC5*S3 - 4*YY6*dq15*m_6*CC2*C3*C4*CC6*S3 - 4*YY6*dq12*m_6*CC2*C4*C5*CC6*S5 - 4*YY6*dq15*m_6*C2*C4*CC5*CC6*S2 - 4*YY6*dq16*m_6*CC2*CC3*C4*C5*S4 - 4*YY6*dq12*m_6*CC3*C4*C5*CC6*S5 - 4*YY6*dq13*m_6*CC2*C4*C5*CC6*S5 - 4*YY6*dq13*m_6*CC3*C4*C5*CC6*S5 - 4*YY6*dq14*m_6*CC2*CC3*C5*C6*S6 - 4*YY6*dq15*m_6*C3*C4*CC5*CC6*S3 + 2*YY6*dq25*m_6*C2*C3*CC5*CC6*S4 - 4*YY6*dq14*m_6*CC2*CC4*C5*C6*S6 - 4*YY6*dq16*m_6*CC2*C4*C5*CC6*S4 + 4*YY6*dq26*m_6*C2*CC4*C5*CC6*S3 + 4*YY6*dq26*m_6*C3*CC4*C5*CC6*S2 + 2*YY6*dq35*m_6*C2*C3*CC5*CC6*S4 - 4*YY6*dq14*m_6*CC3*CC4*C5*C6*S6 - 4*YY6*dq16*m_6*CC3*C4*C5*CC6*S4 + 4*YY6*dq36*m_6*C2*CC4*C5*CC6*S3 + 4*YY6*dq36*m_6*C3*CC4*C5*CC6*S2 - 2*YY6*dq45*m_6*C2*C4*CC5*CC6*S3 - 2*YY6*dq45*m_6*C3*C4*CC5*CC6*S2 + 8*ZZ5*dq12*m_5*CC2*CC3*C4*C5*S5 + 8*ZZ5*dq15*m_5*C2*CC3*C4*CC5*S2 + 8*ZZ5*dq13*m_5*CC2*CC3*C4*C5*S5 + 8*ZZ5*dq15*m_5*CC2*C3*C4*CC5*S3 + 8*ZZ6*dq12*m_6*CC2*CC3*C4*C5*S5 + 8*ZZ6*dq15*m_6*C2*CC3*C4*CC5*S2 + 8*ZZ6*dq13*m_6*CC2*CC3*C4*C5*S5 + 8*ZZ6*dq15*m_6*CC2*C3*C4*CC5*S3 + 4*X6*Y6*dq22*m_6*CC4*C5*CC6*S2*S3 + 4*X6*Y6*dq33*m_6*CC4*C5*CC6*S2*S3 - 8*Ixy6*dq12*C2*CC3*CC4*C6*S2*S6 + 4*Ixy6*dq16*C2*C3*CC4*CC5*S2*S3 - 8*Ixy6*dq12*C2*CC3*CC5*C6*S2*S6 - 8*Ixy6*dq12*CC2*C3*CC4*C6*S3*S6 - 8*Ixy6*dq13*C2*CC3*CC4*C6*S2*S6 - 8*Ixy6*dq14*C2*CC3*C4*CC6*S2*S5 - 8*Ixy6*dq16*C2*C3*CC4*CC6*S2*S3 + 4*Ixy6*dq12*C2*CC4*CC5*C6*S2*S6 - 8*Ixy6*dq12*CC2*C3*CC5*C6*S3*S6 - 8*Ixy6*dq13*C2*CC3*CC5*C6*S2*S6 - 8*Ixy6*dq13*CC2*C3*CC4*C6*S3*S6 - 8*Ixy6*dq14*CC2*C3*C4*CC6*S3*S5 - 8*Ixy6*dq15*C2*CC3*C5*CC6*S2*S4 - 8*Ixy6*dq16*C2*C3*CC5*CC6*S2*S3 + 4*Ixy6*dq13*C2*CC4*CC5*C6*S2*S6 - 8*Ixy6*dq13*CC2*C3*CC5*C6*S3*S6 - 8*Ixy6*dq15*CC2*C3*C5*CC6*S3*S4 + 4*Ixy6*dq12*C3*CC4*CC5*C6*S3*S6 - 8*Ixy6*dq14*CC2*CC3*C4*C6*S4*S6 + 4*Ixy6*dq13*C3*CC4*CC5*C6*S3*S6 + 4*Ixy6*dq14*CC2*C4*CC5*C6*S4*S6 - 4*Ixy6*dq24*C2*CC4*CC5*C6*S3*S6 - 4*Ixy6*dq24*C3*CC4*CC5*C6*S2*S6 - 4*Ixy6*dq26*C2*C4*CC5*CC6*S3*S4 - 4*Ixy6*dq26*C3*C4*CC5*CC6*S2*S4 + 4*Ixy6*dq14*CC3*C4*CC5*C6*S4*S6 - 8*Ixy6*dq15*CC2*CC3*C5*C6*S5*S6 - 4*Ixy6*dq34*C2*CC4*CC5*C6*S3*S6 - 4*Ixy6*dq34*C3*CC4*CC5*C6*S2*S6 - 4*Ixy6*dq36*C2*C4*CC5*CC6*S3*S4 - 4*Ixy6*dq36*C3*C4*CC5*CC6*S2*S4 + 4*Ixy6*dq15*CC2*CC4*C5*C6*S5*S6 + 4*Ixy6*dq15*CC3*CC4*C5*C6*S5*S6 + 8*Ixz5*dq12*C2*CC3*CC4*C5*S2*S5 + 8*Ixz5*dq12*CC2*C3*CC4*C5*S3*S5 + 8*Ixz5*dq13*C2*CC3*CC4*C5*S2*S5 + 8*Ixz5*dq15*C2*C3*CC4*CC5*S2*S3 + 8*Ixz5*dq13*CC2*C3*CC4*C5*S3*S5 + 8*Ixz5*dq14*CC2*CC3*C4*C5*S4*S5 + 8*Ixz6*dq14*C2*CC3*CC5*C6*S2*S4 + 8*Ixz6*dq14*CC2*C3*CC5*C6*S3*S4 + 8*Ixz6*dq16*C2*CC3*C4*CC5*S2*S6 + 4*Ixz6*dq15*CC2*CC3*C4*C5*S4*S6 + 8*Ixz6*dq16*CC2*C3*C4*CC5*S3*S6 + 4*Ixz6*dq16*CC2*CC3*C4*C6*S4*S5 + 8*dd6*dq12*m_6*CC2*CC3*C4*C5*S5 + 8*dd6*dq15*m_6*C2*CC3*C4*CC5*S2 + 8*dd6*dq13*m_6*CC2*CC3*C4*C5*S5 + 8*dd6*dq15*m_6*CC2*C3*C4*CC5*S3 + 4*X6*Y6*dq46*m_6*C2*C3*CC5*CC6 - 8*X6*Z6*dq12*m_6*CC2*CC3*C4*C6 - 8*X6*Z6*dq13*m_6*CC2*CC3*C4*C6 - 8*X6*Z6*dq12*m_6*CC2*C4*CC5*C6 - 8*X6*Z6*dq12*m_6*CC3*C4*CC5*C6 - 8*X6*Z6*dq13*m_6*CC2*C4*CC5*C6 - 8*X6*Z6*dq13*m_6*CC3*C4*CC5*C6 - 8*Ixx6*dq12*CC2*CC3*C6*S4*S5*S6 - 8*Ixx6*dq16*C2*CC3*CC6*S2*S4*S5 - 2*Ixx6*dq23*C4*CC5*CC6*S2*S3*S4 - 8*Ixx6*dq13*CC2*CC3*C6*S4*S5*S6 - 8*Ixx6*dq16*CC2*C3*CC6*S3*S4*S5 + 8*Iyy6*dq12*CC2*CC3*C6*S4*S5*S6 + 8*Iyy6*dq16*C2*CC3*CC6*S2*S4*S5 + 2*Iyy6*dq23*C4*CC5*CC6*S2*S3*S4 + 8*Iyy6*dq13*CC2*CC3*C6*S4*S5*S6 + 8*Iyy6*dq16*CC2*C3*CC6*S3*S4*S5 - 8*Iyz6*dq14*C2*CC3*CC5*S2*S4*S6 - 8*Iyz6*dq14*CC2*C3*CC5*S3*S4*S6 - 4*Iyz6*dq16*CC2*CC3*C4*S4*S5*S6 + 2*Ixz6*dq22*C2*C3*C4*C5*C6*S4*S5 + 2*Ixz6*dq33*C2*C3*C4*C5*C6*S4*S5 - 4*Y6*a3*dq14*m_6*CC2*CC3*C4*C6 + 4*Z5*a3*dq15*m_5*CC2*CC3*C4*C5 + 4*Z6*a3*dq15*m_6*CC2*CC3*C4*C5 + 2*XX6*dq25*m_6*CC5*CC6*S2*S3*S4 + 2*XX6*dq35*m_6*CC5*CC6*S2*S3*S4 + 8*X5*d4*dq12*m_5*CC2*CC3*C4*C5 + 8*X5*d4*dq13*m_5*CC2*CC3*C4*C5 - 8*X6*d6*dq12*m_6*CC2*CC3*C4*C6 - 8*X6*d6*dq13*m_6*CC2*CC3*C4*C6 + 4*X6*d4*dq15*m_6*CC2*CC3*C5*C6 - 8*X6*d6*dq12*m_6*CC2*C4*CC5*C6 - 8*X6*d6*dq12*m_6*CC3*C4*CC5*C6 - 8*X6*d6*dq13*m_6*CC2*C4*CC5*C6 - 8*X6*d6*dq13*m_6*CC3*C4*CC5*C6 - 2*YY6*dq25*m_6*CC5*CC6*S2*S3*S4 - 2*YY6*dq35*m_6*CC5*CC6*S2*S3*S4 - 8*Y5*Z5*dq12*m_5*CC2*CC3*C5*S4 - 8*Y5*Z5*dq13*m_5*CC2*CC3*C5*S4 + 8*Y6*Z6*dq12*m_6*CC2*CC3*C4*S6 + 8*Y6*Z6*dq13*m_6*CC2*CC3*C4*S6 + 8*Y6*Z6*dq12*m_6*CC2*C4*CC5*S6 + 8*Y6*Z6*dq12*m_6*CC3*C4*CC5*S6 + 8*Y6*Z6*dq13*m_6*CC2*C4*CC5*S6 + 4*Y6*Z6*dq14*m_6*CC2*CC3*C6*S5 + 8*Y6*Z6*dq13*m_6*CC3*C4*CC5*S6 + 4*Y6*Z6*dq14*m_6*CC2*CC4*C6*S5 + 4*Y6*Z6*dq14*m_6*CC3*CC4*C6*S5 + 4*a3*d6*dq15*m_6*CC2*CC3*C4*C5 - 2*Iyz6*dq22*C2*C3*C4*C5*S4*S5*S6 - 2*Iyz6*dq33*C2*C3*C4*C5*S4*S5*S6 - 4*X5*a3*dq14*m_5*CC2*CC3*C5*S4 - 4*X5*a3*dq15*m_5*CC2*CC3*C4*S5 - 8*X6*a3*dq12*m_6*CC2*CC3*C6*S5 - 8*X6*a3*dq13*m_6*CC2*CC3*C6*S5 - 4*X6*a3*dq14*m_6*CC2*CC3*C4*S6 - 4*X6*a3*dq16*m_6*CC2*CC3*C6*S4 + XX6*dq22*m_6*C2*C4*C6*S3*S5*S6 + XX6*dq22*m_6*C3*C4*C6*S2*S5*S6 + XX6*dq33*m_6*C2*C4*C6*S3*S5*S6 + XX6*dq33*m_6*C3*C4*C6*S2*S5*S6 - XX6*dq44*m_6*C2*C4*C6*S3*S5*S6 - XX6*dq44*m_6*C3*C4*C6*S2*S5*S6 + XX6*dq55*m_6*C2*C4*C6*S3*S5*S6 + XX6*dq55*m_6*C3*C4*C6*S2*S5*S6 - 8*Y6*d4*dq12*m_6*CC2*CC3*C6*S4 - 8*Y6*d4*dq13*m_6*CC2*CC3*C6*S4 + 8*Y6*d6*dq12*m_6*CC2*CC3*C4*S6 + 8*Y6*d6*dq13*m_6*CC2*CC3*C4*S6 - 4*Y6*d4*dq15*m_6*CC2*CC3*C5*S6 + 8*Y6*d6*dq12*m_6*CC2*C4*CC5*S6 - 4*Y6*d4*dq16*m_6*CC2*CC3*C6*S5 + 8*Y6*d6*dq12*m_6*CC3*C4*CC5*S6 + 8*Y6*d6*dq13*m_6*CC2*C4*CC5*S6 + 4*Y6*d6*dq14*m_6*CC2*CC3*C6*S5 + 8*Y6*d6*dq13*m_6*CC3*C4*CC5*S6 + 4*Y6*d6*dq14*m_6*CC2*CC4*C6*S5 + 4*Y6*d6*dq14*m_6*CC3*CC4*C6*S5 - YY6*dq22*m_6*C2*C4*C6*S3*S5*S6 - YY6*dq22*m_6*C3*C4*C6*S2*S5*S6 - YY6*dq33*m_6*C2*C4*C6*S3*S5*S6 - YY6*dq33*m_6*C3*C4*C6*S2*S5*S6 + YY6*dq44*m_6*C2*C4*C6*S3*S5*S6 + YY6*dq44*m_6*C3*C4*C6*S2*S5*S6 - YY6*dq55*m_6*C2*C4*C6*S3*S5*S6 - YY6*dq55*m_6*C3*C4*C6*S2*S5*S6 + 8*Z5*d4*dq12*m_5*CC2*CC3*C4*S5 + 8*Z5*d4*dq13*m_5*CC2*CC3*C4*S5 - 8*Z6*d6*dq12*m_6*C2*CC3*CC4*S2 + 8*Z6*d4*dq12*m_6*CC2*CC3*C4*S5 + 8*Z6*d6*dq12*m_6*C2*CC3*CC5*S2 - 8*Z6*d6*dq12*m_6*CC2*C3*CC4*S3 - 8*Z6*d6*dq13*m_6*C2*CC3*CC4*S2 + 8*Z6*d4*dq13*m_6*CC2*CC3*C4*S5 - 4*Z6*d6*dq12*m_6*C2*CC4*CC5*S2 + 8*Z6*d6*dq12*m_6*CC2*C3*CC5*S3 + 8*Z6*d6*dq13*m_6*C2*CC3*CC5*S2 - 8*Z6*d6*dq13*m_6*CC2*C3*CC4*S3 - 4*Z6*d6*dq13*m_6*C2*CC4*CC5*S2 + 8*Z6*d6*dq13*m_6*CC2*C3*CC5*S3 - 4*Z6*d6*dq12*m_6*C3*CC4*CC5*S3 - 8*Z6*d6*dq14*m_6*CC2*CC3*C4*S4 - 4*Z6*d6*dq13*m_6*C3*CC4*CC5*S3 - 4*Z6*d6*dq14*m_6*CC2*C4*CC5*S4 + 4*Z6*d6*dq24*m_6*C2*CC4*CC5*S3 + 4*Z6*d6*dq24*m_6*C3*CC4*CC5*S2 - 4*Z6*d6*dq14*m_6*CC3*C4*CC5*S4 + 8*Z6*d6*dq15*m_6*CC2*CC3*C5*S5 + 4*Z6*d6*dq34*m_6*C2*CC4*CC5*S3 + 4*Z6*d6*dq34*m_6*C3*CC4*CC5*S2 - 4*Z6*d6*dq15*m_6*CC2*CC4*C5*S5 - 4*Z6*d6*dq15*m_6*CC3*CC4*C5*S5 + 8*X5*Y5*dq12*m_5*CC2*CC3*S4*S5 + 8*X5*Y5*dq13*m_5*CC2*CC3*S4*S5 - 8*X6*Y6*dq12*m_6*CC2*CC3*S4*S5 - 8*X6*Y6*dq13*m_6*CC2*CC3*S4*S5 - 8*X6*Y6*dq12*m_6*CC2*CC6*S4*S5 - 8*X6*Y6*dq12*m_6*CC3*CC6*S4*S5 - 8*X6*Y6*dq13*m_6*CC2*CC6*S4*S5 - 8*X6*Y6*dq13*m_6*CC3*CC6*S4*S5 - 4*X6*Y6*dq46*m_6*CC5*CC6*S2*S3 + 4*X6*Z6*dq14*m_6*CC2*CC3*S5*S6 + 4*X6*Z6*dq14*m_6*CC2*CC4*S5*S6 + 4*X6*Z6*dq14*m_6*CC3*CC4*S5*S6 - Y6*Z6*dq22*m_6*C2*C4*C5*C6*S3 - Y6*Z6*dq22*m_6*C3*C4*C5*C6*S2 - Y6*Z6*dq33*m_6*C2*C4*C5*C6*S3 - Y6*Z6*dq33*m_6*C3*C4*C5*C6*S2 + Y6*Z6*dq44*m_6*C2*C4*C5*C6*S3 + Y6*Z6*dq44*m_6*C3*C4*C5*C6*S2 - Y6*Z6*dq55*m_6*C2*C4*C5*C6*S3 - Y6*Z6*dq55*m_6*C3*C4*C5*C6*S2 + Y6*Z6*dq66*m_6*C2*C4*C5*C6*S3 + Y6*Z6*dq66*m_6*C3*C4*C5*C6*S2 + 2*Ixy6*dq22*C2*C5*C6*S3*S4*S5*S6 + 2*Ixy6*dq22*C3*C5*C6*S2*S4*S5*S6 + 2*Ixy6*dq33*C2*C5*C6*S3*S4*S5*S6 + 2*Ixy6*dq33*C3*C5*C6*S2*S4*S5*S6 - 2*Ixy6*dq44*C2*C5*C6*S3*S4*S5*S6 - 2*Ixy6*dq44*C3*C5*C6*S2*S4*S5*S6 - 2*Ixz6*dq22*C4*C5*C6*S2*S3*S4*S5 - 2*Ixz6*dq33*C4*C5*C6*S2*S3*S4*S5 + 2*Ixx6*dq25*C2*C3*C4*C5*C6*S6 + 2*Ixx6*dq35*C2*C3*C4*C5*C6*S6 - 2*Iyy6*dq25*C2*C3*C4*C5*C6*S6 - 2*Iyy6*dq35*C2*C3*C4*C5*C6*S6 + 8*d4*d6*dq12*m_6*CC2*CC3*C4*S5 + 8*d4*d6*dq13*m_6*CC2*CC3*C4*S5 - X6*a3*dq22*m_6*C2*C3*C5*C6*S4 - X6*a3*dq33*m_6*C2*C3*C5*C6*S4 + X6*a3*dq44*m_6*C2*C3*C5*C6*S4 + X6*a3*dq55*m_6*C2*C3*C5*C6*S4 + X6*a3*dq66*m_6*C2*C3*C5*C6*S4 + 8*Y6*a3*dq12*m_6*CC2*CC3*S5*S6 + 8*Y6*a3*dq13*m_6*CC2*CC3*S5*S6 + 4*Y6*a3*dq16*m_6*CC2*CC3*S4*S6 - 4*Z5*a3*dq14*m_5*CC2*CC3*S4*S5 - 4*Z6*a3*dq14*m_6*CC2*CC3*S4*S5 - 8*X6*d4*dq12*m_6*CC2*CC3*S4*S6 - 8*X6*d4*dq13*m_6*CC2*CC3*S4*S6 - 4*X6*d4*dq16*m_6*CC2*CC3*S5*S6 + 4*X6*d6*dq14*m_6*CC2*CC3*S5*S6 + 4*X6*d6*dq14*m_6*CC2*CC4*S5*S6 + 4*X6*d6*dq14*m_6*CC3*CC4*S5*S6 + 2*XX6*dq23*m_6*C2*C3*C5*C6*S6 - Y6*d6*dq22*m_6*C2*C4*C5*C6*S3 - Y6*d6*dq22*m_6*C3*C4*C5*C6*S2 - Y6*d6*dq33*m_6*C2*C4*C5*C6*S3 - Y6*d6*dq33*m_6*C3*C4*C5*C6*S2 + Y6*d6*dq44*m_6*C2*C4*C5*C6*S3 + Y6*d6*dq44*m_6*C3*C4*C5*C6*S2 - Y6*d6*dq55*m_6*C2*C4*C5*C6*S3 - Y6*d6*dq55*m_6*C3*C4*C5*C6*S2 + Y6*d6*dq66*m_6*C2*C4*C5*C6*S3 + Y6*d6*dq66*m_6*C3*C4*C5*C6*S2 - 2*YY6*dq23*m_6*C2*C3*C5*C6*S6 - X6*Z6*dq22*m_6*C2*C4*C5*S3*S6 - X6*Z6*dq22*m_6*C3*C4*C5*S2*S6 - X6*Z6*dq33*m_6*C2*C4*C5*S3*S6 - X6*Z6*dq33*m_6*C3*C4*C5*S2*S6 + X6*Z6*dq44*m_6*C2*C4*C5*S3*S6 + X6*Z6*dq44*m_6*C3*C4*C5*S2*S6 - X6*Z6*dq55*m_6*C2*C4*C5*S3*S6 - X6*Z6*dq55*m_6*C3*C4*C5*S2*S6 + X6*Z6*dq66*m_6*C2*C4*C5*S3*S6 + X6*Z6*dq66*m_6*C3*C4*C5*S2*S6 - 4*a3*d6*dq14*m_6*CC2*CC3*S4*S5 + 2*Iyz6*dq22*C4*C5*S2*S3*S4*S5*S6 + 2*Iyz6*dq33*C4*C5*S2*S3*S4*S5*S6 - 4*Ixy6*dq23*C2*C3*C4*C6*S4*S6 - 4*Ixy6*dq26*C2*C3*C4*C6*S5*S6 - 4*Ixy6*dq36*C2*C3*C4*C6*S5*S6
 + 4*Ixy6*dq45*C2*C3*C5*C6*S5*S6 - 4*Ixy6*dq56*C2*C4*C5*C6*S3*S6 - 4*Ixy6*dq56*C3*C4*C5*C6*S2*S6 - 8*Ixz6*dq12*C2*C3*C4*C6*S2*S3 - 8*Ixz6*dq13*C2*C3*C4*C6*S2*S3 + 4*Ixz5*dq23*C2*C3*C4*C5*S4*S5 - 8*Ixz6*dq15*C2*C4*C5*C6*S2*S5 - 8*Ixz6*dq15*C3*C4*C5*C6*S3*S5 + 4*Ixz6*dq25*C2*C3*C5*C6*S4*S5 + 4*Ixz6*dq35*C2*C3*C5*C6*S4*S5 - 4*Ixz6*dq45*C2*C4*C5*C6*S3*S5 - 4*Ixz6*dq45*C3*C4*C5*C6*S2*S5 + Y6*a3*dq22*m_6*C2*C3*C5*S4*S6 + Y6*a3*dq33*m_6*C2*C3*C5*S4*S6 - Y6*a3*dq44*m_6*C2*C3*C5*S4*S6 - Y6*a3*dq55*m_6*C2*C3*C5*S4*S6 - Y6*a3*dq66*m_6*C2*C3*C5*S4*S6 - X6*d4*dq22*m_6*C2*C5*C6*S3*S4 - X6*d4*dq22*m_6*C3*C5*C6*S2*S4 - X6*d4*dq33*m_6*C2*C5*C6*S3*S4 - X6*d4*dq33*m_6*C3*C5*C6*S2*S4 + X6*d4*dq44*m_6*C2*C5*C6*S3*S4 + X6*d4*dq44*m_6*C3*C5*C6*S2*S4 - X6*d6*dq22*m_6*C2*C4*C5*S3*S6 - X6*d6*dq22*m_6*C3*C4*C5*S2*S6 + X6*d4*dq55*m_6*C2*C5*C6*S3*S4 + X6*d4*dq55*m_6*C3*C5*C6*S2*S4 - X6*d6*dq33*m_6*C2*C4*C5*S3*S6 - X6*d6*dq33*m_6*C3*C4*C5*S2*S6 + X6*d4*dq66*m_6*C2*C5*C6*S3*S4 + X6*d4*dq66*m_6*C3*C5*C6*S2*S4 + X6*d6*dq44*m_6*C2*C4*C5*S3*S6 + X6*d6*dq44*m_6*C3*C4*C5*S2*S6 - X6*d6*dq55*m_6*C2*C4*C5*S3*S6 - X6*d6*dq55*m_6*C3*C4*C5*S2*S6 + X6*d6*dq66*m_6*C2*C4*C5*S3*S6 + X6*d6*dq66*m_6*C3*C4*C5*S2*S6 - 2*X5*Y5*dq25*m_5*C2*C3*C4*C5 - 2*X5*Y5*dq35*m_5*C2*C3*C4*C5 + 2*X6*Y6*dq25*m_6*C2*C3*C4*C5 + 2*X6*Y6*dq35*m_6*C2*C3*C4*C5 + 8*Ixx6*dq12*CC2*CC3*C4*C5*CC6*S5 + 8*Ixx6*dq15*C2*CC3*C4*CC5*CC6*S2 + 8*Ixx6*dq13*CC2*CC3*C4*C5*CC6*S5 + 8*Ixx6*dq15*CC2*C3*C4*CC5*CC6*S3 + 8*Ixx6*dq14*CC2*CC3*CC4*C5*C6*S6 + 8*Ixx6*dq16*CC2*CC3*C4*C5*CC6*S4 - 8*Iyy6*dq12*CC2*CC3*C4*C5*CC6*S5 - 8*Iyy6*dq15*C2*CC3*C4*CC5*CC6*S2 - 8*Iyy6*dq13*CC2*CC3*C4*C5*CC6*S5 - 8*Iyy6*dq15*CC2*C3*C4*CC5*CC6*S3 - 8*Iyy6*dq14*CC2*CC3*CC4*C5*C6*S6 - 8*Iyy6*dq16*CC2*CC3*C4*C5*CC6*S4 + 4*Iyz6*dq16*CC2*CC3*CC4*C5*C6*S5 - 4*Ixx4*dq14*C2*C3*C4*S2*S3*S4 + 4*Ixx6*dq14*C2*C3*C4*S2*S3*S4 - 4*Ixx5*dq15*C2*C3*C5*S2*S3*S5 - 2*Ixx5*dq25*C2*C4*C5*S3*S4*S5 - 2*Ixx5*dq25*C3*C4*C5*S2*S4*S5 + 8*Ixx6*dq16*C2*C3*C6*S2*S3*S6 - 2*Ixx5*dq35*C2*C4*C5*S3*S4*S5 - 2*Ixx5*dq35*C3*C4*C5*S2*S4*S5 + 2*Ixx6*dq14*C2*C4*C6*S2*S5*S6 + 2*Ixx6*dq15*C2*C5*C6*S2*S4*S6 - 2*Ixx6*dq23*C2*C4*C6*S3*S5*S6 - 2*Ixx6*dq23*C3*C4*C6*S2*S5*S6 + 2*Ixx6*dq14*C3*C4*C6*S3*S5*S6 + 2*Ixx6*dq15*C3*C5*C6*S3*S4*S6 - 2*Ixx6*dq25*C4*C5*C6*S2*S3*S6 - 2*Ixx6*dq26*C2*C4*C6*S3*S4*S6 - 2*Ixx6*dq26*C3*C4*C6*S2*S4*S6 - 2*Ixx6*dq35*C4*C5*C6*S2*S3*S6 - 2*Ixx6*dq36*C2*C4*C6*S3*S4*S6 - 2*Ixx6*dq36*C3*C4*C6*S2*S4*S6 + 4*Iyy5*dq14*C2*C3*C4*S2*S3*S4 - 4*Iyy6*dq15*C2*C3*C5*S2*S3*S5 - 8*Iyy6*dq16*C2*C3*C6*S2*S3*S6 - 2*Iyy6*dq14*C2*C4*C6*S2*S5*S6 - 2*Iyy6*dq25*C2*C4*C5*S3*S4*S5 - 2*Iyy6*dq25*C3*C4*C5*S2*S4*S5 - 2*Iyy6*dq15*C2*C5*C6*S2*S4*S6 + 2*Iyy6*dq23*C2*C4*C6*S3*S5*S6 + 2*Iyy6*dq23*C3*C4*C6*S2*S5*S6 - 2*Iyy6*dq35*C2*C4*C5*S3*S4*S5 - 2*Iyy6*dq35*C3*C4*C5*S2*S4*S5 - 2*Iyy6*dq14*C3*C4*C6*S3*S5*S6 - 2*Iyy6*dq15*C3*C5*C6*S3*S4*S6 + 2*Iyy6*dq25*C4*C5*C6*S2*S3*S6 + 2*Iyy6*dq26*C2*C4*C6*S3*S4*S6 + 2*Iyy6*dq26*C3*C4*C6*S2*S4*S6 + 2*Iyy6*dq35*C4*C5*C6*S2*S3*S6 + 2*Iyy6*dq36*C2*C4*C6*S3*S4*S6 + 2*Iyy6*dq36*C3*C4*C6*S2*S4*S6 - 8*Iyz5*dq12*C2*C3*C5*S2*S3*S4 - 8*Iyz5*dq13*C2*C3*C5*S2*S3*S4 + 8*Iyz6*dq12*C2*C3*C4*S2*S3*S6 + 8*Iyz6*dq13*C2*C3*C4*S2*S3*S6 + 4*Iyz6*dq12*C2*C4*C6*S2*S4*S5 + 4*Iyz6*dq14*C2*C3*C6*S2*S3*S5 + 4*Iyz6*dq13*C2*C4*C6*S2*S4*S5 + 4*Iyz6*dq12*C3*C4*C6*S3*S4*S5 + 4*Iyz6*dq13*C3*C4*C6*S3*S4*S5 + 8*Iyz6*dq15*C2*C4*C5*S2*S5*S6 - 4*Iyz6*dq24*C2*C4*C6*S3*S4*S5 - 4*Iyz6*dq24*C3*C4*C6*S2*S4*S5 - 4*Iyz6*dq34*C2*C4*C6*S3*S4*S5 - 4*Iyz6*dq34*C3*C4*C6*S2*S4*S5 + 8*Iyz6*dq15*C3*C4*C5*S3*S5*S6 - 4*Iyz6*dq25*C2*C3*C5*S4*S5*S6 - 4*Iyz6*dq35*C2*C3*C5*S4*S5*S6 + 4*Iyz6*dq45*C2*C4*C5*S3*S5*S6 + 4*Iyz6*dq45*C3*C4*C5*S2*S5*S6 + 4*Izz4*dq14*C2*C3*C4*S2*S3*S4 - 4*Izz5*dq14*C2*C3*C4*S2*S3*S4 - 4*Izz6*dq14*C2*C3*C4*S2*S3*S4 + 4*Izz5*dq15*C2*C3*C5*S2*S3*S5 + 4*Izz6*dq15*C2*C3*C5*S2*S3*S5 + 2*Izz5*dq25*C2*C4*C5*S3*S4*S5 + 2*Izz5*dq25*C3*C4*C5*S2*S4*S5 + 2*Izz5*dq35*C2*C4*C5*S3*S4*S5 + 2*Izz5*dq35*C3*C4*C5*S2*S4*S5 + 2*Izz6*dq25*C2*C4*C5*S3*S4*S5 + 2*Izz6*dq25*C3*C4*C5*S2*S4*S5 + 2*Izz6*dq35*C2*C4*C5*S3*S4*S5 + 2*Izz6*dq35*C3*C4*C5*S2*S4*S5 + X6*a3*dq22*m_6*C5*C6*S2*S3*S4 + X6*a3*dq33*m_6*C5*C6*S2*S3*S4 - X6*a3*dq44*m_6*C5*C6*S2*S3*S4 - X6*a3*dq55*m_6*C5*C6*S2*S3*S4 - X6*a3*dq66*m_6*C5*C6*S2*S3*S4 - 2*Y6*a1*dq14*m_6*C2*C3*C4*C6 - 2*Y6*a3*dq23*m_6*C2*C3*C4*C6 + 2*Y6*a2*dq46*m_6*C2*C4*C5*C6 - 4*XX5*dq12*m_5*C2*CC3*CC4*CC5*S2 - 4*XX5*dq12*m_5*CC2*C3*CC4*CC5*S3 - 4*XX5*dq13*m_5*C2*CC3*CC4*CC5*S2 - 4*XX5*dq13*m_5*CC2*C3*CC4*CC5*S3 - 4*XX6*dq12*m_6*C2*CC3*CC4*CC6*S2 - 4*XX5*dq14*m_5*CC2*CC3*C4*CC5*S4 - 4*XX6*dq12*m_6*C2*CC3*CC5*CC6*S2 - 4*XX6*dq12*m_6*CC2*C3*CC4*CC6*S3 - 4*XX6*dq13*m_6*C2*CC3*CC4*CC6*S2 + 2*XX6*dq12*m_6*C2*CC4*CC5*CC6*S2 - 4*XX6*dq12*m_6*CC2*C3*CC5*CC6*S3 - 4*XX6*dq13*m_6*C2*CC3*CC5*CC6*S2 - 4*XX6*dq13*m_6*CC2*C3*CC4*CC6*S3 - 4*XX5*dq15*m_5*CC2*CC3*CC4*C5*S5 + 2*XX6*dq13*m_6*C2*CC4*CC5*CC6*S2 - 4*XX6*dq13*m_6*CC2*C3*CC5*CC6*S3 + 2*XX6*dq12*m_6*C3*CC4*CC5*CC6*S3 - 4*XX6*dq14*m_6*CC2*CC3*C4*CC6*S4 + 2*XX6*dq13*m_6*C3*CC4*CC5*CC6*S3 + 2*XX6*dq14*m_6*CC2*C4*CC5*CC6*S4 - 2*XX6*dq24*m_6*C2*CC4*CC5*CC6*S3 - 2*XX6*dq24*m_6*C3*CC4*CC5*CC6*S2 + 2*XX6*dq14*m_6*CC3*C4*CC5*CC6*S4 - 4*XX6*dq15*m_6*CC2*CC3*C5*CC6*S5 - 2*XX6*dq34*m_6*C2*CC4*CC5*CC6*S3 - 2*XX6*dq34*m_6*C3*CC4*CC5*CC6*S2 + 2*XX6*dq15*m_6*CC2*CC4*C5*CC6*S5 - 4*XX6*dq16*m_6*CC2*CC3*CC4*C6*S6 + 2*XX6*dq15*m_6*CC3*CC4*C5*CC6*S5 - 4*XX6*dq16*m_6*CC2*CC3*CC5*C6*S6 + 2*XX6*dq16*m_6*CC2*CC4*CC5*C6*S6 + 2*XX6*dq16*m_6*CC3*CC4*CC5*C6*S6 + 2*Z5*a1*dq15*m_5*C2*C3*C4*C5 + 2*Z6*a1*dq15*m_6*C2*C3*C4*C5 - 2*Z5*a3*dq45*m_5*C2*C3*C4*C5 - 2*Z6*a3*dq45*m_6*C2*C3*C4*C5 - 4*YY6*dq12*m_6*C2*CC3*CC4*CC5*S2 + 4*YY6*dq12*m_6*C2*CC3*CC4*CC6*S2 - 4*YY6*dq12*m_6*CC2*C3*CC4*CC5*S3 - 4*YY6*dq13*m_6*C2*CC3*CC4*CC5*S2 + 4*YY6*dq12*m_6*C2*CC3*CC5*CC6*S2 + 4*YY6*dq12*m_6*CC2*C3*CC4*CC6*S3 + 4*YY6*dq13*m_6*C2*CC3*CC4*CC6*S2 - 4*YY6*dq13*m_6*CC2*C3*CC4*CC5*S3 - 2*YY6*dq12*m_6*C2*CC4*CC5*CC6*S2 + 4*YY6*dq12*m_6*CC2*C3*CC5*CC6*S3 + 4*YY6*dq13*m_6*C2*CC3*CC5*CC6*S2 + 4*YY6*dq13*m_6*CC2*C3*CC4*CC6*S3 - 2*YY6*dq13*m_6*C2*CC4*CC5*CC6*S2 + 4*YY6*dq13*m_6*CC2*C3*CC5*CC6*S3 - 4*YY6*dq14*m_6*CC2*CC3*C4*CC5*S4 - 2*YY6*dq12*m_6*C3*CC4*CC5*CC6*S3 + 4*YY6*dq14*m_6*CC2*CC3*C4*CC6*S4 - 2*YY6*dq13*m_6*C3*CC4*CC5*CC6*S3 - 4*YY6*dq15*m_6*CC2*CC3*CC4*C5*S5 - 2*YY6*dq14*m_6*CC2*C4*CC5*CC6*S4 + 2*YY6*dq24*m_6*C2*CC4*CC5*CC6*S3 + 2*YY6*dq24*m_6*C3*CC4*CC5*CC6*S2 - 2*YY6*dq14*m_6*CC3*C4*CC5*CC6*S4 + 4*YY6*dq15*m_6*CC2*CC3*C5*CC6*S5 + 2*YY6*dq34*m_6*C2*CC4*CC5*CC6*S3 + 2*YY6*dq34*m_6*C3*CC4*CC5*CC6*S2 - 2*YY6*dq15*m_6*CC2*CC4*C5*CC6*S5 + 4*YY6*dq16*m_6*CC2*CC3*CC4*C6*S6 - 2*YY6*dq15*m_6*CC3*CC4*C5*CC6*S5 + 4*YY6*dq16*m_6*CC2*CC3*CC5*C6*S6 - 2*YY6*dq16*m_6*CC2*CC4*CC5*C6*S6 - 2*YY6*dq16*m_6*CC3*CC4*CC5*C6*S6 - 2*XX5*dq14*m_5*C2*C5*S2*S4*S5 + 2*XX5*dq23*m_5*C2*C5*S3*S4*S5 + 2*XX5*dq23*m_5*C3*C5*S2*S4*S5 - 2*XX5*dq14*m_5*C3*C5*S3*S4*S5 - 2*XX6*dq23*m_6*C5*C6*S2*S3*S6 + 2*XX6*dq56*m_6*C2*C6*S3*S4*S6 + 2*XX6*dq56*m_6*C3*C6*S2*S4*S6 + 4*ZZ5*dq12*m_5*C2*CC3*CC4*CC5*S2 + 4*ZZ5*dq12*m_5*CC2*C3*CC4*CC5*S3 + 4*ZZ5*dq13*m_5*C2*CC3*CC4*CC5*S2 + 4*ZZ5*dq13*m_5*CC2*C3*CC4*CC5*S3 + 4*ZZ6*dq12*m_6*C2*CC3*CC4*CC5*S2 + 4*ZZ6*dq12*m_6*CC2*C3*CC4*CC5*S3 + 4*ZZ6*dq13*m_6*C2*CC3*CC4*CC5*S2 + 4*ZZ5*dq14*m_5*CC2*CC3*C4*CC5*S4 + 4*ZZ6*dq13*m_6*CC2*C3*CC4*CC5*S3 + 4*ZZ5*dq15*m_5*CC2*CC3*CC4*C5*S5 + 4*ZZ6*dq14*m_6*CC2*CC3*C4*CC5*S4 + 4*ZZ6*dq15*m_6*CC2*CC3*CC4*C5*S5 + Y6*d4*dq22*m_6*C2*C5*S3*S4*S6 + Y6*d4*dq22*m_6*C3*C5*S2*S4*S6 + Y6*d4*dq33*m_6*C2*C5*S3*S4*S6 + Y6*d4*dq33*m_6*C3*C5*S2*S4*S6 - Y6*d4*dq44*m_6*C2*C5*S3*S4*S6 - Y6*d4*dq44*m_6*C3*C5*S2*S4*S6 - Y6*d4*dq55*m_6*C2*C5*S3*S4*S6 - Y6*d4*dq55*m_6*C3*C5*S2*S4*S6 - Y6*d4*dq66*m_6*C2*C5*S3*S4*S6 - Y6*d4*dq66*m_6*C3*C5*S2*S4*S6 - 2*YY6*dq14*m_6*C2*C5*S2*S4*S5 + 2*YY6*dq23*m_6*C2*C5*S3*S4*S5 + 2*YY6*dq23*m_6*C3*C5*S2*S4*S5 - 2*YY6*dq14*m_6*C3*C5*S3*S4*S5 + 2*YY6*dq23*m_6*C5*C6*S2*S3*S6 - 2*YY6*dq56*m_6*C2*C6*S3*S4*S6 - 2*YY6*dq56*m_6*C3*C6*S2*S4*S6 - 2*Z6*d6*dq22*m_6*C2*C5*S3*S4*S5 - 2*Z6*d6*dq22*m_6*C3*C5*S2*S4*S5 - 2*Z6*d6*dq33*m_6*C2*C5*S3*S4*S5 - 2*Z6*d6*dq33*m_6*C3*C5*S2*S4*S5 + 2*Z6*d6*dq44*m_6*C2*C5*S3*S4*S5 + 2*Z6*d6*dq44*m_6*C3*C5*S2*S4*S5 + 2*ZZ5*dq14*m_5*C2*C5*S2*S4*S5 - 2*ZZ5*dq23*m_5*C2*C5*S3*S4*S5 - 2*ZZ5*dq23*m_5*C3*C5*S2*S4*S5 + 2*ZZ5*dq14*m_5*C3*C5*S3*S4*S5 + 2*ZZ6*dq14*m_6*C2*C5*S2*S4*S5 - 2*ZZ6*dq23*m_6*C2*C5*S3*S4*S5 - 2*ZZ6*dq23*m_6*C3*C5*S2*S4*S5 + 2*ZZ6*dq14*m_6*C3*C5*S3*S4*S5 + 2*Y5*Z5*dq14*m_5*C2*C4*C5*S2 - 2*Y5*Z5*dq23*m_5*C2*C4*C5*S3 - 2*Y5*Z5*dq23*m_5*C3*C4*C5*S2 + 2*Y5*Z5*dq14*m_5*C3*C4*C5*S3 - 2*Y5*Z5*dq25*m_5*C2*C3*C4*S5 - 2*Y5*Z5*dq35*m_5*C2*C3*C4*S5 - 2*Y6*Z6*dq16*m_6*C2*C4*C6*S2 + 2*Y6*Z6*dq23*m_6*C2*C3*C6*S5 - 2*Y6*Z6*dq16*m_6*C3*C4*C6*S3 + 2*Y6*Z6*dq26*m_6*C2*C3*C6*S4 + 2*Y6*Z6*dq36*m_6*C2*C3*C6*S4 - 8*Ixy6*dq15*CC2*CC3*C4*CC6*S4*S5 + 4*Ixz6*dq16*CC2*CC3*CC4*C5*S5*S6 + 8*Ixy5*dq12*C2*C3*S2*S3*S4*S5 + 8*Ixy5*dq13*C2*C3*S2*S3*S4*S5 - 8*Ixy6*dq12*C2*C3*S2*S3*S4*S5 - 8*Ixy6*dq13*C2*C3*S2*S3*S4*S5 + 4*Ixy6*dq23*C4*C6*S2*S3*S4*S6 - 8*Ixy6*dq16*C2*C6*S2*S4*S5*S6 - 8*Ixy6*dq16*C3*C6*S3*S4*S5*S6 + 4*Ixy6*dq26*C4*C6*S2*S3*S5*S6 + 4*Ixy6*dq36*C4*C6*S2*S3*S5*S6 - 4*Ixy6*dq45*C5*C6*S2*S3*S5*S6 - 4*Ixy6*dq46*C2*C6*S3*S4*S5*S6 - 4*Ixy6*dq46*C3*C6*S2*S4*S5*S6 + 4*Ixz6*dq12*C2*C4*S2*S4*S5*S6 + 4*Ixz6*dq14*C2*C3*S2*S3*S5*S6 - 4*Ixz5*dq23*C4*C5*S2*S3*S4*S5 + 4*Ixz6*dq13*C2*C4*S2*S4*S5*S6 + 4*Ixz6*dq12*C3*C4*S3*S4*S5*S6 + 4*Ixz6*dq13*C3*C4*S3*S4*S5*S6 - 4*Ixz6*dq24*C2*C4*S3*S4*S5*S6 - 4*Ixz6*dq24*C3*C4*S2*S4*S5*S6 - 4*Ixz6*dq34*C2*C4*S3*S4*S5*S6 - 4*Ixz6*dq34*C3*C4*S2*S4*S5*S6 - 4*Ixz6*dq25*C5*C6*S2*S3*S4*S5 - 4*Ixz6*dq35*C5*C6*S2*S3*S4*S5 + 2*a1*d6*dq15*m_6*C2*C3*C4*C5 - 2*a3*d6*dq45*m_6*C2*C3*C4*C5 + 4*dd6*dq12*m_6*C2*CC3*CC4*CC5*S2 + 4*dd6*dq12*m_6*CC2*C3*CC4*CC5*S3 + 4*dd6*dq13*m_6*C2*CC3*CC4*CC5*S2 + 4*dd6*dq13*m_6*CC2*C3*CC4*CC5*S3 + 4*dd6*dq14*m_6*CC2*CC3*C4*CC5*S4 + 4*dd6*dq15*m_6*CC2*CC3*CC4*C5*S5 + 2*dd6*dq14*m_6*C2*C5*S2*S4*S5 - 2*dd6*dq23*m_6*C2*C5*S3*S4*S5 - 2*dd6*dq23*m_6*C3*C5*S2*S4*S5 + 2*dd6*dq14*m_6*C3*C5*S3*S4*S5 - 4*X4*a2*dq12*m_4*C2*C3*C4*S2
 - 2*X4*a2*dq13*m_4*C2*C3*C4*S2 - 2*X5*a1*dq12*m_5*C2*C4*C5*S3 - 2*X5*a1*dq12*m_5*C3*C4*C5*S2 - 2*X5*a1*dq13*m_5*C2*C4*C5*S3 - 2*X5*a1*dq13*m_5*C3*C4*C5*S2 + 4*X5*a3*dq12*m_5*C2*C4*C5*S2 - 2*X5*a1*dq14*m_5*C2*C3*C5*S4 - 2*X5*a2*dq15*m_5*C2*C3*C5*S2 + 4*X5*a3*dq13*m_5*C2*C4*C5*S2 - 2*X5*a1*dq15*m_5*C2*C3*C4*S5 + 4*X5*a3*dq12*m_5*C3*C4*C5*S3 + 4*X5*a3*dq13*m_5*C3*C4*C5*S3 - 2*X5*a3*dq23*m_5*C2*C3*C5*S4 - 2*X6*a1*dq12*m_6*C2*C3*C6*S5 - 2*X6*a1*dq13*m_6*C2*C3*C6*S5 - 2*X6*a1*dq14*m_6*C2*C3*C4*S6 - 2*X6*a1*dq15*m_6*C2*C5*C6*S3 - 2*X6*a1*dq15*m_6*C3*C5*C6*S2 - 2*X6*a1*dq16*m_6*C2*C3*C6*S4 + 2*X6*a2*dq12*m_6*C4*C5*C6*S3 - 2*X6*a3*dq23*m_6*C2*C3*C4*S6 + 2*X5*a3*dq45*m_5*C2*C3*C4*S5 + 2*X6*a3*dq15*m_6*C2*C5*C6*S2 + 2*X6*a3*dq15*m_6*C3*C5*C6*S3 + 2*X6*a2*dq45*m_6*C2*C4*C6*S5 + 2*X6*a3*dq46*m_6*C2*C3*C6*S4 + 2*X6*a2*dq46*m_6*C2*C4*C5*S6 - Y6*a3*dq22*m_6*C5*S2*S3*S4*S6 - Y6*a3*dq33*m_6*C5*S2*S3*S4*S6 + Y6*a3*dq44*m_6*C5*S2*S3*S4*S6 + Y6*a3*dq55*m_6*C5*S2*S3*S4*S6 + Y6*a3*dq66*m_6*C5*S2*S3*S4*S6 - 2*XX6*dq22*m_6*C2*C3*CC4*C5*C6*S6 - 2*XX6*dq33*m_6*C2*C3*CC4*C5*C6*S6 + 2*YY6*dq22*m_6*C2*C3*CC4*C5*C6*S6 + 2*YY6*dq33*m_6*C2*C3*CC4*C5*C6*S6 + 2*Y6*d4*dq14*m_6*C2*C4*C6*S2 - 2*Y6*d4*dq23*m_6*C2*C4*C6*S3 - 2*Y6*d4*dq23*m_6*C3*C4*C6*S2 + 2*Y6*d4*dq14*m_6*C3*C4*C6*S3 - 2*Y6*d6*dq16*m_6*C2*C4*C6*S2 + 2*Y6*d6*dq23*m_6*C2*C3*C6*S5 - 2*Y6*d6*dq16*m_6*C3*C4*C6*S3 + 2*Y6*d6*dq26*m_6*C2*C3*C6*S4 + 2*Y6*d6*dq36*m_6*C2*C3*C6*S4 - 2*Z5*d4*dq15*m_5*C2*C4*C5*S2 - 2*Z5*d4*dq15*m_5*C3*C4*C5*S3 - 2*Z6*d4*dq15*m_6*C2*C4*C5*S2 - 4*Z6*d6*dq23*m_6*C2*C3*C4*S4 - 2*Z5*d4*dq45*m_5*C2*C4*C5*S3 - 2*Z5*d4*dq45*m_5*C3*C4*C5*S2 - 2*Z6*d4*dq15*m_6*C3*C4*C5*S3 - 2*Z6*d4*dq45*m_6*C2*C4*C5*S3 - 2*Z6*d4*dq45*m_6*C3*C4*C5*S2 - 4*Z6*d6*dq45*m_6*C2*C3*C5*S5 - 8*X5*Y5*dq14*m_5*CC2*CC3*CC4*C5 + 8*X6*Y6*dq14*m_6*CC2*CC3*CC4*C5 + 8*X6*Y6*dq14*m_6*CC2*CC3*C5*CC6 + 8*X6*Y6*dq14*m_6*CC2*CC4*C5*CC6 + 8*X6*Y6*dq14*m_6*CC3*CC4*C5*CC6 + 16*X5*Z5*dq12*m_5*CC2*CC3*C4*CC5 + 16*X5*Z5*dq13*m_5*CC2*CC3*C4*CC5 - 4*X6*Z6*dq15*m_6*CC2*CC3*CC4*C6 + 8*X6*Z6*dq15*m_6*CC2*CC3*CC5*C6 - 4*X6*Z6*dq15*m_6*CC2*CC4*CC5*C6 - 4*X6*Z6*dq15*m_6*CC3*CC4*CC5*C6 - 2*X5*Y5*dq14*m_5*C2*C4*S2*S5 - 2*X5*Y5*dq15*m_5*C2*C5*S2*S4 + 2*X5*Y5*dq23*m_5*C2*C4*S3*S5 + 2*X5*Y5*dq23*m_5*C3*C4*S2*S5 - 2*X5*Y5*dq14*m_5*C3*C4*S3*S5 + 8*X6*Y6*dq16*m_6*C2*C3*S2*S3 - 2*X5*Y5*dq15*m_5*C3*C5*S3*S4 + 2*X5*Y5*dq25*m_5*C4*C5*S2*S3 + 2*X6*Y6*dq14*m_6*C2*C4*S2*S5 + 2*X5*Y5*dq35*m_5*C4*C5*S2*S3 + 8*X6*Y6*dq12*m_6*C2*C6*S2*S6 + 2*X6*Y6*dq15*m_6*C2*C5*S2*S4 - 2*X6*Y6*dq23*m_6*C2*C4*S3*S5 - 2*X6*Y6*dq23*m_6*C3*C4*S2*S5 + 8*X6*Y6*dq13*m_6*C2*C6*S2*S6 + 2*X6*Y6*dq14*m_6*C3*C4*S3*S5 + 8*X6*Y6*dq12*m_6*C3*C6*S3*S6 + 2*X6*Y6*dq15*m_6*C3*C5*S3*S4 - 2*X6*Y6*dq25*m_6*C4*C5*S2*S3 - 2*X6*Y6*dq26*m_6*C2*C4*S3*S4 - 2*X6*Y6*dq26*m_6*C3*C4*S2*S4 + 8*X6*Y6*dq13*m_6*C3*C6*S3*S6 - 2*X6*Y6*dq35*m_6*C4*C5*S2*S3 - 2*X6*Y6*dq36*m_6*C2*C4*S3*S4 - 2*X6*Y6*dq36*m_6*C3*C4*S2*S4 + 4*X6*Y6*dq15*m_6*C5*C6*S5*S6 - 8*X3*Z3*dq12*m_3*C2*C3*S2*S3 - 8*X3*Z3*dq13*m_3*C2*C3*S2*S3 - 4*X4*Z4*dq12*m_4*C2*C4*S2*S4 - 4*X4*Z4*dq14*m_4*C2*C3*S2*S3 - 4*X4*Z4*dq13*m_4*C2*C4*S2*S4 - 4*X4*Z4*dq12*m_4*C3*C4*S3*S4 - 4*X4*Z4*dq13*m_4*C3*C4*S3*S4 + 4*X4*Z4*dq24*m_4*C2*C4*S3*S4 + 4*X4*Z4*dq24*m_4*C3*C4*S2*S4 + 4*X5*Z5*dq15*m_5*C2*C3*S2*S3 + 4*X4*Z4*dq34*m_4*C2*C4*S3*S4 + 4*X4*Z4*dq34*m_4*C3*C4*S2*S4 + 4*X5*Z5*dq12*m_5*C2*C5*S2*S5 + 4*X5*Z5*dq13*m_5*C2*C5*S2*S5 + 4*X5*Z5*dq12*m_5*C3*C5*S3*S5 + 4*X5*Z5*dq13*m_5*C3*C5*S3*S5 + 2*X5*Z5*dq25*m_5*C2*C4*S3*S4 + 2*X5*Z5*dq25*m_5*C3*C4*S2*S4 + 4*X5*Z5*dq24*m_5*C2*C5*S3*S5 + 4*X5*Z5*dq24*m_5*C3*C5*S2*S5 + 2*X5*Z5*dq35*m_5*C2*C4*S3*S4 + 2*X5*Z5*dq35*m_5*C3*C4*S2*S4 + 4*X5*Z5*dq34*m_5*C2*C5*S3*S5 + 4*X5*Z5*dq34*m_5*C3*C5*S2*S5 - 2*X6*Z6*dq14*m_6*C2*C6*S2*S4 + 2*X6*Z6*dq23*m_6*C2*C6*S3*S4 + 2*X6*Z6*dq23*m_6*C3*C6*S2*S4 - 2*X6*Z6*dq14*m_6*C3*C6*S3*S4 - 2*X6*Z6*dq16*m_6*C2*C4*S2*S6 + 2*X6*Z6*dq23*m_6*C2*C3*S5*S6 - 2*X6*Z6*dq16*m_6*C3*C4*S3*S6 + 2*X6*Z6*dq26*m_6*C2*C3*S4*S6 + 2*X6*Z6*dq26*m_6*C2*C6*S3*S5 + 2*X6*Z6*dq26*m_6*C3*C6*S2*S5 + 2*X6*Z6*dq36*m_6*C2*C3*S4*S6 + 2*X6*Z6*dq36*m_6*C2*C6*S3*S5 + 2*X6*Z6*dq36*m_6*C3*C6*S2*S5 - 2*Ixy6*dq22*C2*C3*C4*CC5*C6*S4*S6 - 2*Ixy6*dq33*C2*C3*C4*CC5*C6*S4*S6 + 4*Iyz6*dq25*C5*S2*S3*S4*S5*S6 + 4*Iyz6*dq35*C5*S2*S3*S4*S5*S6 - 2*d4*d6*dq15*m_6*C2*C4*C5*S2 - 2*d4*d6*dq15*m_6*C3*C4*C5*S3 - 2*d4*d6*dq45*m_6*C2*C4*C5*S3 - 2*d4*d6*dq45*m_6*C3*C4*C5*S2 + 8*Y4*a3*dq12*m_4*C2*C3*S2*S3 + 8*Y4*a3*dq13*m_4*C2*C3*S2*S3 + 4*Y5*a2*dq12*m_5*C2*C3*S2*S4 + 2*Y5*a2*dq13*m_5*C2*C3*S2*S4 + 2*Y5*a2*dq14*m_5*C2*C4*S2*S3 + 2*Y6*a1*dq12*m_6*C2*C6*S3*S4 + 2*Y6*a1*dq12*m_6*C3*C6*S2*S4 + 2*Y6*a1*dq12*m_6*C2*C3*S5*S6 + 2*Y6*a1*dq13*m_6*C2*C6*S3*S4 + 2*Y6*a1*dq13*m_6*C3*C6*S2*S4 - 4*Y6*a3*dq12*m_6*C2*C6*S2*S4 + 2*Y6*a1*dq13*m_6*C2*C3*S5*S6 + 2*Y6*a1*dq14*m_6*C4*C6*S2*S3 - 4*Y6*a3*dq13*m_6*C2*C6*S2*S4 - 4*Y6*a3*dq12*m_6*C3*C6*S3*S4 + 2*Y6*a1*dq15*m_6*C2*C5*S3*S6 + 2*Y6*a1*dq15*m_6*C3*C5*S2*S6 + 2*Y6*a1*dq16*m_6*C2*C3*S4*S6 - 2*Y6*a2*dq12*m_6*C4*C5*S3*S6 - 4*Y6*a3*dq13*m_6*C3*C6*S3*S4 + 2*Y6*a3*dq23*m_6*C4*C6*S2*S3 + 2*Y6*a1*dq16*m_6*C2*C6*S3*S5 + 2*Y6*a1*dq16*m_6*C3*C6*S2*S5 - 2*Y6*a3*dq15*m_6*C2*C5*S2*S6 - 2*Y6*a3*dq16*m_6*C2*C6*S2*S5 - 2*Y6*a3*dq15*m_6*C3*C5*S3*S6 - 2*Y6*a3*dq16*m_6*C3*C6*S3*S5 - 2*Y6*a2*dq45*m_6*C2*C4*S5*S6 - 2*Y6*a3*dq46*m_6*C2*C3*S4*S6 - 2*Y6*a2*dq56*m_6*C2*C6*S4*S5 - 4*X6*d6*dq15*m_6*CC2*CC3*CC4*C6 + 8*X6*d6*dq15*m_6*CC2*CC3*CC5*C6 - 4*X6*d6*dq15*m_6*CC2*CC4*CC5*C6 - 4*X6*d6*dq15*m_6*CC3*CC4*CC5*C6 - 8*Z3*a3*dq12*m_3*C2*C3*S2*S3 - 8*Z3*a3*dq13*m_3*C2*C3*S2*S3 + 4*Z4*a2*dq12*m_4*C2*C3*S2*S4 + 2*Z4*a2*dq13*m_4*C2*C3*S2*S4 + 2*Z4*a2*dq14*m_4*C2*C4*S2*S3 - 4*Z5*a2*dq12*m_5*C2*C5*S2*S3 - 2*Z5*a1*dq12*m_5*C2*C4*S3*S5 - 2*Z5*a1*dq12*m_5*C3*C4*S2*S5 - 2*Z5*a2*dq13*m_5*C2*C5*S2*S3 - 2*Z5*a1*dq13*m_5*C2*C4*S3*S5 - 2*Z5*a1*dq13*m_5*C3*C4*S2*S5 + 4*Z5*a3*dq12*m_5*C2*C4*S2*S5 - 4*Z6*a2*dq12*m_6*C2*C5*S2*S3 - 2*Z5*a1*dq14*m_5*C2*C3*S4*S5 - 2*Z5*a2*dq15*m_5*C2*C3*S2*S5 + 4*Z5*a3*dq13*m_5*C2*C4*S2*S5 - 2*Z6*a1*dq12*m_6*C2*C4*S3*S5 - 2*Z6*a1*dq12*m_6*C3*C4*S2*S5 - 2*Z6*a2*dq13*m_6*C2*C5*S2*S3 - 2*Z5*a1*dq15*m_5*C4*C5*S2*S3 + 4*Z5*a3*dq12*m_5*C3*C4*S3*S5 - 2*Z6*a1*dq13*m_6*C2*C4*S3*S5 - 2*Z6*a1*dq13*m_6*C3*C4*S2*S5 + 4*Z6*a3*dq12*m_6*C2*C4*S2*S5 + 4*Z5*a3*dq13*m_5*C3*C4*S3*S5 - 2*Z5*a3*dq23*m_5*C2*C3*S4*S5 - 2*Z6*a1*dq14*m_6*C2*C3*S4*S5 - 2*Z6*a2*dq15*m_6*C2*C3*S2*S5 + 4*Z6*a3*dq13*m_6*C2*C4*S2*S5 - 2*Z6*a1*dq15*m_6*C4*C5*S2*S3 + 4*Z6*a3*dq12*m_6*C3*C4*S3*S5 + 4*Z6*a3*dq13*m_6*C3*C4*S3*S5 - 2*Z6*a3*dq23*m_6*C2*C3*S4*S5 + 2*Z5*a3*dq45*m_5*C4*C5*S2*S3 + 2*Z6*a3*dq45*m_6*C4*C5*S2*S3 + 2*X5*d4*dq14*m_5*C2*C5*S2*S4 + 2*X5*d4*dq15*m_5*C2*C4*S2*S5 - 2*X5*d4*dq23*m_5*C2*C5*S3*S4 - 2*X5*d4*dq23*m_5*C3*C5*S2*S4 + 2*X5*d4*dq14*m_5*C3*C5*S3*S4 + 4*X6*d4*dq12*m_6*C2*C6*S2*S5 + 2*X5*d4*dq15*m_5*C3*C4*S3*S5 + 4*X6*d4*dq13*m_6*C2*C6*S2*S5 + 2*X6*d4*dq14*m_6*C2*C4*S2*S6 + 4*X6*d4*dq12*m_6*C3*C6*S3*S5 - 2*X6*d4*dq23*m_6*C2*C4*S3*S6 - 2*X6*d4*dq23*m_6*C3*C4*S2*S6 + 2*X5*d4*dq45*m_5*C2*C4*S3*S5 + 2*X5*d4*dq45*m_5*C3*C4*S2*S5 + 4*X6*d4*dq13*m_6*C3*C6*S3*S5 + 2*X6*d4*dq14*m_6*C3*C4*S3*S6 + 2*X6*d4*dq16*m_6*C2*C6*S2*S4 - 2*X6*d6*dq14*m_6*C2*C6*S2*S4 + 2*X6*d6*dq23*m_6*C2*C6*S3*S4 + 2*X6*d6*dq23*m_6*C3*C6*S2*S4 + 2*X6*d4*dq16*m_6*C3*C6*S3*S4 - 2*X6*d6*dq14*m_6*C3*C6*S3*S4 - 2*X6*d6*dq16*m_6*C2*C4*S2*S6 + 2*X6*d6*dq23*m_6*C2*C3*S5*S6 + 2*X6*d4*dq46*m_6*C2*C6*S3*S4 + 2*X6*d4*dq46*m_6*C3*C6*S2*S4 - 2*X6*d6*dq16*m_6*C3*C4*S3*S6 + 2*X6*d6*dq26*m_6*C2*C3*S4*S6 + 2*X6*d6*dq26*m_6*C2*C6*S3*S5 + 2*X6*d6*dq26*m_6*C3*C6*S2*S5 + 2*X6*d6*dq36*m_6*C2*C3*S4*S6 + 2*X6*d6*dq36*m_6*C2*C6*S3*S5 + 2*X6*d6*dq36*m_6*C3*C6*S2*S5 - 8*Y5*Z5*dq14*m_5*CC2*CC3*CC4*S5 + 4*Y6*Z6*dq15*m_6*CC2*CC3*CC4*S6 - 8*Y6*Z6*dq15*m_6*CC2*CC3*CC5*S6 + 4*Y6*Z6*dq15*m_6*CC2*CC4*CC5*S6 + 4*Y6*Z6*dq15*m_6*CC3*CC4*CC5*S6 - 2*Y5*Z5*dq15*m_5*C2*S2*S4*S5 - 2*Y5*Z5*dq15*m_5*C3*S3*S4*S5 + 2*Y5*Z5*dq25*m_5*C4*S2*S3*S5 + 2*Y5*Z5*dq35*m_5*C4*S2*S3*S5 + 2*Y6*Z6*dq14*m_6*C2*S2*S4*S6 - 2*Y6*Z6*dq23*m_6*C2*S3*S4*S6 - 2*Y6*Z6*dq23*m_6*C3*S2*S4*S6 + 2*Y6*Z6*dq14*m_6*C3*S3*S4*S6 - 2*Y6*Z6*dq23*m_6*C6*S2*S3*S5 - 2*Y6*Z6*dq26*m_6*C6*S2*S3*S4 - 2*Y6*Z6*dq26*m_6*C2*S3*S5*S6 - 2*Y6*Z6*dq26*m_6*C3*S2*S5*S6 - 2*Y6*Z6*dq36*m_6*C6*S2*S3*S4 - 2*Y6*Z6*dq36*m_6*C2*S3*S5*S6 - 2*Y6*Z6*dq36*m_6*C3*S2*S5*S6 - 8*a3*d4*dq12*m_4*C2*C3*S2*S3 - 8*a3*d4*dq12*m_5*C2*C3*S2*S3 - 8*a3*d4*dq13*m_4*C2*C3*S2*S3 - 8*a3*d4*dq12*m_6*C2*C3*S2*S3 - 8*a3*d4*dq13*m_5*C2*C3*S2*S3 - 8*a3*d4*dq13*m_6*C2*C3*S2*S3 - 4*a2*d6*dq12*m_6*C2*C5*S2*S3 - 2*a1*d6*dq12*m_6*C2*C4*S3*S5 - 2*a1*d6*dq12*m_6*C3*C4*S2*S5 - 2*a2*d6*dq13*m_6*C2*C5*S2*S3 - 2*a1*d6*dq13*m_6*C2*C4*S3*S5 - 2*a1*d6*dq13*m_6*C3*C4*S2*S5 + 4*a3*d6*dq12*m_6*C2*C4*S2*S5 - 2*a1*d6*dq14*m_6*C2*C3*S4*S5 - 2*a2*d6*dq15*m_6*C2*C3*S2*S5 + 4*a3*d6*dq13*m_6*C2*C4*S2*S5 - 2*a1*d6*dq15*m_6*C4*C5*S2*S3 + 4*a3*d6*dq12*m_6*C3*C4*S3*S5 + 4*a3*d6*dq13*m_6*C3*C4*S3*S5 - 2*a3*d6*dq23*m_6*C2*C3*S4*S5 + 2*a3*d6*dq45*m_6*C4*C5*S2*S3 + 2*X4*a2*dq14*m_4*C2*S2*S3*S4 + 4*X5*a2*dq12*m_5*C2*S2*S3*S5 + 2*X5*a2*dq13*m_5*C2*S2*S3*S5 + 2*X5*a1*dq14*m_5*C5*S2*S3*S4 + 2*X5*a1*dq15*m_5*C4*S2*S3*S5 + 2*X6*a1*dq12*m_6*C2*S3*S4*S6 + 2*X6*a1*dq12*m_6*C3*S2*S4*S6 + 2*X5*a3*dq23*m_5*C5*S2*S3*S4 + 2*X6*a1*dq12*m_6*C6*S2*S3*S5 + 2*X6*a1*dq13*m_6*C2*S3*S4*S6 + 2*X6*a1*dq13*m_6*C3*S2*S4*S6 - 4*X6*a3*dq12*m_6*C2*S2*S4*S6 + 2*X6*a1*dq13*m_6*C6*S2*S3*S5 + 2*X6*a1*dq14*m_6*C4*S2*S3*S6 - 4*X6*a3*dq13*m_6*C2*S2*S4*S6 - 4*X6*a3*dq12*m_6*C3*S3*S4*S6 + 2*X6*a1*dq16*m_6*C6*S2*S3*S4 - 4*X6*a3*dq13*m_6*C3*S3*S4*S6 + 2*X6*a3*dq23*m_6*C4*S2*S3*S6 - 2*X5*a3*dq45*m_5*C4*S2*S3*S5 + 2*X6*a1*dq16*m_6*C2*S3*S5*S6 + 2*X6*a1*dq16*m_6*C3*S2*S5*S6 - 2*X6*a3*dq16*m_6*C2*S2*S5*S6 - 2*X6*a3*dq16*m_6*C3*S3*S5*S6 - 2*X6*a3*dq46*m_6*C6*S2*S3*S4 - 2*X6*a2*dq56*m_6*C2*S4*S5*S6 + XX6*dq22*m_6*C2*C5*CC6*S3*S4*S5 + XX6*dq22*m_6*C3*C5*CC6*S2*S4*S5 + 2*XX6*dq22*m_6*CC4*C5*C6*S2*S3*S6 + XX6*dq33*m_6*C2*C5*CC6*S3*S4*S5 + XX6*dq33*m_6*C3*C5*CC6*S2*S4*S5 + 2*XX6*dq33*m_6*CC4*C5*C6*S2*S3*S6 - XX6*dq44*m_6*C2*C5*CC6*S3*S4*S5 - XX6*dq44*m_6*C3*C5*CC6*S2*S4*S5 + 4*Y6*d6*dq15*m_6*CC2*CC3*CC4*S6 - 8*Y6*d6*dq15*m_6*CC2*CC3*CC5*S6
 + 4*Y6*d6*dq15*m_6*CC2*CC4*CC5*S6 + 4*Y6*d6*dq15*m_6*CC3*CC4*CC5*S6 - YY6*dq22*m_6*C2*C5*CC6*S3*S4*S5 - YY6*dq22*m_6*C3*C5*CC6*S2*S4*S5 - 2*YY6*dq22*m_6*CC4*C5*C6*S2*S3*S6 - YY6*dq33*m_6*C2*C5*CC6*S3*S4*S5 - YY6*dq33*m_6*C3*C5*CC6*S2*S4*S5 - 2*YY6*dq33*m_6*CC4*C5*C6*S2*S3*S6 + YY6*dq44*m_6*C2*C5*CC6*S3*S4*S5 + YY6*dq44*m_6*C3*C5*CC6*S2*S4*S5 - 4*Y6*d4*dq12*m_6*C2*S2*S5*S6 - 4*Y6*d4*dq13*m_6*C2*S2*S5*S6 - 4*Y6*d4*dq12*m_6*C3*S3*S5*S6 - 4*Y6*d4*dq13*m_6*C3*S3*S5*S6 - 2*Y6*d4*dq16*m_6*C2*S2*S4*S6 + 2*Y6*d6*dq14*m_6*C2*S2*S4*S6 - 2*Y6*d6*dq23*m_6*C2*S3*S4*S6 - 2*Y6*d6*dq23*m_6*C3*S2*S4*S6 - 2*Y6*d4*dq16*m_6*C3*S3*S4*S6 + 2*Y6*d6*dq14*m_6*C3*S3*S4*S6 - 2*Y6*d6*dq23*m_6*C6*S2*S3*S5 - 2*Y6*d4*dq46*m_6*C2*S3*S4*S6 - 2*Y6*d4*dq46*m_6*C3*S2*S4*S6 - 2*Y6*d6*dq26*m_6*C6*S2*S3*S4 - 2*Y6*d6*dq26*m_6*C2*S3*S5*S6 - 2*Y6*d6*dq26*m_6*C3*S2*S5*S6 - 2*Y6*d6*dq36*m_6*C6*S2*S3*S4 - 2*Y6*d6*dq36*m_6*C2*S3*S5*S6 - 2*Y6*d6*dq36*m_6*C3*S2*S5*S6 + 2*Z5*d4*dq14*m_5*C2*S2*S4*S5 - 2*Z5*d4*dq23*m_5*C2*S3*S4*S5 - 2*Z5*d4*dq23*m_5*C3*S2*S4*S5 + 2*Z5*d4*dq14*m_5*C3*S3*S4*S5 + 2*Z6*d4*dq14*m_6*C2*S2*S4*S5 - 2*Z6*d4*dq23*m_6*C2*S3*S4*S5 - 2*Z6*d4*dq23*m_6*C3*S2*S4*S5 + 2*Z6*d4*dq14*m_6*C3*S3*S4*S5 + 4*Z6*d6*dq23*m_6*C4*S2*S3*S4 + 4*Z6*d6*dq45*m_6*C5*S2*S3*S5 - 2*Y6*Z6*dq22*m_6*C2*C3*CC4*C6*S5 - 2*Y6*Z6*dq33*m_6*C2*C3*CC4*C6*S5 - 2*X6*Z6*dq23*m_6*S2*S3*S5*S6 - 2*X6*Z6*dq26*m_6*S2*S3*S4*S6 - 2*X6*Z6*dq36*m_6*S2*S3*S4*S6 + 2*Ixy6*dq22*C4*CC5*C6*S2*S3*S4*S6 + 2*Ixy6*dq33*C4*CC5*C6*S2*S3*S4*S6 + 4*Ixx6*dq23*C2*C3*CC4*C5*C6*S6 - 4*Iyy6*dq23*C2*C3*CC4*C5*C6*S6 + 4*Iyz6*dq14*C2*CC3*C4*C5*C6*S2 + 4*Iyz6*dq14*CC2*C3*C4*C5*C6*S3 + 2*d4*d6*dq14*m_6*C2*S2*S4*S5 - 2*d4*d6*dq23*m_6*C2*S3*S4*S5 - 2*d4*d6*dq23*m_6*C3*S2*S4*S5 + 2*d4*d6*dq14*m_6*C3*S3*S4*S5 - 2*Y6*a1*dq12*m_6*S2*S3*S5*S6 - 2*Y6*a1*dq13*m_6*S2*S3*S5*S6 - 2*Y6*a1*dq16*m_6*S2*S3*S4*S6 + 2*Y6*a3*dq46*m_6*S2*S3*S4*S6 + 2*Z5*a1*dq14*m_5*S2*S3*S4*S5 + 2*Z5*a3*dq23*m_5*S2*S3*S4*S5 + 2*Z6*a1*dq14*m_6*S2*S3*S4*S5 + 2*Z6*a3*dq23*m_6*S2*S3*S4*S5 - 2*XX5*dq23*m_5*C2*C3*C4*CC5*S4 - 2*XX6*dq23*m_6*C2*C3*C4*CC6*S4 - 2*XX6*dq26*m_6*C2*C3*C4*CC6*S5 - 2*XX6*dq36*m_6*C2*C3*C4*CC6*S5 + 2*XX6*dq45*m_6*C2*C3*C5*CC6*S5 - 2*XX6*dq56*m_6*C2*C4*C5*CC6*S3 - 2*XX6*dq56*m_6*C3*C4*C5*CC6*S2 + 2*XX6*dq46*m_6*C2*C3*CC5*C6*S6 - 2*Y6*d6*dq22*m_6*C2*C3*CC4*C6*S5 - 2*Y6*d6*dq33*m_6*C2*C3*CC4*C6*S5 - 2*X6*d6*dq23*m_6*S2*S3*S5*S6 - 2*X6*d6*dq26*m_6*S2*S3*S4*S6 - 2*X6*d6*dq36*m_6*S2*S3*S4*S6 - 2*YY6*dq23*m_6*C2*C3*C4*CC5*S4 + 2*YY6*dq23*m_6*C2*C3*C4*CC6*S4 + 2*YY6*dq26*m_6*C2*C3*C4*CC6*S5 + 2*YY6*dq36*m_6*C2*C3*C4*CC6*S5 - 2*YY6*dq45*m_6*C2*C3*C5*CC6*S5 + 2*YY6*dq56*m_6*C2*C4*C5*CC6*S3 + 2*YY6*dq56*m_6*C3*C4*C5*CC6*S2 - 2*YY6*dq46*m_6*C2*C3*CC5*C6*S6 + 2*Z6*d6*dq22*m_6*C2*C3*C4*CC5*S4 + 2*Z6*d6*dq33*m_6*C2*C3*C4*CC5*S4 + 2*ZZ5*dq23*m_5*C2*C3*C4*CC5*S4 + 2*ZZ6*dq23*m_6*C2*C3*C4*CC5*S4 + 2*X6*Y6*dq22*m_6*C2*C4*CC6*S3*S5 + 2*X6*Y6*dq22*m_6*C3*C4*CC6*S2*S5 + 2*X6*Y6*dq33*m_6*C2*C4*CC6*S3*S5 + 2*X6*Y6*dq33*m_6*C3*C4*CC6*S2*S5 - 2*X6*Y6*dq44*m_6*C2*C4*CC6*S3*S5 - 2*X6*Y6*dq44*m_6*C3*C4*CC6*S2*S5 + 2*X6*Y6*dq55*m_6*C2*C4*CC6*S3*S5 + 2*X6*Y6*dq55*m_6*C3*C4*CC6*S2*S5 - 2*X6*Z6*dq22*m_6*C2*C3*CC4*S5*S6 - 2*X6*Z6*dq22*m_6*C2*CC5*C6*S3*S4 - 2*X6*Z6*dq22*m_6*C3*CC5*C6*S2*S4 - 2*X6*Z6*dq33*m_6*C2*C3*CC4*S5*S6 - 2*X6*Z6*dq33*m_6*C2*CC5*C6*S3*S4 - 2*X6*Z6*dq33*m_6*C3*CC5*C6*S2*S4 + 2*X6*Z6*dq44*m_6*C2*CC5*C6*S3*S4 + 2*X6*Z6*dq44*m_6*C3*CC5*C6*S2*S4 - 8*Ixy5*dq12*C2*CC3*C4*C5*S2*S4 - 8*Ixy5*dq12*CC2*C3*C4*C5*S3*S4 - 8*Ixy5*dq13*C2*CC3*C4*C5*S2*S4 - 8*Ixy5*dq14*C2*C3*CC4*C5*S2*S3 + 8*Ixy6*dq12*C2*CC3*C4*C5*S2*S4 - 8*Ixy5*dq13*CC2*C3*C4*C5*S3*S4 + 8*Ixy6*dq12*CC2*C3*C4*C5*S3*S4 + 8*Ixy6*dq13*C2*CC3*C4*C5*S2*S4 + 8*Ixy6*dq14*C2*C3*CC4*C5*S2*S3 + 8*Ixy6*dq13*CC2*C3*C4*C5*S3*S4 + 8*Ixy6*dq12*C2*C4*C5*CC6*S2*S4 + 8*Ixy6*dq14*C2*C3*C5*CC6*S2*S3 + 8*Ixy6*dq13*C2*C4*C5*CC6*S2*S4 + 8*Ixy6*dq12*C3*C4*C5*CC6*S3*S4 + 8*Ixy6*dq16*C2*CC3*C4*C5*S2*S5 + 8*Ixy6*dq13*C3*C4*C5*CC6*S3*S4 + 8*Ixy6*dq15*C2*CC3*C4*C6*S2*S6 + 8*Ixy6*dq16*CC2*C3*C4*C5*S3*S5 + 8*Ixy6*dq15*CC2*C3*C4*C6*S3*S6 - 8*Ixy6*dq24*C2*C4*C5*CC6*S3*S4 - 8*Ixy6*dq24*C3*C4*C5*CC6*S2*S4 + 8*Ixy6*dq12*CC2*C4*C5*C6*S5*S6 + 8*Ixy6*dq15*C2*C4*CC5*C6*S2*S6 + 8*Ixy6*dq16*C2*C4*C5*CC6*S2*S5 - 8*Ixy6*dq34*C2*C4*C5*CC6*S3*S4 - 8*Ixy6*dq34*C3*C4*C5*CC6*S2*S4 + 8*Ixy6*dq12*CC3*C4*C5*C6*S5*S6 + 8*Ixy6*dq13*CC2*C4*C5*C6*S5*S6 + 8*Ixy6*dq13*CC3*C4*C5*C6*S5*S6 + 8*Ixy6*dq15*C3*C4*CC5*C6*S3*S6 + 8*Ixy6*dq16*C3*C4*C5*CC6*S3*S5 - 4*Ixy6*dq25*C2*C3*CC5*C6*S4*S6 - 4*Ixy6*dq26*C2*C3*C5*CC6*S4*S5 + 8*Ixy6*dq16*CC2*C4*C5*C6*S4*S6 - 8*Ixy6*dq26*C2*CC4*C5*C6*S3*S6 - 8*Ixy6*dq26*C3*CC4*C5*C6*S2*S6 - 4*Ixy6*dq35*C2*C3*CC5*C6*S4*S6 - 4*Ixy6*dq36*C2*C3*C5*CC6*S4*S5 + 8*Ixy6*dq16*CC3*C4*C5*C6*S4*S6 - 8*Ixy6*dq36*C2*CC4*C5*C6*S3*S6 - 8*Ixy6*dq36*C3*CC4*C5*C6*S2*S6 + 4*Ixy6*dq45*C2*C4*CC5*C6*S3*S6 + 4*Ixy6*dq45*C3*C4*CC5*C6*S2*S6 + 4*Ixy6*dq46*C2*C4*C5*CC6*S3*S5 + 4*Ixy6*dq46*C3*C4*C5*CC6*S2*S5 + 16*Ixz5*dq12*C2*C3*C4*CC5*S2*S3 + 16*Ixz5*dq13*C2*C3*C4*CC5*S2*S3 + 16*Ixz5*dq15*C2*CC3*C4*C5*S2*S5 + 8*Ixz6*dq12*C2*CC3*C5*C6*S2*S5 - 4*Ixz6*dq15*C2*C3*CC4*C6*S2*S3 + 16*Ixz5*dq15*CC2*C3*C4*C5*S3*S5 - 4*Ixz6*dq12*C2*CC4*C5*C6*S2*S5 + 8*Ixz6*dq12*CC2*C3*C5*C6*S3*S5 + 8*Ixz6*dq13*C2*CC3*C5*C6*S2*S5 + 4*Ixz6*dq14*C2*CC3*C4*C5*S2*S6 + 8*Ixz6*dq15*C2*C3*CC5*C6*S2*S3 - 4*Ixz6*dq13*C2*CC4*C5*C6*S2*S5 + 8*Ixz6*dq13*CC2*C3*C5*C6*S3*S5 + 4*Ixz6*dq14*CC2*C3*C4*C5*S3*S6 - 4*Ixz6*dq12*C3*CC4*C5*C6*S3*S5 + 4*Ixz6*dq16*C2*CC3*C5*C6*S2*S4 - 4*Ixz6*dq13*C3*CC4*C5*C6*S3*S5 + 4*Ixz6*dq16*CC2*C3*C5*C6*S3*S4 - 4*Ixz6*dq14*CC2*C4*C5*C6*S4*S5 + 4*Ixz6*dq24*C2*CC4*C5*C6*S3*S5 + 4*Ixz6*dq24*C3*CC4*C5*C6*S2*S5 + 4*Ixz6*dq25*C2*C4*CC5*C6*S3*S4 + 4*Ixz6*dq25*C3*C4*CC5*C6*S2*S4 - 4*Ixz6*dq14*CC3*C4*C5*C6*S4*S5 + 4*Ixz6*dq34*C2*CC4*C5*C6*S3*S5 + 4*Ixz6*dq34*C3*CC4*C5*C6*S2*S5 + 4*Ixz6*dq35*C2*C4*CC5*C6*S3*S4 + 4*Ixz6*dq35*C3*C4*CC5*C6*S2*S4 + 2*a1*d6*dq14*m_6*S2*S3*S4*S5 + 2*a3*d6*dq23*m_6*S2*S3*S4*S5 + 2*dd6*dq23*m_6*C2*C3*C4*CC5*S4 - 2*X6*d6*dq22*m_6*C2*C3*CC4*S5*S6 - 2*X6*d6*dq22*m_6*C2*CC5*C6*S3*S4 - 2*X6*d6*dq22*m_6*C3*CC5*C6*S2*S4 - 2*X6*d6*dq33*m_6*C2*C3*CC4*S5*S6 - 2*X6*d6*dq33*m_6*C2*CC5*C6*S3*S4 - 2*X6*d6*dq33*m_6*C3*CC5*C6*S2*S4 + 2*X6*d6*dq44*m_6*C2*CC5*C6*S3*S4 + 2*X6*d6*dq44*m_6*C3*CC5*C6*S2*S4 - 4*X5*Y5*dq23*m_5*C2*C3*CC4*C5 + 4*X6*Y6*dq23*m_6*C2*C3*CC4*C5 + 4*X6*Y6*dq23*m_6*C2*C3*C5*CC6 - 4*X6*Z6*dq45*m_6*C2*C3*CC5*C6 + 2*Y6*Z6*dq22*m_6*C2*CC5*S3*S4*S6 + 2*Y6*Z6*dq22*m_6*C3*CC5*S2*S4*S6 + 2*Y6*Z6*dq22*m_6*CC4*C6*S2*S3*S5 + 2*Y6*Z6*dq33*m_6*C2*CC5*S3*S4*S6 + 2*Y6*Z6*dq33*m_6*C3*CC5*S2*S4*S6 + 2*Y6*Z6*dq33*m_6*CC4*C6*S2*S3*S5 - 2*Y6*Z6*dq44*m_6*C2*CC5*S3*S4*S6 - 2*Y6*Z6*dq44*m_6*C3*CC5*S2*S4*S6 + 4*Ixx6*dq12*C2*CC3*CC4*CC5*CC6*S2 + 4*Ixx6*dq12*CC2*C3*CC4*CC5*CC6*S3 + 4*Ixx6*dq13*C2*CC3*CC4*CC5*CC6*S2 + 4*Ixx6*dq13*CC2*C3*CC4*CC5*CC6*S3 + 4*Ixx6*dq14*CC2*CC3*C4*CC5*CC6*S4 + 4*Ixx6*dq15*CC2*CC3*CC4*C5*CC6*S5 + 4*Ixx6*dq16*CC2*CC3*CC4*CC5*C6*S6 - 4*Iyy6*dq12*C2*CC3*CC4*CC5*CC6*S2 - 4*Iyy6*dq12*CC2*C3*CC4*CC5*CC6*S3 - 4*Iyy6*dq13*C2*CC3*CC4*CC5*CC6*S2 - 4*Iyy6*dq13*CC2*C3*CC4*CC5*CC6*S3 - 4*Iyy6*dq14*CC2*CC3*C4*CC5*CC6*S4 - 4*Iyy6*dq15*CC2*CC3*CC4*C5*CC6*S5 - 4*Iyy6*dq16*CC2*CC3*CC4*CC5*C6*S6 - 4*Ixx5*dq14*C2*CC3*C5*S2*S4*S5 - 4*Ixx5*dq14*CC2*C3*C5*S3*S4*S5 + 2*Ixx6*dq14*C2*C5*CC6*S2*S4*S5 - 2*Ixx6*dq23*C2*C5*CC6*S3*S4*S5 - 2*Ixx6*dq23*C3*C5*CC6*S2*S4*S5 + 2*Ixx6*dq14*C3*C5*CC6*S3*S4*S5 - 4*Ixx6*dq23*CC4*C5*C6*S2*S3*S6 + 2*Ixx6*dq15*CC2*C4*C6*S4*S5*S6 - 2*Ixx6*dq25*C2*CC4*C6*S3*S5*S6 - 2*Ixx6*dq25*C3*CC4*C6*S2*S5*S6 + 2*Ixx6*dq15*CC3*C4*C6*S4*S5*S6 - 2*Ixx6*dq35*C2*CC4*C6*S3*S5*S6 - 2*Ixx6*dq35*C3*CC4*C6*S2*S5*S6 - 4*Iyy6*dq14*C2*CC3*C5*S2*S4*S5 - 4*Iyy6*dq14*CC2*C3*C5*S3*S4*S5 - 2*Iyy6*dq14*C2*C5*CC6*S2*S4*S5 + 2*Iyy6*dq23*C2*C5*CC6*S3*S4*S5 + 2*Iyy6*dq23*C3*C5*CC6*S2*S4*S5 - 2*Iyy6*dq14*C3*C5*CC6*S3*S4*S5 + 4*Iyy6*dq23*CC4*C5*C6*S2*S3*S6 - 2*Iyy6*dq15*CC2*C4*C6*S4*S5*S6 + 2*Iyy6*dq25*C2*CC4*C6*S3*S5*S6 + 2*Iyy6*dq25*C3*CC4*C6*S2*S5*S6 - 2*Iyy6*dq15*CC3*C4*C6*S4*S5*S6 + 2*Iyy6*dq35*C2*CC4*C6*S3*S5*S6 + 2*Iyy6*dq35*C3*CC4*C6*S2*S5*S6 - 8*Iyz5*dq12*C2*CC3*C4*S2*S4*S5 - 8*Iyz5*dq12*CC2*C3*C4*S3*S4*S5 - 8*Iyz5*dq13*C2*CC3*C4*S2*S4*S5 - 8*Iyz5*dq14*C2*C3*CC4*S2*S3*S5 - 8*Iyz5*dq13*CC2*C3*C4*S3*S4*S5 - 8*Iyz6*dq12*C2*CC3*C5*S2*S5*S6 + 4*Iyz6*dq15*C2*C3*CC4*S2*S3*S6 + 4*Iyz6*dq12*C2*CC4*C5*S2*S5*S6 - 8*Iyz6*dq12*CC2*C3*C5*S3*S5*S6 - 8*Iyz6*dq13*C2*CC3*C5*S2*S5*S6 - 8*Iyz6*dq15*C2*C3*CC5*S2*S3*S6 + 4*Iyz6*dq13*C2*CC4*C5*S2*S5*S6 - 8*Iyz6*dq13*CC2*C3*C5*S3*S5*S6 - 4*Iyz6*dq15*C2*CC3*C6*S2*S4*S5 + 4*Iyz6*dq12*C3*CC4*C5*S3*S5*S6 - 4*Iyz6*dq15*CC2*C3*C6*S3*S4*S5 - 4*Iyz6*dq16*C2*CC3*C5*S2*S4*S6 + 4*Iyz6*dq13*C3*CC4*C5*S3*S5*S6 - 4*Iyz6*dq16*CC2*C3*C5*S3*S4*S6 + 4*Iyz6*dq14*CC2*C4*C5*S4*S5*S6 - 4*Iyz6*dq24*C2*CC4*C5*S3*S5*S6 - 4*Iyz6*dq24*C3*CC4*C5*S2*S5*S6 - 4*Iyz6*dq25*C2*C4*CC5*S3*S4*S6 - 4*Iyz6*dq25*C3*C4*CC5*S2*S4*S6 + 4*Iyz6*dq14*CC3*C4*C5*S4*S5*S6 - 4*Iyz6*dq34*C2*CC4*C5*S3*S5*S6 - 4*Iyz6*dq34*C3*CC4*C5*S2*S5*S6 - 4*Iyz6*dq35*C2*C4*CC5*S3*S4*S6 - 4*Iyz6*dq35*C3*C4*CC5*S2*S4*S6 + 4*Izz5*dq14*C2*CC3*C5*S2*S4*S5 + 4*Izz5*dq14*CC2*C3*C5*S3*S4*S5 + 4*Izz6*dq14*C2*CC3*C5*S2*S4*S5 + 4*Izz6*dq14*CC2*C3*C5*S3*S4*S5 - 8*a3*d6*dq12*m_6*C2*CC3*C4*S2*S5 - 8*a3*d6*dq12*m_6*CC2*C3*C4*S3*S5 - 8*a3*d6*dq13*m_6*C2*CC3*C4*S2*S5 - 8*a3*d6*dq13*m_6*CC2*C3*C4*S3*S5 + 8*X6*a3*dq12*m_6*C2*CC3*S2*S4*S6 + 8*X6*a3*dq12*m_6*CC2*C3*S3*S4*S6 + 8*X6*a3*dq13*m_6*C2*CC3*S2*S4*S6 + 8*X6*a3*dq13*m_6*CC2*C3*S3*S4*S6 + 4*X6*a3*dq16*m_6*C2*CC3*S2*S5*S6 + 4*X6*a3*dq16*m_6*CC2*C3*S3*S5*S6 - 8*Y6*d6*dq15*m_6*CC2*CC3*CC4*CC5*S6 + 8*Y6*d4*dq12*m_6*C2*CC3*S2*S5*S6 + 8*Y6*d4*dq12*m_6*CC2*C3*S3*S5*S6 + 8*Y6*d4*dq13*m_6*C2*CC3*S2*S5*S6 + 8*Y6*d4*dq13*m_6*CC2*C3*S3*S5*S6 + 4*Y6*d4*dq16*m_6*C2*CC3*S2*S4*S6 - 4*Y6*d6*dq14*m_6*C2*CC3*S2*S4*S6 + 4*Y6*d4*dq16*m_6*CC2*C3*S3*S4*S6 - 4*Y6*d6*dq14*m_6*CC2*C3*S3*S4*S6 - 4*Y6*d6*dq14*m_6*C2*CC5*S2*S4*S6 + 4*Y6*d6*dq23*m_6*C2*CC5*S3*S4*S6 + 4*Y6*d6*dq23*m_6*C3*CC5*S2*S4*S6 + 4*Y6*d6*dq23*m_6*CC4*C6*S2*S3*S5 - 4*Y6*d6*dq14*m_6*C3*CC5*S3*S4*S6 - 2*Y6*d6*dq16*m_6*CC2*C4*S4*S5*S6 + 2*Y6*d6*dq26*m_6*C2*CC4*S3*S5*S6
 + 2*Y6*d6*dq26*m_6*C3*CC4*S2*S5*S6 + 2*Y6*d6*dq26*m_6*CC5*C6*S2*S3*S4 - 2*Y6*d6*dq16*m_6*CC3*C4*S4*S5*S6 + 2*Y6*d6*dq36*m_6*C2*CC4*S3*S5*S6 + 2*Y6*d6*dq36*m_6*C3*CC4*S2*S5*S6 + 2*Y6*d6*dq36*m_6*CC5*C6*S2*S3*S4 - 4*Z5*d4*dq14*m_5*C2*CC3*S2*S4*S5 - 4*Z5*d4*dq14*m_5*CC2*C3*S3*S4*S5 - 4*Z6*d4*dq14*m_6*C2*CC3*S2*S4*S5 - 4*Z6*d4*dq14*m_6*CC2*C3*S3*S4*S5 - 4*Z6*d6*dq23*m_6*C4*CC5*S2*S3*S4 + 4*X6*Z6*dq23*m_6*CC4*S2*S3*S5*S6 + 2*X6*Z6*dq26*m_6*CC5*S2*S3*S4*S6 + 2*X6*Z6*dq36*m_6*CC5*S2*S3*S4*S6 - 4*d4*d6*dq14*m_6*C2*CC3*S2*S4*S5 - 4*d4*d6*dq14*m_6*CC2*C3*S3*S4*S5 - 2*XX6*dq23*m_6*C2*C3*C4*CC5*CC6*S4 + 4*X6*d6*dq23*m_6*CC4*S2*S3*S5*S6 + 2*X6*d6*dq26*m_6*CC5*S2*S3*S4*S6 + 2*X6*d6*dq36*m_6*CC5*S2*S3*S4*S6 + 2*YY6*dq23*m_6*C2*C3*C4*CC5*CC6*S4 - 16*Ixy6*dq12*C2*CC3*C4*C5*CC6*S2*S4 - 16*Ixy6*dq12*CC2*C3*C4*C5*CC6*S3*S4 - 16*Ixy6*dq13*C2*CC3*C4*C5*CC6*S2*S4 - 16*Ixy6*dq14*C2*C3*CC4*C5*CC6*S2*S3 - 16*Ixy6*dq13*CC2*C3*C4*C5*CC6*S3*S4 - 16*Ixy6*dq12*CC2*CC3*C4*C5*C6*S5*S6 - 16*Ixy6*dq15*C2*CC3*C4*CC5*C6*S2*S6 - 16*Ixy6*dq16*C2*CC3*C4*C5*CC6*S2*S5 - 16*Ixy6*dq13*CC2*CC3*C4*C5*C6*S5*S6 - 16*Ixy6*dq15*CC2*C3*C4*CC5*C6*S3*S6 - 16*Ixy6*dq16*CC2*C3*C4*C5*CC6*S3*S5 - 16*Ixy6*dq16*CC2*CC3*C4*C5*C6*S4*S6 + 8*Ixz6*dq12*C2*CC3*CC4*C5*C6*S2*S5 + 8*Ixz6*dq12*CC2*C3*CC4*C5*C6*S3*S5 + 8*Ixz6*dq13*C2*CC3*CC4*C5*C6*S2*S5 + 8*Ixz6*dq15*C2*C3*CC4*CC5*C6*S2*S3 + 8*Ixz6*dq13*CC2*C3*CC4*C5*C6*S3*S5 + 8*Ixz6*dq14*CC2*CC3*C4*C5*C6*S4*S5 - 8*X6*Y6*dq23*m_6*C2*C3*CC4*C5*CC6 - 4*Ixx6*dq14*C2*CC3*C5*CC6*S2*S4*S5 - 4*Ixx6*dq14*CC2*C3*C5*CC6*S3*S4*S5 - 4*Ixx6*dq15*CC2*CC3*C4*C6*S4*S5*S6 + 4*Iyy6*dq14*C2*CC3*C5*CC6*S2*S4*S5 + 4*Iyy6*dq14*CC2*C3*C5*CC6*S3*S4*S5 + 4*Iyy6*dq15*CC2*CC3*C4*C6*S4*S5*S6 - 8*Iyz6*dq12*C2*CC3*CC4*C5*S2*S5*S6 - 8*Iyz6*dq12*CC2*C3*CC4*C5*S3*S5*S6 - 8*Iyz6*dq13*C2*CC3*CC4*C5*S2*S5*S6 - 8*Iyz6*dq15*C2*C3*CC4*CC5*S2*S3*S6 - 8*Iyz6*dq13*CC2*C3*CC4*C5*S3*S5*S6 - 8*Iyz6*dq14*CC2*CC3*C4*C5*S4*S5*S6 - 4*Y6*a3*dq16*m_6*CC2*CC3*C4*C5*C6 + 8*XX6*dq12*m_6*CC2*CC3*C6*S4*S5*S6 + 8*XX6*dq16*m_6*C2*CC3*CC6*S2*S4*S5 + 2*XX6*dq23*m_6*C4*CC5*CC6*S2*S3*S4 + 8*XX6*dq13*m_6*CC2*CC3*C6*S4*S5*S6 + 8*XX6*dq16*m_6*CC2*C3*CC6*S3*S4*S5 + 8*X6*d4*dq12*m_6*CC2*CC3*C4*C5*C6 + 8*X6*d4*dq13*m_6*CC2*CC3*C4*C5*C6 - 8*YY6*dq12*m_6*CC2*CC3*C6*S4*S5*S6 - 8*YY6*dq16*m_6*C2*CC3*CC6*S2*S4*S5 - 2*YY6*dq23*m_6*C4*CC5*CC6*S2*S3*S4 - 8*YY6*dq13*m_6*CC2*CC3*C6*S4*S5*S6 - 8*YY6*dq16*m_6*CC2*C3*CC6*S3*S4*S5 - 4*Y5*Z5*dq15*m_5*CC2*CC3*C4*C5*S4 - 8*Y6*Z6*dq12*m_6*CC2*CC3*C5*C6*S4 - 8*Y6*Z6*dq13*m_6*CC2*CC3*C5*C6*S4 - 4*Y6*Z6*dq16*m_6*CC2*CC3*C5*C6*S5 + 2*Y6*Z6*dq16*m_6*CC2*CC4*C5*C6*S5 + 2*Y6*Z6*dq16*m_6*CC3*CC4*C5*C6*S5 - 4*X6*a3*dq14*m_6*CC2*CC3*C5*C6*S4 - 4*X6*a3*dq15*m_6*CC2*CC3*C4*C6*S5 - 4*X6*a3*dq16*m_6*CC2*CC3*C4*C5*S6 - 8*Y6*d4*dq12*m_6*CC2*CC3*C4*C5*S6 - 8*Y6*d4*dq13*m_6*CC2*CC3*C4*C5*S6 - 8*Y6*d6*dq12*m_6*CC2*CC3*C5*C6*S4 - 8*Y6*d6*dq13*m_6*CC2*CC3*C5*C6*S4 - 4*Y6*d6*dq16*m_6*CC2*CC3*C5*C6*S5 + 2*Y6*d6*dq16*m_6*CC2*CC4*C5*C6*S5 + 2*Y6*d6*dq16*m_6*CC3*CC4*C5*C6*S5 + 16*Z6*d6*dq12*m_6*CC2*CC3*C4*C5*S5 + 16*Z6*d6*dq15*m_6*C2*CC3*C4*CC5*S2 + 16*Z6*d6*dq13*m_6*CC2*CC3*C4*C5*S5 + 16*Z6*d6*dq15*m_6*CC2*C3*C4*CC5*S3 - 8*X6*Y6*dq16*m_6*CC2*CC3*CC4*CC5*CC6 + 4*X5*Y5*dq15*m_5*CC2*CC3*C4*S4*S5 - 4*X6*Y6*dq15*m_6*CC2*CC3*C4*S4*S5 + 8*X6*Y6*dq23*m_6*CC4*C5*CC6*S2*S3 - 4*X6*Y6*dq15*m_6*CC2*C4*CC6*S4*S5 + 4*X6*Y6*dq25*m_6*C2*CC4*CC6*S3*S5 + 4*X6*Y6*dq25*m_6*C3*CC4*CC6*S2*S5 - 4*X6*Y6*dq15*m_6*CC3*C4*CC6*S4*S5 + 4*X6*Y6*dq35*m_6*C2*CC4*CC6*S3*S5 + 4*X6*Y6*dq35*m_6*C3*CC4*CC6*S2*S5 - 8*X5*Z5*dq14*m_5*C2*CC3*CC5*S2*S4 - 8*X5*Z5*dq14*m_5*CC2*C3*CC5*S3*S4 - 8*X6*Z6*dq12*m_6*CC2*CC3*C5*S4*S6 - 8*X6*Z6*dq13*m_6*CC2*CC3*C5*S4*S6 - 4*X6*Z6*dq16*m_6*CC2*CC3*C5*S5*S6 + 2*X6*Z6*dq16*m_6*CC2*CC4*C5*S5*S6 + 2*X6*Z6*dq16*m_6*CC3*CC4*C5*S5*S6 + 4*Y6*a3*dq14*m_6*CC2*CC3*C5*S4*S6 + 4*Y6*a3*dq15*m_6*CC2*CC3*C4*S5*S6 - 8*X6*d6*dq12*m_6*CC2*CC3*C5*S4*S6 - 8*X6*d6*dq13*m_6*CC2*CC3*C5*S4*S6 - 4*X6*d6*dq16*m_6*CC2*CC3*C5*S5*S6 + 2*X6*d6*dq16*m_6*CC2*CC4*C5*S5*S6 + 2*X6*d6*dq16*m_6*CC3*CC4*C5*S5*S6 - 2*XX6*dq25*m_6*C2*C3*C4*C5*C6*S6 - 2*XX6*dq35*m_6*C2*C3*C4*C5*C6*S6 + 2*YY6*dq25*m_6*C2*C3*C4*C5*C6*S6 + 2*YY6*dq35*m_6*C2*C3*C4*C5*C6*S6 + 2*X6*Y6*dq22*m_6*C2*C3*C4*C6*S4*S6 + 2*X6*Y6*dq33*m_6*C2*C3*C4*C6*S4*S6 - 2*X5*Z5*dq22*m_5*C2*C3*C4*C5*S4*S5 - 2*X5*Z5*dq33*m_5*C2*C3*C4*C5*S4*S5 + 4*Ixz6*dq23*C2*C3*C4*C5*C6*S4*S5 - 8*Ixx5*dq12*C2*C3*C4*C5*S2*S3*S5 - 8*Ixx5*dq13*C2*C3*C4*C5*S2*S3*S5 + 4*Ixx6*dq16*C2*C3*C4*C5*S2*S3*S4 + 4*Ixx6*dq12*C2*C4*C5*C6*S2*S4*S6 + 4*Ixx6*dq14*C2*C3*C5*C6*S2*S3*S6 + 4*Ixx6*dq13*C2*C4*C5*C6*S2*S4*S6 + 4*Ixx6*dq12*C3*C4*C5*C6*S3*S4*S6 + 4*Ixx6*dq13*C3*C4*C5*C6*S3*S4*S6 - 4*Ixx6*dq24*C2*C4*C5*C6*S3*S4*S6 - 4*Ixx6*dq24*C3*C4*C5*C6*S2*S4*S6 + 4*Ixx6*dq16*C2*C4*C5*C6*S2*S5*S6 - 4*Ixx6*dq34*C2*C4*C5*C6*S3*S4*S6 - 4*Ixx6*dq34*C3*C4*C5*C6*S2*S4*S6 + 4*Ixx6*dq16*C3*C4*C5*C6*S3*S5*S6 - 2*Ixx6*dq26*C2*C3*C5*C6*S4*S5*S6 - 2*Ixx6*dq36*C2*C3*C5*C6*S4*S5*S6 + 2*Ixx6*dq46*C2*C4*C5*C6*S3*S5*S6 + 2*Ixx6*dq46*C3*C4*C5*C6*S2*S5*S6 - 8*Iyy6*dq12*C2*C3*C4*C5*S2*S3*S5 - 8*Iyy6*dq13*C2*C3*C4*C5*S2*S3*S5 - 4*Iyy6*dq16*C2*C3*C4*C5*S2*S3*S4 - 4*Iyy6*dq12*C2*C4*C5*C6*S2*S4*S6 - 4*Iyy6*dq14*C2*C3*C5*C6*S2*S3*S6 - 4*Iyy6*dq13*C2*C4*C5*C6*S2*S4*S6 - 4*Iyy6*dq12*C3*C4*C5*C6*S3*S4*S6 - 4*Iyy6*dq13*C3*C4*C5*C6*S3*S4*S6 + 4*Iyy6*dq24*C2*C4*C5*C6*S3*S4*S6 + 4*Iyy6*dq24*C3*C4*C5*C6*S2*S4*S6 - 4*Iyy6*dq16*C2*C4*C5*C6*S2*S5*S6 + 4*Iyy6*dq34*C2*C4*C5*C6*S3*S4*S6 + 4*Iyy6*dq34*C3*C4*C5*C6*S2*S4*S6 - 4*Iyy6*dq16*C3*C4*C5*C6*S3*S5*S6 + 2*Iyy6*dq26*C2*C3*C5*C6*S4*S5*S6 + 2*Iyy6*dq36*C2*C3*C5*C6*S4*S5*S6 - 2*Iyy6*dq46*C2*C4*C5*C6*S3*S5*S6 - 2*Iyy6*dq46*C3*C4*C5*C6*S2*S5*S6 - 4*Iyz5*dq15*C2*C3*C4*C5*S2*S3*S4 - 8*Iyz6*dq12*C2*C3*C5*C6*S2*S3*S4 - 8*Iyz6*dq13*C2*C3*C5*C6*S2*S3*S4 - 4*Iyz6*dq16*C2*C3*C5*C6*S2*S3*S5 - 4*Iyz6*dq23*C2*C3*C4*C5*S4*S5*S6 - 2*Iyz6*dq26*C2*C4*C5*C6*S3*S4*S5 - 2*Iyz6*dq26*C3*C4*C5*C6*S2*S4*S5 - 2*Iyz6*dq36*C2*C4*C5*C6*S3*S4*S5 - 2*Iyz6*dq36*C3*C4*C5*C6*S2*S4*S5 + 8*Izz5*dq12*C2*C3*C4*C5*S2*S3*S5 + 8*Izz5*dq13*C2*C3*C4*C5*S2*S3*S5 + 8*Izz6*dq12*C2*C3*C4*C5*S2*S3*S5 + 8*Izz6*dq13*C2*C3*C4*C5*S2*S3*S5 - 2*Y6*a1*dq16*m_6*C2*C3*C4*C5*C6 + 2*Y6*a3*dq46*m_6*C2*C3*C4*C5*C6 - 8*XX6*dq12*m_6*CC2*CC3*C4*C5*CC6*S5 - 8*XX6*dq15*m_6*C2*CC3*C4*CC5*CC6*S2 - 8*XX6*dq13*m_6*CC2*CC3*C4*C5*CC6*S5 - 8*XX6*dq15*m_6*CC2*C3*C4*CC5*CC6*S3 - 8*XX6*dq14*m_6*CC2*CC3*CC4*C5*C6*S6 - 8*XX6*dq16*m_6*CC2*CC3*C4*C5*CC6*S4 + 8*YY6*dq12*m_6*CC2*CC3*C4*C5*CC6*S5 + 8*YY6*dq15*m_6*C2*CC3*C4*CC5*CC6*S2 + 8*YY6*dq13*m_6*CC2*CC3*C4*C5*CC6*S5 + 8*YY6*dq15*m_6*CC2*C3*C4*CC5*CC6*S3 + 8*YY6*dq14*m_6*CC2*CC3*CC4*C5*C6*S6 + 8*YY6*dq16*m_6*CC2*CC3*C4*C5*CC6*S4 + 4*XX4*dq14*m_4*C2*C3*C4*S2*S3*S4 - 4*XX6*dq14*m_6*C2*C3*C4*S2*S3*S4 + 4*XX5*dq15*m_5*C2*C3*C5*S2*S3*S5 + 2*XX5*dq25*m_5*C2*C4*C5*S3*S4*S5 + 2*XX5*dq25*m_5*C3*C4*C5*S2*S4*S5 + 2*XX5*dq35*m_5*C2*C4*C5*S3*S4*S5 + 2*XX5*dq35*m_5*C3*C4*C5*S2*S4*S5 - 8*XX6*dq16*m_6*C2*C3*C6*S2*S3*S6 - 2*XX6*dq14*m_6*C2*C4*C6*S2*S5*S6 - 2*XX6*dq15*m_6*C2*C5*C6*S2*S4*S6 + 2*XX6*dq23*m_6*C2*C4*C6*S3*S5*S6 + 2*XX6*dq23*m_6*C3*C4*C6*S2*S5*S6 - 2*XX6*dq14*m_6*C3*C4*C6*S3*S5*S6 - 2*XX6*dq15*m_6*C3*C5*C6*S3*S4*S6 + 2*XX6*dq25*m_6*C4*C5*C6*S2*S3*S6 + 2*XX6*dq26*m_6*C2*C4*C6*S3*S4*S6 + 2*XX6*dq26*m_6*C3*C4*C6*S2*S4*S6 + 2*XX6*dq35*m_6*C4*C5*C6*S2*S3*S6 + 2*XX6*dq36*m_6*C2*C4*C6*S3*S4*S6 + 2*XX6*dq36*m_6*C3*C4*C6*S2*S4*S6 - 4*YY5*dq14*m_5*C2*C3*C4*S2*S3*S4 + 4*YY6*dq15*m_6*C2*C3*C5*S2*S3*S5 + 8*YY6*dq16*m_6*C2*C3*C6*S2*S3*S6 + 2*YY6*dq14*m_6*C2*C4*C6*S2*S5*S6 + 2*YY6*dq25*m_6*C2*C4*C5*S3*S4*S5 + 2*YY6*dq25*m_6*C3*C4*C5*S2*S4*S5 + 2*YY6*dq15*m_6*C2*C5*C6*S2*S4*S6 - 2*YY6*dq23*m_6*C2*C4*C6*S3*S5*S6 - 2*YY6*dq23*m_6*C3*C4*C6*S2*S5*S6 + 2*YY6*dq35*m_6*C2*C4*C5*S3*S4*S5 + 2*YY6*dq35*m_6*C3*C4*C5*S2*S4*S5 + 2*YY6*dq14*m_6*C3*C4*C6*S3*S5*S6 + 2*YY6*dq15*m_6*C3*C5*C6*S3*S4*S6 - 2*YY6*dq25*m_6*C4*C5*C6*S2*S3*S6 - 2*YY6*dq26*m_6*C2*C4*C6*S3*S4*S6 - 2*YY6*dq26*m_6*C3*C4*C6*S2*S4*S6 - 2*YY6*dq35*m_6*C4*C5*C6*S2*S3*S6 - 2*YY6*dq36*m_6*C2*C4*C6*S3*S4*S6 - 2*YY6*dq36*m_6*C3*C4*C6*S2*S4*S6 - 4*ZZ4*dq14*m_4*C2*C3*C4*S2*S3*S4 + 4*ZZ5*dq14*m_5*C2*C3*C4*S2*S3*S4 + 4*ZZ6*dq14*m_6*C2*C3*C4*S2*S3*S4 - 4*ZZ5*dq15*m_5*C2*C3*C5*S2*S3*S5 - 4*ZZ6*dq15*m_6*C2*C3*C5*S2*S3*S5 - 2*ZZ5*dq25*m_5*C2*C4*C5*S3*S4*S5 - 2*ZZ5*dq25*m_5*C3*C4*C5*S2*S4*S5 - 2*ZZ5*dq35*m_5*C2*C4*C5*S3*S4*S5 - 2*ZZ5*dq35*m_5*C3*C4*C5*S2*S4*S5 - 2*ZZ6*dq25*m_6*C2*C4*C5*S3*S4*S5 - 2*ZZ6*dq25*m_6*C3*C4*C5*S2*S4*S5 - 2*ZZ6*dq35*m_6*C2*C4*C5*S3*S4*S5 - 2*ZZ6*dq35*m_6*C3*C4*C5*S2*S4*S5 - 2*X6*Y6*dq22*m_6*C4*C6*S2*S3*S4*S6 - 2*X6*Y6*dq33*m_6*C4*C6*S2*S3*S4*S6 + 2*X5*Z5*dq22*m_5*C4*C5*S2*S3*S4*S5 + 2*X5*Z5*dq33*m_5*C4*C5*S2*S3*S4*S5 + 2*Y6*Z6*dq14*m_6*C2*C4*C5*C6*S2 - 2*Y6*Z6*dq23*m_6*C2*C4*C5*C6*S3 - 2*Y6*Z6*dq23*m_6*C3*C4*C5*C6*S2 + 2*Y6*Z6*dq14*m_6*C3*C4*C5*C6*S3 - 2*Y6*Z6*dq25*m_6*C2*C3*C4*C6*S5 - 2*Y6*Z6*dq35*m_6*C2*C3*C4*C6*S5 + 2*Y6*Z6*dq46*m_6*C2*C3*C5*C6*S5 - 8*Ixy6*dq12*C2*CC3*CC4*CC5*C6*S2*S6 - 8*Ixy6*dq12*CC2*C3*CC4*CC5*C6*S3*S6 - 8*Ixy6*dq13*C2*CC3*CC4*CC5*C6*S2*S6 - 8*Ixy6*dq16*C2*C3*CC4*CC5*CC6*S2*S3 - 8*Ixy6*dq13*CC2*C3*CC4*CC5*C6*S3*S6 - 8*Ixy6*dq14*CC2*CC3*C4*CC5*C6*S4*S6 - 8*Ixy6*dq15*CC2*CC3*CC4*C5*C6*S5*S6 + 4*Ixy5*dq15*C2*C3*C4*S2*S3*S4*S5 - 4*Ixy6*dq15*C2*C3*C4*S2*S3*S4*S5 - 4*Ixy6*dq14*C2*C5*C6*S2*S4*S5*S6 + 4*Ixy6*dq23*C2*C5*C6*S3*S4*S5*S6 + 4*Ixy6*dq23*C3*C5*C6*S2*S4*S5*S6 - 4*Ixy6*dq14*C3*C5*C6*S3*S4*S5*S6 - 8*Ixz6*dq12*C2*C3*C5*S2*S3*S4*S6 - 8*Ixz6*dq13*C2*C3*C5*S2*S3*S4*S6 - 4*Ixz6*dq16*C2*C3*C5*S2*S3*S5*S6 - 4*Ixz6*dq23*C4*C5*C6*S2*S3*S4*S5 - 2*Ixz6*dq26*C2*C4*C5*S3*S4*S5*S6 - 2*Ixz6*dq26*C3*C4*C5*S2*S4*S5*S6 - 2*Ixz6*dq36*C2*C4*C5*S3*S4*S5*S6 - 2*Ixz6*dq36*C3*C4*C5*S2*S4*S5*S6 + 4*dd6*dq14*m_6*C2*C3*C4*S2*S3*S4 - 4*dd6*dq15*m_6*C2*C3*C5*S2*S3*S5 - 2*dd6*dq25*m_6*C2*C4*C5*S3*S4*S5 - 2*dd6*dq25*m_6*C3*C4*C5*S2*S4*S5 - 2*dd6*dq35*m_6*C2*C4*C5*S3*S4*S5 - 2*dd6*dq35*m_6*C3*C4*C5*S2*S4*S5 - 4*X5*a2*dq12*m_5*C2*C3*C4*C5*S2 - 2*X5*a2*dq13*m_5*C2*C3*C4*C5*S2 - 2*X6*a1*dq12*m_6*C2*C4*C5*C6*S3 - 2*X6*a1*dq12*m_6*C3*C4*C5*C6*S2 - 2*X6*a1*dq13*m_6*C2*C4*C5*C6*S3 - 2*X6*a1*dq13*m_6*C3*C4*C5*C6*S2
 + 4*X6*a3*dq12*m_6*C2*C4*C5*C6*S2 - 2*X6*a1*dq14*m_6*C2*C3*C5*C6*S4 - 2*X6*a2*dq15*m_6*C2*C3*C5*C6*S2 + 4*X6*a3*dq13*m_6*C2*C4*C5*C6*S2 - 2*X6*a1*dq15*m_6*C2*C3*C4*C6*S5 + 4*X6*a3*dq12*m_6*C3*C4*C5*C6*S3 - 2*X6*a1*dq16*m_6*C2*C3*C4*C5*S6 + 4*X6*a3*dq13*m_6*C3*C4*C5*C6*S3 - 2*X6*a3*dq23*m_6*C2*C3*C5*C6*S4 + 2*X6*a3*dq45*m_6*C2*C3*C4*C6*S5 + 2*X6*a3*dq46*m_6*C2*C3*C4*C5*S6 + 2*Y6*d4*dq16*m_6*C2*C4*C5*C6*S2 + 2*Y6*d6*dq14*m_6*C2*C4*C5*C6*S2 - 2*Y6*d6*dq23*m_6*C2*C4*C5*C6*S3 - 2*Y6*d6*dq23*m_6*C3*C4*C5*C6*S2 + 2*Y6*d4*dq16*m_6*C3*C4*C5*C6*S3 + 2*Y6*d6*dq14*m_6*C3*C4*C5*C6*S3 - 2*Y6*d6*dq25*m_6*C2*C3*C4*C6*S5 + 2*Y6*d4*dq46*m_6*C2*C4*C5*C6*S3 + 2*Y6*d4*dq46*m_6*C3*C4*C5*C6*S2 - 2*Y6*d6*dq35*m_6*C2*C3*C4*C6*S5 + 2*Y6*d6*dq46*m_6*C2*C3*C5*C6*S5 + 16*X6*Z6*dq12*m_6*CC2*CC3*C4*CC5*C6 + 16*X6*Z6*dq13*m_6*CC2*CC3*C4*CC5*C6 + 8*X4*Y4*dq12*m_4*C2*C3*C4*S2*S3 + 8*X4*Y4*dq13*m_4*C2*C3*C4*S2*S3 - 4*X5*Y5*dq12*m_5*C2*C4*C5*S2*S4 - 4*X5*Y5*dq14*m_5*C2*C3*C5*S2*S3 - 4*X5*Y5*dq13*m_5*C2*C4*C5*S2*S4 - 4*X5*Y5*dq12*m_5*C3*C4*C5*S3*S4 - 4*X5*Y5*dq13*m_5*C3*C4*C5*S3*S4 + 4*X6*Y6*dq12*m_6*C2*C4*C5*S2*S4 + 4*X6*Y6*dq14*m_6*C2*C3*C5*S2*S3 + 4*X5*Y5*dq24*m_5*C2*C4*C5*S3*S4 + 4*X5*Y5*dq24*m_5*C3*C4*C5*S2*S4 + 4*X6*Y6*dq13*m_6*C2*C4*C5*S2*S4 + 4*X5*Y5*dq34*m_5*C2*C4*C5*S3*S4 + 4*X5*Y5*dq34*m_5*C3*C4*C5*S2*S4 + 4*X6*Y6*dq12*m_6*C3*C4*C5*S3*S4 + 4*X6*Y6*dq13*m_6*C3*C4*C5*S3*S4 - 4*X6*Y6*dq24*m_6*C2*C4*C5*S3*S4 - 4*X6*Y6*dq24*m_6*C3*C4*C5*S2*S4 + 4*X6*Y6*dq16*m_6*C2*C4*C5*S2*S5 - 4*X6*Y6*dq34*m_6*C2*C4*C5*S3*S4 - 4*X6*Y6*dq34*m_6*C3*C4*C5*S2*S4 + 4*X6*Y6*dq15*m_6*C2*C4*C6*S2*S6 + 4*X6*Y6*dq16*m_6*C3*C4*C5*S3*S5 - 2*X6*Y6*dq26*m_6*C2*C3*C5*S4*S5 + 4*X6*Y6*dq15*m_6*C3*C4*C6*S3*S6 - 2*X6*Y6*dq36*m_6*C2*C3*C5*S4*S5 + 4*X6*Y6*dq12*m_6*C4*C5*C6*S5*S6 + 2*X6*Y6*dq46*m_6*C2*C4*C5*S3*S5 + 2*X6*Y6*dq46*m_6*C3*C4*C5*S2*S5 + 4*X6*Y6*dq13*m_6*C4*C5*C6*S5*S6 - 4*X6*Y6*dq26*m_6*C2*C5*C6*S3*S6 - 4*X6*Y6*dq26*m_6*C3*C5*C6*S2*S6 + 4*X6*Y6*dq45*m_6*C2*C4*C6*S3*S6 + 4*X6*Y6*dq45*m_6*C3*C4*C6*S2*S6 - 4*X6*Y6*dq36*m_6*C2*C5*C6*S3*S6 - 4*X6*Y6*dq36*m_6*C3*C5*C6*S2*S6 + 4*X6*Y6*dq56*m_6*C2*C3*C6*S5*S6 + 8*X5*Z5*dq12*m_5*C2*C3*C4*S2*S3 + 8*X5*Z5*dq13*m_5*C2*C3*C4*S2*S3 + 8*X5*Z5*dq15*m_5*C2*C4*C5*S2*S5 + 4*X6*Z6*dq15*m_6*C2*C3*C6*S2*S3 + 8*X5*Z5*dq15*m_5*C3*C4*C5*S3*S5 - 4*X5*Z5*dq25*m_5*C2*C3*C5*S4*S5 + 4*X6*Z6*dq12*m_6*C2*C5*C6*S2*S5 - 4*X5*Z5*dq35*m_5*C2*C3*C5*S4*S5 + 4*X6*Z6*dq13*m_6*C2*C5*C6*S2*S5 + 2*X6*Z6*dq14*m_6*C2*C4*C5*S2*S6 + 4*X5*Z5*dq45*m_5*C2*C4*C5*S3*S5 + 4*X5*Z5*dq45*m_5*C3*C4*C5*S2*S5 + 4*X6*Z6*dq12*m_6*C3*C5*C6*S3*S5 - 2*X6*Z6*dq23*m_6*C2*C4*C5*S3*S6 - 2*X6*Z6*dq23*m_6*C3*C4*C5*S2*S6 + 4*X6*Z6*dq13*m_6*C3*C5*C6*S3*S5 + 2*X6*Z6*dq14*m_6*C3*C4*C5*S3*S6 + 2*X6*Z6*dq16*m_6*C2*C5*C6*S2*S4 + 2*X6*Z6*dq25*m_6*C2*C4*C6*S3*S4 + 2*X6*Z6*dq25*m_6*C3*C4*C6*S2*S4 + 4*X6*Z6*dq24*m_6*C2*C5*C6*S3*S5 + 4*X6*Z6*dq24*m_6*C3*C5*C6*S2*S5 - 2*X6*Z6*dq25*m_6*C2*C3*C4*S5*S6 + 2*X6*Z6*dq35*m_6*C2*C4*C6*S3*S4 + 2*X6*Z6*dq35*m_6*C3*C4*C6*S2*S4 + 2*X6*Z6*dq16*m_6*C3*C5*C6*S3*S4 + 4*X6*Z6*dq34*m_6*C2*C5*C6*S3*S5 + 4*X6*Z6*dq34*m_6*C3*C5*C6*S2*S5 - 2*X6*Z6*dq35*m_6*C2*C3*C4*S5*S6 + 2*X6*Z6*dq46*m_6*C2*C5*C6*S3*S4 + 2*X6*Z6*dq46*m_6*C3*C5*C6*S2*S4 + 2*X6*Z6*dq46*m_6*C2*C3*C5*S5*S6 + 2*Ixx6*dq26*C5*C6*S2*S3*S4*S5*S6 + 2*Ixx6*dq36*C5*C6*S2*S3*S4*S5*S6 - 2*Iyy6*dq26*C5*C6*S2*S3*S4*S5*S6 - 2*Iyy6*dq36*C5*C6*S2*S3*S4*S5*S6 + 4*Iyz6*dq23*C4*C5*S2*S3*S4*S5*S6 + 4*Y5*a3*dq14*m_5*C2*C3*C4*S2*S3 + 4*Y6*a2*dq12*m_6*C2*C3*C6*S2*S4 + 2*Y6*a2*dq13*m_6*C2*C3*C6*S2*S4 + 2*Y6*a1*dq12*m_6*C2*C4*C5*S3*S6 + 2*Y6*a1*dq12*m_6*C3*C4*C5*S2*S6 + 2*Y6*a2*dq14*m_6*C2*C4*C6*S2*S3 + 2*Y6*a1*dq13*m_6*C2*C4*C5*S3*S6 + 2*Y6*a1*dq13*m_6*C3*C4*C5*S2*S6 - 4*Y6*a3*dq12*m_6*C2*C4*C5*S2*S6 + 2*Y6*a1*dq14*m_6*C2*C3*C5*S4*S6 + 2*Y6*a2*dq15*m_6*C2*C3*C5*S2*S6 - 4*Y6*a3*dq13*m_6*C2*C4*C5*S2*S6 + 2*Y6*a1*dq15*m_6*C2*C3*C4*S5*S6 + 2*Y6*a2*dq16*m_6*C2*C3*C6*S2*S5 - 4*Y6*a3*dq12*m_6*C3*C4*C5*S3*S6 + 2*Y6*a1*dq16*m_6*C4*C5*C6*S2*S3 - 4*Y6*a3*dq13*m_6*C3*C4*C5*S3*S6 + 2*Y6*a3*dq23*m_6*C2*C3*C5*S4*S6 - 2*Y6*a3*dq45*m_6*C2*C3*C4*S5*S6 - 2*Y6*a3*dq46*m_6*C4*C5*C6*S2*S3 - 2*Y6*a3*dq56*m_6*C2*C3*C6*S4*S5 + 16*X6*d6*dq12*m_6*CC2*CC3*C4*CC5*C6 + 16*X6*d6*dq13*m_6*CC2*CC3*C4*CC5*C6 + 4*Z4*a3*dq14*m_4*C2*C3*C4*S2*S3 - 4*Z5*a2*dq12*m_5*C2*C3*C4*S2*S5 - 8*Z5*a3*dq12*m_5*C2*C3*C5*S2*S3 - 2*Z5*a2*dq13*m_5*C2*C3*C4*S2*S5 - 8*Z5*a3*dq13*m_5*C2*C3*C5*S2*S3 - 4*Z6*a2*dq12*m_6*C2*C3*C4*S2*S5 - 8*Z6*a3*dq12*m_6*C2*C3*C5*S2*S3 - 2*Z5*a2*dq15*m_5*C2*C4*C5*S2*S3 - 2*Z6*a2*dq13*m_6*C2*C3*C4*S2*S5 - 8*Z6*a3*dq13*m_6*C2*C3*C5*S2*S3 - 2*Z6*a2*dq15*m_6*C2*C4*C5*S2*S3 - 8*X4*d4*dq12*m_4*C2*C3*C4*S2*S3 - 8*X4*d4*dq13*m_4*C2*C3*C4*S2*S3 - 4*X5*d4*dq15*m_5*C2*C3*C5*S2*S3 + 2*X6*d4*dq14*m_6*C2*C5*C6*S2*S4 + 4*X6*d6*dq15*m_6*C2*C3*C6*S2*S3 + 2*X6*d4*dq15*m_6*C2*C4*C6*S2*S5 - 2*X6*d4*dq23*m_6*C2*C5*C6*S3*S4 - 2*X6*d4*dq23*m_6*C3*C5*C6*S2*S4 + 4*X6*d6*dq12*m_6*C2*C5*C6*S2*S5 + 2*X6*d4*dq14*m_6*C3*C5*C6*S3*S4 + 2*X6*d4*dq16*m_6*C2*C4*C5*S2*S6 + 4*X6*d6*dq13*m_6*C2*C5*C6*S2*S5 + 2*X6*d6*dq14*m_6*C2*C4*C5*S2*S6 + 2*X6*d4*dq15*m_6*C3*C4*C6*S3*S5 + 4*X6*d6*dq12*m_6*C3*C5*C6*S3*S5 - 2*X6*d6*dq23*m_6*C2*C4*C5*S3*S6 - 2*X6*d6*dq23*m_6*C3*C4*C5*S2*S6 + 2*X6*d4*dq16*m_6*C3*C4*C5*S3*S6 + 4*X6*d6*dq13*m_6*C3*C5*C6*S3*S5 + 2*X6*d6*dq14*m_6*C3*C4*C5*S3*S6 + 2*X6*d6*dq16*m_6*C2*C5*C6*S2*S4 + 2*X6*d6*dq25*m_6*C2*C4*C6*S3*S4 + 2*X6*d6*dq25*m_6*C3*C4*C6*S2*S4 + 2*X6*d4*dq45*m_6*C2*C4*C6*S3*S5 + 2*X6*d4*dq45*m_6*C3*C4*C6*S2*S5 + 4*X6*d6*dq24*m_6*C2*C5*C6*S3*S5 + 4*X6*d6*dq24*m_6*C3*C5*C6*S2*S5 - 2*X6*d6*dq25*m_6*C2*C3*C4*S5*S6 + 2*X6*d6*dq35*m_6*C2*C4*C6*S3*S4 + 2*X6*d6*dq35*m_6*C3*C4*C6*S2*S4 + 2*X6*d4*dq46*m_6*C2*C4*C5*S3*S6 + 2*X6*d4*dq46*m_6*C3*C4*C5*S2*S6 + 2*X6*d6*dq16*m_6*C3*C5*C6*S3*S4 + 4*X6*d6*dq34*m_6*C2*C5*C6*S3*S5 + 4*X6*d6*dq34*m_6*C3*C5*C6*S2*S5 - 2*X6*d6*dq35*m_6*C2*C3*C4*S5*S6 + 2*X6*d6*dq46*m_6*C2*C5*C6*S3*S4 + 2*X6*d6*dq46*m_6*C3*C5*C6*S2*S4 + 2*X6*d6*dq46*m_6*C2*C3*C5*S5*S6 - 16*Y6*Z6*dq12*m_6*CC2*CC3*C4*CC5*S6 - 16*Y6*Z6*dq13*m_6*CC2*CC3*C4*CC5*S6 - 8*Y6*Z6*dq14*m_6*CC2*CC3*CC4*C6*S5 - 8*Y4*Z4*dq12*m_4*C2*C3*S2*S3*S4 - 8*Y4*Z4*dq13*m_4*C2*C3*S2*S3*S4 - 4*Y5*Z5*dq12*m_5*C2*C4*S2*S4*S5 - 4*Y5*Z5*dq14*m_5*C2*C3*S2*S3*S5 - 4*Y5*Z5*dq13*m_5*C2*C4*S2*S4*S5 - 4*Y5*Z5*dq12*m_5*C3*C4*S3*S4*S5 - 4*Y5*Z5*dq13*m_5*C3*C4*S3*S4*S5 + 4*Y5*Z5*dq24*m_5*C2*C4*S3*S4*S5 + 4*Y5*Z5*dq24*m_5*C3*C4*S2*S4*S5 + 4*Y5*Z5*dq34*m_5*C2*C4*S3*S4*S5 + 4*Y5*Z5*dq34*m_5*C3*C4*S2*S4*S5 - 4*Y6*Z6*dq15*m_6*C2*C3*S2*S3*S6 - 4*Y6*Z6*dq12*m_6*C2*C5*S2*S5*S6 - 4*Y6*Z6*dq13*m_6*C2*C5*S2*S5*S6 - 4*Y6*Z6*dq12*m_6*C3*C5*S3*S5*S6 - 2*Y6*Z6*dq15*m_6*C2*C6*S2*S4*S5 - 4*Y6*Z6*dq13*m_6*C3*C5*S3*S5*S6 - 2*Y6*Z6*dq16*m_6*C2*C5*S2*S4*S6 - 2*Y6*Z6*dq25*m_6*C2*C4*S3*S4*S6 - 2*Y6*Z6*dq25*m_6*C3*C4*S2*S4*S6 - 2*Y6*Z6*dq15*m_6*C3*C6*S3*S4*S5 - 4*Y6*Z6*dq24*m_6*C2*C5*S3*S5*S6 - 4*Y6*Z6*dq24*m_6*C3*C5*S2*S5*S6 + 2*Y6*Z6*dq25*m_6*C4*C6*S2*S3*S5 - 2*Y6*Z6*dq35*m_6*C2*C4*S3*S4*S6 - 2*Y6*Z6*dq35*m_6*C3*C4*S2*S4*S6 - 2*Y6*Z6*dq16*m_6*C3*C5*S3*S4*S6 - 4*Y6*Z6*dq34*m_6*C2*C5*S3*S5*S6 - 4*Y6*Z6*dq34*m_6*C3*C5*S2*S5*S6 + 2*Y6*Z6*dq35*m_6*C4*C6*S2*S3*S5 - 2*Y6*Z6*dq46*m_6*C2*C5*S3*S4*S6 - 2*Y6*Z6*dq46*m_6*C3*C5*S2*S4*S6 - 2*Y6*Z6*dq46*m_6*C5*C6*S2*S3*S5 - 4*a2*d6*dq12*m_6*C2*C3*C4*S2*S5 - 8*a3*d6*dq12*m_6*C2*C3*C5*S2*S3 - 2*a2*d6*dq13*m_6*C2*C3*C4*S2*S5 - 8*a3*d6*dq13*m_6*C2*C3*C5*S2*S3 - 2*a2*d6*dq15*m_6*C2*C4*C5*S2*S3 + 4*X4*a3*dq14*m_4*C2*C3*S2*S3*S4 + 8*X5*a3*dq12*m_5*C2*C3*S2*S3*S5 + 8*X5*a3*dq13*m_5*C2*C3*S2*S3*S5 + 2*X5*a2*dq14*m_5*C2*C5*S2*S3*S4 + 2*X5*a2*dq15*m_5*C2*C4*S2*S3*S5 + 4*X6*a2*dq12*m_6*C2*C3*S2*S4*S6 + 4*X6*a2*dq12*m_6*C2*C6*S2*S3*S5 + 2*X6*a2*dq13*m_6*C2*C3*S2*S4*S6 + 2*X6*a2*dq13*m_6*C2*C6*S2*S3*S5 + 2*X6*a2*dq14*m_6*C2*C4*S2*S3*S6 + 2*X6*a1*dq14*m_6*C5*C6*S2*S3*S4 + 2*X6*a2*dq16*m_6*C2*C6*S2*S3*S4 + 2*X6*a1*dq15*m_6*C4*C6*S2*S3*S5 + 2*X6*a2*dq16*m_6*C2*C3*S2*S5*S6 + 2*X6*a1*dq16*m_6*C4*C5*S2*S3*S6 + 2*X6*a3*dq23*m_6*C5*C6*S2*S3*S4 - 2*X6*a3*dq45*m_6*C4*C6*S2*S3*S5 - 2*X6*a3*dq46*m_6*C4*C5*S2*S3*S6 - 2*X6*a3*dq56*m_6*C2*C3*S4*S5*S6 - 16*Y6*d6*dq12*m_6*CC2*CC3*C4*CC5*S6 - 16*Y6*d6*dq13*m_6*CC2*CC3*C4*CC5*S6 - 8*Y6*d6*dq14*m_6*CC2*CC3*CC4*C6*S5 + 8*Z6*d6*dq12*m_6*C2*CC3*CC4*CC5*S2 + 8*Z6*d6*dq12*m_6*CC2*C3*CC4*CC5*S3 + 8*Z6*d6*dq13*m_6*C2*CC3*CC4*CC5*S2 + 8*Z6*d6*dq13*m_6*CC2*C3*CC4*CC5*S3 + 8*Z6*d6*dq14*m_6*CC2*CC3*C4*CC5*S4 + 8*Z6*d6*dq15*m_6*CC2*CC3*CC4*C5*S5 + 8*Y5*d4*dq12*m_5*C2*C3*S2*S3*S4 + 8*Y5*d4*dq13*m_5*C2*C3*S2*S3*S4 - 2*Y6*d4*dq14*m_6*C2*C5*S2*S4*S6 - 4*Y6*d6*dq15*m_6*C2*C3*S2*S3*S6 - 2*Y6*d4*dq15*m_6*C2*C4*S2*S5*S6 + 2*Y6*d4*dq23*m_6*C2*C5*S3*S4*S6 + 2*Y6*d4*dq23*m_6*C3*C5*S2*S4*S6 - 4*Y6*d6*dq12*m_6*C2*C5*S2*S5*S6 - 2*Y6*d4*dq14*m_6*C3*C5*S3*S4*S6 - 4*Y6*d6*dq13*m_6*C2*C5*S2*S5*S6 - 2*Y6*d4*dq15*m_6*C3*C4*S3*S5*S6 - 4*Y6*d6*dq12*m_6*C3*C5*S3*S5*S6 - 2*Y6*d6*dq15*m_6*C2*C6*S2*S4*S5 - 4*Y6*d6*dq13*m_6*C3*C5*S3*S5*S6 - 2*Y6*d6*dq16*m_6*C2*C5*S2*S4*S6 - 2*Y6*d6*dq25*m_6*C2*C4*S3*S4*S6 - 2*Y6*d6*dq25*m_6*C3*C4*S2*S4*S6 - 2*Y6*d4*dq45*m_6*C2*C4*S3*S5*S6 - 2*Y6*d4*dq45*m_6*C3*C4*S2*S5*S6 - 2*Y6*d6*dq15*m_6*C3*C6*S3*S4*S5 - 4*Y6*d6*dq24*m_6*C2*C5*S3*S5*S6 - 4*Y6*d6*dq24*m_6*C3*C5*S2*S5*S6 + 2*Y6*d6*dq25*m_6*C4*C6*S2*S3*S5 - 2*Y6*d6*dq35*m_6*C2*C4*S3*S4*S6 - 2*Y6*d6*dq35*m_6*C3*C4*S2*S4*S6 - 2*Y6*d6*dq16*m_6*C3*C5*S3*S4*S6 - 4*Y6*d6*dq34*m_6*C2*C5*S3*S5*S6 - 4*Y6*d6*dq34*m_6*C3*C5*S2*S5*S6 + 2*Y6*d6*dq35*m_6*C4*C6*S2*S3*S5 - 2*Y6*d4*dq56*m_6*C2*C6*S3*S4*S5 - 2*Y6*d4*dq56*m_6*C3*C6*S2*S4*S5 - 2*Y6*d6*dq46*m_6*C2*C5*S3*S4*S6 - 2*Y6*d6*dq46*m_6*C3*C5*S2*S4*S6 - 2*Y6*d6*dq46*m_6*C5*C6*S2*S3*S5 + 8*Z4*d4*dq12*m_4*C2*C3*S2*S3*S4 + 8*Z4*d4*dq13*m_4*C2*C3*S2*S3*S4 - 4*Z5*d4*dq15*m_5*C2*C3*S2*S3*S5 - 4*Z6*d4*dq15*m_6*C2*C3*S2*S3*S5 + 4*Z6*d6*dq14*m_6*C2*C5*S2*S4*S5 - 4*Z6*d6*dq23*m_6*C2*C5*S3*S4*S5 - 4*Z6*d6*dq23*m_6*C3*C5*S2*S4*S5 + 4*Z6*d6*dq14*m_6*C3*C5*S3*S4*S5 + 16*X6*Y6*dq12*m_6*CC2*CC3*CC6*S4*S5 + 16*X6*Y6*dq13*m_6*CC2*CC3*CC6*S4*S5 - 8*X6*Z6*dq14*m_6*CC2*CC3*CC4*S5*S6 + 2*X6*Y6*dq26*m_6*C5*S2*S3*S4*S5 + 2*X6*Y6*dq36*m_6*C5*S2*S3*S4*S5 - 4*X6*Y6*dq56*m_6*C6*S2*S3*S5*S6 + 4*X5*Z5*dq25*m_5*C5*S2*S3*S4*S5 +
 4*X5*Z5*dq35*m_5*C5*S2*S3*S4*S5 - 2*X6*Z6*dq15*m_6*C2*S2*S4*S5*S6 - 2*X6*Z6*dq15*m_6*C3*S3*S4*S5*S6 + 2*X6*Z6*dq25*m_6*C4*S2*S3*S5*S6 + 2*X6*Z6*dq35*m_6*C4*S2*S3*S5*S6 - 2*X6*Z6*dq46*m_6*C5*S2*S3*S5*S6 - 4*d4*d6*dq15*m_6*C2*C3*S2*S3*S5 - 4*Y6*a2*dq12*m_6*C2*S2*S3*S5*S6 - 2*Y6*a2*dq13*m_6*C2*S2*S3*S5*S6 - 2*Y6*a1*dq14*m_6*C5*S2*S3*S4*S6 - 2*Y6*a2*dq16*m_6*C2*S2*S3*S4*S6 - 2*Y6*a1*dq15*m_6*C4*S2*S3*S5*S6 - 2*Y6*a3*dq23*m_6*C5*S2*S3*S4*S6 + 2*Y6*a3*dq45*m_6*C4*S2*S3*S5*S6 + 2*Y6*a3*dq56*m_6*C6*S2*S3*S4*S5 - 8*X6*d6*dq14*m_6*CC2*CC3*CC4*S5*S6 + 2*Z5*a2*dq14*m_5*C2*S2*S3*S4*S5 + 2*Z6*a2*dq14*m_6*C2*S2*S3*S4*S5 - 4*XX6*dq23*m_6*C2*C3*CC4*C5*C6*S6 - 2*X6*d6*dq15*m_6*C2*S2*S4*S5*S6 - 2*X6*d6*dq15*m_6*C3*S3*S4*S5*S6 + 2*X6*d6*dq25*m_6*C4*S2*S3*S5*S6 + 2*X6*d6*dq35*m_6*C4*S2*S3*S5*S6 - 2*X6*d4*dq56*m_6*C2*S3*S4*S5*S6 - 2*X6*d4*dq56*m_6*C3*S2*S4*S5*S6 - 2*X6*d6*dq46*m_6*C5*S2*S3*S5*S6 + 4*YY6*dq23*m_6*C2*C3*CC4*C5*C6*S6 - 4*Ixy6*dq23*C2*C3*C4*CC5*C6*S4*S6 + 16*Ixz6*dq12*C2*C3*C4*CC5*C6*S2*S3 + 16*Ixz6*dq13*C2*C3*C4*CC5*C6*S2*S3 + 16*Ixz6*dq15*C2*CC3*C4*C5*C6*S2*S5 + 16*Ixz6*dq15*CC2*C3*C4*C5*C6*S3*S5 + 2*a2*d6*dq14*m_6*C2*S2*S3*S4*S5 + 2*X6*a3*dq56*m_6*S2*S3*S4*S5*S6 - 4*X6*Y6*dq25*m_6*C2*C3*C4*C5*CC6 - 4*X6*Y6*dq35*m_6*C2*C3*C4*C5*CC6 - 4*Ixx5*dq14*C2*C3*C4*CC5*S2*S3*S4 - 4*Ixx5*dq15*C2*C3*CC4*C5*S2*S3*S5 - 4*Ixx6*dq14*C2*C3*C4*CC6*S2*S3*S4 - 4*Ixx6*dq15*C2*C3*C5*CC6*S2*S3*S5 - 4*Ixx6*dq14*C2*CC3*C4*C6*S2*S5*S6 - 4*Ixx6*dq16*C2*C3*CC4*C6*S2*S3*S6 - 4*Ixx6*dq14*CC2*C3*C4*C6*S3*S5*S6 - 4*Ixx6*dq15*C2*CC3*C5*C6*S2*S4*S6 - 4*Ixx6*dq16*C2*C3*CC5*C6*S2*S3*S6 - 4*Ixx6*dq15*CC2*C3*C5*C6*S3*S4*S6 - 2*Ixx6*dq25*C2*C4*C5*CC6*S3*S4*S5 - 2*Ixx6*dq25*C3*C4*C5*CC6*S2*S4*S5 - 2*Ixx6*dq35*C2*C4*C5*CC6*S3*S4*S5 - 2*Ixx6*dq35*C3*C4*C5*CC6*S2*S4*S5 - 2*Ixx6*dq26*C2*C4*CC5*C6*S3*S4*S6 - 2*Ixx6*dq26*C3*C4*CC5*C6*S2*S4*S6 - 2*Ixx6*dq36*C2*C4*CC5*C6*S3*S4*S6 - 2*Ixx6*dq36*C3*C4*CC5*C6*S2*S4*S6 - 4*Iyy6*dq14*C2*C3*C4*CC5*S2*S3*S4 + 4*Iyy6*dq14*C2*C3*C4*CC6*S2*S3*S4 - 4*Iyy6*dq15*C2*C3*CC4*C5*S2*S3*S5 + 4*Iyy6*dq15*C2*C3*C5*CC6*S2*S3*S5 + 4*Iyy6*dq14*C2*CC3*C4*C6*S2*S5*S6 + 4*Iyy6*dq16*C2*C3*CC4*C6*S2*S3*S6 + 4*Iyy6*dq14*CC2*C3*C4*C6*S3*S5*S6 + 4*Iyy6*dq15*C2*CC3*C5*C6*S2*S4*S6 + 4*Iyy6*dq16*C2*C3*CC5*C6*S2*S3*S6 + 4*Iyy6*dq15*CC2*C3*C5*C6*S3*S4*S6 + 2*Iyy6*dq25*C2*C4*C5*CC6*S3*S4*S5 + 2*Iyy6*dq25*C3*C4*C5*CC6*S2*S4*S5 + 2*Iyy6*dq35*C2*C4*C5*CC6*S3*S4*S5 + 2*Iyy6*dq35*C3*C4*C5*CC6*S2*S4*S5 + 2*Iyy6*dq26*C2*C4*CC5*C6*S3*S4*S6 + 2*Iyy6*dq26*C3*C4*CC5*C6*S2*S4*S6 + 2*Iyy6*dq36*C2*C4*CC5*C6*S3*S4*S6 + 2*Iyy6*dq36*C3*C4*CC5*C6*S2*S4*S6 - 16*Iyz6*dq12*C2*C3*C4*CC5*S2*S3*S6 - 8*Iyz6*dq12*C2*CC3*C4*C6*S2*S4*S5 - 16*Iyz6*dq13*C2*C3*C4*CC5*S2*S3*S6 - 8*Iyz6*dq12*CC2*C3*C4*C6*S3*S4*S5 - 8*Iyz6*dq13*C2*CC3*C4*C6*S2*S4*S5 - 8*Iyz6*dq14*C2*C3*CC4*C6*S2*S3*S5 - 8*Iyz6*dq13*CC2*C3*C4*C6*S3*S4*S5 - 16*Iyz6*dq15*C2*CC3*C4*C5*S2*S5*S6 - 16*Iyz6*dq15*CC2*C3*C4*C5*S3*S5*S6 + 4*Izz5*dq14*C2*C3*C4*CC5*S2*S3*S4 + 4*Izz6*dq14*C2*C3*C4*CC5*S2*S3*S4 + 4*Izz5*dq15*C2*C3*CC4*C5*S2*S3*S5 + 4*Izz6*dq15*C2*C3*CC4*C5*S2*S3*S5 - 2*Y6*a2*dq16*m_6*CC2*C3*C4*C5*C6 - 4*XX6*dq12*m_6*C2*CC3*CC4*CC5*CC6*S2 - 4*XX6*dq12*m_6*CC2*C3*CC4*CC5*CC6*S3 - 4*XX6*dq13*m_6*C2*CC3*CC4*CC5*CC6*S2 - 4*XX6*dq13*m_6*CC2*C3*CC4*CC5*CC6*S3 - 4*XX6*dq14*m_6*CC2*CC3*C4*CC5*CC6*S4 - 4*XX6*dq15*m_6*CC2*CC3*CC4*C5*CC6*S5 - 4*XX6*dq16*m_6*CC2*CC3*CC4*CC5*C6*S6 + 4*YY6*dq12*m_6*C2*CC3*CC4*CC5*CC6*S2 + 4*YY6*dq12*m_6*CC2*C3*CC4*CC5*CC6*S3 + 4*YY6*dq13*m_6*C2*CC3*CC4*CC5*CC6*S2 + 4*YY6*dq13*m_6*CC2*C3*CC4*CC5*CC6*S3 + 4*YY6*dq14*m_6*CC2*CC3*C4*CC5*CC6*S4 + 4*YY6*dq15*m_6*CC2*CC3*CC4*C5*CC6*S5 + 4*YY6*dq16*m_6*CC2*CC3*CC4*CC5*C6*S6 + 4*XX5*dq14*m_5*C2*CC3*C5*S2*S4*S5 + 4*XX5*dq14*m_5*CC2*C3*C5*S3*S4*S5 - 2*XX6*dq14*m_6*C2*C5*CC6*S2*S4*S5 + 2*XX6*dq23*m_6*C2*C5*CC6*S3*S4*S5 + 2*XX6*dq23*m_6*C3*C5*CC6*S2*S4*S5 - 2*XX6*dq14*m_6*C3*C5*CC6*S3*S4*S5 + 4*XX6*dq23*m_6*CC4*C5*C6*S2*S3*S6 - 2*XX6*dq15*m_6*CC2*C4*C6*S4*S5*S6 + 2*XX6*dq25*m_6*C2*CC4*C6*S3*S5*S6 + 2*XX6*dq25*m_6*C3*CC4*C6*S2*S5*S6 - 2*XX6*dq15*m_6*CC3*C4*C6*S4*S5*S6 + 2*XX6*dq35*m_6*C2*CC4*C6*S3*S5*S6 + 2*XX6*dq35*m_6*C3*CC4*C6*S2*S5*S6 + 4*YY6*dq14*m_6*C2*CC3*C5*S2*S4*S5 + 4*YY6*dq14*m_6*CC2*C3*C5*S3*S4*S5 + 2*YY6*dq14*m_6*C2*C5*CC6*S2*S4*S5 - 2*YY6*dq23*m_6*C2*C5*CC6*S3*S4*S5 - 2*YY6*dq23*m_6*C3*C5*CC6*S2*S4*S5 + 2*YY6*dq14*m_6*C3*C5*CC6*S3*S4*S5 - 4*YY6*dq23*m_6*CC4*C5*C6*S2*S3*S6 + 2*YY6*dq15*m_6*CC2*C4*C6*S4*S5*S6 - 2*YY6*dq25*m_6*C2*CC4*C6*S3*S5*S6 - 2*YY6*dq25*m_6*C3*CC4*C6*S2*S5*S6 + 2*YY6*dq15*m_6*CC3*C4*C6*S4*S5*S6 - 2*YY6*dq35*m_6*C2*CC4*C6*S3*S5*S6 - 2*YY6*dq35*m_6*C3*CC4*C6*S2*S5*S6 - 4*ZZ5*dq14*m_5*C2*CC3*C5*S2*S4*S5 - 4*ZZ5*dq14*m_5*CC2*C3*C5*S3*S4*S5 - 4*ZZ6*dq14*m_6*C2*CC3*C5*S2*S4*S5 - 4*ZZ6*dq14*m_6*CC2*C3*C5*S3*S4*S5 - 4*Y5*Z5*dq14*m_5*C2*CC3*C4*C5*S2 - 4*Y5*Z5*dq14*m_5*CC2*C3*C4*C5*S3 + 4*Y6*Z6*dq16*m_6*C2*CC3*C4*C6*S2 + 4*Y6*Z6*dq16*m_6*CC2*C3*C4*C6*S3 - 4*Y6*Z6*dq23*m_6*C2*C3*CC4*C6*S5 + 4*Y6*Z6*dq16*m_6*C2*C4*CC5*C6*S2 + 2*Y6*Z6*dq15*m_6*CC2*C4*C5*C6*S4 - 2*Y6*Z6*dq25*m_6*C2*CC4*C5*C6*S3 - 2*Y6*Z6*dq25*m_6*C3*CC4*C5*C6*S2 + 2*Y6*Z6*dq15*m_6*CC3*C4*C5*C6*S4 + 4*Y6*Z6*dq16*m_6*C3*C4*CC5*C6*S3 - 2*Y6*Z6*dq26*m_6*C2*C3*CC5*C6*S4 - 2*Y6*Z6*dq35*m_6*C2*CC4*C5*C6*S3 - 2*Y6*Z6*dq35*m_6*C3*CC4*C5*C6*S2 - 2*Y6*Z6*dq36*m_6*C2*C3*CC5*C6*S4 + 2*Y6*Z6*dq46*m_6*C2*C4*CC5*C6*S3 + 2*Y6*Z6*dq46*m_6*C3*C4*CC5*C6*S2 + 16*Ixy6*dq12*C2*C3*CC6*S2*S3*S4*S5 + 16*Ixy6*dq13*C2*C3*CC6*S2*S3*S4*S5 + 16*Ixy6*dq16*C2*CC3*C6*S2*S4*S5*S6 + 4*Ixy6*dq23*C4*CC5*C6*S2*S3*S4*S6 + 16*Ixy6*dq16*CC2*C3*C6*S3*S4*S5*S6 - 8*Ixz6*dq12*C2*CC3*C4*S2*S4*S5*S6 - 8*Ixz6*dq12*CC2*C3*C4*S3*S4*S5*S6 - 8*Ixz6*dq13*C2*CC3*C4*S2*S4*S5*S6 - 8*Ixz6*dq14*C2*C3*CC4*S2*S3*S5*S6 - 8*Ixz6*dq13*CC2*C3*C4*S3*S4*S5*S6 - 4*dd6*dq14*m_6*C2*CC3*C5*S2*S4*S5 - 4*dd6*dq14*m_6*CC2*C3*C5*S3*S4*S5 - 8*X5*a3*dq12*m_5*C2*CC3*C4*C5*S2 - 8*X5*a3*dq12*m_5*CC2*C3*C4*C5*S3 - 8*X5*a3*dq13*m_5*C2*CC3*C4*C5*S2 - 8*X5*a3*dq13*m_5*CC2*C3*C4*C5*S3 - 4*X6*a2*dq12*m_6*CC2*C4*C5*C6*S3 - 2*X6*a2*dq13*m_6*CC2*C4*C5*C6*S3 - 2*X6*a2*dq14*m_6*CC2*C3*C5*C6*S4 - 4*X6*a3*dq15*m_6*C2*CC3*C5*C6*S2 - 2*X6*a2*dq15*m_6*CC2*C3*C4*C6*S5 - 4*X6*a3*dq15*m_6*CC2*C3*C5*C6*S3 - 2*X6*a2*dq16*m_6*CC2*C3*C4*C5*S6 - 4*Y6*d4*dq14*m_6*C2*CC3*C4*C6*S2 - 4*Y6*d4*dq14*m_6*CC2*C3*C4*C6*S3 + 4*Y6*d6*dq16*m_6*C2*CC3*C4*C6*S2 + 4*Y6*d6*dq16*m_6*CC2*C3*C4*C6*S3 - 4*Y6*d6*dq23*m_6*C2*C3*CC4*C6*S5 + 4*Y6*d6*dq16*m_6*C2*C4*CC5*C6*S2 + 2*Y6*d6*dq15*m_6*CC2*C4*C5*C6*S4 - 2*Y6*d6*dq25*m_6*C2*CC4*C5*C6*S3 - 2*Y6*d6*dq25*m_6*C3*CC4*C5*C6*S2 + 2*Y6*d6*dq15*m_6*CC3*C4*C5*C6*S4 + 4*Y6*d6*dq16*m_6*C3*C4*CC5*C6*S3 - 2*Y6*d6*dq26*m_6*C2*C3*CC5*C6*S4 - 2*Y6*d6*dq35*m_6*C2*CC4*C5*C6*S3 - 2*Y6*d6*dq35*m_6*C3*CC4*C5*C6*S2 - 2*Y6*d6*dq36*m_6*C2*C3*CC5*C6*S4 + 2*Y6*d6*dq46*m_6*C2*C4*CC5*C6*S3 + 2*Y6*d6*dq46*m_6*C3*C4*CC5*C6*S2 + 4*Z5*d4*dq15*m_5*C2*CC3*C4*C5*S2 + 4*Z5*d4*dq15*m_5*CC2*C3*C4*C5*S3 + 4*Z6*d4*dq15*m_6*C2*CC3*C4*C5*S2 + 4*Z6*d4*dq15*m_6*CC2*C3*C4*C5*S3 + 4*Z6*d6*dq23*m_6*C2*C3*C4*CC5*S4 - 16*X6*Y6*dq14*m_6*CC2*CC3*CC4*C5*CC6 + 8*X6*Z6*dq15*m_6*CC2*CC3*CC4*CC5*C6 + 4*X5*Y5*dq14*m_5*C2*CC3*C4*S2*S5 + 4*X5*Y5*dq14*m_5*CC2*C3*C4*S3*S5 + 4*X5*Y5*dq15*m_5*C2*CC3*C5*S2*S4 + 4*X5*Y5*dq15*m_5*CC2*C3*C5*S3*S4 - 4*X6*Y6*dq14*m_6*C2*CC3*C4*S2*S5 - 4*X6*Y6*dq16*m_6*C2*C3*CC4*S2*S3 - 16*X6*Y6*dq12*m_6*C2*CC3*C6*S2*S6 - 4*X6*Y6*dq14*m_6*CC2*C3*C4*S3*S5 - 4*X6*Y6*dq15*m_6*C2*CC3*C5*S2*S4 - 4*X6*Y6*dq16*m_6*C2*C3*CC5*S2*S3 - 4*X6*Y6*dq12*m_6*C2*CC4*C6*S2*S6 - 16*X6*Y6*dq12*m_6*CC2*C3*C6*S3*S6 - 16*X6*Y6*dq13*m_6*C2*CC3*C6*S2*S6 - 4*X6*Y6*dq15*m_6*CC2*C3*C5*S3*S4 - 16*X6*Y6*dq16*m_6*C2*C3*CC6*S2*S3 - 4*X6*Y6*dq12*m_6*C2*CC5*C6*S2*S6 - 4*X6*Y6*dq13*m_6*C2*CC4*C6*S2*S6 - 16*X6*Y6*dq13*m_6*CC2*C3*C6*S3*S6 - 4*X6*Y6*dq14*m_6*C2*C4*CC6*S2*S5 - 4*X6*Y6*dq12*m_6*C3*CC4*C6*S3*S6 - 4*X6*Y6*dq13*m_6*C2*CC5*C6*S2*S6 - 4*X6*Y6*dq15*m_6*C2*C5*CC6*S2*S4 + 4*X6*Y6*dq23*m_6*C2*C4*CC6*S3*S5 + 4*X6*Y6*dq23*m_6*C3*C4*CC6*S2*S5 - 4*X6*Y6*dq12*m_6*C3*CC5*C6*S3*S6 - 4*X6*Y6*dq13*m_6*C3*CC4*C6*S3*S6 - 4*X6*Y6*dq14*m_6*C3*C4*CC6*S3*S5 - 2*X6*Y6*dq26*m_6*C2*C4*CC5*S3*S4 - 2*X6*Y6*dq26*m_6*C3*C4*CC5*S2*S4 - 4*X6*Y6*dq13*m_6*C3*CC5*C6*S3*S6 - 4*X6*Y6*dq14*m_6*CC2*C4*C6*S4*S6 - 4*X6*Y6*dq15*m_6*C3*C5*CC6*S3*S4 + 4*X6*Y6*dq24*m_6*C2*CC4*C6*S3*S6 + 4*X6*Y6*dq24*m_6*C3*CC4*C6*S2*S6 + 4*X6*Y6*dq25*m_6*C4*C5*CC6*S2*S3 + 4*X6*Y6*dq26*m_6*C2*C4*CC6*S3*S4 + 4*X6*Y6*dq26*m_6*C3*C4*CC6*S2*S4 - 2*X6*Y6*dq36*m_6*C2*C4*CC5*S3*S4 - 2*X6*Y6*dq36*m_6*C3*C4*CC5*S2*S4 - 4*X6*Y6*dq14*m_6*CC3*C4*C6*S4*S6 - 4*X6*Y6*dq24*m_6*C2*CC5*C6*S3*S6 - 4*X6*Y6*dq24*m_6*C3*CC5*C6*S2*S6 + 4*X6*Y6*dq34*m_6*C2*CC4*C6*S3*S6 + 4*X6*Y6*dq34*m_6*C3*CC4*C6*S2*S6 + 4*X6*Y6*dq35*m_6*C4*C5*CC6*S2*S3 + 4*X6*Y6*dq36*m_6*C2*C4*CC6*S3*S4 + 4*X6*Y6*dq36*m_6*C3*C4*CC6*S2*S4 - 4*X6*Y6*dq34*m_6*C2*CC5*C6*S3*S6 - 4*X6*Y6*dq34*m_6*C3*CC5*C6*S2*S6 - 4*X6*Y6*dq15*m_6*CC2*C5*C6*S5*S6 - 4*X6*Y6*dq15*m_6*CC3*C5*C6*S5*S6 + 8*X4*Z4*dq12*m_4*C2*CC3*C4*S2*S4 + 8*X4*Z4*dq12*m_4*CC2*C3*C4*S3*S4 + 8*X4*Z4*dq13*m_4*C2*CC3*C4*S2*S4 + 8*X4*Z4*dq14*m_4*C2*C3*CC4*S2*S3 + 8*X4*Z4*dq13*m_4*CC2*C3*C4*S3*S4 - 8*X5*Z5*dq12*m_5*C2*CC3*C5*S2*S5 + 4*X5*Z5*dq15*m_5*C2*C3*CC4*S2*S3 + 4*X5*Z5*dq12*m_5*C2*CC4*C5*S2*S5 - 8*X5*Z5*dq12*m_5*CC2*C3*C5*S3*S5 - 8*X5*Z5*dq13*m_5*C2*CC3*C5*S2*S5 - 8*X5*Z5*dq15*m_5*C2*C3*CC5*S2*S3 + 4*X5*Z5*dq13*m_5*C2*CC4*C5*S2*S5 - 8*X5*Z5*dq13*m_5*CC2*C3*C5*S3*S5 + 4*X5*Z5*dq12*m_5*C3*CC4*C5*S3*S5 + 4*X5*Z5*dq13*m_5*C3*CC4*C5*S3*S5 + 4*X5*Z5*dq14*m_5*CC2*C4*C5*S4*S5 - 4*X5*Z5*dq24*m_5*C2*CC4*C5*S3*S5 - 4*X5*Z5*dq24*m_5*C3*CC4*C5*S2*S5 - 4*X5*Z5*dq25*m_5*C2*C4*CC5*S3*S4 - 4*X5*Z5*dq25*m_5*C3*C4*CC5*S2*S4 + 4*X6*Z6*dq14*m_6*C2*CC3*C6*S2*S4 + 4*X5*Z5*dq14*m_5*CC3*C4*C5*S4*S5 - 4*X5*Z5*dq34*m_5*C2*CC4*C5*S3*S5 - 4*X5*Z5*dq34*m_5*C3*CC4*C5*S2*S5 - 4*X5*Z5*dq35*m_5*C2*C4*CC5*S3*S4 - 4*X5*Z5*dq35*m_5*C3*C4*CC5*S2*S4 + 4*X6*Z6*dq14*m_6*CC2*C3*C6*S3*S4 + 4*X6*Z6*dq14*m_6*C2*CC5*C6*S2*S4 + 4*X6*Z6*dq16*m_6*C2*CC3*C4*S2*S6 + 4*X6*Z6*dq16*m_6*CC2*C3*C4*S3*S6 - 4*X6*Z6*dq23*m_6*C2*C3*CC4*S5*S6 - 4*X6*Z6*dq23*m_6*C2*CC5*C6*S3*S4 - 4*X6*Z6*dq23*m_6*C3*CC5*C6*S2*S4 + 4*X6*Z6*dq14*m_6*C3*CC5*C6*S3*S4
 + 4*X6*Z6*dq16*m_6*C2*C4*CC5*S2*S6 + 2*X6*Z6*dq15*m_6*CC2*C4*C5*S4*S6 - 2*X6*Z6*dq25*m_6*C2*CC4*C5*S3*S6 - 2*X6*Z6*dq25*m_6*C3*CC4*C5*S2*S6 + 2*X6*Z6*dq15*m_6*CC3*C4*C5*S4*S6 + 4*X6*Z6*dq16*m_6*C3*C4*CC5*S3*S6 + 2*X6*Z6*dq16*m_6*CC2*C4*C6*S4*S5 - 2*X6*Z6*dq26*m_6*C2*C3*CC5*S4*S6 - 2*X6*Z6*dq26*m_6*C2*CC4*C6*S3*S5 - 2*X6*Z6*dq26*m_6*C3*CC4*C6*S2*S5 - 2*X6*Z6*dq35*m_6*C2*CC4*C5*S3*S6 - 2*X6*Z6*dq35*m_6*C3*CC4*C5*S2*S6 + 2*X6*Z6*dq16*m_6*CC3*C4*C6*S4*S5 - 2*X6*Z6*dq36*m_6*C2*C3*CC5*S4*S6 - 2*X6*Z6*dq36*m_6*C2*CC4*C6*S3*S5 - 2*X6*Z6*dq36*m_6*C3*CC4*C6*S2*S5 + 2*X6*Z6*dq46*m_6*C2*C4*CC5*S3*S6 + 2*X6*Z6*dq46*m_6*C3*C4*CC5*S2*S6 + 4*d4*d6*dq15*m_6*C2*CC3*C4*C5*S2 + 4*d4*d6*dq15*m_6*CC2*C3*C4*C5*S3 + 8*Y6*a3*dq12*m_6*C2*CC3*C6*S2*S4 + 8*Y6*a3*dq12*m_6*CC2*C3*C6*S3*S4 + 8*Y6*a3*dq13*m_6*C2*CC3*C6*S2*S4 + 4*Y6*a2*dq12*m_6*CC2*C4*C5*S3*S6 + 8*Y6*a3*dq13*m_6*CC2*C3*C6*S3*S4 + 2*Y6*a2*dq13*m_6*CC2*C4*C5*S3*S6 + 2*Y6*a2*dq14*m_6*CC2*C3*C5*S4*S6 + 4*Y6*a3*dq15*m_6*C2*CC3*C5*S2*S6 + 2*Y6*a2*dq15*m_6*CC2*C3*C4*S5*S6 + 4*Y6*a3*dq15*m_6*CC2*C3*C5*S3*S6 + 4*Y6*a3*dq16*m_6*C2*CC3*C6*S2*S5 + 4*Y6*a3*dq16*m_6*CC2*C3*C6*S3*S5 + 8*X6*d6*dq15*m_6*CC2*CC3*CC4*CC5*C6 - 8*Z5*a3*dq12*m_5*C2*CC3*C4*S2*S5 - 8*Z5*a3*dq12*m_5*CC2*C3*C4*S3*S5 - 8*Z5*a3*dq13*m_5*C2*CC3*C4*S2*S5 - 8*Z5*a3*dq13*m_5*CC2*C3*C4*S3*S5 - 8*Z6*a3*dq12*m_6*C2*CC3*C4*S2*S5 - 8*Z6*a3*dq12*m_6*CC2*C3*C4*S3*S5 - 8*Z6*a3*dq13*m_6*C2*CC3*C4*S2*S5 - 8*Z6*a3*dq13*m_6*CC2*C3*C4*S3*S5 - 4*X5*d4*dq14*m_5*C2*CC3*C5*S2*S4 - 4*X5*d4*dq14*m_5*CC2*C3*C5*S3*S4 - 4*X5*d4*dq15*m_5*C2*CC3*C4*S2*S5 - 4*X5*d4*dq15*m_5*CC2*C3*C4*S3*S5 - 8*X6*d4*dq12*m_6*C2*CC3*C6*S2*S5 - 8*X6*d4*dq12*m_6*CC2*C3*C6*S3*S5 - 8*X6*d4*dq13*m_6*C2*CC3*C6*S2*S5 - 4*X6*d4*dq14*m_6*C2*CC3*C4*S2*S6 - 8*X6*d4*dq13*m_6*CC2*C3*C6*S3*S5 - 4*X6*d4*dq14*m_6*CC2*C3*C4*S3*S6 - 4*X6*d4*dq16*m_6*C2*CC3*C6*S2*S4 + 4*X6*d6*dq14*m_6*C2*CC3*C6*S2*S4 - 4*X6*d4*dq16*m_6*CC2*C3*C6*S3*S4 + 4*X6*d6*dq14*m_6*CC2*C3*C6*S3*S4 + 4*X6*d6*dq14*m_6*C2*CC5*C6*S2*S4 + 4*X6*d6*dq16*m_6*C2*CC3*C4*S2*S6 + 4*X6*d6*dq16*m_6*CC2*C3*C4*S3*S6 - 4*X6*d6*dq23*m_6*C2*C3*CC4*S5*S6 - 4*X6*d6*dq23*m_6*C2*CC5*C6*S3*S4 - 4*X6*d6*dq23*m_6*C3*CC5*C6*S2*S4 + 4*X6*d6*dq14*m_6*C3*CC5*C6*S3*S4 + 4*X6*d6*dq16*m_6*C2*C4*CC5*S2*S6 + 2*X6*d6*dq15*m_6*CC2*C4*C5*S4*S6 - 2*X6*d6*dq25*m_6*C2*CC4*C5*S3*S6 - 2*X6*d6*dq25*m_6*C3*CC4*C5*S2*S6 + 2*X6*d6*dq15*m_6*CC3*C4*C5*S4*S6 + 4*X6*d6*dq16*m_6*C3*C4*CC5*S3*S6 + 2*X6*d6*dq16*m_6*CC2*C4*C6*S4*S5 - 2*X6*d6*dq26*m_6*C2*C3*CC5*S4*S6 - 2*X6*d6*dq26*m_6*C2*CC4*C6*S3*S5 - 2*X6*d6*dq26*m_6*C3*CC4*C6*S2*S5 - 2*X6*d6*dq35*m_6*C2*CC4*C5*S3*S6 - 2*X6*d6*dq35*m_6*C3*CC4*C5*S2*S6 + 2*X6*d6*dq16*m_6*CC3*C4*C6*S4*S5 - 2*X6*d6*dq36*m_6*C2*C3*CC5*S4*S6 - 2*X6*d6*dq36*m_6*C2*CC4*C6*S3*S5 - 2*X6*d6*dq36*m_6*C3*CC4*C6*S2*S5 + 2*X6*d6*dq46*m_6*C2*C4*CC5*S3*S6 + 2*X6*d6*dq46*m_6*C3*C4*CC5*S2*S6 - 8*Y6*Z6*dq15*m_6*CC2*CC3*CC4*CC5*S6 + 4*Y5*Z5*dq15*m_5*C2*CC3*S2*S4*S5 + 4*Y5*Z5*dq15*m_5*CC2*C3*S3*S4*S5 - 4*Y6*Z6*dq14*m_6*C2*CC3*S2*S4*S6 - 4*Y6*Z6*dq14*m_6*CC2*C3*S3*S4*S6 - 4*Y6*Z6*dq14*m_6*C2*CC5*S2*S4*S6 + 4*Y6*Z6*dq23*m_6*C2*CC5*S3*S4*S6 + 4*Y6*Z6*dq23*m_6*C3*CC5*S2*S4*S6 + 4*Y6*Z6*dq23*m_6*CC4*C6*S2*S3*S5 - 4*Y6*Z6*dq14*m_6*C3*CC5*S3*S4*S6 - 2*Y6*Z6*dq16*m_6*CC2*C4*S4*S5*S6 + 2*Y6*Z6*dq26*m_6*C2*CC4*S3*S5*S6 + 2*Y6*Z6*dq26*m_6*C3*CC4*S2*S5*S6 + 2*Y6*Z6*dq26*m_6*CC5*C6*S2*S3*S4 - 2*Y6*Z6*dq16*m_6*CC3*C4*S4*S5*S6 + 2*Y6*Z6*dq36*m_6*C2*CC4*S3*S5*S6 + 2*Y6*Z6*dq36*m_6*C3*CC4*S2*S5*S6 + 2*Y6*Z6*dq36*m_6*CC5*C6*S2*S3*S4 - 4*Ixx6*dq14*C2*C3*C4*CC5*CC6*S2*S3*S4 - 4*Ixx6*dq15*C2*C3*CC4*C5*CC6*S2*S3*S5 - 4*Ixx6*dq16*C2*C3*CC4*CC5*C6*S2*S3*S6 + 4*Iyy6*dq14*C2*C3*C4*CC5*CC6*S2*S3*S4 + 4*Iyy6*dq15*C2*C3*CC4*C5*CC6*S2*S3*S5 + 4*Iyy6*dq16*C2*C3*CC4*CC5*C6*S2*S3*S6 + 4*XX6*dq14*m_6*C2*CC3*C5*CC6*S2*S4*S5 + 4*XX6*dq14*m_6*CC2*C3*C5*CC6*S3*S4*S5 + 4*XX6*dq15*m_6*CC2*CC3*C4*C6*S4*S5*S6 - 4*YY6*dq14*m_6*C2*CC3*C5*CC6*S2*S4*S5 - 4*YY6*dq14*m_6*CC2*C3*C5*CC6*S3*S4*S5 - 4*YY6*dq15*m_6*CC2*CC3*C4*C6*S4*S5*S6 - 8*Y6*Z6*dq16*m_6*C2*CC3*C4*CC5*C6*S2 - 4*Y6*Z6*dq15*m_6*CC2*CC3*C4*C5*C6*S4 - 8*Y6*Z6*dq16*m_6*CC2*C3*C4*CC5*C6*S3 - 8*Y6*d6*dq16*m_6*C2*CC3*C4*CC5*C6*S2 - 4*Y6*d6*dq15*m_6*CC2*CC3*C4*C5*C6*S4 - 8*Y6*d6*dq16*m_6*CC2*C3*C4*CC5*C6*S3 + 8*X6*Y6*dq12*m_6*C2*CC3*CC4*C6*S2*S6 - 4*X6*Y6*dq16*m_6*C2*C3*CC4*CC5*S2*S3 + 8*X6*Y6*dq12*m_6*C2*CC3*CC5*C6*S2*S6 + 8*X6*Y6*dq12*m_6*CC2*C3*CC4*C6*S3*S6 + 8*X6*Y6*dq13*m_6*C2*CC3*CC4*C6*S2*S6 + 8*X6*Y6*dq14*m_6*C2*CC3*C4*CC6*S2*S5 + 8*X6*Y6*dq16*m_6*C2*C3*CC4*CC6*S2*S3 - 4*X6*Y6*dq12*m_6*C2*CC4*CC5*C6*S2*S6 + 8*X6*Y6*dq12*m_6*CC2*C3*CC5*C6*S3*S6 + 8*X6*Y6*dq13*m_6*C2*CC3*CC5*C6*S2*S6 + 8*X6*Y6*dq13*m_6*CC2*C3*CC4*C6*S3*S6 + 8*X6*Y6*dq14*m_6*CC2*C3*C4*CC6*S3*S5 + 8*X6*Y6*dq15*m_6*C2*CC3*C5*CC6*S2*S4 + 8*X6*Y6*dq16*m_6*C2*C3*CC5*CC6*S2*S3 - 4*X6*Y6*dq13*m_6*C2*CC4*CC5*C6*S2*S6 + 8*X6*Y6*dq13*m_6*CC2*C3*CC5*C6*S3*S6 + 8*X6*Y6*dq15*m_6*CC2*C3*C5*CC6*S3*S4 - 4*X6*Y6*dq12*m_6*C3*CC4*CC5*C6*S3*S6 + 8*X6*Y6*dq14*m_6*CC2*CC3*C4*C6*S4*S6 - 4*X6*Y6*dq13*m_6*C3*CC4*CC5*C6*S3*S6 - 4*X6*Y6*dq14*m_6*CC2*C4*CC5*C6*S4*S6 + 4*X6*Y6*dq24*m_6*C2*CC4*CC5*C6*S3*S6 + 4*X6*Y6*dq24*m_6*C3*CC4*CC5*C6*S2*S6 + 4*X6*Y6*dq26*m_6*C2*C4*CC5*CC6*S3*S4 + 4*X6*Y6*dq26*m_6*C3*C4*CC5*CC6*S2*S4 - 4*X6*Y6*dq14*m_6*CC3*C4*CC5*C6*S4*S6 + 8*X6*Y6*dq15*m_6*CC2*CC3*C5*C6*S5*S6 + 4*X6*Y6*dq34*m_6*C2*CC4*CC5*C6*S3*S6 + 4*X6*Y6*dq34*m_6*C3*CC4*CC5*C6*S2*S6 + 4*X6*Y6*dq36*m_6*C2*C4*CC5*CC6*S3*S4 + 4*X6*Y6*dq36*m_6*C3*C4*CC5*CC6*S2*S4 - 4*X6*Y6*dq15*m_6*CC2*CC4*C5*C6*S5*S6 - 4*X6*Y6*dq15*m_6*CC3*CC4*C5*C6*S5*S6 - 8*X5*Z5*dq12*m_5*C2*CC3*CC4*C5*S2*S5 - 8*X5*Z5*dq12*m_5*CC2*C3*CC4*C5*S3*S5 - 8*X5*Z5*dq13*m_5*C2*CC3*CC4*C5*S2*S5 - 8*X5*Z5*dq15*m_5*C2*C3*CC4*CC5*S2*S3 - 8*X5*Z5*dq13*m_5*CC2*C3*CC4*C5*S3*S5 - 8*X5*Z5*dq14*m_5*CC2*CC3*C4*C5*S4*S5 - 8*X6*Z6*dq14*m_6*C2*CC3*CC5*C6*S2*S4 - 8*X6*Z6*dq14*m_6*CC2*C3*CC5*C6*S3*S4 - 8*X6*Z6*dq16*m_6*C2*CC3*C4*CC5*S2*S6 - 4*X6*Z6*dq15*m_6*CC2*CC3*C4*C5*S4*S6 - 8*X6*Z6*dq16*m_6*CC2*C3*C4*CC5*S3*S6 - 4*X6*Z6*dq16*m_6*CC2*CC3*C4*C6*S4*S5 - 8*X6*d6*dq14*m_6*C2*CC3*CC5*C6*S2*S4 - 8*X6*d6*dq14*m_6*CC2*C3*CC5*C6*S3*S4 - 8*X6*d6*dq16*m_6*C2*CC3*C4*CC5*S2*S6 - 4*X6*d6*dq15*m_6*CC2*CC3*C4*C5*S4*S6 - 8*X6*d6*dq16*m_6*CC2*C3*C4*CC5*S3*S6 - 4*X6*d6*dq16*m_6*CC2*CC3*C4*C6*S4*S5 - 2*X6*Z6*dq22*m_6*C2*C3*C4*C5*C6*S4*S5 - 2*X6*Z6*dq33*m_6*C2*C3*C4*C5*C6*S4*S5 + 8*Y6*Z6*dq14*m_6*C2*CC3*CC5*S2*S4*S6 + 8*Y6*Z6*dq14*m_6*CC2*C3*CC5*S3*S4*S6 + 4*Y6*Z6*dq16*m_6*CC2*CC3*C4*S4*S5*S6 - 2*X6*d6*dq22*m_6*C2*C3*C4*C5*C6*S4*S5 - 2*X6*d6*dq33*m_6*C2*C3*C4*C5*C6*S4*S5 + 8*Y6*d6*dq14*m_6*C2*CC3*CC5*S2*S4*S6 + 8*Y6*d6*dq14*m_6*CC2*C3*CC5*S3*S4*S6 + 4*Y6*d6*dq16*m_6*CC2*CC3*C4*S4*S5*S6 + 2*Y6*Z6*dq22*m_6*C2*C3*C4*C5*S4*S5*S6 + 2*Y6*Z6*dq33*m_6*C2*C3*C4*C5*S4*S5*S6 - 4*Iyz6*dq15*C2*C3*C4*C5*C6*S2*S3*S4 + 8*XX5*dq12*m_5*C2*C3*C4*C5*S2*S3*S5 + 8*XX5*dq13*m_5*C2*C3*C4*C5*S2*S3*S5 - 4*XX6*dq16*m_6*C2*C3*C4*C5*S2*S3*S4 - 4*XX6*dq12*m_6*C2*C4*C5*C6*S2*S4*S6 - 4*XX6*dq14*m_6*C2*C3*C5*C6*S2*S3*S6 - 4*XX6*dq13*m_6*C2*C4*C5*C6*S2*S4*S6 - 4*XX6*dq12*m_6*C3*C4*C5*C6*S3*S4*S6 - 4*XX6*dq13*m_6*C3*C4*C5*C6*S3*S4*S6 + 4*XX6*dq24*m_6*C2*C4*C5*C6*S3*S4*S6 + 4*XX6*dq24*m_6*C3*C4*C5*C6*S2*S4*S6 - 4*XX6*dq16*m_6*C2*C4*C5*C6*S2*S5*S6 + 4*XX6*dq34*m_6*C2*C4*C5*C6*S3*S4*S6 + 4*XX6*dq34*m_6*C3*C4*C5*C6*S2*S4*S6 - 4*XX6*dq16*m_6*C3*C4*C5*C6*S3*S5*S6 + 2*XX6*dq26*m_6*C2*C3*C5*C6*S4*S5*S6 + 2*XX6*dq36*m_6*C2*C3*C5*C6*S4*S5*S6 - 2*XX6*dq46*m_6*C2*C4*C5*C6*S3*S5*S6 - 2*XX6*dq46*m_6*C3*C4*C5*C6*S2*S5*S6 + 2*Y6*d6*dq22*m_6*C2*C3*C4*C5*S4*S5*S6 + 2*Y6*d6*dq33*m_6*C2*C3*C4*C5*S4*S5*S6 + 8*YY6*dq12*m_6*C2*C3*C4*C5*S2*S3*S5 + 8*YY6*dq13*m_6*C2*C3*C4*C5*S2*S3*S5 + 4*YY6*dq16*m_6*C2*C3*C4*C5*S2*S3*S4 + 4*YY6*dq12*m_6*C2*C4*C5*C6*S2*S4*S6 + 4*YY6*dq14*m_6*C2*C3*C5*C6*S2*S3*S6 + 4*YY6*dq13*m_6*C2*C4*C5*C6*S2*S4*S6 + 4*YY6*dq12*m_6*C3*C4*C5*C6*S3*S4*S6 + 4*YY6*dq13*m_6*C3*C4*C5*C6*S3*S4*S6 - 4*YY6*dq24*m_6*C2*C4*C5*C6*S3*S4*S6 - 4*YY6*dq24*m_6*C3*C4*C5*C6*S2*S4*S6 + 4*YY6*dq16*m_6*C2*C4*C5*C6*S2*S5*S6 - 4*YY6*dq34*m_6*C2*C4*C5*C6*S3*S4*S6 - 4*YY6*dq34*m_6*C3*C4*C5*C6*S2*S4*S6 + 4*YY6*dq16*m_6*C3*C4*C5*C6*S3*S5*S6 - 2*YY6*dq26*m_6*C2*C3*C5*C6*S4*S5*S6 - 2*YY6*dq36*m_6*C2*C3*C5*C6*S4*S5*S6 + 2*YY6*dq46*m_6*C2*C4*C5*C6*S3*S5*S6 + 2*YY6*dq46*m_6*C3*C4*C5*C6*S2*S5*S6 - 8*ZZ5*dq12*m_5*C2*C3*C4*C5*S2*S3*S5 - 8*ZZ5*dq13*m_5*C2*C3*C4*C5*S2*S3*S5 - 8*ZZ6*dq12*m_6*C2*C3*C4*C5*S2*S3*S5 - 8*ZZ6*dq13*m_6*C2*C3*C4*C5*S2*S3*S5 - 2*X6*Y6*dq22*m_6*C2*C5*C6*S3*S4*S5*S6 - 2*X6*Y6*dq22*m_6*C3*C5*C6*S2*S4*S5*S6 - 2*X6*Y6*dq33*m_6*C2*C5*C6*S3*S4*S5*S6 - 2*X6*Y6*dq33*m_6*C3*C5*C6*S2*S4*S5*S6 + 2*X6*Y6*dq44*m_6*C2*C5*C6*S3*S4*S5*S6 + 2*X6*Y6*dq44*m_6*C3*C5*C6*S2*S4*S5*S6 + 2*X6*Z6*dq22*m_6*C4*C5*C6*S2*S3*S4*S5 + 2*X6*Z6*dq33*m_6*C4*C5*C6*S2*S3*S4*S5 + 8*Ixy6*dq14*C2*C3*C4*C6*S2*S3*S4*S6 + 8*Ixy6*dq15*C2*C3*C5*C6*S2*S3*S5*S6 + 4*Ixy6*dq25*C2*C4*C5*C6*S3*S4*S5*S6 + 4*Ixy6*dq25*C3*C4*C5*C6*S2*S4*S5*S6 + 4*Ixy6*dq35*C2*C4*C5*C6*S3*S4*S5*S6 + 4*Ixy6*dq35*C3*C4*C5*C6*S2*S4*S5*S6 - 8*Ixz5*dq14*C2*C3*C4*C5*S2*S3*S4*S5 - 4*Ixz6*dq15*C2*C3*C4*C5*S2*S3*S4*S6 - 4*Ixz6*dq16*C2*C3*C4*C6*S2*S3*S4*S5 - 8*dd6*dq12*m_6*C2*C3*C4*C5*S2*S3*S5 - 8*dd6*dq13*m_6*C2*C3*C4*C5*S2*S3*S5 - 4*X6*a2*dq12*m_6*C2*C3*C4*C5*C6*S2 - 2*X6*a2*dq13*m_6*C2*C3*C4*C5*C6*S2 + 2*X6*d6*dq22*m_6*C4*C5*C6*S2*S3*S4*S5 + 2*X6*d6*dq33*m_6*C4*C5*C6*S2*S3*S4*S5 + 4*X6*Y6*dq23*m_6*C2*C3*C4*C6*S4*S6 + 4*X6*Y6*dq26*m_6*C2*C3*C4*C6*S5*S6 + 4*X6*Y6*dq36*m_6*C2*C3*C4*C6*S5*S6 - 4*X6*Y6*dq45*m_6*C2*C3*C5*C6*S5*S6 + 4*X6*Y6*dq56*m_6*C2*C4*C5*C6*S3*S6 + 4*X6*Y6*dq56*m_6*C3*C4*C5*C6*S2*S6 + 8*X6*Z6*dq12*m_6*C2*C3*C4*C6*S2*S3 + 8*X6*Z6*dq13*m_6*C2*C3*C4*C6*S2*S3 - 4*X5*Z5*dq23*m_5*C2*C3*C4*C5*S4*S5 + 8*X6*Z6*dq15*m_6*C2*C4*C5*C6*S2*S5 + 8*X6*Z6*dq15*m_6*C3*C4*C5*C6*S3*S5 - 4*X6*Z6*dq25*m_6*C2*C3*C5*C6*S4*S5 - 4*X6*Z6*dq35*m_6*C2*C3*C5*C6*S4*S5 + 4*X6*Z6*dq45*m_6*C2*C4*C5*C6*S3*S5 + 4*X6*Z6*dq45*m_6*C3*C4*C5*C6*S2*S5 - 2*Y6*Z6*dq22*m_6*C4*C5*S2*S3*S4*S5*S6 - 2*Y6*Z6*dq33*m_6*C4*C5*S2*S3*S4*S5*S6 + 8*Ixx6*dq12*C2*C3*C6*S2*S3*S4*S5*S6 + 8*Ixx6*dq13*C2*C3*C6*S2*S3*S4*S5*S6 - 8*Iyy6*dq12*C2*C3*C6*S2*S3*S4*S5*S6 - 8*Iyy6*dq13*C2*C3*C6*S2*S3*S4*S5*S6
 + 4*Iyz6*dq16*C2*C3*C4*S2*S3*S4*S5*S6 + 4*Y6*a2*dq12*m_6*C2*C3*C4*C5*S2*S6 + 2*Y6*a2*dq13*m_6*C2*C3*C4*C5*S2*S6 + 4*Y6*a3*dq14*m_6*C2*C3*C4*C6*S2*S3 + 2*Y6*a2*dq16*m_6*C2*C4*C5*C6*S2*S3 - 4*Z5*a3*dq15*m_5*C2*C3*C4*C5*S2*S3 - 4*Z6*a3*dq15*m_6*C2*C3*C4*C5*S2*S3 - 2*XX6*dq26*m_6*C5*C6*S2*S3*S4*S5*S6 - 2*XX6*dq36*m_6*C5*C6*S2*S3*S4*S5*S6 - 8*X5*d4*dq12*m_5*C2*C3*C4*C5*S2*S3 - 8*X5*d4*dq13*m_5*C2*C3*C4*C5*S2*S3 + 8*X6*d6*dq12*m_6*C2*C3*C4*C6*S2*S3 + 8*X6*d6*dq13*m_6*C2*C3*C4*C6*S2*S3 - 4*X6*d4*dq15*m_6*C2*C3*C5*C6*S2*S3 + 8*X6*d6*dq15*m_6*C2*C4*C5*C6*S2*S5 + 8*X6*d6*dq15*m_6*C3*C4*C5*C6*S3*S5 - 4*X6*d6*dq25*m_6*C2*C3*C5*C6*S4*S5 - 4*X6*d6*dq35*m_6*C2*C3*C5*C6*S4*S5 + 4*X6*d6*dq45*m_6*C2*C4*C5*C6*S3*S5 + 4*X6*d6*dq45*m_6*C3*C4*C5*C6*S2*S5 - 2*Y6*d6*dq22*m_6*C4*C5*S2*S3*S4*S5*S6 - 2*Y6*d6*dq33*m_6*C4*C5*S2*S3*S4*S5*S6 + 2*YY6*dq26*m_6*C5*C6*S2*S3*S4*S5*S6 + 2*YY6*dq36*m_6*C5*C6*S2*S3*S4*S5*S6 - 4*Y6*Z6*dq16*m_6*CC2*CC3*CC4*C5*C6*S5 + 8*Y5*Z5*dq12*m_5*C2*C3*C5*S2*S3*S4 + 8*Y5*Z5*dq13*m_5*C2*C3*C5*S2*S3*S4 - 8*Y6*Z6*dq12*m_6*C2*C3*C4*S2*S3*S6 - 8*Y6*Z6*dq13*m_6*C2*C3*C4*S2*S3*S6 - 4*Y6*Z6*dq12*m_6*C2*C4*C6*S2*S4*S5 - 4*Y6*Z6*dq14*m_6*C2*C3*C6*S2*S3*S5 - 4*Y6*Z6*dq13*m_6*C2*C4*C6*S2*S4*S5 - 4*Y6*Z6*dq12*m_6*C3*C4*C6*S3*S4*S5 - 4*Y6*Z6*dq13*m_6*C3*C4*C6*S3*S4*S5 - 8*Y6*Z6*dq15*m_6*C2*C4*C5*S2*S5*S6 + 4*Y6*Z6*dq24*m_6*C2*C4*C6*S3*S4*S5 + 4*Y6*Z6*dq24*m_6*C3*C4*C6*S2*S4*S5 + 4*Y6*Z6*dq34*m_6*C2*C4*C6*S3*S4*S5 + 4*Y6*Z6*dq34*m_6*C3*C4*C6*S2*S4*S5 - 8*Y6*Z6*dq15*m_6*C3*C4*C5*S3*S5*S6 + 4*Y6*Z6*dq25*m_6*C2*C3*C5*S4*S5*S6 + 4*Y6*Z6*dq35*m_6*C2*C3*C5*S4*S5*S6 - 4*Y6*Z6*dq45*m_6*C2*C4*C5*S3*S5*S6 - 4*Y6*Z6*dq45*m_6*C3*C4*C5*S2*S5*S6 - 4*a3*d6*dq15*m_6*C2*C3*C4*C5*S2*S3 + 4*X5*a3*dq14*m_5*C2*C3*C5*S2*S3*S4 + 4*X5*a3*dq15*m_5*C2*C3*C4*S2*S3*S5 + 8*X6*a3*dq12*m_6*C2*C3*C6*S2*S3*S5 + 8*X6*a3*dq13*m_6*C2*C3*C6*S2*S3*S5 + 4*X6*a3*dq14*m_6*C2*C3*C4*S2*S3*S6 + 2*X6*a2*dq14*m_6*C2*C5*C6*S2*S3*S4 + 2*X6*a2*dq15*m_6*C2*C4*C6*S2*S3*S5 + 4*X6*a3*dq16*m_6*C2*C3*C6*S2*S3*S4 + 2*X6*a2*dq16*m_6*C2*C4*C5*S2*S3*S6 - 4*Y6*d6*dq16*m_6*CC2*CC3*CC4*C5*C6*S5 + 8*Y6*d4*dq12*m_6*C2*C3*C6*S2*S3*S4 + 8*Y6*d4*dq13*m_6*C2*C3*C6*S2*S3*S4 - 8*Y6*d6*dq12*m_6*C2*C3*C4*S2*S3*S6 - 8*Y6*d6*dq13*m_6*C2*C3*C4*S2*S3*S6 + 4*Y6*d4*dq15*m_6*C2*C3*C5*S2*S3*S6 + 4*Y6*d4*dq16*m_6*C2*C3*C6*S2*S3*S5 - 4*Y6*d6*dq12*m_6*C2*C4*C6*S2*S4*S5 - 4*Y6*d6*dq14*m_6*C2*C3*C6*S2*S3*S5 - 4*Y6*d6*dq13*m_6*C2*C4*C6*S2*S4*S5 - 4*Y6*d6*dq12*m_6*C3*C4*C6*S3*S4*S5 - 4*Y6*d6*dq13*m_6*C3*C4*C6*S3*S4*S5 - 8*Y6*d6*dq15*m_6*C2*C4*C5*S2*S5*S6 + 4*Y6*d6*dq24*m_6*C2*C4*C6*S3*S4*S5 + 4*Y6*d6*dq24*m_6*C3*C4*C6*S2*S4*S5 + 4*Y6*d6*dq34*m_6*C2*C4*C6*S3*S4*S5 + 4*Y6*d6*dq34*m_6*C3*C4*C6*S2*S4*S5 - 8*Y6*d6*dq15*m_6*C3*C4*C5*S3*S5*S6 + 4*Y6*d6*dq25*m_6*C2*C3*C5*S4*S5*S6 + 4*Y6*d6*dq35*m_6*C2*C3*C5*S4*S5*S6 - 4*Y6*d6*dq45*m_6*C2*C4*C5*S3*S5*S6 - 4*Y6*d6*dq45*m_6*C3*C4*C5*S2*S5*S6 - 8*Z5*d4*dq12*m_5*C2*C3*C4*S2*S3*S5 - 8*Z5*d4*dq13*m_5*C2*C3*C4*S2*S3*S5 - 8*Z6*d4*dq12*m_6*C2*C3*C4*S2*S3*S5 - 8*Z6*d4*dq13*m_6*C2*C3*C4*S2*S3*S5 + 8*Z6*d6*dq14*m_6*C2*C3*C4*S2*S3*S4 - 8*Z6*d6*dq15*m_6*C2*C3*C5*S2*S3*S5 - 4*Z6*d6*dq25*m_6*C2*C4*C5*S3*S4*S5 - 4*Z6*d6*dq25*m_6*C3*C4*C5*S2*S4*S5 - 4*Z6*d6*dq35*m_6*C2*C4*C5*S3*S4*S5 - 4*Z6*d6*dq35*m_6*C3*C4*C5*S2*S4*S5 + 8*X6*Y6*dq15*m_6*CC2*CC3*C4*CC6*S4*S5 - 4*X6*Z6*dq16*m_6*CC2*CC3*CC4*C5*S5*S6 - 8*X5*Y5*dq12*m_5*C2*C3*S2*S3*S4*S5 - 8*X5*Y5*dq13*m_5*C2*C3*S2*S3*S4*S5 + 8*X6*Y6*dq12*m_6*C2*C3*S2*S3*S4*S5 + 8*X6*Y6*dq13*m_6*C2*C3*S2*S3*S4*S5 - 4*X6*Y6*dq23*m_6*C4*C6*S2*S3*S4*S6 + 8*X6*Y6*dq16*m_6*C2*C6*S2*S4*S5*S6 + 8*X6*Y6*dq16*m_6*C3*C6*S3*S4*S5*S6 - 4*X6*Y6*dq26*m_6*C4*C6*S2*S3*S5*S6 - 4*X6*Y6*dq36*m_6*C4*C6*S2*S3*S5*S6 + 4*X6*Y6*dq45*m_6*C5*C6*S2*S3*S5*S6 + 4*X6*Y6*dq46*m_6*C2*C6*S3*S4*S5*S6 + 4*X6*Y6*dq46*m_6*C3*C6*S2*S4*S5*S6 + 4*X5*Z5*dq23*m_5*C4*C5*S2*S3*S4*S5 - 4*X6*Z6*dq12*m_6*C2*C4*S2*S4*S5*S6 - 4*X6*Z6*dq14*m_6*C2*C3*S2*S3*S5*S6 - 4*X6*Z6*dq13*m_6*C2*C4*S2*S4*S5*S6 - 4*X6*Z6*dq12*m_6*C3*C4*S3*S4*S5*S6 - 4*X6*Z6*dq13*m_6*C3*C4*S3*S4*S5*S6 + 4*X6*Z6*dq24*m_6*C2*C4*S3*S4*S5*S6 + 4*X6*Z6*dq24*m_6*C3*C4*S2*S4*S5*S6 + 4*X6*Z6*dq34*m_6*C2*C4*S3*S4*S5*S6 + 4*X6*Z6*dq34*m_6*C3*C4*S2*S4*S5*S6 + 4*X6*Z6*dq25*m_6*C5*C6*S2*S3*S4*S5 + 4*X6*Z6*dq35*m_6*C5*C6*S2*S3*S4*S5 - 8*d4*d6*dq12*m_6*C2*C3*C4*S2*S3*S5 - 8*d4*d6*dq13*m_6*C2*C3*C4*S2*S3*S5 - 8*Y6*a3*dq12*m_6*C2*C3*S2*S3*S5*S6 - 8*Y6*a3*dq13*m_6*C2*C3*S2*S3*S5*S6 - 2*Y6*a2*dq14*m_6*C2*C5*S2*S3*S4*S6 - 2*Y6*a2*dq15*m_6*C2*C4*S2*S3*S5*S6 - 4*Y6*a3*dq16*m_6*C2*C3*S2*S3*S4*S6 - 4*X6*d6*dq16*m_6*CC2*CC3*CC4*C5*S5*S6 + 4*Z5*a3*dq14*m_5*C2*C3*S2*S3*S4*S5 + 4*Z6*a3*dq14*m_6*C2*C3*S2*S3*S4*S5 + 8*X6*d4*dq12*m_6*C2*C3*S2*S3*S4*S6 + 8*X6*d4*dq13*m_6*C2*C3*S2*S3*S4*S6 + 4*X6*d4*dq16*m_6*C2*C3*S2*S3*S5*S6 - 4*X6*d6*dq12*m_6*C2*C4*S2*S4*S5*S6 - 4*X6*d6*dq14*m_6*C2*C3*S2*S3*S5*S6 - 4*X6*d6*dq13*m_6*C2*C4*S2*S4*S5*S6 - 4*X6*d6*dq12*m_6*C3*C4*S3*S4*S5*S6 - 4*X6*d6*dq13*m_6*C3*C4*S3*S4*S5*S6 + 4*X6*d6*dq24*m_6*C2*C4*S3*S4*S5*S6 + 4*X6*d6*dq24*m_6*C3*C4*S2*S4*S5*S6 + 4*X6*d6*dq34*m_6*C2*C4*S3*S4*S5*S6 + 4*X6*d6*dq34*m_6*C3*C4*S2*S4*S5*S6 + 4*X6*d6*dq25*m_6*C5*C6*S2*S3*S4*S5 + 4*X6*d6*dq35*m_6*C5*C6*S2*S3*S4*S5 + 2*X6*Y6*dq22*m_6*C2*C3*C4*CC5*C6*S4*S6 + 2*X6*Y6*dq33*m_6*C2*C3*C4*CC5*C6*S4*S6 - 4*Y6*Z6*dq25*m_6*C5*S2*S3*S4*S5*S6 - 4*Y6*Z6*dq35*m_6*C5*S2*S3*S4*S5*S6 + 4*a3*d6*dq14*m_6*C2*C3*S2*S3*S4*S5 - 4*Y6*d6*dq25*m_6*C5*S2*S3*S4*S5*S6 - 4*Y6*d6*dq35*m_6*C5*S2*S3*S4*S5*S6 - 8*Ixx6*dq12*C2*C3*C4*C5*CC6*S2*S3*S5 - 8*Ixx6*dq13*C2*C3*C4*C5*CC6*S2*S3*S5 - 8*Ixx6*dq12*C2*CC3*C4*C5*C6*S2*S4*S6 - 8*Ixx6*dq12*CC2*C3*C4*C5*C6*S3*S4*S6 - 8*Ixx6*dq13*C2*CC3*C4*C5*C6*S2*S4*S6 - 8*Ixx6*dq14*C2*C3*CC4*C5*C6*S2*S3*S6 - 8*Ixx6*dq16*C2*C3*C4*C5*CC6*S2*S3*S4 - 8*Ixx6*dq13*CC2*C3*C4*C5*C6*S3*S4*S6 - 8*Ixx6*dq16*C2*CC3*C4*C5*C6*S2*S5*S6 - 8*Ixx6*dq16*CC2*C3*C4*C5*C6*S3*S5*S6 + 8*Iyy6*dq12*C2*C3*C4*C5*CC6*S2*S3*S5 + 8*Iyy6*dq13*C2*C3*C4*C5*CC6*S2*S3*S5 + 8*Iyy6*dq12*C2*CC3*C4*C5*C6*S2*S4*S6 + 8*Iyy6*dq12*CC2*C3*C4*C5*C6*S3*S4*S6 + 8*Iyy6*dq13*C2*CC3*C4*C5*C6*S2*S4*S6 + 8*Iyy6*dq14*C2*C3*CC4*C5*C6*S2*S3*S6 + 8*Iyy6*dq16*C2*C3*C4*C5*CC6*S2*S3*S4 + 8*Iyy6*dq13*CC2*C3*C4*C5*C6*S3*S4*S6 + 8*Iyy6*dq16*C2*CC3*C4*C5*C6*S2*S5*S6 + 8*Iyy6*dq16*CC2*C3*C4*C5*C6*S3*S5*S6 - 4*Iyz6*dq16*C2*C3*CC4*C5*C6*S2*S3*S5 + 4*XX5*dq14*m_5*C2*C3*C4*CC5*S2*S3*S4 + 4*XX5*dq15*m_5*C2*C3*CC4*C5*S2*S3*S5 + 4*XX6*dq14*m_6*C2*C3*C4*CC6*S2*S3*S4 + 4*XX6*dq15*m_6*C2*C3*C5*CC6*S2*S3*S5 + 4*XX6*dq14*m_6*C2*CC3*C4*C6*S2*S5*S6 + 4*XX6*dq16*m_6*C2*C3*CC4*C6*S2*S3*S6 + 4*XX6*dq14*m_6*CC2*C3*C4*C6*S3*S5*S6 + 4*XX6*dq15*m_6*C2*CC3*C5*C6*S2*S4*S6 + 4*XX6*dq16*m_6*C2*C3*CC5*C6*S2*S3*S6 + 4*XX6*dq15*m_6*CC2*C3*C5*C6*S3*S4*S6 + 2*XX6*dq25*m_6*C2*C4*C5*CC6*S3*S4*S5 + 2*XX6*dq25*m_6*C3*C4*C5*CC6*S2*S4*S5 + 2*XX6*dq35*m_6*C2*C4*C5*CC6*S3*S4*S5 + 2*XX6*dq35*m_6*C3*C4*C5*CC6*S2*S4*S5 + 2*XX6*dq26*m_6*C2*C4*CC5*C6*S3*S4*S6 + 2*XX6*dq26*m_6*C3*C4*CC5*C6*S2*S4*S6 + 2*XX6*dq36*m_6*C2*C4*CC5*C6*S3*S4*S6 + 2*XX6*dq36*m_6*C3*C4*CC5*C6*S2*S4*S6 + 4*YY6*dq14*m_6*C2*C3*C4*CC5*S2*S3*S4 - 4*YY6*dq14*m_6*C2*C3*C4*CC6*S2*S3*S4 + 4*YY6*dq15*m_6*C2*C3*CC4*C5*S2*S3*S5 - 4*YY6*dq15*m_6*C2*C3*C5*CC6*S2*S3*S5 - 4*YY6*dq14*m_6*C2*CC3*C4*C6*S2*S5*S6 - 4*YY6*dq16*m_6*C2*C3*CC4*C6*S2*S3*S6 - 4*YY6*dq14*m_6*CC2*C3*C4*C6*S3*S5*S6 - 4*YY6*dq15*m_6*C2*CC3*C5*C6*S2*S4*S6 - 4*YY6*dq16*m_6*C2*C3*CC5*C6*S2*S3*S6 - 4*YY6*dq15*m_6*CC2*C3*C5*C6*S3*S4*S6 - 2*YY6*dq25*m_6*C2*C4*C5*CC6*S3*S4*S5 - 2*YY6*dq25*m_6*C3*C4*C5*CC6*S2*S4*S5 - 2*YY6*dq35*m_6*C2*C4*C5*CC6*S3*S4*S5 - 2*YY6*dq35*m_6*C3*C4*C5*CC6*S2*S4*S5 - 2*YY6*dq26*m_6*C2*C4*CC5*C6*S3*S4*S6 - 2*YY6*dq26*m_6*C3*C4*CC5*C6*S2*S4*S6 - 2*YY6*dq36*m_6*C2*C4*CC5*C6*S3*S4*S6 - 2*YY6*dq36*m_6*C3*C4*CC5*C6*S2*S4*S6 - 4*ZZ5*dq14*m_5*C2*C3*C4*CC5*S2*S3*S4 - 4*ZZ5*dq15*m_5*C2*C3*CC4*C5*S2*S3*S5 - 4*ZZ6*dq14*m_6*C2*C3*C4*CC5*S2*S3*S4 - 4*ZZ6*dq15*m_6*C2*C3*CC4*C5*S2*S3*S5 - 2*X6*Y6*dq22*m_6*C4*CC5*C6*S2*S3*S4*S6 - 2*X6*Y6*dq33*m_6*C4*CC5*C6*S2*S3*S4*S6 - 4*Y6*Z6*dq14*m_6*C2*CC3*C4*C5*C6*S2 - 4*Y6*Z6*dq14*m_6*CC2*C3*C4*C5*C6*S3 + 8*Ixy6*dq15*C2*C3*C4*CC6*S2*S3*S4*S5 + 8*Ixy6*dq14*C2*CC3*C5*C6*S2*S4*S5*S6 + 8*Ixy6*dq14*CC2*C3*C5*C6*S3*S4*S5*S6 - 4*Ixz6*dq16*C2*C3*CC4*C5*S2*S3*S5*S6 - 4*dd6*dq14*m_6*C2*C3*C4*CC5*S2*S3*S4 - 4*dd6*dq15*m_6*C2*C3*CC4*C5*S2*S3*S5 - 8*X6*a3*dq12*m_6*C2*CC3*C4*C5*C6*S2 - 8*X6*a3*dq12*m_6*CC2*C3*C4*C5*C6*S3 - 8*X6*a3*dq13*m_6*C2*CC3*C4*C5*C6*S2 - 8*X6*a3*dq13*m_6*CC2*C3*C4*C5*C6*S3 - 4*Y6*d4*dq16*m_6*C2*CC3*C4*C5*C6*S2 - 4*Y6*d6*dq14*m_6*C2*CC3*C4*C5*C6*S2 - 4*Y6*d4*dq16*m_6*CC2*C3*C4*C5*C6*S3 - 4*Y6*d6*dq14*m_6*CC2*C3*C4*C5*C6*S3 + 8*X5*Y5*dq12*m_5*C2*CC3*C4*C5*S2*S4 + 8*X5*Y5*dq12*m_5*CC2*C3*C4*C5*S3*S4 + 8*X5*Y5*dq13*m_5*C2*CC3*C4*C5*S2*S4 + 8*X5*Y5*dq14*m_5*C2*C3*CC4*C5*S2*S3 + 8*X5*Y5*dq13*m_5*CC2*C3*C4*C5*S3*S4 - 8*X6*Y6*dq12*m_6*C2*CC3*C4*C5*S2*S4 - 8*X6*Y6*dq12*m_6*CC2*C3*C4*C5*S3*S4 - 8*X6*Y6*dq13*m_6*C2*CC3*C4*C5*S2*S4 - 8*X6*Y6*dq14*m_6*C2*C3*CC4*C5*S2*S3 - 8*X6*Y6*dq13*m_6*CC2*C3*C4*C5*S3*S4 - 8*X6*Y6*dq12*m_6*C2*C4*C5*CC6*S2*S4 - 8*X6*Y6*dq14*m_6*C2*C3*C5*CC6*S2*S3 - 8*X6*Y6*dq13*m_6*C2*C4*C5*CC6*S2*S4 - 8*X6*Y6*dq12*m_6*C3*C4*C5*CC6*S3*S4 - 8*X6*Y6*dq16*m_6*C2*CC3*C4*C5*S2*S5 - 8*X6*Y6*dq13*m_6*C3*C4*C5*CC6*S3*S4 - 8*X6*Y6*dq15*m_6*C2*CC3*C4*C6*S2*S6 - 8*X6*Y6*dq16*m_6*CC2*C3*C4*C5*S3*S5 - 8*X6*Y6*dq15*m_6*CC2*C3*C4*C6*S3*S6 + 8*X6*Y6*dq24*m_6*C2*C4*C5*CC6*S3*S4 + 8*X6*Y6*dq24*m_6*C3*C4*C5*CC6*S2*S4 - 8*X6*Y6*dq12*m_6*CC2*C4*C5*C6*S5*S6 - 8*X6*Y6*dq15*m_6*C2*C4*CC5*C6*S2*S6 - 8*X6*Y6*dq16*m_6*C2*C4*C5*CC6*S2*S5 + 8*X6*Y6*dq34*m_6*C2*C4*C5*CC6*S3*S4 + 8*X6*Y6*dq34*m_6*C3*C4*C5*CC6*S2*S4 - 8*X6*Y6*dq12*m_6*CC3*C4*C5*C6*S5*S6 - 8*X6*Y6*dq13*m_6*CC2*C4*C5*C6*S5*S6 - 8*X6*Y6*dq13*m_6*CC3*C4*C5*C6*S5*S6 - 8*X6*Y6*dq15*m_6*C3*C4*CC5*C6*S3*S6 - 8*X6*Y6*dq16*m_6*C3*C4*C5*CC6*S3*S5 + 4*X6*Y6*dq25*m_6*C2*C3*CC5*C6*S4*S6 + 4*X6*Y6*dq26*m_6*C2*C3*C5*CC6*S4*S5 - 8*X6*Y6*dq16*m_6*CC2*C4*C5*C6*S4*S6 + 8*X6*Y6*dq26*m_6*C2*CC4*C5*C6*S3*S6 + 8*X6*Y6*dq26*m_6*C3*CC4*C5*C6*S2*S6 + 4*X6*Y6*dq35*m_6*C2*C3*CC5*C6*S4*S6 + 4*X6*Y6*dq36*m_6*C2*C3*C5*CC6*S4*S5 - 8*X6*Y6*dq16*m_6*CC3*C4*C5*C6*S4*S6 + 8*X6*Y6*dq36*m_6*C2*CC4*C5*C6*S3*S6
 + 8*X6*Y6*dq36*m_6*C3*CC4*C5*C6*S2*S6 - 4*X6*Y6*dq45*m_6*C2*C4*CC5*C6*S3*S6 - 4*X6*Y6*dq45*m_6*C3*C4*CC5*C6*S2*S6 - 4*X6*Y6*dq46*m_6*C2*C4*C5*CC6*S3*S5 - 4*X6*Y6*dq46*m_6*C3*C4*C5*CC6*S2*S5 - 16*X5*Z5*dq12*m_5*C2*C3*C4*CC5*S2*S3 - 16*X5*Z5*dq13*m_5*C2*C3*C4*CC5*S2*S3 - 16*X5*Z5*dq15*m_5*C2*CC3*C4*C5*S2*S5 - 16*X5*Z5*dq15*m_5*CC2*C3*C4*C5*S3*S5 - 8*X6*Z6*dq12*m_6*C2*CC3*C5*C6*S2*S5 + 4*X6*Z6*dq15*m_6*C2*C3*CC4*C6*S2*S3 + 4*X6*Z6*dq12*m_6*C2*CC4*C5*C6*S2*S5 - 8*X6*Z6*dq12*m_6*CC2*C3*C5*C6*S3*S5 - 8*X6*Z6*dq13*m_6*C2*CC3*C5*C6*S2*S5 - 4*X6*Z6*dq14*m_6*C2*CC3*C4*C5*S2*S6 - 8*X6*Z6*dq15*m_6*C2*C3*CC5*C6*S2*S3 + 4*X6*Z6*dq13*m_6*C2*CC4*C5*C6*S2*S5 - 8*X6*Z6*dq13*m_6*CC2*C3*C5*C6*S3*S5 - 4*X6*Z6*dq14*m_6*CC2*C3*C4*C5*S3*S6 + 4*X6*Z6*dq12*m_6*C3*CC4*C5*C6*S3*S5 - 4*X6*Z6*dq16*m_6*C2*CC3*C5*C6*S2*S4 + 4*X6*Z6*dq13*m_6*C3*CC4*C5*C6*S3*S5 - 4*X6*Z6*dq16*m_6*CC2*C3*C5*C6*S3*S4 + 4*X6*Z6*dq14*m_6*CC2*C4*C5*C6*S4*S5 - 4*X6*Z6*dq24*m_6*C2*CC4*C5*C6*S3*S5 - 4*X6*Z6*dq24*m_6*C3*CC4*C5*C6*S2*S5 - 4*X6*Z6*dq25*m_6*C2*C4*CC5*C6*S3*S4 - 4*X6*Z6*dq25*m_6*C3*C4*CC5*C6*S2*S4 + 4*X6*Z6*dq14*m_6*CC3*C4*C5*C6*S4*S5 - 4*X6*Z6*dq34*m_6*C2*CC4*C5*C6*S3*S5 - 4*X6*Z6*dq34*m_6*C3*CC4*C5*C6*S2*S5 - 4*X6*Z6*dq35*m_6*C2*C4*CC5*C6*S3*S4 - 4*X6*Z6*dq35*m_6*C3*C4*CC5*C6*S2*S4 + 8*Y6*a3*dq12*m_6*C2*CC3*C4*C5*S2*S6 + 8*Y6*a3*dq12*m_6*CC2*C3*C4*C5*S3*S6 + 8*Y6*a3*dq13*m_6*C2*CC3*C4*C5*S2*S6 + 8*Y6*a3*dq13*m_6*CC2*C3*C4*C5*S3*S6 - 4*X6*d4*dq14*m_6*C2*CC3*C5*C6*S2*S4 - 4*X6*d4*dq14*m_6*CC2*C3*C5*C6*S3*S4 - 4*X6*d4*dq15*m_6*C2*CC3*C4*C6*S2*S5 - 8*X6*d6*dq12*m_6*C2*CC3*C5*C6*S2*S5 + 4*X6*d6*dq15*m_6*C2*C3*CC4*C6*S2*S3 - 4*X6*d4*dq15*m_6*CC2*C3*C4*C6*S3*S5 - 4*X6*d4*dq16*m_6*C2*CC3*C4*C5*S2*S6 + 4*X6*d6*dq12*m_6*C2*CC4*C5*C6*S2*S5 - 8*X6*d6*dq12*m_6*CC2*C3*C5*C6*S3*S5 - 8*X6*d6*dq13*m_6*C2*CC3*C5*C6*S2*S5 - 4*X6*d6*dq14*m_6*C2*CC3*C4*C5*S2*S6 - 8*X6*d6*dq15*m_6*C2*C3*CC5*C6*S2*S3 - 4*X6*d4*dq16*m_6*CC2*C3*C4*C5*S3*S6 + 4*X6*d6*dq13*m_6*C2*CC4*C5*C6*S2*S5 - 8*X6*d6*dq13*m_6*CC2*C3*C5*C6*S3*S5 - 4*X6*d6*dq14*m_6*CC2*C3*C4*C5*S3*S6 + 4*X6*d6*dq12*m_6*C3*CC4*C5*C6*S3*S5 - 4*X6*d6*dq16*m_6*C2*CC3*C5*C6*S2*S4 + 4*X6*d6*dq13*m_6*C3*CC4*C5*C6*S3*S5 - 4*X6*d6*dq16*m_6*CC2*C3*C5*C6*S3*S4 + 4*X6*d6*dq14*m_6*CC2*C4*C5*C6*S4*S5 - 4*X6*d6*dq24*m_6*C2*CC4*C5*C6*S3*S5 - 4*X6*d6*dq24*m_6*C3*CC4*C5*C6*S2*S5 - 4*X6*d6*dq25*m_6*C2*C4*CC5*C6*S3*S4 - 4*X6*d6*dq25*m_6*C3*C4*CC5*C6*S2*S4 + 4*X6*d6*dq14*m_6*CC3*C4*C5*C6*S4*S5 - 4*X6*d6*dq34*m_6*C2*CC4*C5*C6*S3*S5 - 4*X6*d6*dq34*m_6*C3*CC4*C5*C6*S2*S5 - 4*X6*d6*dq35*m_6*C2*C4*CC5*C6*S3*S4 - 4*X6*d6*dq35*m_6*C3*C4*CC5*C6*S2*S4 + 8*Y5*Z5*dq12*m_5*C2*CC3*C4*S2*S4*S5 + 8*Y5*Z5*dq12*m_5*CC2*C3*C4*S3*S4*S5 + 8*Y5*Z5*dq13*m_5*C2*CC3*C4*S2*S4*S5 + 8*Y5*Z5*dq14*m_5*C2*C3*CC4*S2*S3*S5 + 8*Y5*Z5*dq13*m_5*CC2*C3*C4*S3*S4*S5 + 8*Y6*Z6*dq12*m_6*C2*CC3*C5*S2*S5*S6 - 4*Y6*Z6*dq15*m_6*C2*C3*CC4*S2*S3*S6 - 4*Y6*Z6*dq12*m_6*C2*CC4*C5*S2*S5*S6 + 8*Y6*Z6*dq12*m_6*CC2*C3*C5*S3*S5*S6 + 8*Y6*Z6*dq13*m_6*C2*CC3*C5*S2*S5*S6 + 8*Y6*Z6*dq15*m_6*C2*C3*CC5*S2*S3*S6 - 4*Y6*Z6*dq13*m_6*C2*CC4*C5*S2*S5*S6 + 8*Y6*Z6*dq13*m_6*CC2*C3*C5*S3*S5*S6 + 4*Y6*Z6*dq15*m_6*C2*CC3*C6*S2*S4*S5 - 4*Y6*Z6*dq12*m_6*C3*CC4*C5*S3*S5*S6 + 4*Y6*Z6*dq15*m_6*CC2*C3*C6*S3*S4*S5 + 4*Y6*Z6*dq16*m_6*C2*CC3*C5*S2*S4*S6 - 4*Y6*Z6*dq13*m_6*C3*CC4*C5*S3*S5*S6 + 4*Y6*Z6*dq16*m_6*CC2*C3*C5*S3*S4*S6 - 4*Y6*Z6*dq14*m_6*CC2*C4*C5*S4*S5*S6 + 4*Y6*Z6*dq24*m_6*C2*CC4*C5*S3*S5*S6 + 4*Y6*Z6*dq24*m_6*C3*CC4*C5*S2*S5*S6 + 4*Y6*Z6*dq25*m_6*C2*C4*CC5*S3*S4*S6 + 4*Y6*Z6*dq25*m_6*C3*C4*CC5*S2*S4*S6 - 4*Y6*Z6*dq14*m_6*CC3*C4*C5*S4*S5*S6 + 4*Y6*Z6*dq34*m_6*C2*CC4*C5*S3*S5*S6 + 4*Y6*Z6*dq34*m_6*C3*CC4*C5*S2*S5*S6 + 4*Y6*Z6*dq35*m_6*C2*C4*CC5*S3*S4*S6 + 4*Y6*Z6*dq35*m_6*C3*C4*CC5*S2*S4*S6 + 4*Y6*d4*dq14*m_6*C2*CC3*C5*S2*S4*S6 + 4*Y6*d4*dq14*m_6*CC2*C3*C5*S3*S4*S6 + 4*Y6*d4*dq15*m_6*C2*CC3*C4*S2*S5*S6 + 8*Y6*d6*dq12*m_6*C2*CC3*C5*S2*S5*S6 - 4*Y6*d6*dq15*m_6*C2*C3*CC4*S2*S3*S6 + 4*Y6*d4*dq15*m_6*CC2*C3*C4*S3*S5*S6 - 4*Y6*d6*dq12*m_6*C2*CC4*C5*S2*S5*S6 + 8*Y6*d6*dq12*m_6*CC2*C3*C5*S3*S5*S6 + 8*Y6*d6*dq13*m_6*C2*CC3*C5*S2*S5*S6 + 8*Y6*d6*dq15*m_6*C2*C3*CC5*S2*S3*S6 - 4*Y6*d6*dq13*m_6*C2*CC4*C5*S2*S5*S6 + 8*Y6*d6*dq13*m_6*CC2*C3*C5*S3*S5*S6 + 4*Y6*d6*dq15*m_6*C2*CC3*C6*S2*S4*S5 - 4*Y6*d6*dq12*m_6*C3*CC4*C5*S3*S5*S6 + 4*Y6*d6*dq15*m_6*CC2*C3*C6*S3*S4*S5 + 4*Y6*d6*dq16*m_6*C2*CC3*C5*S2*S4*S6 - 4*Y6*d6*dq13*m_6*C3*CC4*C5*S3*S5*S6 + 4*Y6*d6*dq16*m_6*CC2*C3*C5*S3*S4*S6 - 4*Y6*d6*dq14*m_6*CC2*C4*C5*S4*S5*S6 + 4*Y6*d6*dq24*m_6*C2*CC4*C5*S3*S5*S6 + 4*Y6*d6*dq24*m_6*C3*CC4*C5*S2*S5*S6 + 4*Y6*d6*dq25*m_6*C2*C4*CC5*S3*S4*S6 + 4*Y6*d6*dq25*m_6*C3*C4*CC5*S2*S4*S6 - 4*Y6*d6*dq14*m_6*CC3*C4*C5*S4*S5*S6 + 4*Y6*d6*dq34*m_6*C2*CC4*C5*S3*S5*S6 + 4*Y6*d6*dq34*m_6*C3*CC4*C5*S2*S5*S6 + 4*Y6*d6*dq35*m_6*C2*C4*CC5*S3*S4*S6 + 4*Y6*d6*dq35*m_6*C3*C4*CC5*S2*S4*S6 - 8*Z6*d6*dq14*m_6*C2*CC3*C5*S2*S4*S5 - 8*Z6*d6*dq14*m_6*CC2*C3*C5*S3*S4*S5 - 4*X6*Y6*dq25*m_6*CC5*C6*S2*S3*S4*S6 - 4*X6*Y6*dq26*m_6*C5*CC6*S2*S3*S4*S5 - 4*X6*Y6*dq35*m_6*CC5*C6*S2*S3*S4*S6 - 4*X6*Y6*dq36*m_6*C5*CC6*S2*S3*S4*S5 + 4*X6*Z6*dq15*m_6*C2*CC3*S2*S4*S5*S6 + 4*X6*Z6*dq15*m_6*CC2*C3*S3*S4*S5*S6 + 4*X6*d6*dq15*m_6*C2*CC3*S2*S4*S5*S6 + 4*X6*d6*dq15*m_6*CC2*C3*S3*S4*S5*S6 + 8*Y6*Z6*dq12*m_6*C2*CC3*CC4*C5*S2*S5*S6 + 8*Y6*Z6*dq12*m_6*CC2*C3*CC4*C5*S3*S5*S6 + 8*Y6*Z6*dq13*m_6*C2*CC3*CC4*C5*S2*S5*S6 + 8*Y6*Z6*dq15*m_6*C2*C3*CC4*CC5*S2*S3*S6 + 8*Y6*Z6*dq13*m_6*CC2*C3*CC4*C5*S3*S5*S6 + 8*Y6*Z6*dq14*m_6*CC2*CC3*C4*C5*S4*S5*S6 + 8*Y6*d6*dq12*m_6*C2*CC3*CC4*C5*S2*S5*S6 + 8*Y6*d6*dq12*m_6*CC2*C3*CC4*C5*S3*S5*S6 + 8*Y6*d6*dq13*m_6*C2*CC3*CC4*C5*S2*S5*S6 + 8*Y6*d6*dq15*m_6*C2*C3*CC4*CC5*S2*S3*S6 + 8*Y6*d6*dq13*m_6*CC2*C3*CC4*C5*S3*S5*S6 + 8*Y6*d6*dq14*m_6*CC2*CC3*C4*C5*S4*S5*S6 + 16*Ixy6*dq12*C2*C3*C4*C5*C6*S2*S3*S5*S6 + 16*Ixy6*dq13*C2*C3*C4*C5*C6*S2*S3*S5*S6 + 16*Ixy6*dq16*C2*C3*C4*C5*C6*S2*S3*S4*S6 - 8*Ixz6*dq14*C2*C3*C4*C5*C6*S2*S3*S4*S5 - 4*X6*Z6*dq23*m_6*C2*C3*C4*C5*C6*S4*S5 + 4*Ixx6*dq15*C2*C3*C4*C6*S2*S3*S4*S5*S6 - 4*Iyy6*dq15*C2*C3*C4*C6*S2*S3*S4*S5*S6 + 8*Iyz6*dq14*C2*C3*C4*C5*S2*S3*S4*S5*S6 + 4*Y6*a3*dq16*m_6*C2*C3*C4*C5*C6*S2*S3 - 8*XX6*dq12*m_6*C2*C3*C6*S2*S3*S4*S5*S6 - 8*XX6*dq13*m_6*C2*C3*C6*S2*S3*S4*S5*S6 - 8*X6*d4*dq12*m_6*C2*C3*C4*C5*C6*S2*S3 - 8*X6*d4*dq13*m_6*C2*C3*C4*C5*C6*S2*S3 - 4*X6*d6*dq23*m_6*C2*C3*C4*C5*C6*S4*S5 + 8*YY6*dq12*m_6*C2*C3*C6*S2*S3*S4*S5*S6 + 8*YY6*dq13*m_6*C2*C3*C6*S2*S3*S4*S5*S6 + 4*Y5*Z5*dq15*m_5*C2*C3*C4*C5*S2*S3*S4 + 8*Y6*Z6*dq12*m_6*C2*C3*C5*C6*S2*S3*S4 + 8*Y6*Z6*dq13*m_6*C2*C3*C5*C6*S2*S3*S4 + 4*Y6*Z6*dq16*m_6*C2*C3*C5*C6*S2*S3*S5 + 4*Y6*Z6*dq23*m_6*C2*C3*C4*C5*S4*S5*S6 + 2*Y6*Z6*dq26*m_6*C2*C4*C5*C6*S3*S4*S5 + 2*Y6*Z6*dq26*m_6*C3*C4*C5*C6*S2*S4*S5 + 2*Y6*Z6*dq36*m_6*C2*C4*C5*C6*S3*S4*S5 + 2*Y6*Z6*dq36*m_6*C3*C4*C5*C6*S2*S4*S5 + 4*X6*a3*dq14*m_6*C2*C3*C5*C6*S2*S3*S4 + 4*X6*a3*dq15*m_6*C2*C3*C4*C6*S2*S3*S5 + 4*X6*a3*dq16*m_6*C2*C3*C4*C5*S2*S3*S6 + 8*Y6*d4*dq12*m_6*C2*C3*C4*C5*S2*S3*S6 + 8*Y6*d4*dq13*m_6*C2*C3*C4*C5*S2*S3*S6 + 8*Y6*d6*dq12*m_6*C2*C3*C5*C6*S2*S3*S4 + 8*Y6*d6*dq13*m_6*C2*C3*C5*C6*S2*S3*S4 + 4*Y6*d6*dq16*m_6*C2*C3*C5*C6*S2*S3*S5 + 4*Y6*d6*dq23*m_6*C2*C3*C4*C5*S4*S5*S6 + 2*Y6*d6*dq26*m_6*C2*C4*C5*C6*S3*S4*S5 + 2*Y6*d6*dq26*m_6*C3*C4*C5*C6*S2*S4*S5 + 2*Y6*d6*dq36*m_6*C2*C4*C5*C6*S3*S4*S5 + 2*Y6*d6*dq36*m_6*C3*C4*C5*C6*S2*S4*S5 - 16*Z6*d6*dq12*m_6*C2*C3*C4*C5*S2*S3*S5 - 16*Z6*d6*dq13*m_6*C2*C3*C4*C5*S2*S3*S5 + 8*X6*Y6*dq12*m_6*C2*CC3*CC4*CC5*C6*S2*S6 + 8*X6*Y6*dq12*m_6*CC2*C3*CC4*CC5*C6*S3*S6 + 8*X6*Y6*dq13*m_6*C2*CC3*CC4*CC5*C6*S2*S6 + 8*X6*Y6*dq16*m_6*C2*C3*CC4*CC5*CC6*S2*S3 + 8*X6*Y6*dq13*m_6*CC2*C3*CC4*CC5*C6*S3*S6 + 8*X6*Y6*dq14*m_6*CC2*CC3*C4*CC5*C6*S4*S6 + 8*X6*Y6*dq15*m_6*CC2*CC3*CC4*C5*C6*S5*S6 - 4*X5*Y5*dq15*m_5*C2*C3*C4*S2*S3*S4*S5 + 4*X6*Y6*dq15*m_6*C2*C3*C4*S2*S3*S4*S5 + 4*X6*Y6*dq14*m_6*C2*C5*C6*S2*S4*S5*S6 - 4*X6*Y6*dq23*m_6*C2*C5*C6*S3*S4*S5*S6 - 4*X6*Y6*dq23*m_6*C3*C5*C6*S2*S4*S5*S6 + 4*X6*Y6*dq14*m_6*C3*C5*C6*S3*S4*S5*S6 + 8*X6*Z6*dq12*m_6*C2*C3*C5*S2*S3*S4*S6 + 8*X6*Z6*dq13*m_6*C2*C3*C5*S2*S3*S4*S6 + 4*X6*Z6*dq16*m_6*C2*C3*C5*S2*S3*S5*S6 + 4*X6*Z6*dq23*m_6*C4*C5*C6*S2*S3*S4*S5 + 2*X6*Z6*dq26*m_6*C2*C4*C5*S3*S4*S5*S6 + 2*X6*Z6*dq26*m_6*C3*C4*C5*S2*S4*S5*S6 + 2*X6*Z6*dq36*m_6*C2*C4*C5*S3*S4*S5*S6 + 2*X6*Z6*dq36*m_6*C3*C4*C5*S2*S4*S5*S6 - 4*Y6*a3*dq14*m_6*C2*C3*C5*S2*S3*S4*S6 - 4*Y6*a3*dq15*m_6*C2*C3*C4*S2*S3*S5*S6 + 8*X6*d6*dq12*m_6*C2*C3*C5*S2*S3*S4*S6 + 8*X6*d6*dq13*m_6*C2*C3*C5*S2*S3*S4*S6 + 4*X6*d6*dq16*m_6*C2*C3*C5*S2*S3*S5*S6 + 4*X6*d6*dq23*m_6*C4*C5*C6*S2*S3*S4*S5 + 2*X6*d6*dq26*m_6*C2*C4*C5*S3*S4*S5*S6 + 2*X6*d6*dq26*m_6*C3*C4*C5*S2*S4*S5*S6 + 2*X6*d6*dq36*m_6*C2*C4*C5*S3*S4*S5*S6 + 2*X6*d6*dq36*m_6*C3*C4*C5*S2*S4*S5*S6 - 4*Y6*Z6*dq23*m_6*C4*C5*S2*S3*S4*S5*S6 - 4*Y6*d6*dq23*m_6*C4*C5*S2*S3*S4*S5*S6 + 8*XX6*dq12*m_6*C2*C3*C4*C5*CC6*S2*S3*S5 + 8*XX6*dq13*m_6*C2*C3*C4*C5*CC6*S2*S3*S5 + 8*XX6*dq12*m_6*C2*CC3*C4*C5*C6*S2*S4*S6 + 8*XX6*dq12*m_6*CC2*C3*C4*C5*C6*S3*S4*S6 + 8*XX6*dq13*m_6*C2*CC3*C4*C5*C6*S2*S4*S6 + 8*XX6*dq14*m_6*C2*C3*CC4*C5*C6*S2*S3*S6 + 8*XX6*dq16*m_6*C2*C3*C4*C5*CC6*S2*S3*S4 + 8*XX6*dq13*m_6*CC2*C3*C4*C5*C6*S3*S4*S6 + 8*XX6*dq16*m_6*C2*CC3*C4*C5*C6*S2*S5*S6 + 8*XX6*dq16*m_6*CC2*C3*C4*C5*C6*S3*S5*S6 - 8*YY6*dq12*m_6*C2*C3*C4*C5*CC6*S2*S3*S5 - 8*YY6*dq13*m_6*C2*C3*C4*C5*CC6*S2*S3*S5 - 8*YY6*dq12*m_6*C2*CC3*C4*C5*C6*S2*S4*S6 - 8*YY6*dq12*m_6*CC2*C3*C4*C5*C6*S3*S4*S6 - 8*YY6*dq13*m_6*C2*CC3*C4*C5*C6*S2*S4*S6 - 8*YY6*dq14*m_6*C2*C3*CC4*C5*C6*S2*S3*S6 - 8*YY6*dq16*m_6*C2*C3*C4*C5*CC6*S2*S3*S4 - 8*YY6*dq13*m_6*CC2*C3*C4*C5*C6*S3*S4*S6 - 8*YY6*dq16*m_6*C2*CC3*C4*C5*C6*S2*S5*S6 - 8*YY6*dq16*m_6*CC2*C3*C4*C5*C6*S3*S5*S6 + 8*Ixy6*dq14*C2*C3*C4*CC5*C6*S2*S3*S4*S6 + 8*Ixy6*dq15*C2*C3*CC4*C5*C6*S2*S3*S5*S6 + 4*X6*Y6*dq23*m_6*C2*C3*C4*CC5*C6*S4*S6 - 16*X6*Z6*dq12*m_6*C2*C3*C4*CC5*C6*S2*S3 - 16*X6*Z6*dq13*m_6*C2*C3*C4*CC5*C6*S2*S3 - 16*X6*Z6*dq15*m_6*C2*CC3*C4*C5*C6*S2*S5 - 16*X6*Z6*dq15*m_6*CC2*C3*C4*C5*C6*S3*S5 - 16*X6*d6*dq12*m_6*C2*C3*C4*CC5*C6*S2*S3 - 16*X6*d6*dq13*m_6*C2*C3*C4*CC5*C6*S2*S3 - 16*X6*d6*dq15*m_6*C2*CC3*C4*C5*C6*S2*S5 - 16*X6*d6*dq15*m_6*CC2*C3*C4*C5*C6*S3*S5 + 16*Y6*Z6*dq12*m_6*C2*C3*C4*CC5*S2*S3*S6
 + 8*Y6*Z6*dq12*m_6*C2*CC3*C4*C6*S2*S4*S5 + 16*Y6*Z6*dq13*m_6*C2*C3*C4*CC5*S2*S3*S6 + 8*Y6*Z6*dq12*m_6*CC2*C3*C4*C6*S3*S4*S5 + 8*Y6*Z6*dq13*m_6*C2*CC3*C4*C6*S2*S4*S5 + 8*Y6*Z6*dq14*m_6*C2*C3*CC4*C6*S2*S3*S5 + 8*Y6*Z6*dq13*m_6*CC2*C3*C4*C6*S3*S4*S5 + 16*Y6*Z6*dq15*m_6*C2*CC3*C4*C5*S2*S5*S6 + 16*Y6*Z6*dq15*m_6*CC2*C3*C4*C5*S3*S5*S6 + 16*Y6*d6*dq12*m_6*C2*C3*C4*CC5*S2*S3*S6 + 8*Y6*d6*dq12*m_6*C2*CC3*C4*C6*S2*S4*S5 + 16*Y6*d6*dq13*m_6*C2*C3*C4*CC5*S2*S3*S6 + 8*Y6*d6*dq12*m_6*CC2*C3*C4*C6*S3*S4*S5 + 8*Y6*d6*dq13*m_6*C2*CC3*C4*C6*S2*S4*S5 + 8*Y6*d6*dq14*m_6*C2*C3*CC4*C6*S2*S3*S5 + 8*Y6*d6*dq13*m_6*CC2*C3*C4*C6*S3*S4*S5 + 16*Y6*d6*dq15*m_6*C2*CC3*C4*C5*S2*S5*S6 + 16*Y6*d6*dq15*m_6*CC2*C3*C4*C5*S3*S5*S6 - 8*Z6*d6*dq14*m_6*C2*C3*C4*CC5*S2*S3*S4 - 8*Z6*d6*dq15*m_6*C2*C3*CC4*C5*S2*S3*S5 - 16*X6*Y6*dq12*m_6*C2*C3*CC6*S2*S3*S4*S5 - 16*X6*Y6*dq13*m_6*C2*C3*CC6*S2*S3*S4*S5 - 16*X6*Y6*dq16*m_6*C2*CC3*C6*S2*S4*S5*S6 - 4*X6*Y6*dq23*m_6*C4*CC5*C6*S2*S3*S4*S6 - 16*X6*Y6*dq16*m_6*CC2*C3*C6*S3*S4*S5*S6 + 8*X6*Z6*dq12*m_6*C2*CC3*C4*S2*S4*S5*S6 + 8*X6*Z6*dq12*m_6*CC2*C3*C4*S3*S4*S5*S6 + 8*X6*Z6*dq13*m_6*C2*CC3*C4*S2*S4*S5*S6 + 8*X6*Z6*dq14*m_6*C2*C3*CC4*S2*S3*S5*S6 + 8*X6*Z6*dq13*m_6*CC2*C3*C4*S3*S4*S5*S6 + 8*X6*d6*dq12*m_6*C2*CC3*C4*S2*S4*S5*S6 + 8*X6*d6*dq12*m_6*CC2*C3*C4*S3*S4*S5*S6 + 8*X6*d6*dq13*m_6*C2*CC3*C4*S2*S4*S5*S6 + 8*X6*d6*dq14*m_6*C2*C3*CC4*S2*S3*S5*S6 + 8*X6*d6*dq13*m_6*CC2*C3*C4*S3*S4*S5*S6 + 4*XX6*dq14*m_6*C2*C3*C4*CC5*CC6*S2*S3*S4 + 4*XX6*dq15*m_6*C2*C3*CC4*C5*CC6*S2*S3*S5 + 4*XX6*dq16*m_6*C2*C3*CC4*CC5*C6*S2*S3*S6 - 4*YY6*dq14*m_6*C2*C3*C4*CC5*CC6*S2*S3*S4 - 4*YY6*dq15*m_6*C2*C3*CC4*C5*CC6*S2*S3*S5 - 4*YY6*dq16*m_6*C2*C3*CC4*CC5*C6*S2*S3*S6 + 16*X6*Y6*dq12*m_6*C2*CC3*C4*C5*CC6*S2*S4 + 16*X6*Y6*dq12*m_6*CC2*C3*C4*C5*CC6*S3*S4 + 16*X6*Y6*dq13*m_6*C2*CC3*C4*C5*CC6*S2*S4 + 16*X6*Y6*dq14*m_6*C2*C3*CC4*C5*CC6*S2*S3 + 16*X6*Y6*dq13*m_6*CC2*C3*C4*C5*CC6*S3*S4 + 16*X6*Y6*dq12*m_6*CC2*CC3*C4*C5*C6*S5*S6 + 16*X6*Y6*dq15*m_6*C2*CC3*C4*CC5*C6*S2*S6 + 16*X6*Y6*dq16*m_6*C2*CC3*C4*C5*CC6*S2*S5 + 16*X6*Y6*dq13*m_6*CC2*CC3*C4*C5*C6*S5*S6 + 16*X6*Y6*dq15*m_6*CC2*C3*C4*CC5*C6*S3*S6 + 16*X6*Y6*dq16*m_6*CC2*C3*C4*C5*CC6*S3*S5 + 16*X6*Y6*dq16*m_6*CC2*CC3*C4*C5*C6*S4*S6 - 8*X6*Z6*dq12*m_6*C2*CC3*CC4*C5*C6*S2*S5 - 8*X6*Z6*dq12*m_6*CC2*C3*CC4*C5*C6*S3*S5 - 8*X6*Z6*dq13*m_6*C2*CC3*CC4*C5*C6*S2*S5 - 8*X6*Z6*dq15*m_6*C2*C3*CC4*CC5*C6*S2*S3 - 8*X6*Z6*dq13*m_6*CC2*C3*CC4*C5*C6*S3*S5 - 8*X6*Z6*dq14*m_6*CC2*CC3*C4*C5*C6*S4*S5 - 8*X6*d6*dq12*m_6*C2*CC3*CC4*C5*C6*S2*S5 - 8*X6*d6*dq12*m_6*CC2*C3*CC4*C5*C6*S3*S5 - 8*X6*d6*dq13*m_6*C2*CC3*CC4*C5*C6*S2*S5 - 8*X6*d6*dq15*m_6*C2*C3*CC4*CC5*C6*S2*S3 - 8*X6*d6*dq13*m_6*CC2*C3*CC4*C5*C6*S3*S5 - 8*X6*d6*dq14*m_6*CC2*CC3*C4*C5*C6*S4*S5 - 4*XX6*dq15*m_6*C2*C3*C4*C6*S2*S3*S4*S5*S6 + 4*YY6*dq15*m_6*C2*C3*C4*C6*S2*S3*S4*S5*S6 + 4*Y6*Z6*dq15*m_6*C2*C3*C4*C5*C6*S2*S3*S4 + 4*Y6*d6*dq15*m_6*C2*C3*C4*C5*C6*S2*S3*S4 - 8*X6*Y6*dq14*m_6*C2*C3*C4*C6*S2*S3*S4*S6 - 8*X6*Y6*dq15*m_6*C2*C3*C5*C6*S2*S3*S5*S6 - 4*X6*Y6*dq25*m_6*C2*C4*C5*C6*S3*S4*S5*S6 - 4*X6*Y6*dq25*m_6*C3*C4*C5*C6*S2*S4*S5*S6 - 4*X6*Y6*dq35*m_6*C2*C4*C5*C6*S3*S4*S5*S6 - 4*X6*Y6*dq35*m_6*C3*C4*C5*C6*S2*S4*S5*S6 + 8*X5*Z5*dq14*m_5*C2*C3*C4*C5*S2*S3*S4*S5 + 4*X6*Z6*dq15*m_6*C2*C3*C4*C5*S2*S3*S4*S6 + 4*X6*Z6*dq16*m_6*C2*C3*C4*C6*S2*S3*S4*S5 + 4*X6*d6*dq15*m_6*C2*C3*C4*C5*S2*S3*S4*S6 + 4*X6*d6*dq16*m_6*C2*C3*C4*C6*S2*S3*S4*S5 - 4*Y6*Z6*dq16*m_6*C2*C3*C4*S2*S3*S4*S5*S6 - 4*Y6*d6*dq16*m_6*C2*C3*C4*S2*S3*S4*S5*S6 + 4*Y6*Z6*dq16*m_6*C2*C3*CC4*C5*C6*S2*S3*S5 + 4*Y6*d6*dq16*m_6*C2*C3*CC4*C5*C6*S2*S3*S5 - 8*X6*Y6*dq15*m_6*C2*C3*C4*CC6*S2*S3*S4*S5 - 8*X6*Y6*dq14*m_6*C2*CC3*C5*C6*S2*S4*S5*S6 - 8*X6*Y6*dq14*m_6*CC2*C3*C5*C6*S3*S4*S5*S6 + 4*X6*Z6*dq16*m_6*C2*C3*CC4*C5*S2*S3*S5*S6 + 4*X6*d6*dq16*m_6*C2*C3*CC4*C5*S2*S3*S5*S6 + 8*X6*d6*dq14*m_6*C2*C3*C4*C5*C6*S2*S3*S4*S5 - 8*Y6*Z6*dq14*m_6*C2*C3*C4*C5*S2*S3*S4*S5*S6 - 8*Y6*d6*dq14*m_6*C2*C3*C4*C5*S2*S3*S4*S5*S6 - 8*X6*Y6*dq14*m_6*C2*C3*C4*CC5*C6*S2*S3*S4*S6 - 8*X6*Y6*dq15*m_6*C2*C3*CC4*C5*C6*S2*S3*S5*S6 - 16*X6*Y6*dq12*m_6*C2*C3*C4*C5*C6*S2*S3*S5*S6 - 16*X6*Y6*dq13*m_6*C2*C3*C4*C5*C6*S2*S3*S5*S6 - 16*X6*Y6*dq16*m_6*C2*C3*C4*C5*C6*S2*S3*S4*S6 + 8*X6*Z6*dq14*m_6*C2*C3*C4*C5*C6*S2*S3*S4*S5;
coriolis.array2d[1][0] = Ixy2*dq11 + Ixz3*dq11 - Ixy4*dq11*C4 - Ixy4*dq44*C4 - Ixz5*dq11*C4 - Ixz5*dq44*C4 + Iyz4*dq11*S4 + Iyz4*dq44*S4 - 2*Ixz4*dq24 - 2*Ixz4*dq34 - 2*Ixz5*dq25 - 2*Ixz5*dq35 - 2*Ixy2*dq11*CC2 - 2*Ixz3*dq11*CC2 - 2*Ixz3*dq11*CC3 - (Ixx2*dq11*S22)/2 + (Ixx3*dq11*S22)/2 + (Ixx3*dq11*S33)/2 - (Ixx5*dq11*S22)/2 - (Ixx5*dq11*S33)/2 + (Ixx6*dq11*S22)/2 + (Ixx6*dq11*S33)/2 + (Iyy2*dq11*S22)/2 - (Iyy4*dq11*S22)/2 - (Iyy4*dq11*S33)/2 + (Iyy5*dq11*S22)/2 + (Iyy5*dq11*S33)/2 - (Iyy6*dq11*S22)/2 - (Iyy6*dq11*S33)/2 - (Izz3*dq11*S22)/2 - (Izz3*dq11*S33)/2 + (Izz4*dq11*S22)/2 + (Izz4*dq11*S33)/2 - Ixz6*dq11*C4*C6 - Ixz6*dq44*C4*C6 + Ixz6*dq66*C4*C6 - Iyz5*dq11*C5*S4 + Iyz6*dq11*C4*S6 - Iyz5*dq44*C5*S4 + Iyz5*dq55*C5*S4 + Iyz6*dq44*C4*S6 - Iyz6*dq66*C4*S6 + Ixy5*dq11*S4*S5 - Ixy6*dq11*S4*S5 + Ixy5*dq44*S4*S5 - Ixy5*dq55*S4*S5 - Ixy6*dq44*S4*S5 + Ixy6*dq55*S4*S5 - X2*Y2*dq11*m_2 - X3*Z3*dq11*m_3 - 2*Ixy5*dq24*C5 - 2*Ixy5*dq34*C5 + 2*Ixy6*dq24*C5 + 2*Ixy6*dq34*C5 - 2*Ixy6*dq56*C4 - 2*Ixz6*dq25*C6 - 2*Ixz6*dq35*C6 - Y2*a2*dq11*m_2 + Y4*a3*dq11*m_4 - Z3*a3*dq11*m_3 - a3*d4*dq11*m_4 - a3*d4*dq11*m_5 - a3*d4*dq11*m_6 + Ixx5*dq45*S4 - Ixx6*dq45*S4 - Iyy5*dq45*S4 + Iyy6*dq45*S4 - 2*Iyz5*dq24*S5 - 2*Iyz5*dq34*S5 + 2*Iyz6*dq25*S6 + 2*Iyz6*dq35*S6 - Izz5*dq45*S4 - Izz6*dq45*S4 + 2*Ixy4*dq11*CC2*C4 + 2*Ixy4*dq11*CC3*C4 + 2*Ixz5*dq11*CC2*C4 + 2*Ixz5*dq11*CC3*C4 + 2*Ixz5*dq11*C4*CC5 + 2*Ixz5*dq44*C4*CC5 - 2*Iyz4*dq11*CC2*S4 - 2*Iyz4*dq11*CC3*S4 + (XX2*dq11*m_2*S22)/2 - (XX3*dq11*m_3*S22)/2 - (XX3*dq11*m_3*S33)/2 + (XX5*dq11*m_5*S22)/2 + (XX5*dq11*m_5*S33)/2 - (XX6*dq11*m_6*S22)/2 - (XX6*dq11*m_6*S33)/2 - (YY2*dq11*m_2*S22)/2 + (YY4*dq11*m_4*S22)/2 + (YY4*dq11*m_4*S33)/2 - (YY5*dq11*m_5*S22)/2 - (YY5*dq11*m_5*S33)/2 + (YY6*dq11*m_6*S22)/2 + (YY6*dq11*m_6*S33)/2 + (ZZ3*dq11*m_3*S22)/2 + (ZZ3*dq11*m_3*S33)/2 - (ZZ4*dq11*m_4*S22)/2 - (ZZ4*dq11*m_4*S33)/2 + (aa2*dq11*m_2*S22)/2 + (aa2*dq11*m_3*S22)/2 + (aa2*dq11*m_4*S22)/2 - (aa3*dq11*m_3*S22)/2 + (aa2*dq11*m_5*S22)/2 - (aa3*dq11*m_3*S33)/2 - (aa3*dq11*m_4*S22)/2 + (aa2*dq11*m_6*S22)/2 - (aa3*dq11*m_4*S33)/2 - (aa3*dq11*m_5*S22)/2 - (aa3*dq11*m_5*S33)/2 - (aa3*dq11*m_6*S22)/2 - (aa3*dq11*m_6*S33)/2 + (dd4*dq11*m_4*S22)/2 + (dd4*dq11*m_4*S33)/2 + (dd4*dq11*m_5*S22)/2 + (dd4*dq11*m_5*S33)/2 + (dd4*dq11*m_6*S22)/2 + (dd4*dq11*m_6*S33)/2 - 2*Ixy6*dq26*CC4 + 2*Ixy6*dq26*CC5 - 2*Ixy6*dq36*CC4 + 2*Ixy6*dq36*CC5 + 4*Ixz4*dq24*CC4 + 4*Ixz4*dq34*CC4 + 2*Ixz5*dq25*CC4 + 4*Ixz5*dq25*CC5 + 2*Ixz5*dq35*CC4 + 4*Ixz5*dq35*CC5 + Ixx4*dq24*S44 + Ixx4*dq34*S44 - Ixx6*dq24*S44 - Ixx5*dq25*S55 - Ixx6*dq34*S44 - Ixx5*dq35*S55 - Iyy5*dq24*S44 - Iyy5*dq34*S44 - Iyy6*dq25*S55 - Iyy6*dq35*S55 - Izz4*dq24*S44 - Izz4*dq34*S44 + Izz5*dq24*S44 + Izz5*dq34*S44 + Izz6*dq24*S44 + Izz5*dq25*S55 + Izz6*dq34*S44 + Izz5*dq35*S55 + Izz6*dq25*S55 + Izz6*dq35*S55 + 4*Ixz3*dq11*CC2*CC3 - Ixz6*dq11*C5*S4*S6 - Ixz6*dq44*C5*S4*S6 + Ixz6*dq55*C5*S4*S6 - Ixz6*dq66*C5*S4*S6 + X4*Y4*dq11*m_4*C4 + X4*Y4*dq44*m_4*C4 + X5*Z5*dq11*m_5*C4 + X5*Z5*dq44*m_5*C4 + Y2*a1*dq11*m_2*C2 - Y4*a2*dq11*m_4*C3 - Y4*a2*dq33*m_4*C3 + Z3*a2*dq11*m_3*C3 + Z3*a2*dq33*m_3*C3 - Z5*a3*dq11*m_5*C5 - Z6*a3*dq11*m_6*C5 + Z5*a3*dq55*m_5*C5 + Z6*a3*dq55*m_6*C5 - X4*d4*dq11*m_4*C4 - X4*d4*dq44*m_4*C4 - Y4*Z4*dq11*m_4*S4 - Y4*Z4*dq44*m_4*S4 + a2*d4*dq11*m_4*C3 + a2*d4*dq11*m_5*C3 + a2*d4*dq11*m_6*C3 + a2*d4*dq33*m_4*C3 + a2*d4*dq33*m_5*C3 + a2*d4*dq33*m_6*C3 - a3*d6*dq11*m_6*C5 + a3*d6*dq55*m_6*C5 - Ixx4*dq14*C2*S3 - Ixx4*dq14*C3*S2 - Ixx5*dq14*C2*S3 - Ixx5*dq14*C3*S2 + Ixx6*dq14*C2*S3 + Ixx6*dq14*C3*S2 + Ixx6*dq46*C4*S5 - Ixx6*dq56*C5*S4 - Iyy4*dq14*C2*S3 - Iyy4*dq14*C3*S2 + Iyy5*dq14*C2*S3 + Iyy5*dq14*C3*S2 - Iyy6*dq14*C2*S3 - Iyy6*dq14*C3*S2 - Iyy6*dq46*C4*S5 + Iyy6*dq56*C5*S4 - 2*Iyz6*dq24*C6*S5 - 2*Iyz6*dq34*C6*S5 + Izz4*dq14*C2*S3 + Izz4*dq14*C3*S2 - Izz5*dq14*C2*S3 - Izz5*dq14*C3*S2 - Izz6*dq14*C2*S3 - Izz6*dq14*C3*S2 + Izz6*dq46*C4*S5 + Izz6*dq56*C5*S4 + X2*a1*dq11*m_2*S2 - X3*a2*dq11*m_3*S3 - X3*a2*dq33*m_3*S3 + X5*a3*dq11*m_5*S5 - X5*a3*dq55*m_5*S5 - 2*XX5*dq45*m_5*S4 + Y5*d4*dq11*m_5*S4 + Y5*d4*dq44*m_5*S4 - 2*YY6*dq45*m_6*S4 + Z4*d4*dq11*m_4*S4 + Z4*d4*dq44*m_4*S4 + a1*a2*dq11*m_2*S2 + a1*a2*dq11*m_3*S2 + a1*a2*dq11*m_4*S2 + a1*a2*dq11*m_5*S2 + a1*a2*dq11*m_6*S2 - a2*a3*dq11*m_3*S3 - a2*a3*dq11*m_4*S3 - a2*a3*dq11*m_5*S3 - a2*a3*dq33*m_3*S3 - a2*a3*dq11*m_6*S3 - a2*a3*dq33*m_4*S3 - a2*a3*dq33*m_5*S3 - a2*a3*dq33*m_6*S3 - 2*Ixz6*dq24*S5*S6 - 2*Ixz6*dq34*S5*S6 + 2*X4*Z4*dq24*m_4 + 2*X4*Z4*dq34*m_4 + 2*X5*Z5*dq25*m_5 + 2*X5*Z5*dq35*m_5 + 2*Ixz6*dq11*CC2*C4*C6 + 2*Ixz6*dq11*CC3*C4*C6 + 2*Ixz6*dq11*C4*CC5*C6 + 2*Ixz6*dq44*C4*CC5*C6 - 2*Ixx3*dq11*C2*CC3*S2 - 2*Ixx3*dq11*CC2*C3*S3 + Ixx4*dq11*C2*CC4*S2 + 2*Ixx5*dq11*C2*CC3*S2 + 2*Ixx5*dq11*CC2*C3*S3 - 2*Ixx6*dq11*C2*CC3*S2 + Ixx4*dq11*C3*CC4*S3 + Ixx5*dq11*C2*CC5*S2 - Ixx6*dq11*C2*CC4*S2 - 2*Ixx6*dq11*CC2*C3*S3 + Ixx5*dq11*C3*CC5*S3 - 2*Ixx6*dq11*C2*CC6*S2 - Ixx6*dq11*C3*CC4*S3 - 2*Ixx6*dq11*C3*CC6*S3 + 2*Iyy4*dq11*C2*CC3*S2 + 2*Iyy4*dq11*CC2*C3*S3 - 2*Iyy5*dq11*C2*CC3*S2 - Iyy5*dq11*C2*CC4*S2 - 2*Iyy5*dq11*CC2*C3*S3 + 2*Iyy6*dq11*C2*CC3*S2 + 2*Iyy6*dq11*CC2*C3*S3 - Iyy5*dq11*C3*CC4*S3 + Iyy6*dq11*C2*CC5*S2 + 2*Iyy6*dq11*C2*CC6*S2 + Iyy6*dq11*C3*CC5*S3 + 2*Iyy6*dq11*C3*CC6*S3 + 2*Iyz5*dq11*CC2*C5*S4 + 2*Iyz5*dq11*CC3*C5*S4 - 2*Iyz6*dq11*CC2*C4*S6 - 2*Iyz6*dq11*CC3*C4*S6 - 2*Iyz6*dq11*C4*CC5*S6 - 2*Iyz6*dq44*C4*CC5*S6 + 2*Izz3*dq11*C2*CC3*S2 + 2*Izz3*dq11*CC2*C3*S3 - 2*Izz4*dq11*C2*CC3*S2 - Izz4*dq11*C2*CC4*S2 - 2*Izz4*dq11*CC2*C3*S3 + Izz5*dq11*C2*CC4*S2 - Izz4*dq11*C3*CC4*S3 - Izz5*dq11*C2*CC5*S2 + Izz6*dq11*C2*CC4*S2 + Izz5*dq11*C3*CC4*S3 - Izz6*dq11*C2*CC5*S2 - Izz5*dq11*C3*CC5*S3 + Izz6*dq11*C3*CC4*S3 - Izz6*dq11*C3*CC5*S3 - 2*Ixy5*dq11*CC2*S4*S5 - 2*Ixy5*dq11*CC3*S4*S5 + 2*Ixy6*dq11*CC2*S4*S5 + 2*Ixy6*dq11*CC3*S4*S5 + 2*Ixy6*dq11*CC6*S4*S5 + 2*Ixy6*dq44*CC6*S4*S5 - 2*Ixy6*dq55*CC6*S4*S5 + 2*X2*Y2*dq11*m_2*CC2 + 2*X3*Z3*dq11*m_3*CC2 + 2*X3*Z3*dq11*m_3*CC3 + 4*Ixy5*dq24*CC4*C5 + 4*Ixy5*dq34*CC4*C5 - 4*Ixy6*dq24*CC4*C5 - 4*Ixy6*dq34*CC4*C5 - 4*Ixy6*dq24*C5*CC6 - 4*Ixy6*dq34*C5*CC6 + 4*Ixy6*dq56*C4*CC6 + 2*Ixz6*dq25*CC4*C6 + 4*Ixz6*dq25*CC5*C6 + 2*Ixz6*dq35*CC4*C6 + 4*Ixz6*dq35*CC5*C6 + 2*Y2*a2*dq11*m_2*CC2 - 2*Y4*a3*dq11*m_4*CC2 - 2*Y4*a3*dq11*m_4*CC3 + 2*Z3*a3*dq11*m_3*CC2 + 2*Z3*a3*dq11*m_3*CC3 + 2*a3*d4*dq11*m_4*CC2 + 2*a3*d4*dq11*m_4*CC3 + 2*a3*d4*dq11*m_5*CC2 + 2*a3*d4*dq11*m_5*CC3 + 2*a3*d4*dq11*m_6*CC2 + 2*a3*d4*dq11*m_6*CC3 - 2*Ixx5*dq45*CC5*S4 + 2*Ixx6*dq45*CC6*S4 - 2*Iyy6*dq45*CC5*S4 - 2*Iyy6*dq45*CC6*S4 + 4*Iyz5*dq24*CC4*S5 + 4*Iyz5*dq34*CC4*S5 - 2*Iyz6*dq25*CC4*S6 - 4*Iyz6*dq25*CC5*S6 - 2*Iyz6*dq35*CC4*S6 - 4*Iyz6*dq35*CC5*S6 + 2*Izz5*dq45*CC5*S4 + 2*Izz6*dq45*CC5*S4 + X2*a2*dq11*m_2*S22 - X3*a3*dq11*m_3*S22 - X3*a3*dq11*m_3*S33 - XX4*dq24*m_4*S44 - XX4*dq34*m_4*S44 + XX5*dq25*m_5*S55 + XX6*dq24*m_6*S44 + XX5*dq35*m_5*S55 + XX6*dq34*m_6*S44 - Y4*d4*dq11*m_4*S22 - Y4*d4*dq11*m_4*S33 + YY5*dq24*m_5*S44 + YY5*dq34*m_5*S44 + YY6*dq25*m_6*S55 + YY6*dq35*m_6*S55 + ZZ4*dq24*m_4*S44 + ZZ4*dq34*m_4*S44 - ZZ5*dq24*m_5*S44 - ZZ5*dq34*m_5*S44 - ZZ5*dq25*m_5*S55 - ZZ6*dq24*m_6*S44 - ZZ5*dq35*m_5*S55 - ZZ6*dq34*m_6*S44 - ZZ6*dq25*m_6*S55 - ZZ6*dq35*m_6*S55 - dd6*dq24*m_6*S44 - dd6*dq34*m_6*S44 - dd6*dq25*m_6*S55 - dd6*dq35*m_6*S55 - 4*Ixy4*dq11*CC2*CC3*C4 - 4*Ixz5*dq11*CC2*CC3*C4 - 4*Ixz5*dq11*CC2*C4*CC5 - 4*Ixz5*dq11*CC3*C4*CC5 + 4*Iyz4*dq11*CC2*CC3*S4 - 2*Ixy6*dq26*CC4*CC5 + 4*Ixy6*dq26*CC4*CC6 - 2*Ixy6*dq36*CC4*CC5 - 4*Ixy6*dq26*CC5*CC6 + 4*Ixy6*dq36*CC4*CC6 - 4*Ixy6*dq36*CC5*CC6 - 4*Ixz5*dq25*CC4*CC5 - 4*Ixz5*dq35*CC4*CC5 - Ixx5*dq11*C4*C5*S5 - Ixx5*dq44*C4*C5*S5 - Iyy6*dq11*C4*C5*S5 - Iyy6*dq44*C4*C5*S5 - Iyz6*dq11*C5*C6*S4 - Iyz6*dq44*C5*C6*S4 + Iyz6*dq55*C5*C6*S4 - Iyz6*dq66*C5*C6*S4 + Izz5*dq11*C4*C5*S5 + Izz6*dq11*C4*C5*S5 + Izz5*dq44*C4*C5*S5 + Izz6*dq44*C4*C5*S5 + X3*a1*dq11*m_3*C2*S3 + X3*a1*dq11*m_3*C3*S2 - X4*a2*dq11*m_4*C4*S3 - X4*a2*dq33*m_4*C4*S3 - X4*a2*dq44*m_4*C4*S3 - X5*a2*dq11*m_5*C3*S5 - X5*a2*dq33*m_5*C3*S5 - X5*a2*dq55*m_5*C3*S5 + X6*a3*dq11*m_6*C6*S5 - X6*a3*dq55*m_6*C6*S5 - X6*a3*dq66*m_6*C6*S5 - 2*XX6*dq14*m_6*C2*S3 - 2*XX6*dq14*m_6*C3*S2 + 2*XX6*dq56*m_6*C5*S4 + Y6*d4*dq11*m_6*C6*S4 - Y6*d6*dq11*m_6*C4*S6 + Y6*d4*dq44*m_6*C6*S4 + Y6*d4*dq66*m_6*C6*S4 - Y6*d6*dq44*m_6*C4*S6 + Y6*d6*dq66*m_6*C4*S6 - 2*YY5*dq14*m_5*C2*S3 - 2*YY5*dq14*m_5*C3*S2 + 2*YY6*dq46*m_6*C4*S5 - Z5*d4*dq11*m_5*C4*S5 - Z6*d4*dq11*m_6*C4*S5 - Z5*d4*dq44*m_5*C4*S5 - Z5*d4*dq55*m_5*C4*S5 - Z6*d4*dq44*m_6*C4*S5 - Z6*d4*dq55*m_6*C4*S5 - 2*ZZ4*dq14*m_4*C2*S3 - 2*ZZ4*dq14*m_4*C3*S2 - X5*Y5*dq11*m_5*S4*S5 - X5*Y5*dq44*m_5*S4*S5 + X6*Y6*dq11*m_6*S4*S5 + X5*Y5*dq55*m_5*S4*S5 + X6*Y6*dq44*m_6*S4*S5 - X6*Y6*dq55*m_6*S4*S5 + a1*a3*dq11*m_3*C2*S3 + a1*a3*dq11*m_3*C3*S2 + a1*a3*dq11*m_4*C2*S3 + a1*a3*dq11*m_4*C3*S2 + a1*a3*dq11*m_5*C2*S3 + a1*a3*dq11*m_5*C3*S2 + a1*a3*dq11*m_6*C2*S3 + a1*a3*dq11*m_6*C3*S2 + 4*Ixy6*dq26*CC4*CC5*CC6 + 4*Ixy6*dq36*CC4*CC5*CC6 - 2*Ixy4*dq14*C4*S2*S3 + 2*Ixy5*dq15*C2*S3*S5 + 2*Ixy5*dq15*C3*S2*S5 - 2*Ixy6*dq15*C2*S3*S5 - 2*Ixy6*dq15*C3*S2*S5 - 2*Ixy5*dq25*C4*S4*S5 - 2*Ixy5*dq35*C4*S4*S5 + 2*Ixy6*dq25*C4*S4*S5 + 2*Ixy6*dq35*C4*S4*S5 - 2*Ixy6*dq46*C5*S4*S5 - 4*Ixy6*dq45*C6*S4*S6 - 2*Ixz5*dq14*C4*S2*S3 - 4*Ixz5*dq45*C5*S4*S5 - 2*Ixz6*dq26*C5*S5*S6 - 2*Ixz6*dq36*C5*S5*S6 - d4*d6*dq11*m_6*C4*S5 - d4*d6*dq44*m_6*C4*S5 - d4*d6*dq55*m_6*C4*S5 - Y4*a1*dq11*m_4*S2*S3 + Y5*a2*dq11*m_5*S3*S4 + Y5*a2*dq33*m_5*S3*S4 + Y5*a2*dq44*m_5*S3*S4 - Y6*a3*dq11*m_6*S5*S6 + Y6*a3*dq55*m_6*S5*S6 + Y6*a3*dq66*m_6*S5*S6 + Z3*a1*dq11*m_3*S2*S3 + Z4*a2*dq11*m_4*S3*S4 + Z4*a2*dq33*m_4*S3*S4 + Z4*a2*dq44*m_4*S3*S4 + X6*d4*dq11*m_6*S4*S6 + X6*d4*dq44*m_6*S4*S6 + X6*d4*dq66*m_6*S4*S6 + 2*X5*Y5*dq24*m_5*C5 + 2*X5*Y5*dq34*m_5*C5 - 2*X6*Y6*dq24*m_6*C5 - 2*X6*Y6*dq34*m_6*C5 + 2*X6*Y6*dq56*m_6*C4 + 2*X6*Z6*dq25*m_6*C6 + 2*X6*Z6*dq35*m_6*C6 + a1*d4*dq11*m_4*S2*S3 + a1*d4*dq11*m_5*S2*S3 + a1*d4*dq11*m_6*S2*S3 + Ixx5*dq15*S2*S3*S4 - Ixx6*dq15*S2*S3*S4 - Iyy5*dq15*S2*S3*S4 + Iyy6*dq15*S2*S3*S4 + 2*Iyz4*dq14*S2*S3*S4 - Izz5*dq15*S2*S3*S4
 - Izz6*dq15*S2*S3*S4
 - 2*Y4*a2*dq23*m_4*C3 - 2*Y5*a3*dq24*m_5*C4 - 2*Y5*a3*dq34*m_5*C4 + 2*Z3*a2*dq23*m_3*C3 - 2*Z4*a3*dq24*m_4*C4 - 2*Z4*a3*dq34*m_4*C4 - 2*X5*d4*dq25*m_5*C5 - 2*X5*d4*dq35*m_5*C5 + 2*X6*d6*dq25*m_6*C6 + 2*X6*d6*dq35*m_6*C6 + 2*Y5*Z5*dq24*m_5*S5 + 2*Y5*Z5*dq34*m_5*S5 - 2*Y6*Z6*dq25*m_6*S6 - 2*Y6*Z6*dq35*m_6*S6 + 2*Ixx5*dq11*CC2*C4*C5*S5 + 2*Ixx5*dq11*CC3*C4*C5*S5 - Ixx6*dq11*C4*C5*CC6*S5 - Ixx6*dq44*C4*C5*CC6*S5 + 2*Iyy6*dq11*CC2*C4*C5*S5 + 2*Iyy6*dq11*CC3*C4*C5*S5 + Iyy6*dq11*C4*C5*CC6*S5 + Iyy6*dq44*C4*C5*CC6*S5 + 2*Iyz6*dq11*CC2*C5*C6*S4 + 2*Iyz6*dq11*CC3*C5*C6*S4 - 2*Izz5*dq11*CC2*C4*C5*S5 - 2*Izz5*dq11*CC3*C4*C5*S5 - 2*Izz6*dq11*CC2*C4*C5*S5 - 2*Izz6*dq11*CC3*C4*C5*S5 + 2*a2*d4*dq23*m_4*C3 + 2*a2*d4*dq23*m_5*C3 + 2*a2*d4*dq23*m_6*C3 - 2*X3*a2*dq23*m_3*S3 - 2*X4*a3*dq24*m_4*S4 - 2*X4*a3*dq34*m_4*S4 + 2*XX3*dq11*m_3*C2*CC3*S2 + 2*XX3*dq11*m_3*CC2*C3*S3 - XX4*dq11*m_4*C2*CC4*S2 - 2*XX5*dq11*m_5*C2*CC3*S2 - XX4*dq11*m_4*C3*CC4*S3 - 2*XX5*dq11*m_5*CC2*C3*S3 - XX5*dq11*m_5*C2*CC5*S2 + 2*XX6*dq11*m_6*C2*CC3*S2 + XX6*dq11*m_6*C2*CC4*S2 + 2*XX6*dq11*m_6*CC2*C3*S3 - XX5*dq11*m_5*C3*CC5*S3 + 2*XX6*dq11*m_6*C2*CC6*S2 + XX6*dq11*m_6*C3*CC4*S3 + 2*XX6*dq11*m_6*C3*CC6*S3 - 2*YY4*dq11*m_4*C2*CC3*S2 - 2*YY4*dq11*m_4*CC2*C3*S3 + 2*YY5*dq11*m_5*C2*CC3*S2 + YY5*dq11*m_5*C2*CC4*S2 + 2*YY5*dq11*m_5*CC2*C3*S3 - 2*YY6*dq11*m_6*C2*CC3*S2 + YY5*dq11*m_5*C3*CC4*S3 - 2*YY6*dq11*m_6*CC2*C3*S3 - YY6*dq11*m_6*C2*CC5*S2 - 2*YY6*dq11*m_6*C2*CC6*S2 - YY6*dq11*m_6*C3*CC5*S3 - 2*YY6*dq11*m_6*C3*CC6*S3 - 2*ZZ3*dq11*m_3*C2*CC3*S2 - 2*ZZ3*dq11*m_3*CC2*C3*S3 + 2*ZZ4*dq11*m_4*C2*CC3*S2 + ZZ4*dq11*m_4*C2*CC4*S2 + 2*ZZ4*dq11*m_4*CC2*C3*S3 + ZZ4*dq11*m_4*C3*CC4*S3 - ZZ5*dq11*m_5*C2*CC4*S2 + ZZ5*dq11*m_5*C2*CC5*S2 - ZZ5*dq11*m_5*C3*CC4*S3 - ZZ6*dq11*m_6*C2*CC4*S2 + ZZ5*dq11*m_5*C3*CC5*S3 + ZZ6*dq11*m_6*C2*CC5*S2 - ZZ6*dq11*m_6*C3*CC4*S3 + ZZ6*dq11*m_6*C3*CC5*S3 - 2*Y6*d6*dq25*m_6*S6 - 2*Y6*d6*dq35*m_6*S6 - 2*Z5*d4*dq25*m_5*S5 - 2*Z5*d4*dq35*m_5*S5 - 2*Z6*d4*dq25*m_6*S5 - 2*Z6*d4*dq35*m_6*S5 - 2*a2*a3*dq23*m_3*S3 - 2*a2*a3*dq23*m_4*S3 - 2*a2*a3*dq23*m_5*S3 - 2*a2*a3*dq23*m_6*S3 + 2*aa3*dq11*m_3*C2*CC3*S2 + 2*aa3*dq11*m_3*CC2*C3*S3 + 2*aa3*dq11*m_4*C2*CC3*S2 + 2*aa3*dq11*m_4*CC2*C3*S3 + 2*aa3*dq11*m_5*C2*CC3*S2 + 2*aa3*dq11*m_5*CC2*C3*S3 + 2*aa3*dq11*m_6*C2*CC3*S2 + 2*aa3*dq11*m_6*CC2*C3*S3 + 2*Ixz6*dq11*CC2*C5*S4*S6 + 2*Ixz6*dq11*CC3*C5*S4*S6 - 2*dd4*dq11*m_4*C2*CC3*S2 - 2*dd4*dq11*m_4*CC2*C3*S3 - 2*dd4*dq11*m_5*C2*CC3*S2 - 2*dd4*dq11*m_5*CC2*C3*S3 - 2*dd4*dq11*m_6*C2*CC3*S2 - 2*dd4*dq11*m_6*CC2*C3*S3 - dd6*dq11*m_6*C2*CC4*S2 + dd6*dq11*m_6*C2*CC5*S2 - dd6*dq11*m_6*C3*CC4*S3 + dd6*dq11*m_6*C3*CC5*S3 - 2*d4*d6*dq25*m_6*S5 - 2*d4*d6*dq35*m_6*S5 - 2*X4*Y4*dq11*m_4*CC2*C4 - 2*X4*Y4*dq11*m_4*CC3*C4 - 2*X5*Z5*dq11*m_5*CC2*C4 - 2*X5*Z5*dq11*m_5*CC3*C4 - 2*X5*Z5*dq11*m_5*C4*CC5 - 2*X5*Z5*dq44*m_5*C4*CC5 + 2*Y4*a2*dq11*m_4*CC2*C3 - 2*Z3*a2*dq11*m_3*CC2*C3 + 2*Z5*a3*dq11*m_5*CC2*C5 + 2*Z5*a3*dq11*m_5*CC3*C5 + 2*Z6*a3*dq11*m_6*CC2*C5 + 2*Z6*a3*dq11*m_6*CC3*C5 + 2*X4*d4*dq11*m_4*CC2*C4 + 2*X4*d4*dq11*m_4*CC3*C4 + 2*Y4*Z4*dq11*m_4*CC2*S4 + 2*Y4*Z4*dq11*m_4*CC3*S4 - 2*a2*d4*dq11*m_4*CC2*C3 - 2*a2*d4*dq11*m_5*CC2*C3 - 2*a2*d4*dq11*m_6*CC2*C3 + 2*a3*d6*dq11*m_6*CC2*C5 + 2*a3*d6*dq11*m_6*CC3*C5 + 2*Ixx4*dq14*C2*CC4*S3 + 2*Ixx4*dq14*C3*CC4*S2 - 2*Ixx6*dq14*C2*CC4*S3 - 2*Ixx6*dq14*C3*CC4*S2 - 2*Ixx6*dq14*C2*CC6*S3 - 2*Ixx6*dq14*C3*CC6*S2 + 2*Ixx5*dq24*C4*CC5*S4 + 2*Ixx5*dq34*C4*CC5*S4 + 2*Ixx5*dq25*CC4*C5*S5 + 2*Ixx6*dq24*C4*CC6*S4 + 2*Ixx5*dq35*CC4*C5*S5 + 2*Ixx6*dq34*C4*CC6*S4 - 2*Ixx6*dq25*C5*CC6*S5 + 2*Ixx6*dq26*CC4*C6*S6 - 2*Ixx6*dq35*C5*CC6*S5 - 2*Ixx6*dq26*CC5*C6*S6 + 2*Ixx6*dq36*CC4*C6*S6 - 2*Ixx6*dq46*C4*CC6*S5 - 2*Ixx6*dq36*CC5*C6*S6 + 2*Ixx6*dq56*C5*CC6*S4 - 2*Iyy5*dq14*C2*CC4*S3 - 2*Iyy5*dq14*C3*CC4*S2 + 2*Iyy6*dq14*C2*CC6*S3 + 2*Iyy6*dq14*C3*CC6*S2 + 2*Iyy6*dq24*C4*CC5*S4 - 2*Iyy6*dq24*C4*CC6*S4 + 2*Iyy6*dq34*C4*CC5*S4 + 2*Iyy6*dq25*CC4*C5*S5 - 2*Iyy6*dq34*C4*CC6*S4 + 2*Iyy6*dq35*CC4*C5*S5 + 2*Iyy6*dq25*C5*CC6*S5 - 2*Iyy6*dq26*CC4*C6*S6 + 2*Iyy6*dq35*C5*CC6*S5 + 2*Iyy6*dq26*CC5*C6*S6 - 2*Iyy6*dq36*CC4*C6*S6 + 2*Iyy6*dq46*C4*CC6*S5 + 2*Iyy6*dq36*CC5*C6*S6 - 2*Iyy6*dq56*C5*CC6*S4 + 4*Iyz6*dq24*CC4*C6*S5 + 4*Iyz6*dq34*CC4*C6*S5 - 2*Iyz6*dq46*CC5*C6*S4 - 2*Izz4*dq14*C2*CC4*S3 - 2*Izz4*dq14*C3*CC4*S2 + 2*Izz5*dq14*C2*CC4*S3 + 2*Izz5*dq14*C3*CC4*S2 + 2*Izz6*dq14*C2*CC4*S3 + 2*Izz6*dq14*C3*CC4*S2 - 2*Izz5*dq24*C4*CC5*S4 - 2*Izz5*dq34*C4*CC5*S4 - 2*Izz6*dq24*C4*CC5*S4 - 2*Izz5*dq25*CC4*C5*S5 - 2*Izz6*dq34*C4*CC5*S4 - 2*Izz5*dq35*CC4*C5*S5 - 2*Izz6*dq25*CC4*C5*S5 - 2*Izz6*dq35*CC4*C5*S5 + 2*X3*a2*dq11*m_3*CC2*S3 - 2*X5*a3*dq11*m_5*CC2*S5 - 2*X5*a3*dq11*m_5*CC3*S5 + 2*XX5*dq45*m_5*CC5*S4 - 2*XX6*dq45*m_6*CC6*S4 - 2*Y5*d4*dq11*m_5*CC2*S4 - 2*Y5*d4*dq11*m_5*CC3*S4 + 2*YY6*dq45*m_6*CC5*S4 + 2*YY6*dq45*m_6*CC6*S4 - 2*Z4*d4*dq11*m_4*CC2*S4 - 2*Z4*d4*dq11*m_4*CC3*S4 - 2*ZZ5*dq45*m_5*CC5*S4 - 2*ZZ6*dq45*m_6*CC5*S4 + 2*a2*a3*dq11*m_3*CC2*S3 + 2*a2*a3*dq11*m_4*CC2*S3 + 2*a2*a3*dq11*m_5*CC2*S3 + 2*a2*a3*dq11*m_6*CC2*S3 + 4*Ixz6*dq24*CC4*S5*S6 + 4*Ixz6*dq34*CC4*S5*S6 - 2*Ixz6*dq46*CC5*S4*S6 - 2*dd6*dq45*m_6*CC5*S4 + 2*X6*Y6*dq26*m_6*CC4 - 2*X6*Y6*dq26*m_6*CC5 + 2*X6*Y6*dq36*m_6*CC4 - 2*X6*Y6*dq36*m_6*CC5 - 4*X4*Z4*dq24*m_4*CC4 - 4*X4*Z4*dq34*m_4*CC4 - 2*X5*Z5*dq25*m_5*CC4 - 4*X5*Z5*dq25*m_5*CC5 - 2*X5*Z5*dq35*m_5*CC4 - 4*X5*Z5*dq35*m_5*CC5 - 4*Ixz6*dq11*CC2*CC3*C4*C6 - 4*Ixz6*dq11*CC2*C4*CC5*C6 - 4*Ixz6*dq11*CC3*C4*CC5*C6 - 2*Ixx4*dq11*C2*CC3*CC4*S2 - 2*Ixx4*dq11*CC2*C3*CC4*S3 - 2*Ixx5*dq11*C2*CC3*CC5*S2 + 2*Ixx6*dq11*C2*CC3*CC4*S2 + Ixx5*dq11*C2*CC4*CC5*S2 - 2*Ixx5*dq11*CC2*C3*CC5*S3 + 2*Ixx6*dq11*CC2*C3*CC4*S3 + 4*Ixx6*dq11*C2*CC3*CC6*S2 + Ixx5*dq11*C3*CC4*CC5*S3 + Ixx6*dq11*C2*CC4*CC6*S2 + 4*Ixx6*dq11*CC2*C3*CC6*S3 + Ixx6*dq11*C2*CC5*CC6*S2 + Ixx6*dq11*C3*CC4*CC6*S3 + Ixx6*dq11*C3*CC5*CC6*S3 + 2*Iyy5*dq11*C2*CC3*CC4*S2 + 2*Iyy5*dq11*CC2*C3*CC4*S3 - 2*Iyy6*dq11*C2*CC3*CC5*S2 - 4*Iyy6*dq11*C2*CC3*CC6*S2 + Iyy6*dq11*C2*CC4*CC5*S2 - 2*Iyy6*dq11*CC2*C3*CC5*S3 - Iyy6*dq11*C2*CC4*CC6*S2 - 4*Iyy6*dq11*CC2*C3*CC6*S3 - Iyy6*dq11*C2*CC5*CC6*S2 + Iyy6*dq11*C3*CC4*CC5*S3 - Iyy6*dq11*C3*CC4*CC6*S3 - Iyy6*dq11*C3*CC5*CC6*S3 - 4*Iyz5*dq11*CC2*CC3*C5*S4 + 4*Iyz6*dq11*CC2*CC3*C4*S6 + 4*Iyz6*dq11*CC2*C4*CC5*S6 + 4*Iyz6*dq11*CC3*C4*CC5*S6 + 2*Izz4*dq11*C2*CC3*CC4*S2 + 2*Izz4*dq11*CC2*C3*CC4*S3 - 2*Izz5*dq11*C2*CC3*CC4*S2 + 2*Izz5*dq11*C2*CC3*CC5*S2 - 2*Izz5*dq11*CC2*C3*CC4*S3 - 2*Izz6*dq11*C2*CC3*CC4*S2 - Izz5*dq11*C2*CC4*CC5*S2 + 2*Izz5*dq11*CC2*C3*CC5*S3 + 2*Izz6*dq11*C2*CC3*CC5*S2 - 2*Izz6*dq11*CC2*C3*CC4*S3 - Izz6*dq11*C2*CC4*CC5*S2 + 2*Izz6*dq11*CC2*C3*CC5*S3 - Izz5*dq11*C3*CC4*CC5*S3 - Izz6*dq11*C3*CC4*CC5*S3 - 2*Z6*d6*dq24*m_6*S44 - 2*Z6*d6*dq34*m_6*S44 - 2*Z6*d6*dq25*m_6*S55 - 2*Z6*d6*dq35*m_6*S55 + 4*Ixy5*dq11*CC2*CC3*S4*S5 - 4*Ixy6*dq11*CC2*CC3*S4*S5 - 4*Ixy6*dq11*CC2*CC6*S4*S5 - 4*Ixy6*dq11*CC3*CC6*S4*S5 - 4*X3*Z3*dq11*m_3*CC2*CC3 + 8*Ixy6*dq24*CC4*C5*CC6 + 8*Ixy6*dq34*CC4*C5*CC6 - 4*Ixz6*dq25*CC4*CC5*C6 - 4*Ixz6*dq35*CC4*CC5*C6 + 4*Y4*a3*dq11*m_4*CC2*CC3 - 4*Z3*a3*dq11*m_3*CC2*CC3 - 4*a3*d4*dq11*m_4*CC2*CC3 - 4*a3*d4*dq11*m_5*CC2*CC3 - 4*a3*d4*dq11*m_6*CC2*CC3 - 2*Ixx6*dq45*CC5*CC6*S4 + 2*Iyy6*dq45*CC5*CC6*S4 + 4*Iyz6*dq25*CC4*CC5*S6 + 4*Iyz6*dq35*CC4*CC5*S6 + XX5*dq11*m_5*C4*C5*S5 + XX5*dq44*m_5*C4*C5*S5 + YY6*dq11*m_6*C4*C5*S5 + YY6*dq44*m_6*C4*C5*S5 - ZZ5*dq11*m_5*C4*C5*S5 - ZZ6*dq11*m_6*C4*C5*S5 - ZZ5*dq44*m_5*C4*C5*S5 - ZZ6*dq44*m_6*C4*C5*S5 + 8*Ixz5*dq11*CC2*CC3*C4*CC5 + 4*Ixy6*dq11*C2*C6*S2*S6 + 4*Ixy6*dq11*C3*C6*S3*S6 - 4*Ixz3*dq11*C2*C3*S2*S3 - 2*Ixz4*dq11*C2*C4*S2*S4 - 2*Ixz4*dq11*C3*C4*S3*S4 + 2*Ixz5*dq11*C2*C5*S2*S5 + 2*Ixz5*dq11*C3*C5*S3*S5 - dd6*dq11*m_6*C4*C5*S5 - dd6*dq44*m_6*C4*C5*S5 + X6*Z6*dq11*m_6*C4*C6 + X6*Z6*dq44*m_6*C4*C6 - X6*Z6*dq66*m_6*C4*C6 + Ixx6*dq11*C6*S4*S5*S6 + Ixx6*dq44*C6*S4*S5*S6 - Ixx6*dq55*C6*S4*S5*S6 - Iyy6*dq11*C6*S4*S5*S6 - Iyy6*dq44*C6*S4*S5*S6 + Iyy6*dq55*C6*S4*S5*S6 + 2*Ixy4*dq14*C2*C3*C4 + 2*Ixz5*dq14*C2*C3*C4 + 2*Ixz6*dq46*C4*C5*C6 + Y4*a1*dq11*m_4*C2*C3 - Z3*a1*dq11*m_3*C2*C3 + Z5*a2*dq11*m_5*C3*C5 + Z5*a2*dq33*m_5*C3*C5 + Z6*a2*dq11*m_6*C3*C5 + Z5*a2*dq55*m_5*C3*C5 + Z6*a2*dq33*m_6*C3*C5 + Z6*a2*dq55*m_6*C3*C5 - X5*d4*dq11*m_5*C4*C5 - X5*d4*dq44*m_5*C4*C5 - X5*d4*dq55*m_5*C4*C5 + X6*d6*dq11*m_6*C4*C6 + X6*d6*dq44*m_6*C4*C6 - X6*d6*dq66*m_6*C4*C6 + Y5*Z5*dq11*m_5*C5*S4 + Y5*Z5*dq44*m_5*C5*S4 - Y5*Z5*dq55*m_5*C5*S4 - Y6*Z6*dq11*m_6*C4*S6 - Y6*Z6*dq44*m_6*C4*S6 + Y6*Z6*dq66*m_6*C4*S6 - a1*d4*dq11*m_4*C2*C3 - a1*d4*dq11*m_5*C2*C3 - a1*d4*dq11*m_6*C2*C3 + a2*d6*dq11*m_6*C3*C5 + a2*d6*dq33*m_6*C3*C5 + a2*d6*dq55*m_6*C3*C5 - Ixx5*dq15*C2*C3*S4 + Ixx6*dq15*C2*C3*S4 + Ixx6*dq16*C2*C5*S3 + Ixx6*dq16*C3*C5*S2 - 2*Ixx6*dq26*C4*C5*S4 - 2*Ixx6*dq36*C4*C5*S4 - 2*Ixx6*dq24*C5*C6*S6 - 2*Ixx6*dq34*C5*C6*S6 + 2*Ixx6*dq56*C4*C6*S6 + Iyy5*dq15*C2*C3*S4 - Iyy6*dq15*C2*C3*S4 - Iyy6*dq16*C2*C5*S3 - Iyy6*dq16*C3*C5*S2 + 2*Iyy6*dq26*C4*C5*S4 + 2*Iyy6*dq36*C4*C5*S4 + 2*Iyy6*dq24*C5*C6*S6 + 2*Iyy6*dq34*C5*C6*S6 - 2*Iyy6*dq56*C4*C6*S6 - 2*Iyz4*dq14*C2*C3*S4 - 2*Iyz5*dq15*C2*C5*S3 - 2*Iyz5*dq15*C3*C5*S2 + 2*Iyz5*dq25*C4*C5*S4 + 2*Iyz5*dq35*C4*C5*S4 - 2*Iyz6*dq26*C5*C6*S5 - 2*Iyz6*dq36*C5*C6*S5 - 2*Iyz6*dq46*C4*C5*S6 + Izz5*dq15*C2*C3*S4 + Izz6*dq15*C2*C3*S4 - Izz6*dq16*C2*C5*S3 - Izz6*dq16*C3*C5*S2 + 2*Y6*Z6*dq24*m_6*C6*S5 + 2*Y6*Z6*dq34*m_6*C6*S5 + 2*Ixy5*dq14*S2*S3*S4*S5 - 2*Ixy6*dq14*S2*S3*S4*S5 + 2*a2*d6*dq23*m_6*C3*C5 + 2*a3*d6*dq25*m_6*C4*C5 + 2*a3*d6*dq35*m_6*C4*C5 - 2*X4*a2*dq14*m_4*C4*S2 - 2*X4*a2*dq23*m_4*C4*S3 - 2*X4*a2*dq24*m_4*C3*S4 - 2*X4*a2*dq34*m_4*C3*S4 - 2*X5*a2*dq23*m_5*C3*S5 - 2*X5*a2*dq25*m_5*C5*S3 - 2*X5*a2*dq35*m_5*C5*S3 - 2*X5*a3*dq24*m_5*C5*S4 - 2*X5*a3*dq25*m_5*C4*S5 - 2*X5*a3*dq34*m_5*C5*S4 - 2*X5*a3*dq35*m_5*C4*S5 - 2*X6*a3*dq24*m_6*C4*S6 - 2*X6*a3*dq34*m_6*C4*S6 - 2*X6*a3*dq26*m_6*C6*S4 - 2*X6*a3*dq36*m_6*C6*S4 - 2*X6*a3*dq56*m_6*C5*S6 - 2*XX5*dq11*m_5*CC2*C4*C5*S5 - 2*XX5*dq11*m_5*CC3*C4*C5*S5 + XX6*dq11*m_6*C4*C5*CC6*S5 + XX6*dq44*m_6*C4*C5*CC6*S5 - 2*YY6*dq11*m_6*CC2*C4*C5*S5 - 2*YY6*dq11*m_6*CC3*C4*C5*S5 - YY6*dq11*m_6*C4*C5*CC6*S5 - YY6*dq44*m_6*C4*C5*CC6*S5
 + 2*ZZ5*dq11*m_5*CC2*C4*C5*S5 + 2*ZZ5*dq11*m_5*CC3*C4*C5*S5 + 2*ZZ6*dq11*m_6*CC2*C4*C5*S5 + 2*ZZ6*dq11*m_6*CC3*C4*C5*S5 + 2*Y6*d4*dq25*m_6*C5*S6 + 2*Y6*d4*dq26*m_6*C6*S5 + 2*Y6*d4*dq35*m_6*C5*S6 + 2*Y6*d6*dq24*m_6*C6*S5 + 2*Y6*d4*dq36*m_6*C6*S5 + 2*Y6*d4*dq46*m_6*C4*S6 + 2*Y6*d6*dq34*m_6*C6*S5 - 2*Z5*d4*dq45*m_5*C5*S4 - 2*Z6*d4*dq45*m_6*C5*S4 + 2*X6*Z6*dq24*m_6*S5*S6 + 2*X6*Z6*dq34*m_6*S5*S6 - 8*Ixy6*dq11*C2*CC3*C6*S2*S6 - 2*Ixy6*dq11*C2*CC4*C6*S2*S6 - 8*Ixy6*dq11*CC2*C3*C6*S3*S6 - 2*Ixy6*dq11*C2*CC5*C6*S2*S6 - 2*Ixy6*dq11*C3*CC4*C6*S3*S6 - 2*Ixy6*dq11*C3*CC5*C6*S3*S6 + 4*Ixz4*dq11*C2*CC3*C4*S2*S4 + 4*Ixz4*dq11*CC2*C3*C4*S3*S4 - 4*Ixz5*dq11*C2*CC3*C5*S2*S5 + 2*Ixz5*dq11*C2*CC4*C5*S2*S5 - 4*Ixz5*dq11*CC2*C3*C5*S3*S5 + 2*Ixz5*dq11*C3*CC4*C5*S3*S5 + 2*dd6*dq11*m_6*CC2*C4*C5*S5 + 2*dd6*dq11*m_6*CC3*C4*C5*S5 - 2*d4*d6*dq45*m_6*C5*S4 + 2*Y5*a2*dq14*m_5*S2*S4 + 2*Y5*a2*dq23*m_5*S3*S4 + 2*Y6*a3*dq26*m_6*S4*S6 + 2*Y6*a3*dq36*m_6*S4*S6 + 2*Z4*a2*dq14*m_4*S2*S4 + 2*Z4*a2*dq23*m_4*S3*S4 - 2*Z5*a2*dq25*m_5*S3*S5 - 2*Z5*a2*dq35*m_5*S3*S5 - 2*Z5*a3*dq24*m_5*S4*S5 - 2*Z5*a3*dq34*m_5*S4*S5 - 2*Z6*a2*dq25*m_6*S3*S5 - 2*Z6*a2*dq35*m_6*S3*S5 - 2*Z6*a3*dq24*m_6*S4*S5 - 2*Z6*a3*dq34*m_6*S4*S5 + 2*X5*d4*dq45*m_5*S4*S5 + 2*X6*d4*dq26*m_6*S5*S6 + 2*X6*d6*dq24*m_6*S5*S6 + 2*X6*d4*dq36*m_6*S5*S6 + 2*X6*d6*dq34*m_6*S5*S6 - 2*X6*Z6*dq11*m_6*CC2*C4*C6 - 2*X6*Z6*dq11*m_6*CC3*C4*C6 - 2*X6*Z6*dq11*m_6*C4*CC5*C6 - 2*X6*Z6*dq44*m_6*C4*CC5*C6 - 2*Ixx6*dq11*CC2*C6*S4*S5*S6 - 2*Ixx6*dq11*CC3*C6*S4*S5*S6 + 2*Iyy6*dq11*CC2*C6*S4*S5*S6 + 2*Iyy6*dq11*CC3*C6*S4*S5*S6 - 4*Ixz5*dq14*C2*C3*C4*CC5 - 2*a2*d6*dq25*m_6*S3*S5 - 2*a2*d6*dq35*m_6*S3*S5 - 2*a3*d6*dq24*m_6*S4*S5 - 2*a3*d6*dq34*m_6*S4*S5 - 2*Z5*a2*dq11*m_5*CC2*C3*C5 - 2*Z6*a2*dq11*m_6*CC2*C3*C5 + 2*X5*d4*dq11*m_5*CC2*C4*C5 + 2*X5*d4*dq11*m_5*CC3*C4*C5 - 2*X6*d6*dq11*m_6*CC2*C4*C6 - 2*X6*d6*dq11*m_6*CC3*C4*C6 - 2*X6*d6*dq11*m_6*C4*CC5*C6 - 2*X6*d6*dq44*m_6*C4*CC5*C6 - 2*Y5*Z5*dq11*m_5*CC2*C5*S4 - 2*Y5*Z5*dq11*m_5*CC3*C5*S4 + 2*Y6*Z6*dq11*m_6*CC2*C4*S6 + 2*Y6*Z6*dq11*m_6*CC3*C4*S6 + 2*Y6*Z6*dq11*m_6*C4*CC5*S6 + 2*Y6*Z6*dq44*m_6*C4*CC5*S6 - 2*a2*d6*dq11*m_6*CC2*C3*C5 + 2*Ixx5*dq15*C2*C3*CC5*S4 - 2*Ixx6*dq15*C2*C3*CC6*S4 - 2*Ixx6*dq16*C2*CC4*C5*S3 - 2*Ixx6*dq16*C3*CC4*C5*S2 - 2*Ixx6*dq16*C2*C5*CC6*S3 - 2*Ixx6*dq16*C3*C5*CC6*S2 + 4*Ixx6*dq24*CC4*C5*C6*S6 + 4*Ixx6*dq26*C4*C5*CC6*S4 + 4*Ixx6*dq34*CC4*C5*C6*S6 + 4*Ixx6*dq36*C4*C5*CC6*S4 + 2*Iyy6*dq15*C2*C3*CC5*S4 + 2*Iyy6*dq15*C2*C3*CC6*S4 + 2*Iyy6*dq16*C2*CC4*C5*S3 + 2*Iyy6*dq16*C3*CC4*C5*S2 + 2*Iyy6*dq16*C2*C5*CC6*S3 + 2*Iyy6*dq16*C3*C5*CC6*S2 - 4*Iyy6*dq24*CC4*C5*C6*S6 - 4*Iyy6*dq26*C4*C5*CC6*S4 - 4*Iyy6*dq34*CC4*C5*C6*S6 - 4*Iyy6*dq36*C4*C5*CC6*S4 + 2*Iyz5*dq15*C2*CC4*C5*S3 + 2*Iyz5*dq15*C3*CC4*C5*S2 + 2*Iyz6*dq26*CC4*C5*C6*S5 + 2*Iyz6*dq36*CC4*C5*C6*S5 - 2*Izz5*dq15*C2*C3*CC5*S4 - 2*Izz6*dq15*C2*C3*CC5*S4 + 4*X3*a3*dq11*m_3*C2*CC3*S2 + 4*X3*a3*dq11*m_3*CC2*C3*S3 + 2*X4*a2*dq11*m_4*CC2*C4*S3 + 2*X5*a2*dq11*m_5*CC2*C3*S5 - 2*X6*a3*dq11*m_6*CC2*C6*S5 - 2*X6*a3*dq11*m_6*CC3*C6*S5 - 2*XX4*dq14*m_4*C2*CC4*S3 - 2*XX4*dq14*m_4*C3*CC4*S2 + 2*XX6*dq14*m_6*C2*CC4*S3 + 2*XX6*dq14*m_6*C3*CC4*S2 + 2*XX6*dq14*m_6*C2*CC6*S3 + 2*XX6*dq14*m_6*C3*CC6*S2 - 2*XX5*dq24*m_5*C4*CC5*S4 - 2*XX5*dq34*m_5*C4*CC5*S4 - 2*XX5*dq25*m_5*CC4*C5*S5 - 2*XX5*dq35*m_5*CC4*C5*S5 - 2*XX6*dq24*m_6*C4*CC6*S4 - 2*XX6*dq34*m_6*C4*CC6*S4 + 2*XX6*dq25*m_6*C5*CC6*S5 - 2*XX6*dq26*m_6*CC4*C6*S6 + 2*XX6*dq35*m_6*C5*CC6*S5 + 2*XX6*dq26*m_6*CC5*C6*S6 - 2*XX6*dq36*m_6*CC4*C6*S6 + 2*XX6*dq46*m_6*C4*CC6*S5 + 2*XX6*dq36*m_6*CC5*C6*S6 - 2*XX6*dq56*m_6*C5*CC6*S4 + 4*Y4*d4*dq11*m_4*C2*CC3*S2 + 4*Y4*d4*dq11*m_4*CC2*C3*S3 - 2*Y6*d4*dq11*m_6*CC2*C6*S4 - 2*Y6*d4*dq11*m_6*CC3*C6*S4 + 2*Y6*d6*dq11*m_6*CC2*C4*S6 + 2*Y6*d6*dq11*m_6*CC3*C4*S6 + 2*Y6*d6*dq11*m_6*C4*CC5*S6 + 2*Y6*d6*dq44*m_6*C4*CC5*S6 + 2*YY5*dq14*m_5*C2*CC4*S3 + 2*YY5*dq14*m_5*C3*CC4*S2 - 2*YY6*dq14*m_6*C2*CC6*S3 - 2*YY6*dq14*m_6*C3*CC6*S2 - 2*YY6*dq24*m_6*C4*CC5*S4 + 2*YY6*dq24*m_6*C4*CC6*S4 - 2*YY6*dq34*m_6*C4*CC5*S4 - 2*YY6*dq25*m_6*CC4*C5*S5 + 2*YY6*dq34*m_6*C4*CC6*S4 - 2*YY6*dq35*m_6*CC4*C5*S5 - 2*YY6*dq25*m_6*C5*CC6*S5 + 2*YY6*dq26*m_6*CC4*C6*S6 - 2*YY6*dq35*m_6*C5*CC6*S5 - 2*YY6*dq26*m_6*CC5*C6*S6 + 2*YY6*dq36*m_6*CC4*C6*S6 - 2*YY6*dq46*m_6*C4*CC6*S5 - 2*YY6*dq36*m_6*CC5*C6*S6 + 2*YY6*dq56*m_6*C5*CC6*S4 + 2*Z5*d4*dq11*m_5*CC2*C4*S5 + 2*Z5*d4*dq11*m_5*CC3*C4*S5 - 2*Z6*d6*dq11*m_6*C2*CC4*S2 + 2*Z6*d4*dq11*m_6*CC2*C4*S5 + 2*Z6*d6*dq11*m_6*C2*CC5*S2 + 2*Z6*d4*dq11*m_6*CC3*C4*S5 - 2*Z6*d6*dq11*m_6*C3*CC4*S3 + 2*Z6*d6*dq11*m_6*C3*CC5*S3 + 2*ZZ4*dq14*m_4*C2*CC4*S3 + 2*ZZ4*dq14*m_4*C3*CC4*S2 - 2*ZZ5*dq14*m_5*C2*CC4*S3 - 2*ZZ5*dq14*m_5*C3*CC4*S2 - 2*ZZ6*dq14*m_6*C2*CC4*S3 - 2*ZZ6*dq14*m_6*C3*CC4*S2 + 2*ZZ5*dq24*m_5*C4*CC5*S4 + 2*ZZ5*dq34*m_5*C4*CC5*S4 + 2*ZZ5*dq25*m_5*CC4*C5*S5 + 2*ZZ6*dq24*m_6*C4*CC5*S4 + 2*ZZ5*dq35*m_5*CC4*C5*S5 + 2*ZZ6*dq34*m_6*C4*CC5*S4 + 2*ZZ6*dq25*m_6*CC4*C5*S5 + 2*ZZ6*dq35*m_6*CC4*C5*S5 + 2*X5*Y5*dq11*m_5*CC2*S4*S5 + 2*X5*Y5*dq11*m_5*CC3*S4*S5 - 2*X6*Y6*dq11*m_6*CC2*S4*S5 - 2*X6*Y6*dq11*m_6*CC3*S4*S5 - 2*X6*Y6*dq11*m_6*CC6*S4*S5 - 2*X6*Y6*dq44*m_6*CC6*S4*S5 + 2*X6*Y6*dq55*m_6*CC6*S4*S5 - 2*Ixy5*dq15*C2*CC4*S3*S5 - 2*Ixy5*dq15*C3*CC4*S2*S5 + 2*Ixy6*dq15*C2*CC4*S3*S5 + 2*Ixy6*dq15*C3*CC4*S2*S5 + 4*Ixy6*dq15*C2*CC6*S3*S5 + 4*Ixy6*dq15*C3*CC6*S2*S5 - 4*Ixy6*dq25*C4*CC6*S4*S5 - 4*Ixy6*dq35*C4*CC6*S4*S5 + 4*Ixy6*dq45*CC5*C6*S4*S6 + 4*Ixy6*dq46*C5*CC6*S4*S5 + 4*Ixz5*dq14*C4*CC5*S2*S3 + 2*Ixz6*dq26*CC4*C5*S5*S6 + 2*Ixz6*dq36*CC4*C5*S5*S6 + 2*d4*d6*dq11*m_6*CC2*C4*S5 + 2*d4*d6*dq11*m_6*CC3*C4*S5 - 2*dd6*dq14*m_6*C2*CC4*S3 - 2*dd6*dq14*m_6*C3*CC4*S2 + 2*dd6*dq24*m_6*C4*CC5*S4 + 2*dd6*dq34*m_6*C4*CC5*S4 + 2*dd6*dq25*m_6*CC4*C5*S5 + 2*dd6*dq35*m_6*CC4*C5*S5 - 2*Y5*a2*dq11*m_5*CC2*S3*S4 + 2*Y6*a3*dq11*m_6*CC2*S5*S6 + 2*Y6*a3*dq11*m_6*CC3*S5*S6 - 2*Z4*a2*dq11*m_4*CC2*S3*S4 - 2*X6*d4*dq11*m_6*CC2*S4*S6 - 2*X6*d4*dq11*m_6*CC3*S4*S6 - 4*X5*Y5*dq24*m_5*CC4*C5 - 4*X5*Y5*dq34*m_5*CC4*C5 + 4*X6*Y6*dq24*m_6*CC4*C5 + 4*X6*Y6*dq34*m_6*CC4*C5 + 4*X6*Y6*dq24*m_6*C5*CC6 + 4*X6*Y6*dq34*m_6*C5*CC6 - 4*X6*Y6*dq56*m_6*C4*CC6 - 2*X6*Z6*dq25*m_6*CC4*C6 - 4*X6*Z6*dq25*m_6*CC5*C6 - 2*X6*Z6*dq35*m_6*CC4*C6 - 4*X6*Z6*dq35*m_6*CC5*C6 - 2*Ixx5*dq15*CC5*S2*S3*S4 + 2*Ixx6*dq15*CC6*S2*S3*S4 - 2*Iyy6*dq15*CC5*S2*S3*S4 - 2*Iyy6*dq15*CC6*S2*S3*S4 + 2*Izz5*dq15*CC5*S2*S3*S4 + 2*Izz6*dq15*CC5*S2*S3*S4 - 2*X6*d6*dq25*m_6*CC4*C6 - 4*X6*d6*dq25*m_6*CC5*C6 - 2*X6*d6*dq35*m_6*CC4*C6 - 4*X6*d6*dq35*m_6*CC5*C6 - 4*Y5*Z5*dq24*m_5*CC4*S5 - 4*Y5*Z5*dq34*m_5*CC4*S5 + 2*Y6*Z6*dq25*m_6*CC4*S6 + 4*Y6*Z6*dq25*m_6*CC5*S6 + 2*Y6*Z6*dq35*m_6*CC4*S6 + 4*Y6*Z6*dq35*m_6*CC5*S6 - 4*Ixx5*dq11*CC2*CC3*C4*C5*S5 + 2*Ixx6*dq11*CC2*C4*C5*CC6*S5 + 2*Ixx6*dq11*CC3*C4*C5*CC6*S5 - 4*Iyy6*dq11*CC2*CC3*C4*C5*S5 - 2*Iyy6*dq11*CC2*C4*C5*CC6*S5 - 2*Iyy6*dq11*CC3*C4*C5*CC6*S5 - 4*Iyz6*dq11*CC2*CC3*C5*C6*S4 + 4*Izz5*dq11*CC2*CC3*C4*C5*S5 + 4*Izz6*dq11*CC2*CC3*C4*C5*S5 + 2*XX4*dq11*m_4*C2*CC3*CC4*S2 + 2*XX4*dq11*m_4*CC2*C3*CC4*S3 + 2*XX5*dq11*m_5*C2*CC3*CC5*S2 - XX5*dq11*m_5*C2*CC4*CC5*S2 + 2*XX5*dq11*m_5*CC2*C3*CC5*S3 - 2*XX6*dq11*m_6*C2*CC3*CC4*S2 - 2*XX6*dq11*m_6*CC2*C3*CC4*S3 - XX5*dq11*m_5*C3*CC4*CC5*S3 - 4*XX6*dq11*m_6*C2*CC3*CC6*S2 - XX6*dq11*m_6*C2*CC4*CC6*S2 - 4*XX6*dq11*m_6*CC2*C3*CC6*S3 - XX6*dq11*m_6*C2*CC5*CC6*S2 - XX6*dq11*m_6*C3*CC4*CC6*S3 - XX6*dq11*m_6*C3*CC5*CC6*S3 - 2*YY5*dq11*m_5*C2*CC3*CC4*S2 - 2*YY5*dq11*m_5*CC2*C3*CC4*S3 + 2*YY6*dq11*m_6*C2*CC3*CC5*S2 + 4*YY6*dq11*m_6*C2*CC3*CC6*S2 - YY6*dq11*m_6*C2*CC4*CC5*S2 + 2*YY6*dq11*m_6*CC2*C3*CC5*S3 + YY6*dq11*m_6*C2*CC4*CC6*S2 + 4*YY6*dq11*m_6*CC2*C3*CC6*S3 + YY6*dq11*m_6*C2*CC5*CC6*S2 - YY6*dq11*m_6*C3*CC4*CC5*S3 + YY6*dq11*m_6*C3*CC4*CC6*S3 + YY6*dq11*m_6*C3*CC5*CC6*S3 - 2*ZZ4*dq11*m_4*C2*CC3*CC4*S2 - 2*ZZ4*dq11*m_4*CC2*C3*CC4*S3 + 2*ZZ5*dq11*m_5*C2*CC3*CC4*S2 - 2*ZZ5*dq11*m_5*C2*CC3*CC5*S2 + 2*ZZ5*dq11*m_5*CC2*C3*CC4*S3 + ZZ5*dq11*m_5*C2*CC4*CC5*S2 - 2*ZZ5*dq11*m_5*CC2*C3*CC5*S3 + 2*ZZ6*dq11*m_6*C2*CC3*CC4*S2 - 2*ZZ6*dq11*m_6*C2*CC3*CC5*S2 + 2*ZZ6*dq11*m_6*CC2*C3*CC4*S3 + ZZ5*dq11*m_5*C3*CC4*CC5*S3 + ZZ6*dq11*m_6*C2*CC4*CC5*S2 - 2*ZZ6*dq11*m_6*CC2*C3*CC5*S3 + ZZ6*dq11*m_6*C3*CC4*CC5*S3 + 2*Y6*d6*dq25*m_6*CC4*S6 + 4*Y6*d6*dq25*m_6*CC5*S6 + 2*Y6*d6*dq35*m_6*CC4*S6 + 4*Y6*d6*dq35*m_6*CC5*S6 - 4*Z6*d6*dq45*m_6*CC5*S4 - 4*Ixz6*dq11*CC2*CC3*C5*S4*S6 + 2*dd6*dq11*m_6*C2*CC3*CC4*S2 - 2*dd6*dq11*m_6*C2*CC3*CC5*S2 + 2*dd6*dq11*m_6*CC2*C3*CC4*S3 + dd6*dq11*m_6*C2*CC4*CC5*S2 - 2*dd6*dq11*m_6*CC2*C3*CC5*S3 + dd6*dq11*m_6*C3*CC4*CC5*S3 + 4*X4*Y4*dq11*m_4*CC2*CC3*C4 + 4*X5*Z5*dq11*m_5*CC2*CC3*C4 + 4*X5*Z5*dq11*m_5*CC2*C4*CC5 + 4*X5*Z5*dq11*m_5*CC3*C4*CC5 - 4*Z5*a3*dq11*m_5*CC2*CC3*C5 - 4*Z6*a3*dq11*m_6*CC2*CC3*C5 - 4*X4*d4*dq11*m_4*CC2*CC3*C4 - 4*Y4*Z4*dq11*m_4*CC2*CC3*S4 - 4*a3*d6*dq11*m_6*CC2*CC3*C5 + 2*Ixx5*dq14*C2*CC4*CC5*S3 + 2*Ixx5*dq14*C3*CC4*CC5*S2 + 2*Ixx6*dq14*C2*CC4*CC6*S3 + 2*Ixx6*dq14*C3*CC4*CC6*S2 + 2*Ixx6*dq24*C4*CC5*CC6*S4 + 2*Ixx6*dq34*C4*CC5*CC6*S4 + 2*Ixx6*dq25*CC4*C5*CC6*S5 + 2*Ixx6*dq35*CC4*C5*CC6*S5 + 2*Ixx6*dq26*CC4*CC5*C6*S6 + 2*Ixx6*dq36*CC4*CC5*C6*S6 + 2*Iyy6*dq14*C2*CC4*CC5*S3 + 2*Iyy6*dq14*C3*CC4*CC5*S2 - 2*Iyy6*dq14*C2*CC4*CC6*S3 - 2*Iyy6*dq14*C3*CC4*CC6*S2 - 2*Iyy6*dq24*C4*CC5*CC6*S4 - 2*Iyy6*dq34*C4*CC5*CC6*S4 - 2*Iyy6*dq25*CC4*C5*CC6*S5 - 2*Iyy6*dq35*CC4*C5*CC6*S5 - 2*Iyy6*dq26*CC4*CC5*C6*S6 - 2*Iyy6*dq36*CC4*CC5*C6*S6 - 2*Izz5*dq14*C2*CC4*CC5*S3 - 2*Izz5*dq14*C3*CC4*CC5*S2 - 2*Izz6*dq14*C2*CC4*CC5*S3 - 2*Izz6*dq14*C3*CC4*CC5*S2 + 4*X5*a3*dq11*m_5*CC2*CC3*S5 + 2*XX6*dq45*m_6*CC5*CC6*S4 + 4*Y5*d4*dq11*m_5*CC2*CC3*S4 - 2*YY6*dq45*m_6*CC5*CC6*S4 + 4*Z4*d4*dq11*m_4*CC2*CC3*S4 + 2*X6*Y6*dq26*m_6*CC4*CC5 - 4*X6*Y6*dq26*m_6*CC4*CC6 + 2*X6*Y6*dq36*m_6*CC4*CC5 + 4*X6*Y6*dq26*m_6*CC5*CC6 - 4*X6*Y6*dq36*m_6*CC4*CC6 + 4*X6*Y6*dq36*m_6*CC5*CC6 + 4*X5*Z5*dq25*m_5*CC4*CC5 + 4*X5*Z5*dq35*m_5*CC4*CC5 + 8*Ixz6*dq11*CC2*CC3*C4*CC5*C6 + 4*Ixy4*dq11*C2*C3*C4*S2*S3 - 2*Ixy5*dq11*C2*C4*C5*S2*S4 + 2*Ixy6*dq11*C2*C4*C5*S2*S4 - 2*Ixy5*dq11*C3*C4*C5*S3*S4 + 2*Ixy6*dq11*C3*C4*C5*S3*S4 + 2*Ixy6*dq11*C4*C5*C6*S5*S6 + 2*Ixy6*dq44*C4*C5*C6*S5*S6 + 4*Ixz5*dq11*C2*C3*C4*S2*S3
 + 2*Ixz6*dq11*C2*C5*C6*S2*S5 + 2*Ixz6*dq11*C3*C5*C6*S3*S5 - 2*Ixx5*dq11*C2*CC3*CC4*CC5*S2 - 2*Ixx5*dq11*CC2*C3*CC4*CC5*S3 - 2*Ixx6*dq11*C2*CC3*CC4*CC6*S2 - 2*Ixx6*dq11*C2*CC3*CC5*CC6*S2 - 2*Ixx6*dq11*CC2*C3*CC4*CC6*S3 + Ixx6*dq11*C2*CC4*CC5*CC6*S2 - 2*Ixx6*dq11*CC2*C3*CC5*CC6*S3 + Ixx6*dq11*C3*CC4*CC5*CC6*S3 - 2*Iyy6*dq11*C2*CC3*CC4*CC5*S2 + 2*Iyy6*dq11*C2*CC3*CC4*CC6*S2 - 2*Iyy6*dq11*CC2*C3*CC4*CC5*S3 + 2*Iyy6*dq11*C2*CC3*CC5*CC6*S2 + 2*Iyy6*dq11*CC2*C3*CC4*CC6*S3 - Iyy6*dq11*C2*CC4*CC5*CC6*S2 + 2*Iyy6*dq11*CC2*C3*CC5*CC6*S3 - Iyy6*dq11*C3*CC4*CC5*CC6*S3 - 8*Iyz6*dq11*CC2*CC3*C4*CC5*S6 + 2*Izz5*dq11*C2*CC3*CC4*CC5*S2 + 2*Izz5*dq11*CC2*C3*CC4*CC5*S3 + 2*Izz6*dq11*C2*CC3*CC4*CC5*S2 + 2*Izz6*dq11*CC2*C3*CC4*CC5*S3 - 4*Iyz4*dq11*C2*C3*S2*S3*S4 - 2*Iyz5*dq11*C2*C4*S2*S4*S5 - 2*Iyz5*dq11*C3*C4*S3*S4*S5 - 2*Iyz6*dq11*C2*C5*S2*S5*S6 - 2*Iyz6*dq11*C3*C5*S3*S5*S6 + 2*Ixz6*dq14*C2*C3*C4*C6 - Z5*a1*dq11*m_5*C2*C3*C5 - Z6*a1*dq11*m_6*C2*C3*C5 - XX6*dq11*m_6*C6*S4*S5*S6 - XX6*dq44*m_6*C6*S4*S5*S6 + XX6*dq55*m_6*C6*S4*S5*S6 - X6*d4*dq11*m_6*C4*C5*C6 - X6*d4*dq44*m_6*C4*C5*C6 - X6*d4*dq55*m_6*C4*C5*C6 - X6*d4*dq66*m_6*C4*C5*C6 + YY6*dq11*m_6*C6*S4*S5*S6 + YY6*dq44*m_6*C6*S4*S5*S6 - YY6*dq55*m_6*C6*S4*S5*S6 + Y6*Z6*dq11*m_6*C5*C6*S4 + Y6*Z6*dq44*m_6*C5*C6*S4 - Y6*Z6*dq55*m_6*C5*C6*S4 + Y6*Z6*dq66*m_6*C5*C6*S4 + 8*Ixy6*dq11*CC2*CC3*CC6*S4*S5 - a1*d6*dq11*m_6*C2*C3*C5 - Ixx6*dq16*C2*C3*C4*S5 + Iyy6*dq16*C2*C3*C4*S5 + 2*Iyz5*dq14*C2*C3*C5*S4 - 2*Iyz6*dq14*C2*C3*C4*S6 - 2*Iyz6*dq15*C2*C5*C6*S3 - 2*Iyz6*dq15*C3*C5*C6*S2 + 2*Iyz6*dq25*C4*C5*C6*S4 + 2*Iyz6*dq35*C4*C5*C6*S4 - Izz6*dq16*C2*C3*C4*S5 + 2*X3*a2*dq11*m_3*C2*C3*S2 + X4*a1*dq11*m_4*C2*C4*S3 + X4*a1*dq11*m_4*C3*C4*S2 - 2*X4*a3*dq11*m_4*C2*C4*S2 - 2*X4*a3*dq11*m_4*C3*C4*S3 + X5*a1*dq11*m_5*C2*C3*S5 - X5*a2*dq11*m_5*C4*C5*S3 - X5*a2*dq33*m_5*C4*C5*S3 - X5*a2*dq44*m_5*C4*C5*S3 - X5*a2*dq55*m_5*C4*C5*S3 - X6*a2*dq11*m_6*C3*C6*S5 - X6*a2*dq33*m_6*C3*C6*S5 - X6*a2*dq55*m_6*C3*C6*S5 - X6*a2*dq66*m_6*C3*C6*S5 + 2*XX5*dq15*m_5*C2*C3*S4 - 2*XX6*dq16*m_6*C2*C5*S3 - 2*XX6*dq16*m_6*C3*C5*S2 + 2*XX6*dq26*m_6*C4*C5*S4 + 2*XX6*dq36*m_6*C4*C5*S4 + 2*XX6*dq24*m_6*C5*C6*S6 + 2*XX6*dq34*m_6*C5*C6*S6 - 2*XX6*dq56*m_6*C4*C6*S6 + Y6*d4*dq11*m_6*C4*C5*S6 + Y6*d6*dq11*m_6*C5*C6*S4 + Y6*d4*dq44*m_6*C4*C5*S6 + Y6*d4*dq55*m_6*C4*C5*S6 + Y6*d4*dq66*m_6*C4*C5*S6 + Y6*d6*dq44*m_6*C5*C6*S4 - Y6*d6*dq55*m_6*C5*C6*S4 + Y6*d6*dq66*m_6*C5*C6*S4 + 2*YY6*dq15*m_6*C2*C3*S4 - 2*YY6*dq26*m_6*C4*C5*S4 - 2*YY6*dq36*m_6*C4*C5*S4 - 2*YY6*dq24*m_6*C5*C6*S6 - 2*YY6*dq34*m_6*C5*C6*S6 + 2*YY6*dq56*m_6*C4*C6*S6 + 2*Z5*d4*dq11*m_5*C2*C5*S2 + 2*Z5*d4*dq11*m_5*C3*C5*S3 + 2*Z6*d4*dq11*m_6*C2*C5*S2 + 2*Z6*d4*dq11*m_6*C3*C5*S3 - 2*Z6*d6*dq11*m_6*C4*C5*S5 - 2*Z6*d6*dq44*m_6*C4*C5*S5 + X6*Z6*dq11*m_6*C5*S4*S6 + X6*Z6*dq44*m_6*C5*S4*S6 - X6*Z6*dq55*m_6*C5*S4*S6 + X6*Z6*dq66*m_6*C5*S4*S6 + 2*a2*a3*dq11*m_3*C2*C3*S2 + 2*a2*a3*dq11*m_4*C2*C3*S2 + 2*a2*a3*dq11*m_5*C2*C3*S2 + 2*a2*a3*dq11*m_6*C2*C3*S2 - 2*Ixy5*dq14*C2*C3*S4*S5 + 2*Ixy6*dq14*C2*C3*S4*S5 + 2*Ixy6*dq16*C2*C4*S3*S4 + 2*Ixy6*dq16*C3*C4*S2*S4 + 4*Ixy6*dq14*C2*C6*S3*S6 + 4*Ixy6*dq14*C3*C6*S2*S6 - 4*Ixy6*dq24*C4*C6*S4*S6 - 4*Ixy6*dq34*C4*C6*S4*S6 + 4*Ixy6*dq25*C5*C6*S5*S6 + 4*Ixy6*dq35*C5*C6*S5*S6 + 4*Ixy6*dq46*C4*C6*S5*S6 - 4*Ixy6*dq56*C5*C6*S4*S6 - 4*Ixz4*dq14*C2*C4*S3*S4 - 4*Ixz4*dq14*C3*C4*S2*S4 - 2*Ixz5*dq15*C2*C4*S3*S4 - 2*Ixz5*dq15*C3*C4*S2*S4 - 2*Ixz6*dq14*C4*C6*S2*S3 - 2*Ixz6*dq15*C2*C5*S3*S6 - 2*Ixz6*dq15*C3*C5*S2*S6 + 4*Ixz5*dq24*C4*C5*S4*S5 + 4*Ixz5*dq34*C4*C5*S4*S5 + 2*Ixz6*dq25*C4*C5*S4*S6 + 2*Ixz6*dq26*C4*C6*S4*S5 + 2*Ixz6*dq35*C4*C5*S4*S6 + 2*Ixz6*dq36*C4*C6*S4*S5 - 4*Ixz6*dq45*C5*C6*S4*S5 + 2*d4*d6*dq11*m_6*C2*C5*S2 + 2*d4*d6*dq11*m_6*C3*C5*S3 - 2*Y4*a2*dq11*m_4*C2*S2*S3 - Y5*a1*dq11*m_5*C2*S3*S4 - Y5*a1*dq11*m_5*C3*S2*S4 + 2*Y5*a3*dq11*m_5*C2*S2*S4 + 2*Y5*a3*dq11*m_5*C3*S3*S4 + Y6*a2*dq11*m_6*C6*S3*S4 + Y6*a2*dq11*m_6*C3*S5*S6 + Y6*a2*dq33*m_6*C6*S3*S4 + Y6*a2*dq33*m_6*C3*S5*S6 + Y6*a2*dq44*m_6*C6*S3*S4 + Y6*a2*dq55*m_6*C3*S5*S6 + Y6*a2*dq66*m_6*C6*S3*S4 + Y6*a2*dq66*m_6*C3*S5*S6 + 2*Z3*a2*dq11*m_3*C2*S2*S3 - Z4*a1*dq11*m_4*C2*S3*S4 - Z4*a1*dq11*m_4*C3*S2*S4 + 2*Z4*a3*dq11*m_4*C2*S2*S4 + 2*Z4*a3*dq11*m_4*C3*S3*S4 + Z5*a1*dq11*m_5*C5*S2*S3 + Z6*a1*dq11*m_6*C5*S2*S3 - Z5*a2*dq11*m_5*C4*S3*S5 - Z5*a2*dq33*m_5*C4*S3*S5 - Z6*a2*dq11*m_6*C4*S3*S5 - Z5*a2*dq44*m_5*C4*S3*S5 - Z5*a2*dq55*m_5*C4*S3*S5 - Z6*a2*dq33*m_6*C4*S3*S5 - Z6*a2*dq44*m_6*C4*S3*S5 - Z6*a2*dq55*m_6*C4*S3*S5 - 2*X5*d4*dq11*m_5*C2*S2*S5 - 2*X5*d4*dq11*m_5*C3*S3*S5 + X6*d6*dq11*m_6*C5*S4*S6 + X6*d6*dq44*m_6*C5*S4*S6 - X6*d6*dq55*m_6*C5*S4*S6 + X6*d6*dq66*m_6*C5*S4*S6 + 2*a2*d4*dq11*m_4*C2*S2*S3 + 2*a2*d4*dq11*m_5*C2*S2*S3 + 2*a2*d4*dq11*m_6*C2*S2*S3 + a1*d6*dq11*m_6*C5*S2*S3 - a2*d6*dq11*m_6*C4*S3*S5 - a2*d6*dq33*m_6*C4*S3*S5 - a2*d6*dq44*m_6*C4*S3*S5 - a2*d6*dq55*m_6*C4*S3*S5 + Ixx6*dq16*C4*S2*S3*S5 - Iyy6*dq16*C4*S2*S3*S5 - 2*Iyz5*dq14*C5*S2*S3*S4 + 2*Iyz6*dq14*C4*S2*S3*S6 - 2*Iyz6*dq26*C4*S4*S5*S6 - 2*Iyz6*dq36*C4*S4*S5*S6 + 4*Iyz6*dq45*C5*S4*S5*S6 + Izz6*dq16*C4*S2*S3*S5 - X5*a1*dq11*m_5*S2*S3*S5 + X6*a2*dq11*m_6*S3*S4*S6 + X6*a2*dq33*m_6*S3*S4*S6 + X6*a2*dq44*m_6*S3*S4*S6 + X6*a2*dq66*m_6*S3*S4*S6 - 2*Y5*a2*dq24*m_5*C3*C4 - 2*Y5*a2*dq34*m_5*C3*C4 - 2*Y6*a3*dq24*m_6*C4*C6 - 2*Y6*a3*dq34*m_6*C4*C6 - 2*Y6*a3*dq56*m_6*C5*C6 - 2*Z4*a2*dq24*m_4*C3*C4 - 2*Z4*a2*dq34*m_4*C3*C4 + 2*Z5*a2*dq23*m_5*C3*C5 + 2*Z6*a2*dq23*m_6*C3*C5 + 2*Z5*a3*dq25*m_5*C4*C5 + 2*Z5*a3*dq35*m_5*C4*C5 + 2*Z6*a3*dq25*m_6*C4*C5 + 2*Z6*a3*dq35*m_6*C4*C5 - 2*XX5*dq15*m_5*S2*S3*S4 - 2*X6*d4*dq25*m_6*C5*C6 - 2*X6*d4*dq35*m_6*C5*C6 - 2*X6*d4*dq46*m_6*C4*C6 - 2*YY6*dq15*m_6*S2*S3*S4 + 2*Z4*d4*dq14*m_4*S2*S3*S4 - 2*Y6*Z6*dq11*m_6*CC2*C5*C6*S4 - 2*Y6*Z6*dq11*m_6*CC3*C5*C6*S4 + 2*Ixx6*dq16*C2*C3*C4*CC6*S5 - 2*Iyy6*dq16*C2*C3*C4*CC6*S5 + 4*Iyz6*dq14*C2*C3*C4*CC5*S6 + 2*Iyz6*dq15*C2*CC4*C5*C6*S3 + 2*Iyz6*dq15*C3*CC4*C5*C6*S2 + 2*Iyz6*dq16*C2*C3*CC5*C6*S4 + 4*X4*a3*dq11*m_4*C2*CC3*C4*S2 + 4*X4*a3*dq11*m_4*CC2*C3*C4*S3 + 2*X5*a2*dq11*m_5*CC2*C4*C5*S3 + 2*X6*a2*dq11*m_6*CC2*C3*C6*S5 - 2*XX5*dq15*m_5*C2*C3*CC5*S4 + 2*XX6*dq15*m_6*C2*C3*CC6*S4 + 2*XX6*dq16*m_6*C2*CC4*C5*S3 + 2*XX6*dq16*m_6*C3*CC4*C5*S2 + 2*XX6*dq16*m_6*C2*C5*CC6*S3 + 2*XX6*dq16*m_6*C3*C5*CC6*S2 - 4*XX6*dq24*m_6*CC4*C5*C6*S6 - 4*XX6*dq26*m_6*C4*C5*CC6*S4 - 4*XX6*dq34*m_6*CC4*C5*C6*S6 - 4*XX6*dq36*m_6*C4*C5*CC6*S4 - 2*Y6*d4*dq11*m_6*CC2*C4*C5*S6 - 2*Y6*d4*dq11*m_6*CC3*C4*C5*S6 - 2*Y6*d6*dq11*m_6*CC2*C5*C6*S4 - 2*Y6*d6*dq11*m_6*CC3*C5*C6*S4 - 2*YY6*dq15*m_6*C2*C3*CC5*S4 - 2*YY6*dq15*m_6*C2*C3*CC6*S4 - 2*YY6*dq16*m_6*C2*CC4*C5*S3 - 2*YY6*dq16*m_6*C3*CC4*C5*S2 - 2*YY6*dq16*m_6*C2*C5*CC6*S3 - 2*YY6*dq16*m_6*C3*C5*CC6*S2 + 4*YY6*dq24*m_6*CC4*C5*C6*S6 + 4*YY6*dq26*m_6*C4*C5*CC6*S4 + 4*YY6*dq34*m_6*CC4*C5*C6*S6 + 4*YY6*dq36*m_6*C4*C5*CC6*S4 - 4*Z5*d4*dq11*m_5*C2*CC3*C5*S2 - 4*Z5*d4*dq11*m_5*CC2*C3*C5*S3 - 4*Z6*d4*dq11*m_6*C2*CC3*C5*S2 - 4*Z6*d4*dq11*m_6*CC2*C3*C5*S3 + 4*Z6*d6*dq11*m_6*CC2*C4*C5*S5 + 4*Z6*d6*dq11*m_6*CC3*C4*C5*S5 + 2*ZZ5*dq15*m_5*C2*C3*CC5*S4 + 2*ZZ6*dq15*m_6*C2*C3*CC5*S4 - 2*X6*Z6*dq11*m_6*CC2*C5*S4*S6 - 2*X6*Z6*dq11*m_6*CC3*C5*S4*S6 - 4*Ixy6*dq14*C2*C3*CC6*S4*S5 + 2*Ixy6*dq16*C2*C4*CC5*S3*S4 + 2*Ixy6*dq16*C3*C4*CC5*S2*S4 - 4*Ixy6*dq14*C2*CC4*C6*S3*S6 - 4*Ixy6*dq14*C3*CC4*C6*S2*S6 - 4*Ixy6*dq16*C2*C4*CC6*S3*S4 - 4*Ixy6*dq16*C3*C4*CC6*S2*S4 - 4*Ixy6*dq24*C4*CC5*C6*S4*S6 - 4*Ixy6*dq34*C4*CC5*C6*S4*S6 - 4*Ixy6*dq25*CC4*C5*C6*S5*S6 - 4*Ixy6*dq35*CC4*C5*C6*S5*S6 + 4*Ixz5*dq14*C2*CC4*C5*S3*S5 + 4*Ixz5*dq14*C3*CC4*C5*S2*S5 + 4*Ixz5*dq15*C2*C4*CC5*S3*S4 + 4*Ixz5*dq15*C3*C4*CC5*S2*S4 + 4*Ixz6*dq14*C4*CC5*C6*S2*S3 + 2*Ixz6*dq15*C2*CC4*C5*S3*S6 + 2*Ixz6*dq15*C3*CC4*C5*S2*S6 + 2*Ixz6*dq16*C2*C3*CC5*S4*S6 + 2*Ixz6*dq16*C2*CC4*C6*S3*S5 + 2*Ixz6*dq16*C3*CC4*C6*S2*S5 - 4*d4*d6*dq11*m_6*C2*CC3*C5*S2 - 4*d4*d6*dq11*m_6*CC2*C3*C5*S3 + 2*dd6*dq15*m_6*C2*C3*CC5*S4 - 4*Y5*a3*dq11*m_5*C2*CC3*S2*S4 - 4*Y5*a3*dq11*m_5*CC2*C3*S3*S4 - 2*Y6*a2*dq11*m_6*CC2*C6*S3*S4 - 2*Y6*a2*dq11*m_6*CC2*C3*S5*S6 - 4*Z4*a3*dq11*m_4*C2*CC3*S2*S4 - 4*Z4*a3*dq11*m_4*CC2*C3*S3*S4 + 2*Z5*a2*dq11*m_5*CC2*C4*S3*S5 + 2*Z6*a2*dq11*m_6*CC2*C4*S3*S5 + 4*X5*d4*dq11*m_5*C2*CC3*S2*S5 + 4*X5*d4*dq11*m_5*CC2*C3*S3*S5 - 2*X6*d6*dq11*m_6*CC2*C5*S4*S6 - 2*X6*d6*dq11*m_6*CC3*C5*S4*S6 + 2*a2*d6*dq11*m_6*CC2*C4*S3*S5 - 2*Ixx6*dq16*C4*CC6*S2*S3*S5 + 2*Iyy6*dq16*C4*CC6*S2*S3*S5 - 4*Iyz6*dq14*C4*CC5*S2*S3*S6 - 2*Iyz6*dq16*C2*CC4*S3*S5*S6 - 2*Iyz6*dq16*C3*CC4*S2*S5*S6 - 2*Iyz6*dq16*CC5*C6*S2*S3*S4 - 2*X6*a2*dq11*m_6*CC2*S3*S4*S6 + 2*XX5*dq15*m_5*CC5*S2*S3*S4 - 2*XX6*dq15*m_6*CC6*S2*S3*S4 + 2*YY6*dq15*m_6*CC5*S2*S3*S4 + 2*YY6*dq15*m_6*CC6*S2*S3*S4 - 2*ZZ5*dq15*m_5*CC5*S2*S3*S4 - 2*ZZ6*dq15*m_6*CC5*S2*S3*S4 - 4*Y6*Z6*dq24*m_6*CC4*C6*S5 - 4*Y6*Z6*dq34*m_6*CC4*C6*S5 + 2*Y6*Z6*dq46*m_6*CC5*C6*S4 + 4*Ixy6*dq14*CC6*S2*S3*S4*S5 - 2*Ixz6*dq16*CC5*S2*S3*S4*S6 - 2*dd6*dq15*m_6*CC5*S2*S3*S4 + 4*XX5*dq11*m_5*CC2*CC3*C4*C5*S5 - 2*XX6*dq11*m_6*CC2*C4*C5*CC6*S5 - 2*XX6*dq11*m_6*CC3*C4*C5*CC6*S5 + 4*YY6*dq11*m_6*CC2*CC3*C4*C5*S5 + 2*YY6*dq11*m_6*CC2*C4*C5*CC6*S5 + 2*YY6*dq11*m_6*CC3*C4*C5*CC6*S5 - 4*ZZ5*dq11*m_5*CC2*CC3*C4*C5*S5 - 4*ZZ6*dq11*m_6*CC2*CC3*C4*C5*S5 - 4*Y6*d6*dq24*m_6*CC4*C6*S5 - 4*Y6*d6*dq34*m_6*CC4*C6*S5 + 2*Y6*d6*dq46*m_6*CC5*C6*S4 - 4*Z6*d6*dq14*m_6*C2*CC4*S3 - 4*Z6*d6*dq14*m_6*C3*CC4*S2 + 4*Z6*d6*dq24*m_6*C4*CC5*S4 + 4*Z6*d6*dq34*m_6*C4*CC5*S4 + 4*Z6*d6*dq25*m_6*CC4*C5*S5 + 4*Z6*d6*dq35*m_6*CC4*C5*S5 - 4*X6*Z6*dq24*m_6*CC4*S5*S6 - 4*X6*Z6*dq34*m_6*CC4*S5*S6 + 2*X6*Z6*dq46*m_6*CC5*S4*S6 + 4*Ixy6*dq11*C2*CC3*CC4*C6*S2*S6 + 4*Ixy6*dq11*C2*CC3*CC5*C6*S2*S6 + 4*Ixy6*dq11*CC2*C3*CC4*C6*S3*S6 - 2*Ixy6*dq11*C2*CC4*CC5*C6*S2*S6 + 4*Ixy6*dq11*CC2*C3*CC5*C6*S3*S6 - 2*Ixy6*dq11*C3*CC4*CC5*C6*S3*S6 - 4*Ixz5*dq11*C2*CC3*CC4*C5*S2*S5 - 4*Ixz5*dq11*CC2*C3*CC4*C5*S3*S5 - 4*dd6*dq11*m_6*CC2*CC3*C4*C5*S5 - 4*X6*d6*dq24*m_6*CC4*S5*S6 - 4*X6*d6*dq34*m_6*CC4*S5*S6 + 2*X6*d6*dq46*m_6*CC5*S4*S6 + 4*X6*Z6*dq11*m_6*CC2*CC3*C4*C6 + 4*X6*Z6*dq11*m_6*CC2*C4*CC5*C6 + 4*X6*Z6*dq11*m_6*CC3*C4*CC5*C6 + 4*Ixx6*dq11*CC2*CC3*C6*S4*S5*S6 - 4*Iyy6*dq11*CC2*CC3*C6*S4*S5*S6 - 4*X5*d4*dq11*m_5*CC2*CC3*C4*C5
 + 4*X6*d6*dq11*m_6*CC2*CC3*C4*C6 + 4*X6*d6*dq11*m_6*CC2*C4*CC5*C6 + 4*X6*d6*dq11*m_6*CC3*C4*CC5*C6 + 4*Y5*Z5*dq11*m_5*CC2*CC3*C5*S4 - 4*Y6*Z6*dq11*m_6*CC2*CC3*C4*S6 - 4*Y6*Z6*dq11*m_6*CC2*C4*CC5*S6 - 4*Y6*Z6*dq11*m_6*CC3*C4*CC5*S6 + 2*Ixx6*dq15*C2*C3*CC5*CC6*S4 + 4*Ixx6*dq16*C2*CC4*C5*CC6*S3 + 4*Ixx6*dq16*C3*CC4*C5*CC6*S2 - 2*Iyy6*dq15*C2*C3*CC5*CC6*S4 - 4*Iyy6*dq16*C2*CC4*C5*CC6*S3 - 4*Iyy6*dq16*C3*CC4*C5*CC6*S2 + 4*X6*a3*dq11*m_6*CC2*CC3*C6*S5 - 2*XX5*dq14*m_5*C2*CC4*CC5*S3 - 2*XX5*dq14*m_5*C3*CC4*CC5*S2 - 2*XX6*dq14*m_6*C2*CC4*CC6*S3 - 2*XX6*dq14*m_6*C3*CC4*CC6*S2 - 2*XX6*dq24*m_6*C4*CC5*CC6*S4 - 2*XX6*dq34*m_6*C4*CC5*CC6*S4 - 2*XX6*dq25*m_6*CC4*C5*CC6*S5 - 2*XX6*dq35*m_6*CC4*C5*CC6*S5 - 2*XX6*dq26*m_6*CC4*CC5*C6*S6 - 2*XX6*dq36*m_6*CC4*CC5*C6*S6 + 4*Y6*d4*dq11*m_6*CC2*CC3*C6*S4 - 4*Y6*d6*dq11*m_6*CC2*CC3*C4*S6 - 4*Y6*d6*dq11*m_6*CC2*C4*CC5*S6 - 4*Y6*d6*dq11*m_6*CC3*C4*CC5*S6 - 2*YY6*dq14*m_6*C2*CC4*CC5*S3 - 2*YY6*dq14*m_6*C3*CC4*CC5*S2 + 2*YY6*dq14*m_6*C2*CC4*CC6*S3 + 2*YY6*dq14*m_6*C3*CC4*CC6*S2 + 2*YY6*dq24*m_6*C4*CC5*CC6*S4 + 2*YY6*dq34*m_6*C4*CC5*CC6*S4 + 2*YY6*dq25*m_6*CC4*C5*CC6*S5 + 2*YY6*dq35*m_6*CC4*C5*CC6*S5 + 2*YY6*dq26*m_6*CC4*CC5*C6*S6 + 2*YY6*dq36*m_6*CC4*CC5*C6*S6 - 4*Z5*d4*dq11*m_5*CC2*CC3*C4*S5 + 4*Z6*d6*dq11*m_6*C2*CC3*CC4*S2 - 4*Z6*d4*dq11*m_6*CC2*CC3*C4*S5 - 4*Z6*d6*dq11*m_6*C2*CC3*CC5*S2 + 4*Z6*d6*dq11*m_6*CC2*C3*CC4*S3 + 2*Z6*d6*dq11*m_6*C2*CC4*CC5*S2 - 4*Z6*d6*dq11*m_6*CC2*C3*CC5*S3 + 2*Z6*d6*dq11*m_6*C3*CC4*CC5*S3 + 2*ZZ5*dq14*m_5*C2*CC4*CC5*S3 + 2*ZZ5*dq14*m_5*C3*CC4*CC5*S2 + 2*ZZ6*dq14*m_6*C2*CC4*CC5*S3 + 2*ZZ6*dq14*m_6*C3*CC4*CC5*S2 - 4*X5*Y5*dq11*m_5*CC2*CC3*S4*S5 + 4*X6*Y6*dq11*m_6*CC2*CC3*S4*S5 + 4*X6*Y6*dq11*m_6*CC2*CC6*S4*S5 + 4*X6*Y6*dq11*m_6*CC3*CC6*S4*S5 - 4*Ixy6*dq15*C2*CC4*CC6*S3*S5 - 4*Ixy6*dq15*C3*CC4*CC6*S2*S5 - 4*d4*d6*dq11*m_6*CC2*CC3*C4*S5 + 2*dd6*dq14*m_6*C2*CC4*CC5*S3 + 2*dd6*dq14*m_6*C3*CC4*CC5*S2 - 4*Y6*a3*dq11*m_6*CC2*CC3*S5*S6 + 4*X6*d4*dq11*m_6*CC2*CC3*S4*S6 - 8*X6*Y6*dq24*m_6*CC4*C5*CC6 - 8*X6*Y6*dq34*m_6*CC4*C5*CC6 + 4*X6*Z6*dq25*m_6*CC4*CC5*C6 + 4*X6*Z6*dq35*m_6*CC4*CC5*C6 - 2*Ixx6*dq15*CC5*CC6*S2*S3*S4 + 2*Iyy6*dq15*CC5*CC6*S2*S3*S4 + 4*Ixz6*dq11*C2*C3*C4*C6*S2*S3 + 4*X6*d6*dq25*m_6*CC4*CC5*C6 + 4*X6*d6*dq35*m_6*CC4*CC5*C6 - 4*Y6*Z6*dq25*m_6*CC4*CC5*S6 - 4*Y6*Z6*dq35*m_6*CC4*CC5*S6 - 4*Ixx6*dq11*CC2*CC3*C4*C5*CC6*S5 + 4*Iyy6*dq11*CC2*CC3*C4*C5*CC6*S5 + 4*Iyz5*dq11*C2*C3*C5*S2*S3*S4 - 4*Iyz6*dq11*C2*C3*C4*S2*S3*S6 - 2*Iyz6*dq11*C2*C4*C6*S2*S4*S5 - 2*Iyz6*dq11*C3*C4*C6*S3*S4*S5 - 2*Ixz6*dq16*C2*C3*C4*C5*C6 + 2*XX5*dq11*m_5*C2*CC3*CC4*CC5*S2 + 2*XX5*dq11*m_5*CC2*C3*CC4*CC5*S3 + 2*XX6*dq11*m_6*C2*CC3*CC4*CC6*S2 + 2*XX6*dq11*m_6*C2*CC3*CC5*CC6*S2 + 2*XX6*dq11*m_6*CC2*C3*CC4*CC6*S3 - XX6*dq11*m_6*C2*CC4*CC5*CC6*S2 + 2*XX6*dq11*m_6*CC2*C3*CC5*CC6*S3 - XX6*dq11*m_6*C3*CC4*CC5*CC6*S3 + 2*YY6*dq11*m_6*C2*CC3*CC4*CC5*S2 - 2*YY6*dq11*m_6*C2*CC3*CC4*CC6*S2 + 2*YY6*dq11*m_6*CC2*C3*CC4*CC5*S3 - 2*YY6*dq11*m_6*C2*CC3*CC5*CC6*S2 - 2*YY6*dq11*m_6*CC2*C3*CC4*CC6*S3 + YY6*dq11*m_6*C2*CC4*CC5*CC6*S2 - 2*YY6*dq11*m_6*CC2*C3*CC5*CC6*S3 + YY6*dq11*m_6*C3*CC4*CC5*CC6*S3 - 2*ZZ5*dq11*m_5*C2*CC3*CC4*CC5*S2 - 2*ZZ5*dq11*m_5*CC2*C3*CC4*CC5*S3 - 2*ZZ6*dq11*m_6*C2*CC3*CC4*CC5*S2 - 2*ZZ6*dq11*m_6*CC2*C3*CC4*CC5*S3 - 4*Y6*d6*dq25*m_6*CC4*CC5*S6 - 4*Y6*d6*dq35*m_6*CC4*CC5*S6 - 4*Ixy5*dq11*C2*C3*S2*S3*S4*S5 + 4*Ixy6*dq11*C2*C3*S2*S3*S4*S5 - 2*Ixz6*dq11*C2*C4*S2*S4*S5*S6 - 2*Ixz6*dq11*C3*C4*S3*S4*S5*S6 + 2*Ixx5*dq14*C2*C3*C4*C5*S5 + 2*Iyy6*dq14*C2*C3*C4*C5*S5 + 2*Iyz6*dq14*C2*C3*C5*C6*S4 + 2*Iyz6*dq16*C2*C3*C4*C5*S6 - 2*Izz5*dq14*C2*C3*C4*C5*S5 - 2*Izz6*dq14*C2*C3*C4*C5*S5 - 2*dd6*dq11*m_6*C2*CC3*CC4*CC5*S2 - 2*dd6*dq11*m_6*CC2*C3*CC4*CC5*S3 + 2*X4*a2*dq11*m_4*C2*C3*C4*S2 + X5*a1*dq11*m_5*C2*C4*C5*S3 + X5*a1*dq11*m_5*C3*C4*C5*S2 - 2*X5*a3*dq11*m_5*C2*C4*C5*S2 - 2*X5*a3*dq11*m_5*C3*C4*C5*S3 + X6*a1*dq11*m_6*C2*C3*C6*S5 - X6*a2*dq11*m_6*C4*C5*C6*S3 - X6*a2*dq33*m_6*C4*C5*C6*S3 - X6*a2*dq44*m_6*C4*C5*C6*S3 - X6*a2*dq55*m_6*C4*C5*C6*S3 - X6*a2*dq66*m_6*C4*C5*C6*S3 - 2*YY6*dq16*m_6*C2*C3*C4*S5 - 8*X5*Z5*dq11*m_5*CC2*CC3*C4*CC5 - 4*X6*Y6*dq11*m_6*C2*C6*S2*S6 - 4*X6*Y6*dq11*m_6*C3*C6*S3*S6 + 4*X3*Z3*dq11*m_3*C2*C3*S2*S3 + 2*X4*Z4*dq11*m_4*C2*C4*S2*S4 + 2*X4*Z4*dq11*m_4*C3*C4*S3*S4 - 2*X5*Z5*dq11*m_5*C2*C5*S2*S5 - 2*X5*Z5*dq11*m_5*C3*C5*S3*S5 - 4*Ixy5*dq14*C2*C4*C5*S3*S4 - 4*Ixy5*dq14*C3*C4*C5*S2*S4 + 4*Ixy6*dq14*C2*C4*C5*S3*S4 + 4*Ixy6*dq14*C3*C4*C5*S2*S4 + 2*Ixy6*dq16*C2*C3*C5*S4*S5 + 4*Ixy6*dq15*C2*C3*C6*S4*S6 + 4*Ixy6*dq16*C2*C5*C6*S3*S6 + 4*Ixy6*dq16*C3*C5*C6*S2*S6 - 8*Ixy6*dq26*C4*C5*C6*S4*S6 - 8*Ixy6*dq36*C4*C5*C6*S4*S6 + 4*Ixz5*dq15*C2*C3*C5*S4*S5 + 2*Ixz6*dq14*C2*C3*C5*S4*S6 - 2*Ixz6*dq15*C2*C4*C6*S3*S4 - 2*Ixz6*dq15*C3*C4*C6*S2*S4 + 2*Ixz6*dq16*C4*C5*C6*S2*S3 + 4*Ixz6*dq24*C4*C5*C6*S4*S5 + 4*Ixz6*dq34*C4*C5*C6*S4*S5 - 4*Y4*a3*dq11*m_4*C2*C3*S2*S3 - 2*Y5*a2*dq11*m_5*C2*C3*S2*S4 - Y6*a1*dq11*m_6*C2*C6*S3*S4 - Y6*a1*dq11*m_6*C3*C6*S2*S4 - Y6*a1*dq11*m_6*C2*C3*S5*S6 + 2*Y6*a3*dq11*m_6*C2*C6*S2*S4 + 2*Y6*a3*dq11*m_6*C3*C6*S3*S4 + Y6*a2*dq11*m_6*C4*C5*S3*S6 + Y6*a2*dq33*m_6*C4*C5*S3*S6 + Y6*a2*dq44*m_6*C4*C5*S3*S6 + Y6*a2*dq55*m_6*C4*C5*S3*S6 + Y6*a2*dq66*m_6*C4*C5*S3*S6 + 4*Z3*a3*dq11*m_3*C2*C3*S2*S3 - 2*Z4*a2*dq11*m_4*C2*C3*S2*S4 + 2*Z5*a2*dq11*m_5*C2*C5*S2*S3 + Z5*a1*dq11*m_5*C2*C4*S3*S5 + Z5*a1*dq11*m_5*C3*C4*S2*S5 - 2*Z5*a3*dq11*m_5*C2*C4*S2*S5 + 2*Z6*a2*dq11*m_6*C2*C5*S2*S3 + Z6*a1*dq11*m_6*C2*C4*S3*S5 + Z6*a1*dq11*m_6*C3*C4*S2*S5 - 2*Z5*a3*dq11*m_5*C3*C4*S3*S5 - 2*Z6*a3*dq11*m_6*C2*C4*S2*S5 - 2*Z6*a3*dq11*m_6*C3*C4*S3*S5 - 2*X6*d4*dq11*m_6*C2*C6*S2*S5 - 2*X6*d4*dq11*m_6*C3*C6*S3*S5 - 2*X4*Y4*dq14*m_4*C2*C3*C4 - 2*X5*Z5*dq14*m_5*C2*C3*C4 - 2*X6*Z6*dq46*m_6*C4*C5*C6 + 2*Ixx6*dq14*C2*CC4*CC5*CC6*S3 + 2*Ixx6*dq14*C3*CC4*CC5*CC6*S2 - 2*Iyy6*dq14*C2*CC4*CC5*CC6*S3 - 2*Iyy6*dq14*C3*CC4*CC5*CC6*S2 + 4*a3*d4*dq11*m_4*C2*C3*S2*S3 + 4*a3*d4*dq11*m_5*C2*C3*S2*S3 + 4*a3*d4*dq11*m_6*C2*C3*S2*S3 + 2*a2*d6*dq11*m_6*C2*C5*S2*S3 + a1*d6*dq11*m_6*C2*C4*S3*S5 + a1*d6*dq11*m_6*C3*C4*S2*S5 - 2*a3*d6*dq11*m_6*C2*C4*S2*S5 - 2*a3*d6*dq11*m_6*C3*C4*S3*S5 - 2*Ixx5*dq14*C4*C5*S2*S3*S5 + 2*Ixx6*dq15*C2*C6*S3*S5*S6 + 2*Ixx6*dq15*C3*C6*S2*S5*S6 - 2*Ixx6*dq25*C4*C6*S4*S5*S6 - 2*Ixx6*dq35*C4*C6*S4*S5*S6 + 2*Ixx6*dq46*C5*C6*S4*S5*S6 - 2*Iyy6*dq14*C4*C5*S2*S3*S5 - 2*Iyy6*dq15*C2*C6*S3*S5*S6 - 2*Iyy6*dq15*C3*C6*S2*S5*S6 + 2*Iyy6*dq25*C4*C6*S4*S5*S6 + 2*Iyy6*dq35*C4*C6*S4*S5*S6 - 2*Iyy6*dq46*C5*C6*S4*S5*S6 - 4*Iyz5*dq14*C2*C4*S3*S4*S5 - 4*Iyz5*dq14*C3*C4*S2*S4*S5 - 2*Iyz6*dq14*C5*C6*S2*S3*S4 + 2*Iyz6*dq15*C2*C4*S3*S4*S6 + 2*Iyz6*dq15*C3*C4*S2*S4*S6 - 2*Iyz6*dq16*C4*C5*S2*S3*S6 - 4*Iyz6*dq24*C4*C5*S4*S5*S6 - 4*Iyz6*dq34*C4*C5*S4*S5*S6 + 2*Izz5*dq14*C4*C5*S2*S3*S5 + 2*Izz6*dq14*C4*C5*S2*S3*S5 - 2*X5*a2*dq11*m_5*C2*S2*S3*S5 - X6*a1*dq11*m_6*C2*S3*S4*S6 - X6*a1*dq11*m_6*C3*S2*S4*S6 - X6*a1*dq11*m_6*C6*S2*S3*S5 + 2*X6*a3*dq11*m_6*C2*S2*S4*S6 + 2*X6*a3*dq11*m_6*C3*S3*S4*S6 - 2*Y6*a2*dq24*m_6*C3*C4*C6 - 2*Y6*a2*dq34*m_6*C3*C4*C6 - 2*Y6*a3*dq26*m_6*C4*C5*C6 - 2*Y6*a2*dq56*m_6*C3*C5*C6 - 2*Y6*a3*dq36*m_6*C4*C5*C6 + 2*Z5*a2*dq25*m_5*C3*C4*C5 + 2*Z5*a2*dq35*m_5*C3*C4*C5 + 2*Z6*a2*dq25*m_6*C3*C4*C5 + 2*Z6*a2*dq35*m_6*C3*C4*C5 + 2*X4*d4*dq14*m_4*C2*C3*C4 - 2*X6*d6*dq46*m_6*C4*C5*C6 + 2*Y6*d4*dq11*m_6*C2*S2*S5*S6 + 2*Y6*d4*dq11*m_6*C3*S3*S5*S6 + 2*YY6*dq16*m_6*C4*S2*S3*S5 + 2*Y4*Z4*dq14*m_4*C2*C3*S4 + 2*Y5*Z5*dq15*m_5*C2*C5*S3 + 2*Y5*Z5*dq15*m_5*C3*C5*S2 - 2*Y5*Z5*dq25*m_5*C4*C5*S4 - 2*Y5*Z5*dq35*m_5*C4*C5*S4 + 2*Y6*Z6*dq26*m_6*C5*C6*S5 + 2*Y6*Z6*dq36*m_6*C5*C6*S5 + 2*Y6*Z6*dq46*m_6*C4*C5*S6 - 2*Ixy6*dq16*C5*S2*S3*S4*S5 - 4*Ixy6*dq15*C6*S2*S3*S4*S6 - 4*Ixz5*dq15*C5*S2*S3*S4*S5 - 2*Ixz6*dq14*C5*S2*S3*S4*S6 + 2*a2*d6*dq25*m_6*C3*C4*C5 + 2*a2*d6*dq35*m_6*C3*C4*C5 - 2*X4*a3*dq14*m_4*C2*C4*S3 - 2*X4*a3*dq14*m_4*C3*C4*S2 - 2*X5*a2*dq14*m_5*C4*C5*S2 - 2*X5*a2*dq23*m_5*C4*C5*S3 - 2*X5*a2*dq24*m_5*C3*C5*S4 - 2*X5*a2*dq25*m_5*C3*C4*S5 - 2*X5*a2*dq34*m_5*C3*C5*S4 - 2*X5*a2*dq35*m_5*C3*C4*S5 - 2*X6*a2*dq16*m_6*C4*C6*S2 - 2*X6*a2*dq23*m_6*C3*C6*S5 - 2*X6*a2*dq24*m_6*C3*C4*S6 - 2*X6*a2*dq34*m_6*C3*C4*S6 - 2*X6*a2*dq25*m_6*C5*C6*S3 - 2*X6*a2*dq26*m_6*C3*C6*S4 - 2*X6*a2*dq35*m_6*C5*C6*S3 - 2*X6*a2*dq36*m_6*C3*C6*S4 - 2*X6*a3*dq24*m_6*C5*C6*S4 - 2*X6*a2*dq46*m_6*C4*C6*S3 - 2*X6*a3*dq25*m_6*C4*C6*S5 - 2*X6*a3*dq34*m_6*C5*C6*S4 - 2*X6*a3*dq26*m_6*C4*C5*S6 - 2*X6*a3*dq35*m_6*C4*C6*S5 - 2*X6*a2*dq56*m_6*C3*C5*S6 - 2*X6*a3*dq36*m_6*C4*C5*S6 + Y6*a1*dq11*m_6*S2*S3*S5*S6 - 2*Y5*d4*dq14*m_5*C2*C3*S4 + 2*Y6*d4*dq46*m_6*C5*C6*S4 + 2*Y6*d4*dq56*m_6*C4*C6*S5 + 2*Y6*d6*dq26*m_6*C5*C6*S5 + 2*Y6*d6*dq36*m_6*C5*C6*S5 + 2*Y6*d6*dq46*m_6*C4*C5*S6 - 2*Z4*d4*dq14*m_4*C2*C3*S4 - 4*X6*Y6*dq26*m_6*CC4*CC5*CC6 - 4*X6*Y6*dq36*m_6*CC4*CC5*CC6 + 2*X4*Y4*dq14*m_4*C4*S2*S3 - 2*X5*Y5*dq15*m_5*C2*S3*S5 - 2*X5*Y5*dq15*m_5*C3*S2*S5 + 2*X6*Y6*dq15*m_6*C2*S3*S5 + 2*X6*Y6*dq15*m_6*C3*S2*S5 + 2*X5*Y5*dq25*m_5*C4*S4*S5 + 2*X5*Y5*dq35*m_5*C4*S4*S5 - 2*X6*Y6*dq25*m_6*C4*S4*S5 - 2*X6*Y6*dq35*m_6*C4*S4*S5 + 2*X6*Y6*dq46*m_6*C5*S4*S5 + 4*X6*Y6*dq45*m_6*C6*S4*S6 + 2*X5*Z5*dq14*m_5*C4*S2*S3 + 4*X5*Z5*dq45*m_5*C5*S4*S5 + 2*X6*Z6*dq26*m_6*C5*S5*S6 + 2*X6*Z6*dq36*m_6*C5*S5*S6 + 4*Ixy5*dq11*C2*CC3*C4*C5*S2*S4 + 4*Ixy5*dq11*CC2*C3*C4*C5*S3*S4 - 4*Ixy6*dq11*C2*CC3*C4*C5*S2*S4 - 4*Ixy6*dq11*CC2*C3*C4*C5*S3*S4 - 4*Ixy6*dq11*C2*C4*C5*CC6*S2*S4 - 4*Ixy6*dq11*C3*C4*C5*CC6*S3*S4 - 4*Ixy6*dq11*CC2*C4*C5*C6*S5*S6 - 4*Ixy6*dq11*CC3*C4*C5*C6*S5*S6 - 8*Ixz5*dq11*C2*C3*C4*CC5*S2*S3 - 4*Ixz6*dq11*C2*CC3*C5*C6*S2*S5 + 2*Ixz6*dq11*C2*CC4*C5*C6*S2*S5 - 4*Ixz6*dq11*CC2*C3*C5*C6*S3*S5 + 2*Ixz6*dq11*C3*CC4*C5*C6*S3*S5 + 2*Y5*a3*dq14*m_5*C2*S3*S4 + 2*Y5*a3*dq14*m_5*C3*S2*S4 + 2*Y6*a2*dq14*m_6*C6*S2*S4 + 2*Y6*a2*dq23*m_6*C6*S3*S4 + 2*Y6*a2*dq16*m_6*C4*S2*S6 + 2*Y6*a2*dq23*m_6*C3*S5*S6 + 2*Y6*a2*dq25*m_6*C5*S3*S6 + 2*Y6*a2*dq26*m_6*C3*S4*S6 + 2*Y6*a2*dq26*m_6*C6*S3*S5 + 2*Y6*a2*dq35*m_6*C5*S3*S6 + 2*Y6*a2*dq36*m_6*C3*S4*S6 + 2*Y6*a3*dq24*m_6*C5*S4*S6 + 2*Y6*a2*dq36*m_6*C6*S3*S5 + 2*Y6*a2*dq46*m_6*C4*S3*S6 + 2*Y6*a3*dq25*m_6*C4*S5*S6 + 2*Y6*a3*dq34*m_6*C5*S4*S6 + 2*Y6*a3*dq35*m_6*C4*S5*S6 + 2*Z4*a3*dq14*m_4*C2*S3*S4 + 2*Z4*a3*dq14*m_4*C3*S2*S4
 - 2*Z5*a2*dq14*m_5*C4*S2*S5 - 2*Z5*a2*dq15*m_5*C5*S2*S4 - 2*Z5*a2*dq23*m_5*C4*S3*S5 - 2*Z5*a2*dq24*m_5*C3*S4*S5 - 2*Z6*a2*dq14*m_6*C4*S2*S5 - 2*Z5*a2*dq34*m_5*C3*S4*S5 - 2*Z6*a2*dq15*m_6*C5*S2*S4 - 2*Z6*a2*dq23*m_6*C4*S3*S5 - 2*Z6*a2*dq24*m_6*C3*S4*S5 - 2*Z5*a2*dq45*m_5*C5*S3*S4 - 2*Z6*a2*dq34*m_6*C3*S4*S5 - 2*Z6*a2*dq45*m_6*C5*S3*S4 - 2*X4*d4*dq14*m_4*C4*S2*S3 + 2*X6*d4*dq45*m_6*C6*S4*S5 + 2*X6*d4*dq46*m_6*C5*S4*S6 + 2*X6*d4*dq56*m_6*C4*S5*S6 + 2*X6*d6*dq26*m_6*C5*S5*S6 + 2*X6*d6*dq36*m_6*C5*S5*S6 - 2*Ixx6*dq11*C2*CC3*CC4*CC5*CC6*S2 - 2*Ixx6*dq11*CC2*C3*CC4*CC5*CC6*S3 + 2*Iyy6*dq11*C2*CC3*CC4*CC5*CC6*S2 + 2*Iyy6*dq11*CC2*C3*CC4*CC5*CC6*S3 - 2*Y4*Z4*dq14*m_4*S2*S3*S4 + 4*Iyz5*dq11*C2*CC3*C4*S2*S4*S5 + 4*Iyz5*dq11*CC2*C3*C4*S3*S4*S5 + 4*Iyz6*dq11*C2*CC3*C5*S2*S5*S6 - 2*Iyz6*dq11*C2*CC4*C5*S2*S5*S6 + 4*Iyz6*dq11*CC2*C3*C5*S3*S5*S6 - 2*Iyz6*dq11*C3*CC4*C5*S3*S5*S6 - 4*Ixz6*dq14*C2*C3*C4*CC5*C6 - 2*a2*d6*dq14*m_6*C4*S2*S5 - 2*a2*d6*dq15*m_6*C5*S2*S4 - 2*a2*d6*dq23*m_6*C4*S3*S5 - 2*a2*d6*dq24*m_6*C3*S4*S5 - 2*a2*d6*dq34*m_6*C3*S4*S5 - 2*a2*d6*dq45*m_6*C5*S3*S4 + 2*X5*a2*dq15*m_5*S2*S4*S5 + 2*X6*a2*dq14*m_6*S2*S4*S6 + 2*X6*a2*dq23*m_6*S3*S4*S6 + 2*X5*a2*dq45*m_5*S3*S4*S5 + 2*X6*a2*dq26*m_6*S3*S5*S6 + 2*X6*a2*dq36*m_6*S3*S5*S6 + 2*XX6*dq11*m_6*CC2*C6*S4*S5*S6 + 2*XX6*dq11*m_6*CC3*C6*S4*S5*S6 + 2*X6*d4*dq11*m_6*CC2*C4*C5*C6 + 2*X6*d4*dq11*m_6*CC3*C4*C5*C6 - 2*YY6*dq11*m_6*CC2*C6*S4*S5*S6 - 2*YY6*dq11*m_6*CC3*C6*S4*S5*S6 + 2*Y5*d4*dq14*m_5*S2*S3*S4 - 2*Y6*d4*dq45*m_6*S4*S5*S6 + 2*XX6*dq16*m_6*C4*CC6*S2*S3*S5 - 4*Y6*d4*dq11*m_6*C2*CC3*S2*S5*S6 - 4*Y6*d4*dq11*m_6*CC2*C3*S3*S5*S6 - 2*YY6*dq16*m_6*C4*CC6*S2*S3*S5 - 2*Y5*Z5*dq15*m_5*C2*CC4*C5*S3 - 2*Y5*Z5*dq15*m_5*C3*CC4*C5*S2 - 2*Y6*Z6*dq26*m_6*CC4*C5*C6*S5 - 2*Y6*Z6*dq36*m_6*CC4*C5*C6*S5 + 4*Ixy6*dq15*CC5*C6*S2*S3*S4*S6 + 4*Ixy6*dq16*C5*CC6*S2*S3*S4*S5 - 2*Y6*d6*dq26*m_6*CC4*C5*C6*S5 - 2*Y6*d6*dq36*m_6*CC4*C5*C6*S5 + 4*Z6*d6*dq15*m_6*C2*C3*CC5*S4 + 2*X5*Y5*dq15*m_5*C2*CC4*S3*S5 + 2*X5*Y5*dq15*m_5*C3*CC4*S2*S5 - 2*X6*Y6*dq15*m_6*C2*CC4*S3*S5 - 2*X6*Y6*dq15*m_6*C3*CC4*S2*S5 - 4*X6*Y6*dq15*m_6*C2*CC6*S3*S5 - 4*X6*Y6*dq15*m_6*C3*CC6*S2*S5 + 4*X6*Y6*dq25*m_6*C4*CC6*S4*S5 + 4*X6*Y6*dq35*m_6*C4*CC6*S4*S5 - 4*X6*Y6*dq45*m_6*CC5*C6*S4*S6 - 4*X6*Y6*dq46*m_6*C5*CC6*S4*S5 - 4*X5*Z5*dq14*m_5*C4*CC5*S2*S3 - 2*X6*Z6*dq26*m_6*CC4*C5*S5*S6 - 2*X6*Z6*dq36*m_6*CC4*C5*S5*S6 + 8*Ixy6*dq11*C2*CC3*C4*C5*CC6*S2*S4 + 8*Ixy6*dq11*CC2*C3*C4*C5*CC6*S3*S4 + 8*Ixy6*dq11*CC2*CC3*C4*C5*C6*S5*S6 - 4*Ixz6*dq11*C2*CC3*CC4*C5*C6*S2*S5 - 4*Ixz6*dq11*CC2*C3*CC4*C5*C6*S3*S5 - 2*X6*d6*dq26*m_6*CC4*C5*S5*S6 - 2*X6*d6*dq36*m_6*CC4*C5*S5*S6 + 4*Iyz6*dq11*C2*CC3*CC4*C5*S2*S5*S6 + 4*Iyz6*dq11*CC2*C3*CC4*C5*S3*S5*S6 - 4*XX6*dq11*m_6*CC2*CC3*C6*S4*S5*S6 - 4*X6*d4*dq11*m_6*CC2*CC3*C4*C5*C6 + 4*YY6*dq11*m_6*CC2*CC3*C6*S4*S5*S6 - 4*Z6*d6*dq15*m_6*CC5*S2*S3*S4 + 4*Y6*Z6*dq11*m_6*CC2*CC3*C5*C6*S4 - 2*XX6*dq15*m_6*C2*C3*CC5*CC6*S4 - 4*XX6*dq16*m_6*C2*CC4*C5*CC6*S3 - 4*XX6*dq16*m_6*C3*CC4*C5*CC6*S2 + 4*Y6*d4*dq11*m_6*CC2*CC3*C4*C5*S6 + 4*Y6*d6*dq11*m_6*CC2*CC3*C5*C6*S4 + 2*YY6*dq15*m_6*C2*C3*CC5*CC6*S4 + 4*YY6*dq16*m_6*C2*CC4*C5*CC6*S3 + 4*YY6*dq16*m_6*C3*CC4*C5*CC6*S2 - 8*Z6*d6*dq11*m_6*CC2*CC3*C4*C5*S5 + 4*X6*Z6*dq11*m_6*CC2*CC3*C5*S4*S6 - 4*Ixy6*dq14*C2*CC4*CC5*C6*S3*S6 - 4*Ixy6*dq14*C3*CC4*CC5*C6*S2*S6 - 4*Ixy6*dq16*C2*C4*CC5*CC6*S3*S4 - 4*Ixy6*dq16*C3*C4*CC5*CC6*S2*S4 + 4*X6*d6*dq11*m_6*CC2*CC3*C5*S4*S6 + 2*XX6*dq15*m_6*CC5*CC6*S2*S3*S4 - 2*YY6*dq15*m_6*CC5*CC6*S2*S3*S4 + 4*Ixx5*dq11*C2*C3*C4*C5*S2*S3*S5 - 2*Ixx6*dq11*C2*C4*C5*C6*S2*S4*S6 - 2*Ixx6*dq11*C3*C4*C5*C6*S3*S4*S6 + 4*Iyy6*dq11*C2*C3*C4*C5*S2*S3*S5 + 2*Iyy6*dq11*C2*C4*C5*C6*S2*S4*S6 + 2*Iyy6*dq11*C3*C4*C5*C6*S3*S4*S6 + 4*Iyz6*dq11*C2*C3*C5*C6*S2*S3*S4 - 4*Izz5*dq11*C2*C3*C4*C5*S2*S3*S5 - 4*Izz6*dq11*C2*C3*C4*C5*S2*S3*S5 + 4*XX6*dq11*m_6*CC2*CC3*C4*C5*CC6*S5 - 4*YY6*dq11*m_6*CC2*CC3*C4*C5*CC6*S5 + 4*Z6*d6*dq14*m_6*C2*CC4*CC5*S3 + 4*Z6*d6*dq14*m_6*C3*CC4*CC5*S2 + 4*Ixy6*dq11*C2*CC3*CC4*CC5*C6*S2*S6 + 4*Ixy6*dq11*CC2*C3*CC4*CC5*C6*S3*S6 + 4*Ixz6*dq11*C2*C3*C5*S2*S3*S4*S6 + 2*X5*a2*dq11*m_5*C2*C3*C4*C5*S2 + X6*a1*dq11*m_6*C2*C4*C5*C6*S3 + X6*a1*dq11*m_6*C3*C4*C5*C6*S2 - 2*X6*a3*dq11*m_6*C2*C4*C5*C6*S2 - 2*X6*a3*dq11*m_6*C3*C4*C5*C6*S3 - 2*XX5*dq14*m_5*C2*C3*C4*C5*S5 - 2*YY6*dq14*m_6*C2*C3*C4*C5*S5 + 2*ZZ5*dq14*m_5*C2*C3*C4*C5*S5 + 2*ZZ6*dq14*m_6*C2*C3*C4*C5*S5 - 8*X6*Z6*dq11*m_6*CC2*CC3*C4*CC5*C6 - 4*X4*Y4*dq11*m_4*C2*C3*C4*S2*S3 + 2*X5*Y5*dq11*m_5*C2*C4*C5*S2*S4 + 2*X5*Y5*dq11*m_5*C3*C4*C5*S3*S4 - 2*X6*Y6*dq11*m_6*C2*C4*C5*S2*S4 - 2*X6*Y6*dq11*m_6*C3*C4*C5*S3*S4 - 2*X6*Y6*dq11*m_6*C4*C5*C6*S5*S6 - 2*X6*Y6*dq44*m_6*C4*C5*C6*S5*S6 - 4*X5*Z5*dq11*m_5*C2*C3*C4*S2*S3 - 2*X6*Z6*dq11*m_6*C2*C5*C6*S2*S5 - 2*X6*Z6*dq11*m_6*C3*C5*C6*S3*S5 - 4*Ixy6*dq16*C2*C3*C4*C6*S5*S6 + 4*Ixz6*dq15*C2*C3*C5*C6*S4*S5 + 2*dd6*dq14*m_6*C2*C3*C4*C5*S5 - 2*Y6*a2*dq11*m_6*C2*C3*C6*S2*S4 - Y6*a1*dq11*m_6*C2*C4*C5*S3*S6 - Y6*a1*dq11*m_6*C3*C4*C5*S2*S6 + 2*Y6*a3*dq11*m_6*C2*C4*C5*S2*S6 + 2*Y6*a3*dq11*m_6*C3*C4*C5*S3*S6 - 8*X6*d6*dq11*m_6*CC2*CC3*C4*CC5*C6 + 2*Z5*a2*dq11*m_5*C2*C3*C4*S2*S5 + 4*Z5*a3*dq11*m_5*C2*C3*C5*S2*S3 + 2*Z6*a2*dq11*m_6*C2*C3*C4*S2*S5 + 4*Z6*a3*dq11*m_6*C2*C3*C5*S2*S3 + 4*X4*d4*dq11*m_4*C2*C3*C4*S2*S3 - 2*X6*d6*dq11*m_6*C2*C5*C6*S2*S5 - 2*X6*d6*dq11*m_6*C3*C5*C6*S3*S5 + 8*Y6*Z6*dq11*m_6*CC2*CC3*C4*CC5*S6 - 2*X6*Z6*dq14*m_6*C2*C3*C4*C6 + 4*Y4*Z4*dq11*m_4*C2*C3*S2*S3*S4 + 2*Y5*Z5*dq11*m_5*C2*C4*S2*S4*S5 + 2*Y5*Z5*dq11*m_5*C3*C4*S3*S4*S5 + 2*Y6*Z6*dq11*m_6*C2*C5*S2*S5*S6 + 2*Y6*Z6*dq11*m_6*C3*C5*S3*S5*S6 + 2*a2*d6*dq11*m_6*C2*C3*C4*S2*S5 + 4*a3*d6*dq11*m_6*C2*C3*C5*S2*S3 - 2*Ixx5*dq15*C2*C4*C5*S3*S4*S5 - 2*Ixx5*dq15*C3*C4*C5*S2*S4*S5 - 2*Ixx6*dq14*C2*C3*C6*S4*S5*S6 - 2*Ixx6*dq16*C2*C4*C6*S3*S4*S6 - 2*Ixx6*dq16*C3*C4*C6*S2*S4*S6 - 2*Iyy6*dq15*C2*C4*C5*S3*S4*S5 - 2*Iyy6*dq15*C3*C4*C5*S2*S4*S5 + 2*Iyy6*dq14*C2*C3*C6*S4*S5*S6 + 2*Iyy6*dq16*C2*C4*C6*S3*S4*S6 + 2*Iyy6*dq16*C3*C4*C6*S2*S4*S6 - 4*Iyz6*dq14*C2*C4*C6*S3*S4*S5 - 4*Iyz6*dq14*C3*C4*C6*S2*S4*S5 - 4*Iyz6*dq15*C2*C3*C5*S4*S5*S6 + 2*Izz5*dq15*C2*C4*C5*S3*S4*S5 + 2*Izz5*dq15*C3*C4*C5*S2*S4*S5 + 2*Izz6*dq15*C2*C4*C5*S3*S4*S5 + 2*Izz6*dq15*C3*C4*C5*S2*S4*S5 - 4*X5*a3*dq11*m_5*C2*C3*S2*S3*S5 - 2*X6*a2*dq11*m_6*C2*C3*S2*S4*S6 - 2*X6*a2*dq11*m_6*C2*C6*S2*S3*S5 - 2*Y6*a2*dq26*m_6*C3*C4*C5*C6 - 2*Y6*a2*dq36*m_6*C3*C4*C5*C6 - 2*XX6*dq14*m_6*C2*CC4*CC5*CC6*S3 - 2*XX6*dq14*m_6*C3*CC4*CC5*CC6*S2 + 8*Y6*d6*dq11*m_6*CC2*CC3*C4*CC5*S6 + 2*YY6*dq14*m_6*C2*CC4*CC5*CC6*S3 + 2*YY6*dq14*m_6*C3*CC4*CC5*CC6*S2 - 4*Z6*d6*dq11*m_6*C2*CC3*CC4*CC5*S2 - 4*Z6*d6*dq11*m_6*CC2*C3*CC4*CC5*S3 + 2*XX5*dq14*m_5*C4*C5*S2*S3*S5 - 2*XX6*dq15*m_6*C2*C6*S3*S5*S6 - 2*XX6*dq15*m_6*C3*C6*S2*S5*S6 + 2*XX6*dq25*m_6*C4*C6*S4*S5*S6 + 2*XX6*dq35*m_6*C4*C6*S4*S5*S6 - 2*XX6*dq46*m_6*C5*C6*S4*S5*S6 + 2*X5*d4*dq14*m_5*C2*C3*C4*C5 + 2*X6*d4*dq16*m_6*C2*C3*C4*C6 - 2*X6*d6*dq14*m_6*C2*C3*C4*C6 - 4*Y5*d4*dq11*m_5*C2*C3*S2*S3*S4 + 2*Y6*d6*dq11*m_6*C2*C5*S2*S5*S6 + 2*Y6*d6*dq11*m_6*C3*C5*S3*S5*S6 + 2*YY6*dq14*m_6*C4*C5*S2*S3*S5 + 2*YY6*dq15*m_6*C2*C6*S3*S5*S6 + 2*YY6*dq15*m_6*C3*C6*S2*S5*S6 - 2*YY6*dq25*m_6*C4*C6*S4*S5*S6 - 2*YY6*dq35*m_6*C4*C6*S4*S5*S6 + 2*YY6*dq46*m_6*C5*C6*S4*S5*S6 - 4*Z4*d4*dq11*m_4*C2*C3*S2*S3*S4 - 2*ZZ5*dq14*m_5*C4*C5*S2*S3*S5 - 2*ZZ6*dq14*m_6*C4*C5*S2*S3*S5 - 8*X6*Y6*dq11*m_6*CC2*CC3*CC6*S4*S5 - 2*Y5*Z5*dq14*m_5*C2*C3*C5*S4 + 2*Y6*Z6*dq14*m_6*C2*C3*C4*S6 + 2*Y6*Z6*dq15*m_6*C2*C5*C6*S3 + 2*Y6*Z6*dq15*m_6*C3*C5*C6*S2 - 2*Y6*Z6*dq25*m_6*C4*C5*C6*S4 - 2*Y6*Z6*dq35*m_6*C4*C5*C6*S4 + 4*Ixy6*dq16*C4*C6*S2*S3*S5*S6 - 4*Ixz6*dq14*C2*C4*S3*S4*S5*S6 - 4*Ixz6*dq14*C3*C4*S2*S4*S5*S6 - 4*Ixz6*dq15*C5*C6*S2*S3*S4*S5 - 2*dd6*dq14*m_6*C4*C5*S2*S3*S5 - 2*X5*a3*dq14*m_5*C2*C4*C5*S3 - 2*X5*a3*dq14*m_5*C3*C4*C5*S2 - 2*X6*a2*dq14*m_6*C4*C5*C6*S2 - 2*X6*a2*dq23*m_6*C4*C5*C6*S3 - 2*X6*a3*dq16*m_6*C2*C4*C6*S3 - 2*X6*a3*dq16*m_6*C3*C4*C6*S2 - 2*X6*a2*dq24*m_6*C3*C5*C6*S4 - 2*X6*a2*dq25*m_6*C3*C4*C6*S5 - 2*X6*a2*dq34*m_6*C3*C5*C6*S4 - 2*X6*a2*dq26*m_6*C3*C4*C5*S6 - 2*X6*a2*dq35*m_6*C3*C4*C6*S5 - 2*X6*a2*dq36*m_6*C3*C4*C5*S6 + 2*Y6*a2*dq11*m_6*C2*S2*S3*S5*S6 - 2*Y6*d4*dq14*m_6*C2*C3*C6*S4 - 2*Y6*d4*dq16*m_6*C2*C3*C4*S6 + 2*Y6*d6*dq14*m_6*C2*C3*C4*S6 + 2*Y6*d6*dq15*m_6*C2*C5*C6*S3 + 2*Y6*d6*dq15*m_6*C3*C5*C6*S2 - 2*Y6*d6*dq25*m_6*C4*C5*C6*S4 - 2*Y6*d6*dq35*m_6*C4*C5*C6*S4 + 2*Z5*d4*dq14*m_5*C2*C3*C4*S5 + 2*Z5*d4*dq15*m_5*C2*C3*C5*S4 + 2*Z6*d4*dq14*m_6*C2*C3*C4*S5 + 2*Z6*d4*dq15*m_6*C2*C3*C5*S4 + 2*X5*Y5*dq14*m_5*C2*C3*S4*S5 - 2*X6*Y6*dq14*m_6*C2*C3*S4*S5 - 2*X6*Y6*dq16*m_6*C2*C4*S3*S4 - 2*X6*Y6*dq16*m_6*C3*C4*S2*S4 - 4*X6*Y6*dq14*m_6*C2*C6*S3*S6 - 4*X6*Y6*dq14*m_6*C3*C6*S2*S6 + 4*X6*Y6*dq24*m_6*C4*C6*S4*S6 + 4*X6*Y6*dq34*m_6*C4*C6*S4*S6 - 4*X6*Y6*dq25*m_6*C5*C6*S5*S6 - 4*X6*Y6*dq35*m_6*C5*C6*S5*S6 - 4*X6*Y6*dq46*m_6*C4*C6*S5*S6 + 4*X6*Y6*dq56*m_6*C5*C6*S4*S6 + 4*X4*Z4*dq14*m_4*C2*C4*S3*S4 + 4*X4*Z4*dq14*m_4*C3*C4*S2*S4 + 2*X5*Z5*dq15*m_5*C2*C4*S3*S4 + 2*X5*Z5*dq15*m_5*C3*C4*S2*S4 + 2*X6*Z6*dq14*m_6*C4*C6*S2*S3 - 4*X5*Z5*dq24*m_5*C4*C5*S4*S5 - 4*X5*Z5*dq34*m_5*C4*C5*S4*S5 + 2*X6*Z6*dq15*m_6*C2*C5*S3*S6 + 2*X6*Z6*dq15*m_6*C3*C5*S2*S6 - 2*X6*Z6*dq25*m_6*C4*C5*S4*S6 - 2*X6*Z6*dq26*m_6*C4*C6*S4*S5 - 2*X6*Z6*dq35*m_6*C4*C5*S4*S6 - 2*X6*Z6*dq36*m_6*C4*C6*S4*S5 + 4*X6*Z6*dq45*m_6*C5*C6*S4*S5 - 8*Ixz6*dq11*C2*C3*C4*CC5*C6*S2*S3 + 2*Ixx6*dq14*C6*S2*S3*S4*S5*S6 - 2*Iyy6*dq14*C6*S2*S3*S4*S5*S6 + 4*Iyz6*dq15*C5*S2*S3*S4*S5*S6 + 2*d4*d6*dq14*m_6*C2*C3*C4*S5 + 2*d4*d6*dq15*m_6*C2*C3*C5*S4 + 2*Y6*a3*dq14*m_6*C2*C6*S3*S4 + 2*Y6*a3*dq14*m_6*C3*C6*S2*S4 + 2*Y6*a2*dq14*m_6*C4*C5*S2*S6 + 2*Y6*a2*dq23*m_6*C4*C5*S3*S6 + 2*Y6*a3*dq16*m_6*C2*C4*S3*S6 + 2*Y6*a3*dq16*m_6*C3*C4*S2*S6 + 2*Y6*a2*dq16*m_6*C5*C6*S2*S4 + 2*Y6*a2*dq24*m_6*C3*C5*S4*S6 + 2*Y6*a2*dq25*m_6*C3*C4*S5*S6 + 2*Y6*a2*dq34*m_6*C3*C5*S4*S6 + 2*Y6*a2*dq35*m_6*C3*C4*S5*S6 + 2*Y6*a2*dq46*m_6*C5*C6*S3*S4 + 2*Y6*a2*dq56*m_6*C4*C6*S3*S5 - 2*Z5*a3*dq14*m_5*C2*C4*S3*S5 - 2*Z5*a3*dq14*m_5*C3*C4*S2*S5 - 2*Z5*a3*dq15*m_5*C2*C5*S3*S4 - 2*Z5*a3*dq15*m_5*C3*C5*S2*S4 - 2*Z6*a3*dq14*m_6*C2*C4*S3*S5 - 2*Z6*a3*dq14*m_6*C3*C4*S2*S5 - 2*Z6*a3*dq15*m_6*C2*C5*S3*S4 - 2*Z6*a3*dq15*m_6*C3*C5*S2*S4
 - 2*X5*d4*dq14*m_5*C4*C5*S2*S3 - 2*X5*d4*dq15*m_5*C2*C3*S4*S5 - 2*X6*d4*dq14*m_6*C2*C3*S4*S6 - 2*X6*d4*dq16*m_6*C4*C6*S2*S3 + 2*X6*d6*dq14*m_6*C4*C6*S2*S3 + 2*X6*d6*dq15*m_6*C2*C5*S3*S6 + 2*X6*d6*dq15*m_6*C3*C5*S2*S6 - 2*X6*d6*dq25*m_6*C4*C5*S4*S6 - 2*X6*d6*dq26*m_6*C4*C6*S4*S5 - 2*X6*d6*dq35*m_6*C4*C5*S4*S6 - 2*X6*d6*dq36*m_6*C4*C6*S4*S5 + 4*X6*d6*dq45*m_6*C5*C6*S4*S5 + 2*Y5*Z5*dq14*m_5*C5*S2*S3*S4 - 2*Y6*Z6*dq14*m_6*C4*S2*S3*S6 + 2*Y6*Z6*dq26*m_6*C4*S4*S5*S6 + 2*Y6*Z6*dq36*m_6*C4*S4*S5*S6 - 4*Y6*Z6*dq45*m_6*C5*S4*S5*S6 + 8*Iyz6*dq11*C2*C3*C4*CC5*S2*S3*S6 + 4*Iyz6*dq11*C2*CC3*C4*C6*S2*S4*S5 + 4*Iyz6*dq11*CC2*C3*C4*C6*S3*S4*S5 - 2*a3*d6*dq14*m_6*C2*C4*S3*S5 - 2*a3*d6*dq14*m_6*C3*C4*S2*S5 - 2*a3*d6*dq15*m_6*C2*C5*S3*S4 - 2*a3*d6*dq15*m_6*C3*C5*S2*S4 + 2*X5*a3*dq15*m_5*C2*S3*S4*S5 + 2*X5*a3*dq15*m_5*C3*S2*S4*S5 + 2*X6*a3*dq14*m_6*C2*S3*S4*S6 + 2*X6*a3*dq14*m_6*C3*S2*S4*S6 + 2*X6*a2*dq15*m_6*C6*S2*S4*S5 + 2*X6*a2*dq16*m_6*C5*S2*S4*S6 + 2*X6*a2*dq45*m_6*C6*S3*S4*S5 + 2*X6*a2*dq46*m_6*C5*S3*S4*S6 + 2*X6*a2*dq56*m_6*C4*S3*S5*S6 + 2*XX6*dq11*m_6*C2*CC3*CC4*CC5*CC6*S2 + 2*XX6*dq11*m_6*CC2*C3*CC4*CC5*CC6*S3 - 2*YY6*dq11*m_6*C2*CC3*CC4*CC5*CC6*S2 - 2*YY6*dq11*m_6*CC2*C3*CC4*CC5*CC6*S3 + 2*Y6*d4*dq14*m_6*C6*S2*S3*S4 + 2*Y6*d4*dq16*m_6*C4*S2*S3*S6 - 2*Y6*d6*dq14*m_6*C4*S2*S3*S6 + 2*Y6*d6*dq26*m_6*C4*S4*S5*S6 + 2*Y6*d6*dq36*m_6*C4*S4*S5*S6 - 4*Y6*d6*dq45*m_6*C5*S4*S5*S6 - 2*Z5*d4*dq14*m_5*C4*S2*S3*S5 - 2*Z5*d4*dq15*m_5*C5*S2*S3*S4 - 2*Z6*d4*dq14*m_6*C4*S2*S3*S5 - 2*Z6*d4*dq15*m_6*C5*S2*S3*S4 - 2*X5*Y5*dq14*m_5*S2*S3*S4*S5 + 2*X6*Y6*dq14*m_6*S2*S3*S4*S5 - 8*Ixy6*dq11*C2*C3*CC6*S2*S3*S4*S5 + 4*Ixz6*dq11*C2*CC3*C4*S2*S4*S5*S6 + 4*Ixz6*dq11*CC2*C3*C4*S3*S4*S5*S6 + 2*Ixx6*dq14*C2*C3*C4*C5*CC6*S5 - 2*Iyy6*dq14*C2*C3*C4*C5*CC6*S5 + 4*X5*a3*dq11*m_5*C2*CC3*C4*C5*S2 + 4*X5*a3*dq11*m_5*CC2*C3*C4*C5*S3 + 2*X6*a2*dq11*m_6*CC2*C4*C5*C6*S3 - 2*d4*d6*dq14*m_6*C4*S2*S3*S5 - 2*d4*d6*dq15*m_6*C5*S2*S3*S4 - 2*Y6*a2*dq15*m_6*S2*S4*S5*S6 - 2*Y6*a2*dq45*m_6*S3*S4*S5*S6 - 2*XX6*dq16*m_6*C2*C3*C4*CC6*S5 + 2*X5*d4*dq15*m_5*S2*S3*S4*S5 + 2*X6*d4*dq14*m_6*S2*S3*S4*S6 + 2*YY6*dq16*m_6*C2*C3*C4*CC6*S5 + 8*X6*Y6*dq11*m_6*C2*CC3*C6*S2*S6 + 2*X6*Y6*dq11*m_6*C2*CC4*C6*S2*S6 + 8*X6*Y6*dq11*m_6*CC2*C3*C6*S3*S6 + 2*X6*Y6*dq11*m_6*C2*CC5*C6*S2*S6 + 2*X6*Y6*dq11*m_6*C3*CC4*C6*S3*S6 + 2*X6*Y6*dq11*m_6*C3*CC5*C6*S3*S6 - 4*X4*Z4*dq11*m_4*C2*CC3*C4*S2*S4 - 4*X4*Z4*dq11*m_4*CC2*C3*C4*S3*S4 + 4*X5*Z5*dq11*m_5*C2*CC3*C5*S2*S5 - 2*X5*Z5*dq11*m_5*C2*CC4*C5*S2*S5 + 4*X5*Z5*dq11*m_5*CC2*C3*C5*S3*S5 - 2*X5*Z5*dq11*m_5*C3*CC4*C5*S3*S5 - 8*Ixy6*dq14*C2*C4*C5*CC6*S3*S4 - 8*Ixy6*dq14*C3*C4*C5*CC6*S2*S4 - 4*Ixy6*dq15*C2*C3*CC5*C6*S4*S6 - 4*Ixy6*dq16*C2*C3*C5*CC6*S4*S5 - 8*Ixy6*dq16*C2*CC4*C5*C6*S3*S6 - 8*Ixy6*dq16*C3*CC4*C5*C6*S2*S6 + 4*Ixz6*dq14*C2*CC4*C5*C6*S3*S5 + 4*Ixz6*dq14*C3*CC4*C5*C6*S2*S5 + 4*Ixz6*dq15*C2*C4*CC5*C6*S3*S4 + 4*Ixz6*dq15*C3*C4*CC5*C6*S2*S4 - 4*Y6*a3*dq11*m_6*C2*CC3*C6*S2*S4 - 4*Y6*a3*dq11*m_6*CC2*C3*C6*S3*S4 - 2*Y6*a2*dq11*m_6*CC2*C4*C5*S3*S6 + 4*Z5*a3*dq11*m_5*C2*CC3*C4*S2*S5 + 4*Z5*a3*dq11*m_5*CC2*C3*C4*S3*S5 + 4*Z6*a3*dq11*m_6*C2*CC3*C4*S2*S5 + 4*Z6*a3*dq11*m_6*CC2*C3*C4*S3*S5 + 4*X6*d4*dq11*m_6*C2*CC3*C6*S2*S5 + 4*X6*d4*dq11*m_6*CC2*C3*C6*S3*S5 + 4*X5*Z5*dq14*m_5*C2*C3*C4*CC5 + 4*a3*d6*dq11*m_6*C2*CC3*C4*S2*S5 + 4*a3*d6*dq11*m_6*CC2*C3*C4*S3*S5 - 2*Ixx6*dq14*C4*C5*CC6*S2*S3*S5 - 2*Ixx6*dq15*C2*CC4*C6*S3*S5*S6 - 2*Ixx6*dq15*C3*CC4*C6*S2*S5*S6 + 2*Iyy6*dq14*C4*C5*CC6*S2*S3*S5 + 2*Iyy6*dq15*C2*CC4*C6*S3*S5*S6 + 2*Iyy6*dq15*C3*CC4*C6*S2*S5*S6 - 4*Iyz6*dq14*C2*CC4*C5*S3*S5*S6 - 4*Iyz6*dq14*C3*CC4*C5*S2*S5*S6 - 4*Iyz6*dq15*C2*C4*CC5*S3*S4*S6 - 4*Iyz6*dq15*C3*C4*CC5*S2*S4*S6 - 4*X6*a3*dq11*m_6*C2*CC3*S2*S4*S6 - 4*X6*a3*dq11*m_6*CC2*C3*S3*S4*S6 + 4*Y6*d6*dq14*m_6*C4*CC5*S2*S3*S6 + 2*Y6*d6*dq16*m_6*C2*CC4*S3*S5*S6 + 2*Y6*d6*dq16*m_6*C3*CC4*S2*S5*S6 + 2*Y6*d6*dq16*m_6*CC5*C6*S2*S3*S4 - 4*X6*Y6*dq14*m_6*CC6*S2*S3*S4*S5 + 2*X6*Z6*dq16*m_6*CC5*S2*S3*S4*S6 + 2*X6*d6*dq16*m_6*CC5*S2*S3*S4*S6 - 4*X6*Y6*dq11*m_6*C2*CC3*CC4*C6*S2*S6 - 4*X6*Y6*dq11*m_6*C2*CC3*CC5*C6*S2*S6 - 4*X6*Y6*dq11*m_6*CC2*C3*CC4*C6*S3*S6 + 2*X6*Y6*dq11*m_6*C2*CC4*CC5*C6*S2*S6 - 4*X6*Y6*dq11*m_6*CC2*C3*CC5*C6*S3*S6 + 2*X6*Y6*dq11*m_6*C3*CC4*CC5*C6*S3*S6 + 4*X5*Z5*dq11*m_5*C2*CC3*CC4*C5*S2*S5 + 4*X5*Z5*dq11*m_5*CC2*C3*CC4*C5*S3*S5 - 4*XX5*dq11*m_5*C2*C3*C4*C5*S2*S3*S5 + 2*XX6*dq11*m_6*C2*C4*C5*C6*S2*S4*S6 + 2*XX6*dq11*m_6*C3*C4*C5*C6*S3*S4*S6 - 4*YY6*dq11*m_6*C2*C3*C4*C5*S2*S3*S5 - 2*YY6*dq11*m_6*C2*C4*C5*C6*S2*S4*S6 - 2*YY6*dq11*m_6*C3*C4*C5*C6*S3*S4*S6 + 4*ZZ5*dq11*m_5*C2*C3*C4*C5*S2*S3*S5 + 4*ZZ6*dq11*m_6*C2*C3*C4*C5*S2*S3*S5 + 4*X6*Y6*dq15*m_6*C2*CC4*CC6*S3*S5 + 4*X6*Y6*dq15*m_6*C3*CC4*CC6*S2*S5 + 4*dd6*dq11*m_6*C2*C3*C4*C5*S2*S3*S5 + 2*X6*a2*dq11*m_6*C2*C3*C4*C5*C6*S2 - 4*X6*Z6*dq11*m_6*C2*C3*C4*C6*S2*S3 - 4*Ixx6*dq11*C2*C3*C6*S2*S3*S4*S5*S6 + 4*Iyy6*dq11*C2*C3*C6*S2*S3*S4*S5*S6 - 4*Ixy6*dq14*C2*C3*C4*C5*C6*S5*S6 - 2*Y6*a2*dq11*m_6*C2*C3*C4*C5*S2*S6 + 4*X5*d4*dq11*m_5*C2*C3*C4*C5*S2*S3 - 4*X6*d6*dq11*m_6*C2*C3*C4*C6*S2*S3 + 2*X6*Z6*dq16*m_6*C2*C3*C4*C5*C6 - 4*Y5*Z5*dq11*m_5*C2*C3*C5*S2*S3*S4 + 4*Y6*Z6*dq11*m_6*C2*C3*C4*S2*S3*S6 + 2*Y6*Z6*dq11*m_6*C2*C4*C6*S2*S4*S5 + 2*Y6*Z6*dq11*m_6*C3*C4*C6*S3*S4*S5 - 4*Ixx6*dq14*C2*C4*C5*C6*S3*S4*S6 - 4*Ixx6*dq14*C3*C4*C5*C6*S2*S4*S6 - 2*Ixx6*dq16*C2*C3*C5*C6*S4*S5*S6 + 4*Iyy6*dq14*C2*C4*C5*C6*S3*S4*S6 + 4*Iyy6*dq14*C3*C4*C5*C6*S2*S4*S6 + 2*Iyy6*dq16*C2*C3*C5*C6*S4*S5*S6 - 2*Iyz6*dq16*C2*C4*C5*C6*S3*S4*S5 - 2*Iyz6*dq16*C3*C4*C5*C6*S2*S4*S5 - 4*X6*a3*dq11*m_6*C2*C3*C6*S2*S3*S5 + 2*XX5*dq15*m_5*C2*C4*C5*S3*S4*S5 + 2*XX5*dq15*m_5*C3*C4*C5*S2*S4*S5 + 2*XX6*dq14*m_6*C2*C3*C6*S4*S5*S6 + 2*XX6*dq16*m_6*C2*C4*C6*S3*S4*S6 + 2*XX6*dq16*m_6*C3*C4*C6*S2*S4*S6 + 2*X6*d4*dq14*m_6*C2*C3*C4*C5*C6 + 2*X6*d6*dq16*m_6*C2*C3*C4*C5*C6 - 4*Y6*d4*dq11*m_6*C2*C3*C6*S2*S3*S4 + 4*Y6*d6*dq11*m_6*C2*C3*C4*S2*S3*S6 + 2*Y6*d6*dq11*m_6*C2*C4*C6*S2*S4*S5 + 2*Y6*d6*dq11*m_6*C3*C4*C6*S3*S4*S5 + 2*YY6*dq15*m_6*C2*C4*C5*S3*S4*S5 + 2*YY6*dq15*m_6*C3*C4*C5*S2*S4*S5 - 2*YY6*dq14*m_6*C2*C3*C6*S4*S5*S6 - 2*YY6*dq16*m_6*C2*C4*C6*S3*S4*S6 - 2*YY6*dq16*m_6*C3*C4*C6*S2*S4*S6 + 4*Z5*d4*dq11*m_5*C2*C3*C4*S2*S3*S5 + 4*Z6*d4*dq11*m_6*C2*C3*C4*S2*S3*S5 - 2*ZZ5*dq15*m_5*C2*C4*C5*S3*S4*S5 - 2*ZZ5*dq15*m_5*C3*C4*C5*S2*S4*S5 - 2*ZZ6*dq15*m_6*C2*C4*C5*S3*S4*S5 - 2*ZZ6*dq15*m_6*C3*C4*C5*S2*S4*S5 + 4*X5*Y5*dq11*m_5*C2*C3*S2*S3*S4*S5 - 4*X6*Y6*dq11*m_6*C2*C3*S2*S3*S4*S5 + 2*X6*Z6*dq11*m_6*C2*C4*S2*S4*S5*S6 + 2*X6*Z6*dq11*m_6*C3*C4*S3*S4*S5*S6 - 2*Y6*Z6*dq14*m_6*C2*C3*C5*C6*S4 - 2*Y6*Z6*dq16*m_6*C2*C3*C4*C5*S6 + 4*Ixy6*dq14*C4*C5*C6*S2*S3*S5*S6 - 2*Ixz6*dq16*C2*C4*C5*S3*S4*S5*S6 - 2*Ixz6*dq16*C3*C4*C5*S2*S4*S5*S6 + 4*d4*d6*dq11*m_6*C2*C3*C4*S2*S3*S5 - 2*dd6*dq15*m_6*C2*C4*C5*S3*S4*S5 - 2*dd6*dq15*m_6*C3*C4*C5*S2*S4*S5 - 2*X6*a3*dq14*m_6*C2*C4*C5*C6*S3 - 2*X6*a3*dq14*m_6*C3*C4*C5*C6*S2 + 4*Y6*a3*dq11*m_6*C2*C3*S2*S3*S5*S6 - 4*X6*d4*dq11*m_6*C2*C3*S2*S3*S4*S6 + 2*X6*d6*dq11*m_6*C2*C4*S2*S4*S5*S6 + 2*X6*d6*dq11*m_6*C3*C4*S3*S4*S5*S6 - 2*Y6*d4*dq14*m_6*C2*C3*C4*C5*S6 - 2*Y6*d4*dq16*m_6*C2*C3*C5*C6*S4 - 2*Y6*d6*dq14*m_6*C2*C3*C5*C6*S4 - 2*Y6*d6*dq16*m_6*C2*C3*C4*C5*S6 + 4*Z6*d6*dq14*m_6*C2*C3*C4*C5*S5 + 4*X5*Y5*dq14*m_5*C2*C4*C5*S3*S4 + 4*X5*Y5*dq14*m_5*C3*C4*C5*S2*S4 - 4*X6*Y6*dq14*m_6*C2*C4*C5*S3*S4 - 4*X6*Y6*dq14*m_6*C3*C4*C5*S2*S4 - 2*X6*Y6*dq16*m_6*C2*C3*C5*S4*S5 - 4*X6*Y6*dq15*m_6*C2*C3*C6*S4*S6 - 4*X6*Y6*dq16*m_6*C2*C5*C6*S3*S6 - 4*X6*Y6*dq16*m_6*C3*C5*C6*S2*S6 + 8*X6*Y6*dq26*m_6*C4*C5*C6*S4*S6 + 8*X6*Y6*dq36*m_6*C4*C5*C6*S4*S6 - 4*X5*Z5*dq15*m_5*C2*C3*C5*S4*S5 - 2*X6*Z6*dq14*m_6*C2*C3*C5*S4*S6 + 2*X6*Z6*dq15*m_6*C2*C4*C6*S3*S4 + 2*X6*Z6*dq15*m_6*C3*C4*C6*S2*S4 - 2*X6*Z6*dq16*m_6*C4*C5*C6*S2*S3 - 4*X6*Z6*dq24*m_6*C4*C5*C6*S4*S5 - 4*X6*Z6*dq34*m_6*C4*C5*C6*S4*S5 + 2*Ixx6*dq16*C5*C6*S2*S3*S4*S5*S6 - 2*Iyy6*dq16*C5*C6*S2*S3*S4*S5*S6 + 2*Y6*a3*dq14*m_6*C2*C4*C5*S3*S6 + 2*Y6*a3*dq14*m_6*C3*C4*C5*S2*S6 + 2*Y6*a3*dq16*m_6*C2*C5*C6*S3*S4 + 2*Y6*a3*dq16*m_6*C3*C5*C6*S2*S4 - 2*XX6*dq14*m_6*C6*S2*S3*S4*S5*S6 - 2*X6*d4*dq14*m_6*C4*C5*C6*S2*S3 - 2*X6*d4*dq15*m_6*C2*C3*C6*S4*S5 - 2*X6*d4*dq16*m_6*C2*C3*C5*S4*S6 - 2*X6*d6*dq14*m_6*C2*C3*C5*S4*S6 + 2*X6*d6*dq15*m_6*C2*C4*C6*S3*S4 + 2*X6*d6*dq15*m_6*C3*C4*C6*S2*S4 - 2*X6*d6*dq16*m_6*C4*C5*C6*S2*S3 - 4*X6*d6*dq24*m_6*C4*C5*C6*S4*S5 - 4*X6*d6*dq34*m_6*C4*C5*C6*S4*S5 + 2*YY6*dq14*m_6*C6*S2*S3*S4*S5*S6 + 4*Y5*Z5*dq14*m_5*C2*C4*S3*S4*S5 + 4*Y5*Z5*dq14*m_5*C3*C4*S2*S4*S5 + 2*Y6*Z6*dq14*m_6*C5*C6*S2*S3*S4 - 2*Y6*Z6*dq15*m_6*C2*C4*S3*S4*S6 - 2*Y6*Z6*dq15*m_6*C3*C4*S2*S4*S6 + 2*Y6*Z6*dq16*m_6*C4*C5*S2*S3*S6 + 4*Y6*Z6*dq24*m_6*C4*C5*S4*S5*S6 + 4*Y6*Z6*dq34*m_6*C4*C5*S4*S5*S6 + 4*Ixx6*dq11*C2*C3*C4*C5*CC6*S2*S3*S5 + 4*Ixx6*dq11*C2*CC3*C4*C5*C6*S2*S4*S6 + 4*Ixx6*dq11*CC2*C3*C4*C5*C6*S3*S4*S6 - 4*Iyy6*dq11*C2*C3*C4*C5*CC6*S2*S3*S5 - 4*Iyy6*dq11*C2*CC3*C4*C5*C6*S2*S4*S6 - 4*Iyy6*dq11*CC2*C3*C4*C5*C6*S3*S4*S6 + 2*X6*a3*dq15*m_6*C2*C6*S3*S4*S5 + 2*X6*a3*dq15*m_6*C3*C6*S2*S4*S5 + 2*X6*a3*dq16*m_6*C2*C5*S3*S4*S6 + 2*X6*a3*dq16*m_6*C3*C5*S2*S4*S6 + 2*Y6*d4*dq14*m_6*C4*C5*S2*S3*S6 + 2*Y6*d4*dq15*m_6*C2*C3*S4*S5*S6 + 2*Y6*d4*dq16*m_6*C5*C6*S2*S3*S4 + 2*Y6*d6*dq14*m_6*C5*C6*S2*S3*S4 - 2*Y6*d6*dq15*m_6*C2*C4*S3*S4*S6 - 2*Y6*d6*dq15*m_6*C3*C4*S2*S4*S6 + 2*Y6*d6*dq16*m_6*C4*C5*S2*S3*S6 + 4*Y6*d6*dq24*m_6*C4*C5*S4*S5*S6 + 4*Y6*d6*dq34*m_6*C4*C5*S4*S5*S6 - 4*Z6*d6*dq14*m_6*C4*C5*S2*S3*S5 + 2*X6*Y6*dq16*m_6*C5*S2*S3*S4*S5 + 4*X6*Y6*dq15*m_6*C6*S2*S3*S4*S6 + 4*X5*Z5*dq15*m_5*C5*S2*S3*S4*S5 + 2*X6*Z6*dq14*m_6*C5*S2*S3*S4*S6 + 4*X6*a3*dq11*m_6*C2*CC3*C4*C5*C6*S2 + 4*X6*a3*dq11*m_6*CC2*C3*C4*C5*C6*S3 - 2*Y6*a3*dq15*m_6*C2*S3*S4*S5*S6 - 2*Y6*a3*dq15*m_6*C3*S2*S4*S5*S6 - 2*XX6*dq14*m_6*C2*C3*C4*C5*CC6*S5 + 2*X6*d4*dq15*m_6*C6*S2*S3*S4*S5 + 2*X6*d4*dq16*m_6*C5*S2*S3*S4*S6 + 2*X6*d6*dq14*m_6*C5*S2*S3*S4*S6 + 2*YY6*dq14*m_6*C2*C3*C4*C5*CC6*S5 - 4*X5*Y5*dq11*m_5*C2*CC3*C4*C5*S2*S4 - 4*X5*Y5*dq11*m_5*CC2*C3*C4*C5*S3*S4 + 4*X6*Y6*dq11*m_6*C2*CC3*C4*C5*S2*S4 + 4*X6*Y6*dq11*m_6*CC2*C3*C4*C5*S3*S4 + 4*X6*Y6*dq11*m_6*C2*C4*C5*CC6*S2*S4 + 4*X6*Y6*dq11*m_6*C3*C4*C5*CC6*S3*S4 + 4*X6*Y6*dq11*m_6*CC2*C4*C5*C6*S5*S6 + 4*X6*Y6*dq11*m_6*CC3*C4*C5*C6*S5*S6
 + 8*X5*Z5*dq11*m_5*C2*C3*C4*CC5*S2*S3 + 4*X6*Z6*dq11*m_6*C2*CC3*C5*C6*S2*S5 - 2*X6*Z6*dq11*m_6*C2*CC4*C5*C6*S2*S5 + 4*X6*Z6*dq11*m_6*CC2*C3*C5*C6*S3*S5 - 2*X6*Z6*dq11*m_6*C3*CC4*C5*C6*S3*S5 - 4*Y6*a3*dq11*m_6*C2*CC3*C4*C5*S2*S6 - 4*Y6*a3*dq11*m_6*CC2*C3*C4*C5*S3*S6 + 4*X6*d6*dq11*m_6*C2*CC3*C5*C6*S2*S5 - 2*X6*d6*dq11*m_6*C2*CC4*C5*C6*S2*S5 + 4*X6*d6*dq11*m_6*CC2*C3*C5*C6*S3*S5 - 2*X6*d6*dq11*m_6*C3*CC4*C5*C6*S3*S5 - 2*Y6*d4*dq15*m_6*S2*S3*S4*S5*S6 + 4*X6*Z6*dq14*m_6*C2*C3*C4*CC5*C6 - 4*Y5*Z5*dq11*m_5*C2*CC3*C4*S2*S4*S5 - 4*Y5*Z5*dq11*m_5*CC2*C3*C4*S3*S4*S5 - 4*Y6*Z6*dq11*m_6*C2*CC3*C5*S2*S5*S6 + 2*Y6*Z6*dq11*m_6*C2*CC4*C5*S2*S5*S6 - 4*Y6*Z6*dq11*m_6*CC2*C3*C5*S3*S5*S6 + 2*Y6*Z6*dq11*m_6*C3*CC4*C5*S3*S5*S6 - 2*Ixx6*dq15*C2*C4*C5*CC6*S3*S4*S5 - 2*Ixx6*dq15*C3*C4*C5*CC6*S2*S4*S5 - 2*Ixx6*dq16*C2*C4*CC5*C6*S3*S4*S6 - 2*Ixx6*dq16*C3*C4*CC5*C6*S2*S4*S6 + 2*Iyy6*dq15*C2*C4*C5*CC6*S3*S4*S5 + 2*Iyy6*dq15*C3*C4*C5*CC6*S2*S4*S5 + 2*Iyy6*dq16*C2*C4*CC5*C6*S3*S4*S6 + 2*Iyy6*dq16*C3*C4*CC5*C6*S2*S4*S6 + 2*XX6*dq14*m_6*C4*C5*CC6*S2*S3*S5 + 2*XX6*dq15*m_6*C2*CC4*C6*S3*S5*S6 + 2*XX6*dq15*m_6*C3*CC4*C6*S2*S5*S6 + 4*X6*d6*dq14*m_6*C2*C3*C4*CC5*C6 - 4*Y6*d6*dq11*m_6*C2*CC3*C5*S2*S5*S6 + 2*Y6*d6*dq11*m_6*C2*CC4*C5*S2*S5*S6 - 4*Y6*d6*dq11*m_6*CC2*C3*C5*S3*S5*S6 + 2*Y6*d6*dq11*m_6*C3*CC4*C5*S3*S5*S6 - 2*YY6*dq14*m_6*C4*C5*CC6*S2*S3*S5 - 2*YY6*dq15*m_6*C2*CC4*C6*S3*S5*S6 - 2*YY6*dq15*m_6*C3*CC4*C6*S2*S5*S6 - 4*Y6*Z6*dq14*m_6*C2*C3*C4*CC5*S6 - 2*Y6*Z6*dq15*m_6*C2*CC4*C5*C6*S3 - 2*Y6*Z6*dq15*m_6*C3*CC4*C5*C6*S2 - 2*Y6*Z6*dq16*m_6*C2*C3*CC5*C6*S4 - 4*Y6*d6*dq14*m_6*C2*C3*C4*CC5*S6 - 2*Y6*d6*dq15*m_6*C2*CC4*C5*C6*S3 - 2*Y6*d6*dq15*m_6*C3*CC4*C5*C6*S2 - 2*Y6*d6*dq16*m_6*C2*C3*CC5*C6*S4 + 4*X6*Y6*dq14*m_6*C2*C3*CC6*S4*S5 - 2*X6*Y6*dq16*m_6*C2*C4*CC5*S3*S4 - 2*X6*Y6*dq16*m_6*C3*C4*CC5*S2*S4 + 4*X6*Y6*dq14*m_6*C2*CC4*C6*S3*S6 + 4*X6*Y6*dq14*m_6*C3*CC4*C6*S2*S6 + 4*X6*Y6*dq16*m_6*C2*C4*CC6*S3*S4 + 4*X6*Y6*dq16*m_6*C3*C4*CC6*S2*S4 + 4*X6*Y6*dq24*m_6*C4*CC5*C6*S4*S6 + 4*X6*Y6*dq34*m_6*C4*CC5*C6*S4*S6 + 4*X6*Y6*dq25*m_6*CC4*C5*C6*S5*S6 + 4*X6*Y6*dq35*m_6*CC4*C5*C6*S5*S6 - 4*X5*Z5*dq14*m_5*C2*CC4*C5*S3*S5 - 4*X5*Z5*dq14*m_5*C3*CC4*C5*S2*S5 - 4*X5*Z5*dq15*m_5*C2*C4*CC5*S3*S4 - 4*X5*Z5*dq15*m_5*C3*C4*CC5*S2*S4 - 4*X6*Z6*dq14*m_6*C4*CC5*C6*S2*S3 - 2*X6*Z6*dq15*m_6*C2*CC4*C5*S3*S6 - 2*X6*Z6*dq15*m_6*C3*CC4*C5*S2*S6 - 2*X6*Z6*dq16*m_6*C2*C3*CC5*S4*S6 - 2*X6*Z6*dq16*m_6*C2*CC4*C6*S3*S5 - 2*X6*Z6*dq16*m_6*C3*CC4*C6*S2*S5 - 4*X6*d6*dq14*m_6*C4*CC5*C6*S2*S3 - 2*X6*d6*dq15*m_6*C2*CC4*C5*S3*S6 - 2*X6*d6*dq15*m_6*C3*CC4*C5*S2*S6 - 2*X6*d6*dq16*m_6*C2*C3*CC5*S4*S6 - 2*X6*d6*dq16*m_6*C2*CC4*C6*S3*S5 - 2*X6*d6*dq16*m_6*C3*CC4*C6*S2*S5 + 4*Y6*Z6*dq14*m_6*C4*CC5*S2*S3*S6 + 2*Y6*Z6*dq16*m_6*C2*CC4*S3*S5*S6 + 2*Y6*Z6*dq16*m_6*C3*CC4*S2*S5*S6 + 2*Y6*Z6*dq16*m_6*CC5*C6*S2*S3*S4 - 4*Y6*Z6*dq11*m_6*C2*CC3*CC4*C5*S2*S5*S6 - 4*Y6*Z6*dq11*m_6*CC2*C3*CC4*C5*S3*S5*S6 - 4*Y6*d6*dq11*m_6*C2*CC3*CC4*C5*S2*S5*S6 - 4*Y6*d6*dq11*m_6*CC2*C3*CC4*C5*S3*S5*S6 + 4*X6*Y6*dq14*m_6*C2*CC4*CC5*C6*S3*S6 + 4*X6*Y6*dq14*m_6*C3*CC4*CC5*C6*S2*S6 + 4*X6*Y6*dq16*m_6*C2*C4*CC5*CC6*S3*S4 + 4*X6*Y6*dq16*m_6*C3*C4*CC5*CC6*S2*S4 - 8*Ixy6*dq11*C2*C3*C4*C5*C6*S2*S3*S5*S6 + 4*XX6*dq11*m_6*C2*C3*C6*S2*S3*S4*S5*S6 + 4*X6*d4*dq11*m_6*C2*C3*C4*C5*C6*S2*S3 - 4*YY6*dq11*m_6*C2*C3*C6*S2*S3*S4*S5*S6 - 4*Y6*Z6*dq11*m_6*C2*C3*C5*C6*S2*S3*S4 + 4*XX6*dq14*m_6*C2*C4*C5*C6*S3*S4*S6 + 4*XX6*dq14*m_6*C3*C4*C5*C6*S2*S4*S6 + 2*XX6*dq16*m_6*C2*C3*C5*C6*S4*S5*S6 - 4*Y6*d4*dq11*m_6*C2*C3*C4*C5*S2*S3*S6 - 4*Y6*d6*dq11*m_6*C2*C3*C5*C6*S2*S3*S4 - 4*YY6*dq14*m_6*C2*C4*C5*C6*S3*S4*S6 - 4*YY6*dq14*m_6*C3*C4*C5*C6*S2*S4*S6 - 2*YY6*dq16*m_6*C2*C3*C5*C6*S4*S5*S6 + 8*Z6*d6*dq11*m_6*C2*C3*C4*C5*S2*S3*S5 - 4*X6*Y6*dq11*m_6*C2*CC3*CC4*CC5*C6*S2*S6 - 4*X6*Y6*dq11*m_6*CC2*C3*CC4*CC5*C6*S3*S6 - 4*X6*Z6*dq11*m_6*C2*C3*C5*S2*S3*S4*S6 + 4*Ixy6*dq15*C2*C4*C5*C6*S3*S4*S5*S6 + 4*Ixy6*dq15*C3*C4*C5*C6*S2*S4*S5*S6 - 4*X6*d6*dq11*m_6*C2*C3*C5*S2*S3*S4*S6 + 4*X6*Y6*dq16*m_6*C2*C3*C4*C6*S5*S6 - 4*X6*Z6*dq15*m_6*C2*C3*C5*C6*S4*S5 - 2*XX6*dq16*m_6*C5*C6*S2*S3*S4*S5*S6 - 4*X6*d6*dq15*m_6*C2*C3*C5*C6*S4*S5 + 2*YY6*dq16*m_6*C5*C6*S2*S3*S4*S5*S6 + 4*Y6*Z6*dq14*m_6*C2*C4*C6*S3*S4*S5 + 4*Y6*Z6*dq14*m_6*C3*C4*C6*S2*S4*S5 + 4*Y6*Z6*dq15*m_6*C2*C3*C5*S4*S5*S6 - 4*XX6*dq11*m_6*C2*C3*C4*C5*CC6*S2*S3*S5 - 4*XX6*dq11*m_6*C2*CC3*C4*C5*C6*S2*S4*S6 - 4*XX6*dq11*m_6*CC2*C3*C4*C5*C6*S3*S4*S6 + 4*YY6*dq11*m_6*C2*C3*C4*C5*CC6*S2*S3*S5 + 4*YY6*dq11*m_6*C2*CC3*C4*C5*C6*S2*S4*S6 + 4*YY6*dq11*m_6*CC2*C3*C4*C5*C6*S3*S4*S6 + 4*Y6*d6*dq14*m_6*C2*C4*C6*S3*S4*S5 + 4*Y6*d6*dq14*m_6*C3*C4*C6*S2*S4*S5 + 4*Y6*d6*dq15*m_6*C2*C3*C5*S4*S5*S6 - 4*Z6*d6*dq15*m_6*C2*C4*C5*S3*S4*S5 - 4*Z6*d6*dq15*m_6*C3*C4*C5*S2*S4*S5 - 4*X6*Y6*dq16*m_6*C4*C6*S2*S3*S5*S6 + 4*X6*Z6*dq14*m_6*C2*C4*S3*S4*S5*S6 + 4*X6*Z6*dq14*m_6*C3*C4*S2*S4*S5*S6 + 4*X6*Z6*dq15*m_6*C5*C6*S2*S3*S4*S5 + 4*X6*d6*dq14*m_6*C2*C4*S3*S4*S5*S6 + 4*X6*d6*dq14*m_6*C3*C4*S2*S4*S5*S6 + 4*X6*d6*dq15*m_6*C5*C6*S2*S3*S4*S5 + 8*X6*Z6*dq11*m_6*C2*C3*C4*CC5*C6*S2*S3 - 4*Y6*Z6*dq15*m_6*C5*S2*S3*S4*S5*S6 + 8*X6*d6*dq11*m_6*C2*C3*C4*CC5*C6*S2*S3 - 4*Y6*d6*dq15*m_6*C5*S2*S3*S4*S5*S6 - 8*Y6*Z6*dq11*m_6*C2*C3*C4*CC5*S2*S3*S6 - 4*Y6*Z6*dq11*m_6*C2*CC3*C4*C6*S2*S4*S5 - 4*Y6*Z6*dq11*m_6*CC2*C3*C4*C6*S3*S4*S5 + 2*XX6*dq15*m_6*C2*C4*C5*CC6*S3*S4*S5 + 2*XX6*dq15*m_6*C3*C4*C5*CC6*S2*S4*S5 + 2*XX6*dq16*m_6*C2*C4*CC5*C6*S3*S4*S6 + 2*XX6*dq16*m_6*C3*C4*CC5*C6*S2*S4*S6 - 8*Y6*d6*dq11*m_6*C2*C3*C4*CC5*S2*S3*S6 - 4*Y6*d6*dq11*m_6*C2*CC3*C4*C6*S2*S4*S5 - 4*Y6*d6*dq11*m_6*CC2*C3*C4*C6*S3*S4*S5 - 2*YY6*dq15*m_6*C2*C4*C5*CC6*S3*S4*S5 - 2*YY6*dq15*m_6*C3*C4*C5*CC6*S2*S4*S5 - 2*YY6*dq16*m_6*C2*C4*CC5*C6*S3*S4*S6 - 2*YY6*dq16*m_6*C3*C4*CC5*C6*S2*S4*S6 + 8*X6*Y6*dq11*m_6*C2*C3*CC6*S2*S3*S4*S5 - 4*X6*Z6*dq11*m_6*C2*CC3*C4*S2*S4*S5*S6 - 4*X6*Z6*dq11*m_6*CC2*C3*C4*S3*S4*S5*S6 - 4*X6*d6*dq11*m_6*C2*CC3*C4*S2*S4*S5*S6 - 4*X6*d6*dq11*m_6*CC2*C3*C4*S3*S4*S5*S6 + 8*X6*Y6*dq14*m_6*C2*C4*C5*CC6*S3*S4 + 8*X6*Y6*dq14*m_6*C3*C4*C5*CC6*S2*S4 + 4*X6*Y6*dq15*m_6*C2*C3*CC5*C6*S4*S6 + 4*X6*Y6*dq16*m_6*C2*C3*C5*CC6*S4*S5 + 8*X6*Y6*dq16*m_6*C2*CC4*C5*C6*S3*S6 + 8*X6*Y6*dq16*m_6*C3*CC4*C5*C6*S2*S6 - 4*X6*Z6*dq14*m_6*C2*CC4*C5*C6*S3*S5 - 4*X6*Z6*dq14*m_6*C3*CC4*C5*C6*S2*S5 - 4*X6*Z6*dq15*m_6*C2*C4*CC5*C6*S3*S4 - 4*X6*Z6*dq15*m_6*C3*C4*CC5*C6*S2*S4 - 4*X6*d6*dq14*m_6*C2*CC4*C5*C6*S3*S5 - 4*X6*d6*dq14*m_6*C3*CC4*C5*C6*S2*S5 - 4*X6*d6*dq15*m_6*C2*C4*CC5*C6*S3*S4 - 4*X6*d6*dq15*m_6*C3*C4*CC5*C6*S2*S4 + 4*Y6*Z6*dq14*m_6*C2*CC4*C5*S3*S5*S6 + 4*Y6*Z6*dq14*m_6*C3*CC4*C5*S2*S5*S6 + 4*Y6*Z6*dq15*m_6*C2*C4*CC5*S3*S4*S6 + 4*Y6*Z6*dq15*m_6*C3*C4*CC5*S2*S4*S6 + 4*Y6*d6*dq14*m_6*C2*CC4*C5*S3*S5*S6 + 4*Y6*d6*dq14*m_6*C3*CC4*C5*S2*S5*S6 + 4*Y6*d6*dq15*m_6*C2*C4*CC5*S3*S4*S6 + 4*Y6*d6*dq15*m_6*C3*C4*CC5*S2*S4*S6 - 4*X6*Y6*dq15*m_6*CC5*C6*S2*S3*S4*S6 - 4*X6*Y6*dq16*m_6*C5*CC6*S2*S3*S4*S5 - 8*X6*Y6*dq11*m_6*C2*CC3*C4*C5*CC6*S2*S4 - 8*X6*Y6*dq11*m_6*CC2*C3*C4*C5*CC6*S3*S4 - 8*X6*Y6*dq11*m_6*CC2*CC3*C4*C5*C6*S5*S6 + 4*X6*Z6*dq11*m_6*C2*CC3*CC4*C5*C6*S2*S5 + 4*X6*Z6*dq11*m_6*CC2*C3*CC4*C5*C6*S3*S5 + 4*X6*d6*dq11*m_6*C2*CC3*CC4*C5*C6*S2*S5 + 4*X6*d6*dq11*m_6*CC2*C3*CC4*C5*C6*S3*S5 + 4*X6*Y6*dq14*m_6*C2*C3*C4*C5*C6*S5*S6 + 2*Y6*Z6*dq16*m_6*C2*C4*C5*C6*S3*S4*S5 + 2*Y6*Z6*dq16*m_6*C3*C4*C5*C6*S2*S4*S5 + 2*Y6*d6*dq16*m_6*C2*C4*C5*C6*S3*S4*S5 + 2*Y6*d6*dq16*m_6*C3*C4*C5*C6*S2*S4*S5 - 4*X6*Y6*dq14*m_6*C4*C5*C6*S2*S3*S5*S6 + 2*X6*Z6*dq16*m_6*C2*C4*C5*S3*S4*S5*S6 + 2*X6*Z6*dq16*m_6*C3*C4*C5*S2*S4*S5*S6 + 2*X6*d6*dq16*m_6*C2*C4*C5*S3*S4*S5*S6 + 2*X6*d6*dq16*m_6*C3*C4*C5*S2*S4*S5*S6 - 4*X6*Y6*dq15*m_6*C2*C4*C5*C6*S3*S4*S5*S6 - 4*X6*Y6*dq15*m_6*C3*C4*C5*C6*S2*S4*S5*S6 + 8*X6*Y6*dq11*m_6*C2*C3*C4*C5*C6*S2*S3*S5*S6;
coriolis.array2d[2][0] = Ixz3*dq11 - Ixy4*dq11*C4 - Ixy4*dq44*C4 - Ixz5*dq11*C4 - Ixz5*dq44*C4 + Iyz4*dq11*S4 + Iyz4*dq44*S4 - 2*Ixz4*dq24 - 2*Ixz4*dq34 - 2*Ixz5*dq25 - 2*Ixz5*dq35 - 2*Ixz3*dq11*CC2 - 2*Ixz3*dq11*CC3 + (Ixx3*dq11*S22)/2 + (Ixx3*dq11*S33)/2 - (Ixx5*dq11*S22)/2 - (Ixx5*dq11*S33)/2 + (Ixx6*dq11*S22)/2 + (Ixx6*dq11*S33)/2 - (Iyy4*dq11*S22)/2 - (Iyy4*dq11*S33)/2 + (Iyy5*dq11*S22)/2 + (Iyy5*dq11*S33)/2 - (Iyy6*dq11*S22)/2 - (Iyy6*dq11*S33)/2 - (Izz3*dq11*S22)/2 - (Izz3*dq11*S33)/2 + (Izz4*dq11*S22)/2 + (Izz4*dq11*S33)/2 - Ixz6*dq11*C4*C6 - Ixz6*dq44*C4*C6 + Ixz6*dq66*C4*C6 - Iyz5*dq11*C5*S4 + Iyz6*dq11*C4*S6 - Iyz5*dq44*C5*S4 + Iyz5*dq55*C5*S4 + Iyz6*dq44*C4*S6 - Iyz6*dq66*C4*S6 + Ixy5*dq11*S4*S5 - Ixy6*dq11*S4*S5 + Ixy5*dq44*S4*S5 - Ixy5*dq55*S4*S5 - Ixy6*dq44*S4*S5 + Ixy6*dq55*S4*S5 - X3*Z3*dq11*m_3 - 2*Ixy5*dq24*C5 - 2*Ixy5*dq34*C5 + 2*Ixy6*dq24*C5 + 2*Ixy6*dq34*C5 - 2*Ixy6*dq56*C4 - 2*Ixz6*dq25*C6 - 2*Ixz6*dq35*C6 + Y4*a3*dq11*m_4 - Z3*a3*dq11*m_3 - a3*d4*dq11*m_4 - a3*d4*dq11*m_5 - a3*d4*dq11*m_6 + Ixx5*dq45*S4 - Ixx6*dq45*S4 - Iyy5*dq45*S4 + Iyy6*dq45*S4 - 2*Iyz5*dq24*S5 - 2*Iyz5*dq34*S5 + 2*Iyz6*dq25*S6 + 2*Iyz6*dq35*S6 - Izz5*dq45*S4 - Izz6*dq45*S4 + 2*Ixy4*dq11*CC2*C4 + 2*Ixy4*dq11*CC3*C4 + 2*Ixz5*dq11*CC2*C4 + 2*Ixz5*dq11*CC3*C4 + 2*Ixz5*dq11*C4*CC5 + 2*Ixz5*dq44*C4*CC5 - 2*Iyz4*dq11*CC2*S4 - 2*Iyz4*dq11*CC3*S4 - (XX3*dq11*m_3*S22)/2 - (XX3*dq11*m_3*S33)/2 + (XX5*dq11*m_5*S22)/2 + (XX5*dq11*m_5*S33)/2 - (XX6*dq11*m_6*S22)/2 - (XX6*dq11*m_6*S33)/2 + (YY4*dq11*m_4*S22)/2 + (YY4*dq11*m_4*S33)/2 - (YY5*dq11*m_5*S22)/2 - (YY5*dq11*m_5*S33)/2 + (YY6*dq11*m_6*S22)/2 + (YY6*dq11*m_6*S33)/2 + (ZZ3*dq11*m_3*S22)/2 + (ZZ3*dq11*m_3*S33)/2 - (ZZ4*dq11*m_4*S22)/2 - (ZZ4*dq11*m_4*S33)/2 - (aa3*dq11*m_3*S22)/2 - (aa3*dq11*m_3*S33)/2 - (aa3*dq11*m_4*S22)/2 - (aa3*dq11*m_4*S33)/2 - (aa3*dq11*m_5*S22)/2 - (aa3*dq11*m_5*S33)/2 - (aa3*dq11*m_6*S22)/2 - (aa3*dq11*m_6*S33)/2 + (dd4*dq11*m_4*S22)/2 + (dd4*dq11*m_4*S33)/2 + (dd4*dq11*m_5*S22)/2 + (dd4*dq11*m_5*S33)/2 + (dd4*dq11*m_6*S22)/2 + (dd4*dq11*m_6*S33)/2 - 2*Ixy6*dq26*CC4 + 2*Ixy6*dq26*CC5 - 2*Ixy6*dq36*CC4 + 2*Ixy6*dq36*CC5 + 4*Ixz4*dq24*CC4 + 4*Ixz4*dq34*CC4 + 2*Ixz5*dq25*CC4 + 4*Ixz5*dq25*CC5 + 2*Ixz5*dq35*CC4 + 4*Ixz5*dq35*CC5 + Ixx4*dq24*S44 + Ixx4*dq34*S44 - Ixx6*dq24*S44 - Ixx5*dq25*S55 - Ixx6*dq34*S44 - Ixx5*dq35*S55 - Iyy5*dq24*S44 - Iyy5*dq34*S44 - Iyy6*dq25*S55 - Iyy6*dq35*S55 - Izz4*dq24*S44 - Izz4*dq34*S44 + Izz5*dq24*S44 + Izz5*dq34*S44 + Izz6*dq24*S44 + Izz5*dq25*S55 + Izz6*dq34*S44 + Izz5*dq35*S55 + Izz6*dq25*S55 + Izz6*dq35*S55 + 4*Ixz3*dq11*CC2*CC3 - Ixz6*dq11*C5*S4*S6 - Ixz6*dq44*C5*S4*S6 + Ixz6*dq55*C5*S4*S6 - Ixz6*dq66*C5*S4*S6 + X4*Y4*dq11*m_4*C4 + X4*Y4*dq44*m_4*C4 + X5*Z5*dq11*m_5*C4 + X5*Z5*dq44*m_5*C4 + Y4*a2*dq22*m_4*C3 - Z3*a2*dq22*m_3*C3 - Z5*a3*dq11*m_5*C5 - Z6*a3*dq11*m_6*C5 + Z5*a3*dq55*m_5*C5 + Z6*a3*dq55*m_6*C5 - X4*d4*dq11*m_4*C4 - X4*d4*dq44*m_4*C4 - Y4*Z4*dq11*m_4*S4 - Y4*Z4*dq44*m_4*S4 - a2*d4*dq22*m_4*C3 - a2*d4*dq22*m_5*C3 - a2*d4*dq22*m_6*C3 - a3*d6*dq11*m_6*C5 + a3*d6*dq55*m_6*C5 - Ixx4*dq14*C2*S3 - Ixx4*dq14*C3*S2 - Ixx5*dq14*C2*S3 - Ixx5*dq14*C3*S2 + Ixx6*dq14*C2*S3 + Ixx6*dq14*C3*S2 + Ixx6*dq46*C4*S5 - Ixx6*dq56*C5*S4 - Iyy4*dq14*C2*S3 - Iyy4*dq14*C3*S2 + Iyy5*dq14*C2*S3 + Iyy5*dq14*C3*S2 - Iyy6*dq14*C2*S3 - Iyy6*dq14*C3*S2 - Iyy6*dq46*C4*S5 + Iyy6*dq56*C5*S4 - 2*Iyz6*dq24*C6*S5 - 2*Iyz6*dq34*C6*S5 + Izz4*dq14*C2*S3 + Izz4*dq14*C3*S2 - Izz5*dq14*C2*S3 - Izz5*dq14*C3*S2 - Izz6*dq14*C2*S3 - Izz6*dq14*C3*S2 + Izz6*dq46*C4*S5 + Izz6*dq56*C5*S4 + X3*a2*dq22*m_3*S3 + X5*a3*dq11*m_5*S5 - X5*a3*dq55*m_5*S5 - 2*XX5*dq45*m_5*S4 + Y5*d4*dq11*m_5*S4 + Y5*d4*dq44*m_5*S4 - 2*YY6*dq45*m_6*S4 + Z4*d4*dq11*m_4*S4 + Z4*d4*dq44*m_4*S4 + a2*a3*dq22*m_3*S3 + a2*a3*dq22*m_4*S3 + a2*a3*dq22*m_5*S3 + a2*a3*dq22*m_6*S3 - 2*Ixz6*dq24*S5*S6 - 2*Ixz6*dq34*S5*S6 + 2*X4*Z4*dq24*m_4 + 2*X4*Z4*dq34*m_4 + 2*X5*Z5*dq25*m_5 + 2*X5*Z5*dq35*m_5 + 2*Ixz6*dq11*CC2*C4*C6 + 2*Ixz6*dq11*CC3*C4*C6 + 2*Ixz6*dq11*C4*CC5*C6 + 2*Ixz6*dq44*C4*CC5*C6 - 2*Ixx3*dq11*C2*CC3*S2 - 2*Ixx3*dq11*CC2*C3*S3 + Ixx4*dq11*C2*CC4*S2 + 2*Ixx5*dq11*C2*CC3*S2 + 2*Ixx5*dq11*CC2*C3*S3 - 2*Ixx6*dq11*C2*CC3*S2 + Ixx4*dq11*C3*CC4*S3 + Ixx5*dq11*C2*CC5*S2 - Ixx6*dq11*C2*CC4*S2 - 2*Ixx6*dq11*CC2*C3*S3 + Ixx5*dq11*C3*CC5*S3 - 2*Ixx6*dq11*C2*CC6*S2 - Ixx6*dq11*C3*CC4*S3 - 2*Ixx6*dq11*C3*CC6*S3 + 2*Iyy4*dq11*C2*CC3*S2 + 2*Iyy4*dq11*CC2*C3*S3 - 2*Iyy5*dq11*C2*CC3*S2 - Iyy5*dq11*C2*CC4*S2 - 2*Iyy5*dq11*CC2*C3*S3 + 2*Iyy6*dq11*C2*CC3*S2 + 2*Iyy6*dq11*CC2*C3*S3 - Iyy5*dq11*C3*CC4*S3 + Iyy6*dq11*C2*CC5*S2 + 2*Iyy6*dq11*C2*CC6*S2 + Iyy6*dq11*C3*CC5*S3 + 2*Iyy6*dq11*C3*CC6*S3 + 2*Iyz5*dq11*CC2*C5*S4 + 2*Iyz5*dq11*CC3*C5*S4 - 2*Iyz6*dq11*CC2*C4*S6 - 2*Iyz6*dq11*CC3*C4*S6 - 2*Iyz6*dq11*C4*CC5*S6 - 2*Iyz6*dq44*C4*CC5*S6 + 2*Izz3*dq11*C2*CC3*S2 + 2*Izz3*dq11*CC2*C3*S3 - 2*Izz4*dq11*C2*CC3*S2 - Izz4*dq11*C2*CC4*S2 - 2*Izz4*dq11*CC2*C3*S3 + Izz5*dq11*C2*CC4*S2 - Izz4*dq11*C3*CC4*S3 - Izz5*dq11*C2*CC5*S2 + Izz6*dq11*C2*CC4*S2 + Izz5*dq11*C3*CC4*S3 - Izz6*dq11*C2*CC5*S2 - Izz5*dq11*C3*CC5*S3 + Izz6*dq11*C3*CC4*S3 - Izz6*dq11*C3*CC5*S3 - 2*Ixy5*dq11*CC2*S4*S5 - 2*Ixy5*dq11*CC3*S4*S5 + 2*Ixy6*dq11*CC2*S4*S5 + 2*Ixy6*dq11*CC3*S4*S5 + 2*Ixy6*dq11*CC6*S4*S5 + 2*Ixy6*dq44*CC6*S4*S5 - 2*Ixy6*dq55*CC6*S4*S5 + 2*X3*Z3*dq11*m_3*CC2 + 2*X3*Z3*dq11*m_3*CC3 + 4*Ixy5*dq24*CC4*C5 + 4*Ixy5*dq34*CC4*C5 - 4*Ixy6*dq24*CC4*C5 - 4*Ixy6*dq34*CC4*C5 - 4*Ixy6*dq24*C5*CC6 - 4*Ixy6*dq34*C5*CC6 + 4*Ixy6*dq56*C4*CC6 + 2*Ixz6*dq25*CC4*C6 + 4*Ixz6*dq25*CC5*C6 + 2*Ixz6*dq35*CC4*C6 + 4*Ixz6*dq35*CC5*C6 - 2*Y4*a3*dq11*m_4*CC2 - 2*Y4*a3*dq11*m_4*CC3 + 2*Z3*a3*dq11*m_3*CC2 + 2*Z3*a3*dq11*m_3*CC3 + 2*a3*d4*dq11*m_4*CC2 + 2*a3*d4*dq11*m_4*CC3 + 2*a3*d4*dq11*m_5*CC2 + 2*a3*d4*dq11*m_5*CC3 + 2*a3*d4*dq11*m_6*CC2 + 2*a3*d4*dq11*m_6*CC3 - 2*Ixx5*dq45*CC5*S4 + 2*Ixx6*dq45*CC6*S4 - 2*Iyy6*dq45*CC5*S4 - 2*Iyy6*dq45*CC6*S4 + 4*Iyz5*dq24*CC4*S5 + 4*Iyz5*dq34*CC4*S5 - 2*Iyz6*dq25*CC4*S6 - 4*Iyz6*dq25*CC5*S6 - 2*Iyz6*dq35*CC4*S6 - 4*Iyz6*dq35*CC5*S6 + 2*Izz5*dq45*CC5*S4 + 2*Izz6*dq45*CC5*S4 - X3*a3*dq11*m_3*S22 - X3*a3*dq11*m_3*S33 - XX4*dq24*m_4*S44 - XX4*dq34*m_4*S44 + XX5*dq25*m_5*S55 + XX6*dq24*m_6*S44 + XX5*dq35*m_5*S55 + XX6*dq34*m_6*S44 - Y4*d4*dq11*m_4*S22 - Y4*d4*dq11*m_4*S33 + YY5*dq24*m_5*S44 + YY5*dq34*m_5*S44 + YY6*dq25*m_6*S55 + YY6*dq35*m_6*S55 + ZZ4*dq24*m_4*S44 + ZZ4*dq34*m_4*S44 - ZZ5*dq24*m_5*S44 - ZZ5*dq34*m_5*S44 - ZZ5*dq25*m_5*S55 - ZZ6*dq24*m_6*S44 - ZZ5*dq35*m_5*S55 - ZZ6*dq34*m_6*S44 - ZZ6*dq25*m_6*S55 - ZZ6*dq35*m_6*S55 - dd6*dq24*m_6*S44 - dd6*dq34*m_6*S44 - dd6*dq25*m_6*S55 - dd6*dq35*m_6*S55 - 4*Ixy4*dq11*CC2*CC3*C4 - 4*Ixz5*dq11*CC2*CC3*C4 - 4*Ixz5*dq11*CC2*C4*CC5 - 4*Ixz5*dq11*CC3*C4*CC5 + 4*Iyz4*dq11*CC2*CC3*S4 - 2*Ixy6*dq26*CC4*CC5 + 4*Ixy6*dq26*CC4*CC6 - 2*Ixy6*dq36*CC4*CC5 - 4*Ixy6*dq26*CC5*CC6 + 4*Ixy6*dq36*CC4*CC6 - 4*Ixy6*dq36*CC5*CC6 - 4*Ixz5*dq25*CC4*CC5 - 4*Ixz5*dq35*CC4*CC5 - Ixx5*dq11*C4*C5*S5 - Ixx5*dq44*C4*C5*S5 - Iyy6*dq11*C4*C5*S5 - Iyy6*dq44*C4*C5*S5 - Iyz6*dq11*C5*C6*S4 - Iyz6*dq44*C5*C6*S4 + Iyz6*dq55*C5*C6*S4 - Iyz6*dq66*C5*C6*S4 + Izz5*dq11*C4*C5*S5 + Izz6*dq11*C4*C5*S5 + Izz5*dq44*C4*C5*S5 + Izz6*dq44*C4*C5*S5 + X3*a1*dq11*m_3*C2*S3 + X3*a1*dq11*m_3*C3*S2 + X4*a2*dq22*m_4*C4*S3 + X5*a2*dq22*m_5*C3*S5 + X6*a3*dq11*m_6*C6*S5 - X6*a3*dq55*m_6*C6*S5 - X6*a3*dq66*m_6*C6*S5 - 2*XX6*dq14*m_6*C2*S3 - 2*XX6*dq14*m_6*C3*S2 + 2*XX6*dq56*m_6*C5*S4 + Y6*d4*dq11*m_6*C6*S4 - Y6*d6*dq11*m_6*C4*S6 + Y6*d4*dq44*m_6*C6*S4 + Y6*d4*dq66*m_6*C6*S4 - Y6*d6*dq44*m_6*C4*S6 + Y6*d6*dq66*m_6*C4*S6 - 2*YY5*dq14*m_5*C2*S3 - 2*YY5*dq14*m_5*C3*S2 + 2*YY6*dq46*m_6*C4*S5 - Z5*d4*dq11*m_5*C4*S5 - Z6*d4*dq11*m_6*C4*S5 - Z5*d4*dq44*m_5*C4*S5 - Z5*d4*dq55*m_5*C4*S5 - Z6*d4*dq44*m_6*C4*S5 - Z6*d4*dq55*m_6*C4*S5 - 2*ZZ4*dq14*m_4*C2*S3 - 2*ZZ4*dq14*m_4*C3*S2 - X5*Y5*dq11*m_5*S4*S5 - X5*Y5*dq44*m_5*S4*S5 + X6*Y6*dq11*m_6*S4*S5 + X5*Y5*dq55*m_5*S4*S5 + X6*Y6*dq44*m_6*S4*S5 - X6*Y6*dq55*m_6*S4*S5 + a1*a3*dq11*m_3*C2*S3 + a1*a3*dq11*m_3*C3*S2 + a1*a3*dq11*m_4*C2*S3 + a1*a3*dq11*m_4*C3*S2 + a1*a3*dq11*m_5*C2*S3 + a1*a3*dq11*m_5*C3*S2 + a1*a3*dq11*m_6*C2*S3 + a1*a3*dq11*m_6*C3*S2 + 4*Ixy6*dq26*CC4*CC5*CC6 + 4*Ixy6*dq36*CC4*CC5*CC6 - 2*Ixy4*dq14*C4*S2*S3 + 2*Ixy5*dq15*C2*S3*S5 + 2*Ixy5*dq15*C3*S2*S5 - 2*Ixy6*dq15*C2*S3*S5 - 2*Ixy6*dq15*C3*S2*S5 - 2*Ixy5*dq25*C4*S4*S5 - 2*Ixy5*dq35*C4*S4*S5 + 2*Ixy6*dq25*C4*S4*S5 + 2*Ixy6*dq35*C4*S4*S5 - 2*Ixy6*dq46*C5*S4*S5 - 4*Ixy6*dq45*C6*S4*S6 - 2*Ixz5*dq14*C4*S2*S3 - 4*Ixz5*dq45*C5*S4*S5 - 2*Ixz6*dq26*C5*S5*S6 - 2*Ixz6*dq36*C5*S5*S6 - d4*d6*dq11*m_6*C4*S5 - d4*d6*dq44*m_6*C4*S5 - d4*d6*dq55*m_6*C4*S5 - Y4*a1*dq11*m_4*S2*S3 - Y5*a2*dq22*m_5*S3*S4 - Y6*a3*dq11*m_6*S5*S6 + Y6*a3*dq55*m_6*S5*S6 + Y6*a3*dq66*m_6*S5*S6 + Z3*a1*dq11*m_3*S2*S3 - Z4*a2*dq22*m_4*S3*S4 + X6*d4*dq11*m_6*S4*S6 + X6*d4*dq44*m_6*S4*S6 + X6*d4*dq66*m_6*S4*S6 + 2*X5*Y5*dq24*m_5*C5 + 2*X5*Y5*dq34*m_5*C5 - 2*X6*Y6*dq24*m_6*C5 - 2*X6*Y6*dq34*m_6*C5 + 2*X6*Y6*dq56*m_6*C4 + 2*X6*Z6*dq25*m_6*C6 + 2*X6*Z6*dq35*m_6*C6 + a1*d4*dq11*m_4*S2*S3 + a1*d4*dq11*m_5*S2*S3 + a1*d4*dq11*m_6*S2*S3 + Ixx5*dq15*S2*S3*S4 - Ixx6*dq15*S2*S3*S4 - Iyy5*dq15*S2*S3*S4 + Iyy6*dq15*S2*S3*S4 + 2*Iyz4*dq14*S2*S3*S4 - Izz5*dq15*S2*S3*S4 - Izz6*dq15*S2*S3*S4 - 2*Y5*a3*dq24*m_5*C4 - 2*Y5*a3*dq34*m_5*C4 - 2*Z4*a3*dq24*m_4*C4 - 2*Z4*a3*dq34*m_4*C4 - 2*X5*d4*dq25*m_5*C5 - 2*X5*d4*dq35*m_5*C5 + 2*X6*d6*dq25*m_6*C6 + 2*X6*d6*dq35*m_6*C6 + 2*Y5*Z5*dq24*m_5*S5 + 2*Y5*Z5*dq34*m_5*S5 - 2*Y6*Z6*dq25*m_6*S6 - 2*Y6*Z6*dq35*m_6*S6 + 2*Ixx5*dq11*CC2*C4*C5*S5 + 2*Ixx5*dq11*CC3*C4*C5*S5 - Ixx6*dq11*C4*C5*CC6*S5 - Ixx6*dq44*C4*C5*CC6*S5 + 2*Iyy6*dq11*CC2*C4*C5*S5 + 2*Iyy6*dq11*CC3*C4*C5*S5 + Iyy6*dq11*C4*C5*CC6*S5 + Iyy6*dq44*C4*C5*CC6*S5 + 2*Iyz6*dq11*CC2*C5*C6*S4 + 2*Iyz6*dq11*CC3*C5*C6*S4 - 2*Izz5*dq11*CC2*C4*C5*S5 - 2*Izz5*dq11*CC3*C4*C5*S5 - 2*Izz6*dq11*CC2*C4*C5*S5 - 2*Izz6*dq11*CC3*C4*C5*S5 - 2*X4*a3*dq24*m_4*S4 - 2*X4*a3*dq34*m_4*S4 + 2*XX3*dq11*m_3*C2*CC3*S2 + 2*XX3*dq11*m_3*CC2*C3*S3 - XX4*dq11*m_4*C2*CC4*S2 - 2*XX5*dq11*m_5*C2*CC3*S2 - XX4*dq11*m_4*C3*CC4*S3 - 2*XX5*dq11*m_5*CC2*C3*S3
 - XX5*dq11*m_5*C2*CC5*S2
 + 2*XX6*dq11*m_6*C2*CC3*S2 + XX6*dq11*m_6*C2*CC4*S2 + 2*XX6*dq11*m_6*CC2*C3*S3 - XX5*dq11*m_5*C3*CC5*S3 + 2*XX6*dq11*m_6*C2*CC6*S2 + XX6*dq11*m_6*C3*CC4*S3 + 2*XX6*dq11*m_6*C3*CC6*S3 - 2*YY4*dq11*m_4*C2*CC3*S2 - 2*YY4*dq11*m_4*CC2*C3*S3 + 2*YY5*dq11*m_5*C2*CC3*S2 + YY5*dq11*m_5*C2*CC4*S2 + 2*YY5*dq11*m_5*CC2*C3*S3 - 2*YY6*dq11*m_6*C2*CC3*S2 + YY5*dq11*m_5*C3*CC4*S3 - 2*YY6*dq11*m_6*CC2*C3*S3 - YY6*dq11*m_6*C2*CC5*S2 - 2*YY6*dq11*m_6*C2*CC6*S2 - YY6*dq11*m_6*C3*CC5*S3 - 2*YY6*dq11*m_6*C3*CC6*S3 - 2*ZZ3*dq11*m_3*C2*CC3*S2 - 2*ZZ3*dq11*m_3*CC2*C3*S3 + 2*ZZ4*dq11*m_4*C2*CC3*S2 + ZZ4*dq11*m_4*C2*CC4*S2 + 2*ZZ4*dq11*m_4*CC2*C3*S3 + ZZ4*dq11*m_4*C3*CC4*S3 - ZZ5*dq11*m_5*C2*CC4*S2 + ZZ5*dq11*m_5*C2*CC5*S2 - ZZ5*dq11*m_5*C3*CC4*S3 - ZZ6*dq11*m_6*C2*CC4*S2 + ZZ5*dq11*m_5*C3*CC5*S3 + ZZ6*dq11*m_6*C2*CC5*S2 - ZZ6*dq11*m_6*C3*CC4*S3 + ZZ6*dq11*m_6*C3*CC5*S3 - 2*Y6*d6*dq25*m_6*S6 - 2*Y6*d6*dq35*m_6*S6 - 2*Z5*d4*dq25*m_5*S5 - 2*Z5*d4*dq35*m_5*S5 - 2*Z6*d4*dq25*m_6*S5 - 2*Z6*d4*dq35*m_6*S5 + 2*aa3*dq11*m_3*C2*CC3*S2 + 2*aa3*dq11*m_3*CC2*C3*S3 + 2*aa3*dq11*m_4*C2*CC3*S2 + 2*aa3*dq11*m_4*CC2*C3*S3 + 2*aa3*dq11*m_5*C2*CC3*S2 + 2*aa3*dq11*m_5*CC2*C3*S3 + 2*aa3*dq11*m_6*C2*CC3*S2 + 2*aa3*dq11*m_6*CC2*C3*S3 + 2*Ixz6*dq11*CC2*C5*S4*S6 + 2*Ixz6*dq11*CC3*C5*S4*S6 - 2*dd4*dq11*m_4*C2*CC3*S2 - 2*dd4*dq11*m_4*CC2*C3*S3 - 2*dd4*dq11*m_5*C2*CC3*S2 - 2*dd4*dq11*m_5*CC2*C3*S3 - 2*dd4*dq11*m_6*C2*CC3*S2 - 2*dd4*dq11*m_6*CC2*C3*S3 - dd6*dq11*m_6*C2*CC4*S2 + dd6*dq11*m_6*C2*CC5*S2 - dd6*dq11*m_6*C3*CC4*S3 + dd6*dq11*m_6*C3*CC5*S3 - 2*d4*d6*dq25*m_6*S5 - 2*d4*d6*dq35*m_6*S5 - 2*X4*Y4*dq11*m_4*CC2*C4 - 2*X4*Y4*dq11*m_4*CC3*C4 - 2*X5*Z5*dq11*m_5*CC2*C4 - 2*X5*Z5*dq11*m_5*CC3*C4 - 2*X5*Z5*dq11*m_5*C4*CC5 - 2*X5*Z5*dq44*m_5*C4*CC5 + Y4*a2*dq11*m_4*CC2*C3 - Z3*a2*dq11*m_3*CC2*C3 + 2*Z5*a3*dq11*m_5*CC2*C5 + 2*Z5*a3*dq11*m_5*CC3*C5 + 2*Z6*a3*dq11*m_6*CC2*C5 + 2*Z6*a3*dq11*m_6*CC3*C5 + 2*X4*d4*dq11*m_4*CC2*C4 + 2*X4*d4*dq11*m_4*CC3*C4 + 2*Y4*Z4*dq11*m_4*CC2*S4 + 2*Y4*Z4*dq11*m_4*CC3*S4 - a2*d4*dq11*m_4*CC2*C3 - a2*d4*dq11*m_5*CC2*C3 - a2*d4*dq11*m_6*CC2*C3 + 2*a3*d6*dq11*m_6*CC2*C5 + 2*a3*d6*dq11*m_6*CC3*C5 + 2*Ixx4*dq14*C2*CC4*S3 + 2*Ixx4*dq14*C3*CC4*S2 - 2*Ixx6*dq14*C2*CC4*S3 - 2*Ixx6*dq14*C3*CC4*S2 - 2*Ixx6*dq14*C2*CC6*S3 - 2*Ixx6*dq14*C3*CC6*S2 + 2*Ixx5*dq24*C4*CC5*S4 + 2*Ixx5*dq34*C4*CC5*S4 + 2*Ixx5*dq25*CC4*C5*S5 + 2*Ixx6*dq24*C4*CC6*S4 + 2*Ixx5*dq35*CC4*C5*S5 + 2*Ixx6*dq34*C4*CC6*S4 - 2*Ixx6*dq25*C5*CC6*S5 + 2*Ixx6*dq26*CC4*C6*S6 - 2*Ixx6*dq35*C5*CC6*S5 - 2*Ixx6*dq26*CC5*C6*S6 + 2*Ixx6*dq36*CC4*C6*S6 - 2*Ixx6*dq46*C4*CC6*S5 - 2*Ixx6*dq36*CC5*C6*S6 + 2*Ixx6*dq56*C5*CC6*S4 - 2*Iyy5*dq14*C2*CC4*S3 - 2*Iyy5*dq14*C3*CC4*S2 + 2*Iyy6*dq14*C2*CC6*S3 + 2*Iyy6*dq14*C3*CC6*S2 + 2*Iyy6*dq24*C4*CC5*S4 - 2*Iyy6*dq24*C4*CC6*S4 + 2*Iyy6*dq34*C4*CC5*S4 + 2*Iyy6*dq25*CC4*C5*S5 - 2*Iyy6*dq34*C4*CC6*S4 + 2*Iyy6*dq35*CC4*C5*S5 + 2*Iyy6*dq25*C5*CC6*S5 - 2*Iyy6*dq26*CC4*C6*S6 + 2*Iyy6*dq35*C5*CC6*S5 + 2*Iyy6*dq26*CC5*C6*S6 - 2*Iyy6*dq36*CC4*C6*S6 + 2*Iyy6*dq46*C4*CC6*S5 + 2*Iyy6*dq36*CC5*C6*S6 - 2*Iyy6*dq56*C5*CC6*S4 + 4*Iyz6*dq24*CC4*C6*S5 + 4*Iyz6*dq34*CC4*C6*S5 - 2*Iyz6*dq46*CC5*C6*S4 - 2*Izz4*dq14*C2*CC4*S3 - 2*Izz4*dq14*C3*CC4*S2 + 2*Izz5*dq14*C2*CC4*S3 + 2*Izz5*dq14*C3*CC4*S2 + 2*Izz6*dq14*C2*CC4*S3 + 2*Izz6*dq14*C3*CC4*S2 - 2*Izz5*dq24*C4*CC5*S4 - 2*Izz5*dq34*C4*CC5*S4 - 2*Izz6*dq24*C4*CC5*S4 - 2*Izz5*dq25*CC4*C5*S5 - 2*Izz6*dq34*C4*CC5*S4 - 2*Izz5*dq35*CC4*C5*S5 - 2*Izz6*dq25*CC4*C5*S5 - 2*Izz6*dq35*CC4*C5*S5 + X3*a2*dq11*m_3*CC2*S3 - 2*X5*a3*dq11*m_5*CC2*S5 - 2*X5*a3*dq11*m_5*CC3*S5 + 2*XX5*dq45*m_5*CC5*S4 - 2*XX6*dq45*m_6*CC6*S4 - 2*Y5*d4*dq11*m_5*CC2*S4 - 2*Y5*d4*dq11*m_5*CC3*S4 + 2*YY6*dq45*m_6*CC5*S4 + 2*YY6*dq45*m_6*CC6*S4 - 2*Z4*d4*dq11*m_4*CC2*S4 - 2*Z4*d4*dq11*m_4*CC3*S4 - 2*ZZ5*dq45*m_5*CC5*S4 - 2*ZZ6*dq45*m_6*CC5*S4 + a2*a3*dq11*m_3*CC2*S3 + a2*a3*dq11*m_4*CC2*S3 + a2*a3*dq11*m_5*CC2*S3 + a2*a3*dq11*m_6*CC2*S3 + 4*Ixz6*dq24*CC4*S5*S6 + 4*Ixz6*dq34*CC4*S5*S6 - 2*Ixz6*dq46*CC5*S4*S6 - 2*dd6*dq45*m_6*CC5*S4 + 2*X6*Y6*dq26*m_6*CC4 - 2*X6*Y6*dq26*m_6*CC5 + 2*X6*Y6*dq36*m_6*CC4 - 2*X6*Y6*dq36*m_6*CC5 - 4*X4*Z4*dq24*m_4*CC4 - 4*X4*Z4*dq34*m_4*CC4 - 2*X5*Z5*dq25*m_5*CC4 - 4*X5*Z5*dq25*m_5*CC5 - 2*X5*Z5*dq35*m_5*CC4 - 4*X5*Z5*dq35*m_5*CC5 - 4*Ixz6*dq11*CC2*CC3*C4*C6 - 4*Ixz6*dq11*CC2*C4*CC5*C6 - 4*Ixz6*dq11*CC3*C4*CC5*C6 - 2*Ixx4*dq11*C2*CC3*CC4*S2 - 2*Ixx4*dq11*CC2*C3*CC4*S3 - 2*Ixx5*dq11*C2*CC3*CC5*S2 + 2*Ixx6*dq11*C2*CC3*CC4*S2 + Ixx5*dq11*C2*CC4*CC5*S2 - 2*Ixx5*dq11*CC2*C3*CC5*S3 + 2*Ixx6*dq11*CC2*C3*CC4*S3 + 4*Ixx6*dq11*C2*CC3*CC6*S2 + Ixx5*dq11*C3*CC4*CC5*S3 + Ixx6*dq11*C2*CC4*CC6*S2 + 4*Ixx6*dq11*CC2*C3*CC6*S3 + Ixx6*dq11*C2*CC5*CC6*S2 + Ixx6*dq11*C3*CC4*CC6*S3 + Ixx6*dq11*C3*CC5*CC6*S3 + 2*Iyy5*dq11*C2*CC3*CC4*S2 + 2*Iyy5*dq11*CC2*C3*CC4*S3 - 2*Iyy6*dq11*C2*CC3*CC5*S2 - 4*Iyy6*dq11*C2*CC3*CC6*S2 + Iyy6*dq11*C2*CC4*CC5*S2 - 2*Iyy6*dq11*CC2*C3*CC5*S3 - Iyy6*dq11*C2*CC4*CC6*S2 - 4*Iyy6*dq11*CC2*C3*CC6*S3 - Iyy6*dq11*C2*CC5*CC6*S2 + Iyy6*dq11*C3*CC4*CC5*S3 - Iyy6*dq11*C3*CC4*CC6*S3 - Iyy6*dq11*C3*CC5*CC6*S3 - 4*Iyz5*dq11*CC2*CC3*C5*S4 + 4*Iyz6*dq11*CC2*CC3*C4*S6 + 4*Iyz6*dq11*CC2*C4*CC5*S6 + 4*Iyz6*dq11*CC3*C4*CC5*S6 + 2*Izz4*dq11*C2*CC3*CC4*S2 + 2*Izz4*dq11*CC2*C3*CC4*S3 - 2*Izz5*dq11*C2*CC3*CC4*S2 + 2*Izz5*dq11*C2*CC3*CC5*S2 - 2*Izz5*dq11*CC2*C3*CC4*S3 - 2*Izz6*dq11*C2*CC3*CC4*S2 - Izz5*dq11*C2*CC4*CC5*S2 + 2*Izz5*dq11*CC2*C3*CC5*S3 + 2*Izz6*dq11*C2*CC3*CC5*S2 - 2*Izz6*dq11*CC2*C3*CC4*S3 - Izz6*dq11*C2*CC4*CC5*S2 + 2*Izz6*dq11*CC2*C3*CC5*S3 - Izz5*dq11*C3*CC4*CC5*S3 - Izz6*dq11*C3*CC4*CC5*S3 - 2*Z6*d6*dq24*m_6*S44 - 2*Z6*d6*dq34*m_6*S44 - 2*Z6*d6*dq25*m_6*S55 - 2*Z6*d6*dq35*m_6*S55 + 4*Ixy5*dq11*CC2*CC3*S4*S5 - 4*Ixy6*dq11*CC2*CC3*S4*S5 - 4*Ixy6*dq11*CC2*CC6*S4*S5 - 4*Ixy6*dq11*CC3*CC6*S4*S5 - 4*X3*Z3*dq11*m_3*CC2*CC3 + 8*Ixy6*dq24*CC4*C5*CC6 + 8*Ixy6*dq34*CC4*C5*CC6 - 4*Ixz6*dq25*CC4*CC5*C6 - 4*Ixz6*dq35*CC4*CC5*C6 + 4*Y4*a3*dq11*m_4*CC2*CC3 - 4*Z3*a3*dq11*m_3*CC2*CC3 - 4*a3*d4*dq11*m_4*CC2*CC3 - 4*a3*d4*dq11*m_5*CC2*CC3 - 4*a3*d4*dq11*m_6*CC2*CC3 - 2*Ixx6*dq45*CC5*CC6*S4 + 2*Iyy6*dq45*CC5*CC6*S4 + 4*Iyz6*dq25*CC4*CC5*S6 + 4*Iyz6*dq35*CC4*CC5*S6 + XX5*dq11*m_5*C4*C5*S5 + XX5*dq44*m_5*C4*C5*S5 + YY6*dq11*m_6*C4*C5*S5 + YY6*dq44*m_6*C4*C5*S5 - ZZ5*dq11*m_5*C4*C5*S5 - ZZ6*dq11*m_6*C4*C5*S5 - ZZ5*dq44*m_5*C4*C5*S5 - ZZ6*dq44*m_6*C4*C5*S5 + 8*Ixz5*dq11*CC2*CC3*C4*CC5 + 4*Ixy6*dq11*C2*C6*S2*S6 + 4*Ixy6*dq11*C3*C6*S3*S6 - 4*Ixz3*dq11*C2*C3*S2*S3 - 2*Ixz4*dq11*C2*C4*S2*S4 - 2*Ixz4*dq11*C3*C4*S3*S4 + 2*Ixz5*dq11*C2*C5*S2*S5 + 2*Ixz5*dq11*C3*C5*S3*S5 - dd6*dq11*m_6*C4*C5*S5 - dd6*dq44*m_6*C4*C5*S5 + X6*Z6*dq11*m_6*C4*C6 + X6*Z6*dq44*m_6*C4*C6 - X6*Z6*dq66*m_6*C4*C6 + Ixx6*dq11*C6*S4*S5*S6 + Ixx6*dq44*C6*S4*S5*S6 - Ixx6*dq55*C6*S4*S5*S6 - Iyy6*dq11*C6*S4*S5*S6 - Iyy6*dq44*C6*S4*S5*S6 + Iyy6*dq55*C6*S4*S5*S6 + 2*Ixy4*dq14*C2*C3*C4 + 2*Ixz5*dq14*C2*C3*C4 + 2*Ixz6*dq46*C4*C5*C6 + Y4*a1*dq11*m_4*C2*C3 - Z3*a1*dq11*m_3*C2*C3 - Z5*a2*dq22*m_5*C3*C5 - Z6*a2*dq22*m_6*C3*C5 - X5*d4*dq11*m_5*C4*C5 - X5*d4*dq44*m_5*C4*C5 - X5*d4*dq55*m_5*C4*C5 + X6*d6*dq11*m_6*C4*C6 + X6*d6*dq44*m_6*C4*C6 - X6*d6*dq66*m_6*C4*C6 + Y5*Z5*dq11*m_5*C5*S4 + Y5*Z5*dq44*m_5*C5*S4 - Y5*Z5*dq55*m_5*C5*S4 - Y6*Z6*dq11*m_6*C4*S6 - Y6*Z6*dq44*m_6*C4*S6 + Y6*Z6*dq66*m_6*C4*S6 - a1*d4*dq11*m_4*C2*C3 - a1*d4*dq11*m_5*C2*C3 - a1*d4*dq11*m_6*C2*C3 - a2*d6*dq22*m_6*C3*C5 - Ixx5*dq15*C2*C3*S4 + Ixx6*dq15*C2*C3*S4 + Ixx6*dq16*C2*C5*S3 + Ixx6*dq16*C3*C5*S2 - 2*Ixx6*dq26*C4*C5*S4 - 2*Ixx6*dq36*C4*C5*S4 - 2*Ixx6*dq24*C5*C6*S6 - 2*Ixx6*dq34*C5*C6*S6 + 2*Ixx6*dq56*C4*C6*S6 + Iyy5*dq15*C2*C3*S4 - Iyy6*dq15*C2*C3*S4 - Iyy6*dq16*C2*C5*S3 - Iyy6*dq16*C3*C5*S2 + 2*Iyy6*dq26*C4*C5*S4 + 2*Iyy6*dq36*C4*C5*S4 + 2*Iyy6*dq24*C5*C6*S6 + 2*Iyy6*dq34*C5*C6*S6 - 2*Iyy6*dq56*C4*C6*S6 - 2*Iyz4*dq14*C2*C3*S4 - 2*Iyz5*dq15*C2*C5*S3 - 2*Iyz5*dq15*C3*C5*S2 + 2*Iyz5*dq25*C4*C5*S4 + 2*Iyz5*dq35*C4*C5*S4 - 2*Iyz6*dq26*C5*C6*S5 - 2*Iyz6*dq36*C5*C6*S5 - 2*Iyz6*dq46*C4*C5*S6 + Izz5*dq15*C2*C3*S4 + Izz6*dq15*C2*C3*S4 - Izz6*dq16*C2*C5*S3 - Izz6*dq16*C3*C5*S2 + 2*Y6*Z6*dq24*m_6*C6*S5 + 2*Y6*Z6*dq34*m_6*C6*S5 + 2*Ixy5*dq14*S2*S3*S4*S5 - 2*Ixy6*dq14*S2*S3*S4*S5 + 2*a3*d6*dq25*m_6*C4*C5 + 2*a3*d6*dq35*m_6*C4*C5 - 2*X5*a3*dq24*m_5*C5*S4 - 2*X5*a3*dq25*m_5*C4*S5 - 2*X5*a3*dq34*m_5*C5*S4 - 2*X5*a3*dq35*m_5*C4*S5 - 2*X6*a3*dq24*m_6*C4*S6 - 2*X6*a3*dq34*m_6*C4*S6 - 2*X6*a3*dq26*m_6*C6*S4 - 2*X6*a3*dq36*m_6*C6*S4 - 2*X6*a3*dq56*m_6*C5*S6 - 2*XX5*dq11*m_5*CC2*C4*C5*S5 - 2*XX5*dq11*m_5*CC3*C4*C5*S5 + XX6*dq11*m_6*C4*C5*CC6*S5 + XX6*dq44*m_6*C4*C5*CC6*S5 - 2*YY6*dq11*m_6*CC2*C4*C5*S5 - 2*YY6*dq11*m_6*CC3*C4*C5*S5 - YY6*dq11*m_6*C4*C5*CC6*S5 - YY6*dq44*m_6*C4*C5*CC6*S5 + 2*ZZ5*dq11*m_5*CC2*C4*C5*S5 + 2*ZZ5*dq11*m_5*CC3*C4*C5*S5 + 2*ZZ6*dq11*m_6*CC2*C4*C5*S5 + 2*ZZ6*dq11*m_6*CC3*C4*C5*S5 + 2*Y6*d4*dq25*m_6*C5*S6 + 2*Y6*d4*dq26*m_6*C6*S5 + 2*Y6*d4*dq35*m_6*C5*S6 + 2*Y6*d6*dq24*m_6*C6*S5 + 2*Y6*d4*dq36*m_6*C6*S5 + 2*Y6*d4*dq46*m_6*C4*S6 + 2*Y6*d6*dq34*m_6*C6*S5 - 2*Z5*d4*dq45*m_5*C5*S4 - 2*Z6*d4*dq45*m_6*C5*S4 + 2*X6*Z6*dq24*m_6*S5*S6 + 2*X6*Z6*dq34*m_6*S5*S6 - 8*Ixy6*dq11*C2*CC3*C6*S2*S6 - 2*Ixy6*dq11*C2*CC4*C6*S2*S6 - 8*Ixy6*dq11*CC2*C3*C6*S3*S6 - 2*Ixy6*dq11*C2*CC5*C6*S2*S6 - 2*Ixy6*dq11*C3*CC4*C6*S3*S6 - 2*Ixy6*dq11*C3*CC5*C6*S3*S6 + 4*Ixz4*dq11*C2*CC3*C4*S2*S4 + 4*Ixz4*dq11*CC2*C3*C4*S3*S4 - 4*Ixz5*dq11*C2*CC3*C5*S2*S5 + 2*Ixz5*dq11*C2*CC4*C5*S2*S5 - 4*Ixz5*dq11*CC2*C3*C5*S3*S5 + 2*Ixz5*dq11*C3*CC4*C5*S3*S5 + 2*dd6*dq11*m_6*CC2*C4*C5*S5 + 2*dd6*dq11*m_6*CC3*C4*C5*S5 - 2*d4*d6*dq45*m_6*C5*S4 + 2*Y6*a3*dq26*m_6*S4*S6 + 2*Y6*a3*dq36*m_6*S4*S6 - 2*Z5*a3*dq24*m_5*S4*S5 - 2*Z5*a3*dq34*m_5*S4*S5 - 2*Z6*a3*dq24*m_6*S4*S5 - 2*Z6*a3*dq34*m_6*S4*S5 + 2*X5*d4*dq45*m_5*S4*S5 + 2*X6*d4*dq26*m_6*S5*S6 + 2*X6*d6*dq24*m_6*S5*S6 + 2*X6*d4*dq36*m_6*S5*S6 + 2*X6*d6*dq34*m_6*S5*S6 - 2*X6*Z6*dq11*m_6*CC2*C4*C6 - 2*X6*Z6*dq11*m_6*CC3*C4*C6 - 2*X6*Z6*dq11*m_6*C4*CC5*C6 - 2*X6*Z6*dq44*m_6*C4*CC5*C6 - 2*Ixx6*dq11*CC2*C6*S4*S5*S6 - 2*Ixx6*dq11*CC3*C6*S4*S5*S6 + 2*Iyy6*dq11*CC2*C6*S4*S5*S6 + 2*Iyy6*dq11*CC3*C6*S4*S5*S6 - 4*Ixz5*dq14*C2*C3*C4*CC5 - 2*a3*d6*dq24*m_6*S4*S5 - 2*a3*d6*dq34*m_6*S4*S5
 - Z5*a2*dq11*m_5*CC2*C3*C5 - Z6*a2*dq11*m_6*CC2*C3*C5 + 2*X5*d4*dq11*m_5*CC2*C4*C5 + 2*X5*d4*dq11*m_5*CC3*C4*C5 - 2*X6*d6*dq11*m_6*CC2*C4*C6 - 2*X6*d6*dq11*m_6*CC3*C4*C6 - 2*X6*d6*dq11*m_6*C4*CC5*C6 - 2*X6*d6*dq44*m_6*C4*CC5*C6 - 2*Y5*Z5*dq11*m_5*CC2*C5*S4 - 2*Y5*Z5*dq11*m_5*CC3*C5*S4 + 2*Y6*Z6*dq11*m_6*CC2*C4*S6 + 2*Y6*Z6*dq11*m_6*CC3*C4*S6 + 2*Y6*Z6*dq11*m_6*C4*CC5*S6 + 2*Y6*Z6*dq44*m_6*C4*CC5*S6 - a2*d6*dq11*m_6*CC2*C3*C5 + 2*Ixx5*dq15*C2*C3*CC5*S4 - 2*Ixx6*dq15*C2*C3*CC6*S4 - 2*Ixx6*dq16*C2*CC4*C5*S3 - 2*Ixx6*dq16*C3*CC4*C5*S2 - 2*Ixx6*dq16*C2*C5*CC6*S3 - 2*Ixx6*dq16*C3*C5*CC6*S2 + 4*Ixx6*dq24*CC4*C5*C6*S6 + 4*Ixx6*dq26*C4*C5*CC6*S4 + 4*Ixx6*dq34*CC4*C5*C6*S6 + 4*Ixx6*dq36*C4*C5*CC6*S4 + 2*Iyy6*dq15*C2*C3*CC5*S4 + 2*Iyy6*dq15*C2*C3*CC6*S4 + 2*Iyy6*dq16*C2*CC4*C5*S3 + 2*Iyy6*dq16*C3*CC4*C5*S2 + 2*Iyy6*dq16*C2*C5*CC6*S3 + 2*Iyy6*dq16*C3*C5*CC6*S2 - 4*Iyy6*dq24*CC4*C5*C6*S6 - 4*Iyy6*dq26*C4*C5*CC6*S4 - 4*Iyy6*dq34*CC4*C5*C6*S6 - 4*Iyy6*dq36*C4*C5*CC6*S4 + 2*Iyz5*dq15*C2*CC4*C5*S3 + 2*Iyz5*dq15*C3*CC4*C5*S2 + 2*Iyz6*dq26*CC4*C5*C6*S5 + 2*Iyz6*dq36*CC4*C5*C6*S5 - 2*Izz5*dq15*C2*C3*CC5*S4 - 2*Izz6*dq15*C2*C3*CC5*S4 + 4*X3*a3*dq11*m_3*C2*CC3*S2 + 4*X3*a3*dq11*m_3*CC2*C3*S3 + X4*a2*dq11*m_4*CC2*C4*S3 + X5*a2*dq11*m_5*CC2*C3*S5 - 2*X6*a3*dq11*m_6*CC2*C6*S5 - 2*X6*a3*dq11*m_6*CC3*C6*S5 - 2*XX4*dq14*m_4*C2*CC4*S3 - 2*XX4*dq14*m_4*C3*CC4*S2 + 2*XX6*dq14*m_6*C2*CC4*S3 + 2*XX6*dq14*m_6*C3*CC4*S2 + 2*XX6*dq14*m_6*C2*CC6*S3 + 2*XX6*dq14*m_6*C3*CC6*S2 - 2*XX5*dq24*m_5*C4*CC5*S4 - 2*XX5*dq34*m_5*C4*CC5*S4 - 2*XX5*dq25*m_5*CC4*C5*S5 - 2*XX5*dq35*m_5*CC4*C5*S5 - 2*XX6*dq24*m_6*C4*CC6*S4 - 2*XX6*dq34*m_6*C4*CC6*S4 + 2*XX6*dq25*m_6*C5*CC6*S5 - 2*XX6*dq26*m_6*CC4*C6*S6 + 2*XX6*dq35*m_6*C5*CC6*S5 + 2*XX6*dq26*m_6*CC5*C6*S6 - 2*XX6*dq36*m_6*CC4*C6*S6 + 2*XX6*dq46*m_6*C4*CC6*S5 + 2*XX6*dq36*m_6*CC5*C6*S6 - 2*XX6*dq56*m_6*C5*CC6*S4 + 4*Y4*d4*dq11*m_4*C2*CC3*S2 + 4*Y4*d4*dq11*m_4*CC2*C3*S3 - 2*Y6*d4*dq11*m_6*CC2*C6*S4 - 2*Y6*d4*dq11*m_6*CC3*C6*S4 + 2*Y6*d6*dq11*m_6*CC2*C4*S6 + 2*Y6*d6*dq11*m_6*CC3*C4*S6 + 2*Y6*d6*dq11*m_6*C4*CC5*S6 + 2*Y6*d6*dq44*m_6*C4*CC5*S6 + 2*YY5*dq14*m_5*C2*CC4*S3 + 2*YY5*dq14*m_5*C3*CC4*S2 - 2*YY6*dq14*m_6*C2*CC6*S3 - 2*YY6*dq14*m_6*C3*CC6*S2 - 2*YY6*dq24*m_6*C4*CC5*S4 + 2*YY6*dq24*m_6*C4*CC6*S4 - 2*YY6*dq34*m_6*C4*CC5*S4 - 2*YY6*dq25*m_6*CC4*C5*S5 + 2*YY6*dq34*m_6*C4*CC6*S4 - 2*YY6*dq35*m_6*CC4*C5*S5 - 2*YY6*dq25*m_6*C5*CC6*S5 + 2*YY6*dq26*m_6*CC4*C6*S6 - 2*YY6*dq35*m_6*C5*CC6*S5 - 2*YY6*dq26*m_6*CC5*C6*S6 + 2*YY6*dq36*m_6*CC4*C6*S6 - 2*YY6*dq46*m_6*C4*CC6*S5 - 2*YY6*dq36*m_6*CC5*C6*S6 + 2*YY6*dq56*m_6*C5*CC6*S4 + 2*Z5*d4*dq11*m_5*CC2*C4*S5 + 2*Z5*d4*dq11*m_5*CC3*C4*S5 - 2*Z6*d6*dq11*m_6*C2*CC4*S2 + 2*Z6*d4*dq11*m_6*CC2*C4*S5 + 2*Z6*d6*dq11*m_6*C2*CC5*S2 + 2*Z6*d4*dq11*m_6*CC3*C4*S5 - 2*Z6*d6*dq11*m_6*C3*CC4*S3 + 2*Z6*d6*dq11*m_6*C3*CC5*S3 + 2*ZZ4*dq14*m_4*C2*CC4*S3 + 2*ZZ4*dq14*m_4*C3*CC4*S2 - 2*ZZ5*dq14*m_5*C2*CC4*S3 - 2*ZZ5*dq14*m_5*C3*CC4*S2 - 2*ZZ6*dq14*m_6*C2*CC4*S3 - 2*ZZ6*dq14*m_6*C3*CC4*S2 + 2*ZZ5*dq24*m_5*C4*CC5*S4 + 2*ZZ5*dq34*m_5*C4*CC5*S4 + 2*ZZ5*dq25*m_5*CC4*C5*S5 + 2*ZZ6*dq24*m_6*C4*CC5*S4 + 2*ZZ5*dq35*m_5*CC4*C5*S5 + 2*ZZ6*dq34*m_6*C4*CC5*S4 + 2*ZZ6*dq25*m_6*CC4*C5*S5 + 2*ZZ6*dq35*m_6*CC4*C5*S5 + 2*X5*Y5*dq11*m_5*CC2*S4*S5 + 2*X5*Y5*dq11*m_5*CC3*S4*S5 - 2*X6*Y6*dq11*m_6*CC2*S4*S5 - 2*X6*Y6*dq11*m_6*CC3*S4*S5 - 2*X6*Y6*dq11*m_6*CC6*S4*S5 - 2*X6*Y6*dq44*m_6*CC6*S4*S5 + 2*X6*Y6*dq55*m_6*CC6*S4*S5 - 2*Ixy5*dq15*C2*CC4*S3*S5 - 2*Ixy5*dq15*C3*CC4*S2*S5 + 2*Ixy6*dq15*C2*CC4*S3*S5 + 2*Ixy6*dq15*C3*CC4*S2*S5 + 4*Ixy6*dq15*C2*CC6*S3*S5 + 4*Ixy6*dq15*C3*CC6*S2*S5 - 4*Ixy6*dq25*C4*CC6*S4*S5 - 4*Ixy6*dq35*C4*CC6*S4*S5 + 4*Ixy6*dq45*CC5*C6*S4*S6 + 4*Ixy6*dq46*C5*CC6*S4*S5 + 4*Ixz5*dq14*C4*CC5*S2*S3 + 2*Ixz6*dq26*CC4*C5*S5*S6 + 2*Ixz6*dq36*CC4*C5*S5*S6 + 2*d4*d6*dq11*m_6*CC2*C4*S5 + 2*d4*d6*dq11*m_6*CC3*C4*S5 - 2*dd6*dq14*m_6*C2*CC4*S3 - 2*dd6*dq14*m_6*C3*CC4*S2 + 2*dd6*dq24*m_6*C4*CC5*S4 + 2*dd6*dq34*m_6*C4*CC5*S4 + 2*dd6*dq25*m_6*CC4*C5*S5 + 2*dd6*dq35*m_6*CC4*C5*S5 - Y5*a2*dq11*m_5*CC2*S3*S4 + 2*Y6*a3*dq11*m_6*CC2*S5*S6 + 2*Y6*a3*dq11*m_6*CC3*S5*S6 - Z4*a2*dq11*m_4*CC2*S3*S4 - 2*X6*d4*dq11*m_6*CC2*S4*S6 - 2*X6*d4*dq11*m_6*CC3*S4*S6 - 4*X5*Y5*dq24*m_5*CC4*C5 - 4*X5*Y5*dq34*m_5*CC4*C5 + 4*X6*Y6*dq24*m_6*CC4*C5 + 4*X6*Y6*dq34*m_6*CC4*C5 + 4*X6*Y6*dq24*m_6*C5*CC6 + 4*X6*Y6*dq34*m_6*C5*CC6 - 4*X6*Y6*dq56*m_6*C4*CC6 - 2*X6*Z6*dq25*m_6*CC4*C6 - 4*X6*Z6*dq25*m_6*CC5*C6 - 2*X6*Z6*dq35*m_6*CC4*C6 - 4*X6*Z6*dq35*m_6*CC5*C6 - 2*Ixx5*dq15*CC5*S2*S3*S4 + 2*Ixx6*dq15*CC6*S2*S3*S4 - 2*Iyy6*dq15*CC5*S2*S3*S4 - 2*Iyy6*dq15*CC6*S2*S3*S4 + 2*Izz5*dq15*CC5*S2*S3*S4 + 2*Izz6*dq15*CC5*S2*S3*S4 - 2*X6*d6*dq25*m_6*CC4*C6 - 4*X6*d6*dq25*m_6*CC5*C6 - 2*X6*d6*dq35*m_6*CC4*C6 - 4*X6*d6*dq35*m_6*CC5*C6 - 4*Y5*Z5*dq24*m_5*CC4*S5 - 4*Y5*Z5*dq34*m_5*CC4*S5 + 2*Y6*Z6*dq25*m_6*CC4*S6 + 4*Y6*Z6*dq25*m_6*CC5*S6 + 2*Y6*Z6*dq35*m_6*CC4*S6 + 4*Y6*Z6*dq35*m_6*CC5*S6 - 4*Ixx5*dq11*CC2*CC3*C4*C5*S5 + 2*Ixx6*dq11*CC2*C4*C5*CC6*S5 + 2*Ixx6*dq11*CC3*C4*C5*CC6*S5 - 4*Iyy6*dq11*CC2*CC3*C4*C5*S5 - 2*Iyy6*dq11*CC2*C4*C5*CC6*S5 - 2*Iyy6*dq11*CC3*C4*C5*CC6*S5 - 4*Iyz6*dq11*CC2*CC3*C5*C6*S4 + 4*Izz5*dq11*CC2*CC3*C4*C5*S5 + 4*Izz6*dq11*CC2*CC3*C4*C5*S5 + 2*XX4*dq11*m_4*C2*CC3*CC4*S2 + 2*XX4*dq11*m_4*CC2*C3*CC4*S3 + 2*XX5*dq11*m_5*C2*CC3*CC5*S2 - XX5*dq11*m_5*C2*CC4*CC5*S2 + 2*XX5*dq11*m_5*CC2*C3*CC5*S3 - 2*XX6*dq11*m_6*C2*CC3*CC4*S2 - 2*XX6*dq11*m_6*CC2*C3*CC4*S3 - XX5*dq11*m_5*C3*CC4*CC5*S3 - 4*XX6*dq11*m_6*C2*CC3*CC6*S2 - XX6*dq11*m_6*C2*CC4*CC6*S2 - 4*XX6*dq11*m_6*CC2*C3*CC6*S3 - XX6*dq11*m_6*C2*CC5*CC6*S2 - XX6*dq11*m_6*C3*CC4*CC6*S3 - XX6*dq11*m_6*C3*CC5*CC6*S3 - 2*YY5*dq11*m_5*C2*CC3*CC4*S2 - 2*YY5*dq11*m_5*CC2*C3*CC4*S3 + 2*YY6*dq11*m_6*C2*CC3*CC5*S2 + 4*YY6*dq11*m_6*C2*CC3*CC6*S2 - YY6*dq11*m_6*C2*CC4*CC5*S2 + 2*YY6*dq11*m_6*CC2*C3*CC5*S3 + YY6*dq11*m_6*C2*CC4*CC6*S2 + 4*YY6*dq11*m_6*CC2*C3*CC6*S3 + YY6*dq11*m_6*C2*CC5*CC6*S2 - YY6*dq11*m_6*C3*CC4*CC5*S3 + YY6*dq11*m_6*C3*CC4*CC6*S3 + YY6*dq11*m_6*C3*CC5*CC6*S3 - 2*ZZ4*dq11*m_4*C2*CC3*CC4*S2 - 2*ZZ4*dq11*m_4*CC2*C3*CC4*S3 + 2*ZZ5*dq11*m_5*C2*CC3*CC4*S2 - 2*ZZ5*dq11*m_5*C2*CC3*CC5*S2 + 2*ZZ5*dq11*m_5*CC2*C3*CC4*S3 + ZZ5*dq11*m_5*C2*CC4*CC5*S2 - 2*ZZ5*dq11*m_5*CC2*C3*CC5*S3 + 2*ZZ6*dq11*m_6*C2*CC3*CC4*S2 - 2*ZZ6*dq11*m_6*C2*CC3*CC5*S2 + 2*ZZ6*dq11*m_6*CC2*C3*CC4*S3 + ZZ5*dq11*m_5*C3*CC4*CC5*S3 + ZZ6*dq11*m_6*C2*CC4*CC5*S2 - 2*ZZ6*dq11*m_6*CC2*C3*CC5*S3 + ZZ6*dq11*m_6*C3*CC4*CC5*S3 + 2*Y6*d6*dq25*m_6*CC4*S6 + 4*Y6*d6*dq25*m_6*CC5*S6 + 2*Y6*d6*dq35*m_6*CC4*S6 + 4*Y6*d6*dq35*m_6*CC5*S6 - 4*Z6*d6*dq45*m_6*CC5*S4 - 4*Ixz6*dq11*CC2*CC3*C5*S4*S6 + 2*dd6*dq11*m_6*C2*CC3*CC4*S2 - 2*dd6*dq11*m_6*C2*CC3*CC5*S2 + 2*dd6*dq11*m_6*CC2*C3*CC4*S3 + dd6*dq11*m_6*C2*CC4*CC5*S2 - 2*dd6*dq11*m_6*CC2*C3*CC5*S3 + dd6*dq11*m_6*C3*CC4*CC5*S3 + 4*X4*Y4*dq11*m_4*CC2*CC3*C4 + 4*X5*Z5*dq11*m_5*CC2*CC3*C4 + 4*X5*Z5*dq11*m_5*CC2*C4*CC5 + 4*X5*Z5*dq11*m_5*CC3*C4*CC5 - 4*Z5*a3*dq11*m_5*CC2*CC3*C5 - 4*Z6*a3*dq11*m_6*CC2*CC3*C5 - 4*X4*d4*dq11*m_4*CC2*CC3*C4 - 4*Y4*Z4*dq11*m_4*CC2*CC3*S4 - 4*a3*d6*dq11*m_6*CC2*CC3*C5 + 2*Ixx5*dq14*C2*CC4*CC5*S3 + 2*Ixx5*dq14*C3*CC4*CC5*S2 + 2*Ixx6*dq14*C2*CC4*CC6*S3 + 2*Ixx6*dq14*C3*CC4*CC6*S2 + 2*Ixx6*dq24*C4*CC5*CC6*S4 + 2*Ixx6*dq34*C4*CC5*CC6*S4 + 2*Ixx6*dq25*CC4*C5*CC6*S5 + 2*Ixx6*dq35*CC4*C5*CC6*S5 + 2*Ixx6*dq26*CC4*CC5*C6*S6 + 2*Ixx6*dq36*CC4*CC5*C6*S6 + 2*Iyy6*dq14*C2*CC4*CC5*S3 + 2*Iyy6*dq14*C3*CC4*CC5*S2 - 2*Iyy6*dq14*C2*CC4*CC6*S3 - 2*Iyy6*dq14*C3*CC4*CC6*S2 - 2*Iyy6*dq24*C4*CC5*CC6*S4 - 2*Iyy6*dq34*C4*CC5*CC6*S4 - 2*Iyy6*dq25*CC4*C5*CC6*S5 - 2*Iyy6*dq35*CC4*C5*CC6*S5 - 2*Iyy6*dq26*CC4*CC5*C6*S6 - 2*Iyy6*dq36*CC4*CC5*C6*S6 - 2*Izz5*dq14*C2*CC4*CC5*S3 - 2*Izz5*dq14*C3*CC4*CC5*S2 - 2*Izz6*dq14*C2*CC4*CC5*S3 - 2*Izz6*dq14*C3*CC4*CC5*S2 + 4*X5*a3*dq11*m_5*CC2*CC3*S5 + 2*XX6*dq45*m_6*CC5*CC6*S4 + 4*Y5*d4*dq11*m_5*CC2*CC3*S4 - 2*YY6*dq45*m_6*CC5*CC6*S4 + 4*Z4*d4*dq11*m_4*CC2*CC3*S4 + 2*X6*Y6*dq26*m_6*CC4*CC5 - 4*X6*Y6*dq26*m_6*CC4*CC6 + 2*X6*Y6*dq36*m_6*CC4*CC5 + 4*X6*Y6*dq26*m_6*CC5*CC6 - 4*X6*Y6*dq36*m_6*CC4*CC6 + 4*X6*Y6*dq36*m_6*CC5*CC6 + 4*X5*Z5*dq25*m_5*CC4*CC5 + 4*X5*Z5*dq35*m_5*CC4*CC5 + 8*Ixz6*dq11*CC2*CC3*C4*CC5*C6 + 4*Ixy4*dq11*C2*C3*C4*S2*S3 - 2*Ixy5*dq11*C2*C4*C5*S2*S4 + 2*Ixy6*dq11*C2*C4*C5*S2*S4 - 2*Ixy5*dq11*C3*C4*C5*S3*S4 + 2*Ixy6*dq11*C3*C4*C5*S3*S4 + 2*Ixy6*dq11*C4*C5*C6*S5*S6 + 2*Ixy6*dq44*C4*C5*C6*S5*S6 + 4*Ixz5*dq11*C2*C3*C4*S2*S3 + 2*Ixz6*dq11*C2*C5*C6*S2*S5 + 2*Ixz6*dq11*C3*C5*C6*S3*S5 - 2*Ixx5*dq11*C2*CC3*CC4*CC5*S2 - 2*Ixx5*dq11*CC2*C3*CC4*CC5*S3 - 2*Ixx6*dq11*C2*CC3*CC4*CC6*S2 - 2*Ixx6*dq11*C2*CC3*CC5*CC6*S2 - 2*Ixx6*dq11*CC2*C3*CC4*CC6*S3 + Ixx6*dq11*C2*CC4*CC5*CC6*S2 - 2*Ixx6*dq11*CC2*C3*CC5*CC6*S3 + Ixx6*dq11*C3*CC4*CC5*CC6*S3 - 2*Iyy6*dq11*C2*CC3*CC4*CC5*S2 + 2*Iyy6*dq11*C2*CC3*CC4*CC6*S2 - 2*Iyy6*dq11*CC2*C3*CC4*CC5*S3 + 2*Iyy6*dq11*C2*CC3*CC5*CC6*S2 + 2*Iyy6*dq11*CC2*C3*CC4*CC6*S3 - Iyy6*dq11*C2*CC4*CC5*CC6*S2 + 2*Iyy6*dq11*CC2*C3*CC5*CC6*S3 - Iyy6*dq11*C3*CC4*CC5*CC6*S3 - 8*Iyz6*dq11*CC2*CC3*C4*CC5*S6 + 2*Izz5*dq11*C2*CC3*CC4*CC5*S2 + 2*Izz5*dq11*CC2*C3*CC4*CC5*S3 + 2*Izz6*dq11*C2*CC3*CC4*CC5*S2 + 2*Izz6*dq11*CC2*C3*CC4*CC5*S3 - 4*Iyz4*dq11*C2*C3*S2*S3*S4 - 2*Iyz5*dq11*C2*C4*S2*S4*S5 - 2*Iyz5*dq11*C3*C4*S3*S4*S5 - 2*Iyz6*dq11*C2*C5*S2*S5*S6 - 2*Iyz6*dq11*C3*C5*S3*S5*S6 + 2*Ixz6*dq14*C2*C3*C4*C6 - Z5*a1*dq11*m_5*C2*C3*C5 - Z6*a1*dq11*m_6*C2*C3*C5 - XX6*dq11*m_6*C6*S4*S5*S6 - XX6*dq44*m_6*C6*S4*S5*S6 + XX6*dq55*m_6*C6*S4*S5*S6 - X6*d4*dq11*m_6*C4*C5*C6 - X6*d4*dq44*m_6*C4*C5*C6 - X6*d4*dq55*m_6*C4*C5*C6 - X6*d4*dq66*m_6*C4*C5*C6 + YY6*dq11*m_6*C6*S4*S5*S6 + YY6*dq44*m_6*C6*S4*S5*S6 - YY6*dq55*m_6*C6*S4*S5*S6 + Y6*Z6*dq11*m_6*C5*C6*S4 + Y6*Z6*dq44*m_6*C5*C6*S4 - Y6*Z6*dq55*m_6*C5*C6*S4 + Y6*Z6*dq66*m_6*C5*C6*S4 + 8*Ixy6*dq11*CC2*CC3*CC6*S4*S5 - a1*d6*dq11*m_6*C2*C3*C5 - Ixx6*dq16*C2*C3*C4*S5 + Iyy6*dq16*C2*C3*C4*S5 + 2*Iyz5*dq14*C2*C3*C5*S4 - 2*Iyz6*dq14*C2*C3*C4*S6 - 2*Iyz6*dq15*C2*C5*C6*S3 - 2*Iyz6*dq15*C3*C5*C6*S2 + 2*Iyz6*dq25*C4*C5*C6*S4 + 2*Iyz6*dq35*C4*C5*C6*S4 - Izz6*dq16*C2*C3*C4*S5 + X3*a2*dq11*m_3*C2*C3*S2 + X4*a1*dq11*m_4*C2*C4*S3 + X4*a1*dq11*m_4*C3*C4*S2 -
 2*X4*a3*dq11*m_4*C2*C4*S2 - 2*X4*a3*dq11*m_4*C3*C4*S3 + X5*a1*dq11*m_5*C2*C3*S5 + X5*a2*dq22*m_5*C4*C5*S3 + X6*a2*dq22*m_6*C3*C6*S5 + 2*XX5*dq15*m_5*C2*C3*S4 - 2*XX6*dq16*m_6*C2*C5*S3 - 2*XX6*dq16*m_6*C3*C5*S2 + 2*XX6*dq26*m_6*C4*C5*S4 + 2*XX6*dq36*m_6*C4*C5*S4 + 2*XX6*dq24*m_6*C5*C6*S6 + 2*XX6*dq34*m_6*C5*C6*S6 - 2*XX6*dq56*m_6*C4*C6*S6 + Y6*d4*dq11*m_6*C4*C5*S6 + Y6*d6*dq11*m_6*C5*C6*S4 + Y6*d4*dq44*m_6*C4*C5*S6 + Y6*d4*dq55*m_6*C4*C5*S6 + Y6*d4*dq66*m_6*C4*C5*S6 + Y6*d6*dq44*m_6*C5*C6*S4 - Y6*d6*dq55*m_6*C5*C6*S4 + Y6*d6*dq66*m_6*C5*C6*S4 + 2*YY6*dq15*m_6*C2*C3*S4 - 2*YY6*dq26*m_6*C4*C5*S4 - 2*YY6*dq36*m_6*C4*C5*S4 - 2*YY6*dq24*m_6*C5*C6*S6 - 2*YY6*dq34*m_6*C5*C6*S6 + 2*YY6*dq56*m_6*C4*C6*S6 + 2*Z5*d4*dq11*m_5*C2*C5*S2 + 2*Z5*d4*dq11*m_5*C3*C5*S3 + 2*Z6*d4*dq11*m_6*C2*C5*S2 + 2*Z6*d4*dq11*m_6*C3*C5*S3 - 2*Z6*d6*dq11*m_6*C4*C5*S5 - 2*Z6*d6*dq44*m_6*C4*C5*S5 + X6*Z6*dq11*m_6*C5*S4*S6 + X6*Z6*dq44*m_6*C5*S4*S6 - X6*Z6*dq55*m_6*C5*S4*S6 + X6*Z6*dq66*m_6*C5*S4*S6 + a2*a3*dq11*m_3*C2*C3*S2 + a2*a3*dq11*m_4*C2*C3*S2 + a2*a3*dq11*m_5*C2*C3*S2 + a2*a3*dq11*m_6*C2*C3*S2 - 2*Ixy5*dq14*C2*C3*S4*S5 + 2*Ixy6*dq14*C2*C3*S4*S5 + 2*Ixy6*dq16*C2*C4*S3*S4 + 2*Ixy6*dq16*C3*C4*S2*S4 + 4*Ixy6*dq14*C2*C6*S3*S6 + 4*Ixy6*dq14*C3*C6*S2*S6 - 4*Ixy6*dq24*C4*C6*S4*S6 - 4*Ixy6*dq34*C4*C6*S4*S6 + 4*Ixy6*dq25*C5*C6*S5*S6 + 4*Ixy6*dq35*C5*C6*S5*S6 + 4*Ixy6*dq46*C4*C6*S5*S6 - 4*Ixy6*dq56*C5*C6*S4*S6 - 4*Ixz4*dq14*C2*C4*S3*S4 - 4*Ixz4*dq14*C3*C4*S2*S4 - 2*Ixz5*dq15*C2*C4*S3*S4 - 2*Ixz5*dq15*C3*C4*S2*S4 - 2*Ixz6*dq14*C4*C6*S2*S3 - 2*Ixz6*dq15*C2*C5*S3*S6 - 2*Ixz6*dq15*C3*C5*S2*S6 + 4*Ixz5*dq24*C4*C5*S4*S5 + 4*Ixz5*dq34*C4*C5*S4*S5 + 2*Ixz6*dq25*C4*C5*S4*S6 + 2*Ixz6*dq26*C4*C6*S4*S5 + 2*Ixz6*dq35*C4*C5*S4*S6 + 2*Ixz6*dq36*C4*C6*S4*S5 - 4*Ixz6*dq45*C5*C6*S4*S5 + 2*d4*d6*dq11*m_6*C2*C5*S2 + 2*d4*d6*dq11*m_6*C3*C5*S3 - Y4*a2*dq11*m_4*C2*S2*S3 - Y5*a1*dq11*m_5*C2*S3*S4 - Y5*a1*dq11*m_5*C3*S2*S4 + 2*Y5*a3*dq11*m_5*C2*S2*S4 + 2*Y5*a3*dq11*m_5*C3*S3*S4 - Y6*a2*dq22*m_6*C6*S3*S4 - Y6*a2*dq22*m_6*C3*S5*S6 + Z3*a2*dq11*m_3*C2*S2*S3 - Z4*a1*dq11*m_4*C2*S3*S4 - Z4*a1*dq11*m_4*C3*S2*S4 + 2*Z4*a3*dq11*m_4*C2*S2*S4 + 2*Z4*a3*dq11*m_4*C3*S3*S4 + Z5*a1*dq11*m_5*C5*S2*S3 + Z6*a1*dq11*m_6*C5*S2*S3 + Z5*a2*dq22*m_5*C4*S3*S5 + Z6*a2*dq22*m_6*C4*S3*S5 - 2*X5*d4*dq11*m_5*C2*S2*S5 - 2*X5*d4*dq11*m_5*C3*S3*S5 + X6*d6*dq11*m_6*C5*S4*S6 + X6*d6*dq44*m_6*C5*S4*S6 - X6*d6*dq55*m_6*C5*S4*S6 + X6*d6*dq66*m_6*C5*S4*S6 + a2*d4*dq11*m_4*C2*S2*S3 + a2*d4*dq11*m_5*C2*S2*S3 + a2*d4*dq11*m_6*C2*S2*S3 + a1*d6*dq11*m_6*C5*S2*S3 + a2*d6*dq22*m_6*C4*S3*S5 + Ixx6*dq16*C4*S2*S3*S5 - Iyy6*dq16*C4*S2*S3*S5 - 2*Iyz5*dq14*C5*S2*S3*S4 + 2*Iyz6*dq14*C4*S2*S3*S6 - 2*Iyz6*dq26*C4*S4*S5*S6 - 2*Iyz6*dq36*C4*S4*S5*S6 + 4*Iyz6*dq45*C5*S4*S5*S6 + Izz6*dq16*C4*S2*S3*S5 - X5*a1*dq11*m_5*S2*S3*S5 - X6*a2*dq22*m_6*S3*S4*S6 - 2*Y6*a3*dq24*m_6*C4*C6 - 2*Y6*a3*dq34*m_6*C4*C6 - 2*Y6*a3*dq56*m_6*C5*C6 + 2*Z5*a3*dq25*m_5*C4*C5 + 2*Z5*a3*dq35*m_5*C4*C5 + 2*Z6*a3*dq25*m_6*C4*C5 + 2*Z6*a3*dq35*m_6*C4*C5 - 2*XX5*dq15*m_5*S2*S3*S4 - 2*X6*d4*dq25*m_6*C5*C6 - 2*X6*d4*dq35*m_6*C5*C6 - 2*X6*d4*dq46*m_6*C4*C6 - 2*YY6*dq15*m_6*S2*S3*S4 + 2*Z4*d4*dq14*m_4*S2*S3*S4 - 2*Y6*Z6*dq11*m_6*CC2*C5*C6*S4 - 2*Y6*Z6*dq11*m_6*CC3*C5*C6*S4 + 2*Ixx6*dq16*C2*C3*C4*CC6*S5 - 2*Iyy6*dq16*C2*C3*C4*CC6*S5 + 4*Iyz6*dq14*C2*C3*C4*CC5*S6 + 2*Iyz6*dq15*C2*CC4*C5*C6*S3 + 2*Iyz6*dq15*C3*CC4*C5*C6*S2 + 2*Iyz6*dq16*C2*C3*CC5*C6*S4 + 4*X4*a3*dq11*m_4*C2*CC3*C4*S2 + 4*X4*a3*dq11*m_4*CC2*C3*C4*S3 + X5*a2*dq11*m_5*CC2*C4*C5*S3 + X6*a2*dq11*m_6*CC2*C3*C6*S5 - 2*XX5*dq15*m_5*C2*C3*CC5*S4 + 2*XX6*dq15*m_6*C2*C3*CC6*S4 + 2*XX6*dq16*m_6*C2*CC4*C5*S3 + 2*XX6*dq16*m_6*C3*CC4*C5*S2 + 2*XX6*dq16*m_6*C2*C5*CC6*S3 + 2*XX6*dq16*m_6*C3*C5*CC6*S2 - 4*XX6*dq24*m_6*CC4*C5*C6*S6 - 4*XX6*dq26*m_6*C4*C5*CC6*S4 - 4*XX6*dq34*m_6*CC4*C5*C6*S6 - 4*XX6*dq36*m_6*C4*C5*CC6*S4 - 2*Y6*d4*dq11*m_6*CC2*C4*C5*S6 - 2*Y6*d4*dq11*m_6*CC3*C4*C5*S6 - 2*Y6*d6*dq11*m_6*CC2*C5*C6*S4 - 2*Y6*d6*dq11*m_6*CC3*C5*C6*S4 - 2*YY6*dq15*m_6*C2*C3*CC5*S4 - 2*YY6*dq15*m_6*C2*C3*CC6*S4 - 2*YY6*dq16*m_6*C2*CC4*C5*S3 - 2*YY6*dq16*m_6*C3*CC4*C5*S2 - 2*YY6*dq16*m_6*C2*C5*CC6*S3 - 2*YY6*dq16*m_6*C3*C5*CC6*S2 + 4*YY6*dq24*m_6*CC4*C5*C6*S6 + 4*YY6*dq26*m_6*C4*C5*CC6*S4 + 4*YY6*dq34*m_6*CC4*C5*C6*S6 + 4*YY6*dq36*m_6*C4*C5*CC6*S4 - 4*Z5*d4*dq11*m_5*C2*CC3*C5*S2 - 4*Z5*d4*dq11*m_5*CC2*C3*C5*S3 - 4*Z6*d4*dq11*m_6*C2*CC3*C5*S2 - 4*Z6*d4*dq11*m_6*CC2*C3*C5*S3 + 4*Z6*d6*dq11*m_6*CC2*C4*C5*S5 + 4*Z6*d6*dq11*m_6*CC3*C4*C5*S5 + 2*ZZ5*dq15*m_5*C2*C3*CC5*S4 + 2*ZZ6*dq15*m_6*C2*C3*CC5*S4 - 2*X6*Z6*dq11*m_6*CC2*C5*S4*S6 - 2*X6*Z6*dq11*m_6*CC3*C5*S4*S6 - 4*Ixy6*dq14*C2*C3*CC6*S4*S5 + 2*Ixy6*dq16*C2*C4*CC5*S3*S4 + 2*Ixy6*dq16*C3*C4*CC5*S2*S4 - 4*Ixy6*dq14*C2*CC4*C6*S3*S6 - 4*Ixy6*dq14*C3*CC4*C6*S2*S6 - 4*Ixy6*dq16*C2*C4*CC6*S3*S4 - 4*Ixy6*dq16*C3*C4*CC6*S2*S4 - 4*Ixy6*dq24*C4*CC5*C6*S4*S6 - 4*Ixy6*dq34*C4*CC5*C6*S4*S6 - 4*Ixy6*dq25*CC4*C5*C6*S5*S6 - 4*Ixy6*dq35*CC4*C5*C6*S5*S6 + 4*Ixz5*dq14*C2*CC4*C5*S3*S5 + 4*Ixz5*dq14*C3*CC4*C5*S2*S5 + 4*Ixz5*dq15*C2*C4*CC5*S3*S4 + 4*Ixz5*dq15*C3*C4*CC5*S2*S4 + 4*Ixz6*dq14*C4*CC5*C6*S2*S3 + 2*Ixz6*dq15*C2*CC4*C5*S3*S6 + 2*Ixz6*dq15*C3*CC4*C5*S2*S6 + 2*Ixz6*dq16*C2*C3*CC5*S4*S6 + 2*Ixz6*dq16*C2*CC4*C6*S3*S5 + 2*Ixz6*dq16*C3*CC4*C6*S2*S5 - 4*d4*d6*dq11*m_6*C2*CC3*C5*S2 - 4*d4*d6*dq11*m_6*CC2*C3*C5*S3 + 2*dd6*dq15*m_6*C2*C3*CC5*S4 - 4*Y5*a3*dq11*m_5*C2*CC3*S2*S4 - 4*Y5*a3*dq11*m_5*CC2*C3*S3*S4 - Y6*a2*dq11*m_6*CC2*C6*S3*S4 - Y6*a2*dq11*m_6*CC2*C3*S5*S6 - 4*Z4*a3*dq11*m_4*C2*CC3*S2*S4 - 4*Z4*a3*dq11*m_4*CC2*C3*S3*S4 + Z5*a2*dq11*m_5*CC2*C4*S3*S5 + Z6*a2*dq11*m_6*CC2*C4*S3*S5 + 4*X5*d4*dq11*m_5*C2*CC3*S2*S5 + 4*X5*d4*dq11*m_5*CC2*C3*S3*S5 - 2*X6*d6*dq11*m_6*CC2*C5*S4*S6 - 2*X6*d6*dq11*m_6*CC3*C5*S4*S6 + a2*d6*dq11*m_6*CC2*C4*S3*S5 - 2*Ixx6*dq16*C4*CC6*S2*S3*S5 + 2*Iyy6*dq16*C4*CC6*S2*S3*S5 - 4*Iyz6*dq14*C4*CC5*S2*S3*S6 - 2*Iyz6*dq16*C2*CC4*S3*S5*S6 - 2*Iyz6*dq16*C3*CC4*S2*S5*S6 - 2*Iyz6*dq16*CC5*C6*S2*S3*S4 - X6*a2*dq11*m_6*CC2*S3*S4*S6 + 2*XX5*dq15*m_5*CC5*S2*S3*S4 - 2*XX6*dq15*m_6*CC6*S2*S3*S4 + 2*YY6*dq15*m_6*CC5*S2*S3*S4 + 2*YY6*dq15*m_6*CC6*S2*S3*S4 - 2*ZZ5*dq15*m_5*CC5*S2*S3*S4 - 2*ZZ6*dq15*m_6*CC5*S2*S3*S4 - 4*Y6*Z6*dq24*m_6*CC4*C6*S5 - 4*Y6*Z6*dq34*m_6*CC4*C6*S5 + 2*Y6*Z6*dq46*m_6*CC5*C6*S4 + 4*Ixy6*dq14*CC6*S2*S3*S4*S5 - 2*Ixz6*dq16*CC5*S2*S3*S4*S6 - 2*dd6*dq15*m_6*CC5*S2*S3*S4 + 4*XX5*dq11*m_5*CC2*CC3*C4*C5*S5 - 2*XX6*dq11*m_6*CC2*C4*C5*CC6*S5 - 2*XX6*dq11*m_6*CC3*C4*C5*CC6*S5 + 4*YY6*dq11*m_6*CC2*CC3*C4*C5*S5 + 2*YY6*dq11*m_6*CC2*C4*C5*CC6*S5 + 2*YY6*dq11*m_6*CC3*C4*C5*CC6*S5 - 4*ZZ5*dq11*m_5*CC2*CC3*C4*C5*S5 - 4*ZZ6*dq11*m_6*CC2*CC3*C4*C5*S5 - 4*Y6*d6*dq24*m_6*CC4*C6*S5 - 4*Y6*d6*dq34*m_6*CC4*C6*S5 + 2*Y6*d6*dq46*m_6*CC5*C6*S4 - 4*Z6*d6*dq14*m_6*C2*CC4*S3 - 4*Z6*d6*dq14*m_6*C3*CC4*S2 + 4*Z6*d6*dq24*m_6*C4*CC5*S4 + 4*Z6*d6*dq34*m_6*C4*CC5*S4 + 4*Z6*d6*dq25*m_6*CC4*C5*S5 + 4*Z6*d6*dq35*m_6*CC4*C5*S5 - 4*X6*Z6*dq24*m_6*CC4*S5*S6 - 4*X6*Z6*dq34*m_6*CC4*S5*S6 + 2*X6*Z6*dq46*m_6*CC5*S4*S6 + 4*Ixy6*dq11*C2*CC3*CC4*C6*S2*S6 + 4*Ixy6*dq11*C2*CC3*CC5*C6*S2*S6 + 4*Ixy6*dq11*CC2*C3*CC4*C6*S3*S6 - 2*Ixy6*dq11*C2*CC4*CC5*C6*S2*S6 + 4*Ixy6*dq11*CC2*C3*CC5*C6*S3*S6 - 2*Ixy6*dq11*C3*CC4*CC5*C6*S3*S6 - 4*Ixz5*dq11*C2*CC3*CC4*C5*S2*S5 - 4*Ixz5*dq11*CC2*C3*CC4*C5*S3*S5 - 4*dd6*dq11*m_6*CC2*CC3*C4*C5*S5 - 4*X6*d6*dq24*m_6*CC4*S5*S6 - 4*X6*d6*dq34*m_6*CC4*S5*S6 + 2*X6*d6*dq46*m_6*CC5*S4*S6 + 4*X6*Z6*dq11*m_6*CC2*CC3*C4*C6 + 4*X6*Z6*dq11*m_6*CC2*C4*CC5*C6 + 4*X6*Z6*dq11*m_6*CC3*C4*CC5*C6 + 4*Ixx6*dq11*CC2*CC3*C6*S4*S5*S6 - 4*Iyy6*dq11*CC2*CC3*C6*S4*S5*S6 - 4*X5*d4*dq11*m_5*CC2*CC3*C4*C5 + 4*X6*d6*dq11*m_6*CC2*CC3*C4*C6 + 4*X6*d6*dq11*m_6*CC2*C4*CC5*C6 + 4*X6*d6*dq11*m_6*CC3*C4*CC5*C6 + 4*Y5*Z5*dq11*m_5*CC2*CC3*C5*S4 - 4*Y6*Z6*dq11*m_6*CC2*CC3*C4*S6 - 4*Y6*Z6*dq11*m_6*CC2*C4*CC5*S6 - 4*Y6*Z6*dq11*m_6*CC3*C4*CC5*S6 + 2*Ixx6*dq15*C2*C3*CC5*CC6*S4 + 4*Ixx6*dq16*C2*CC4*C5*CC6*S3 + 4*Ixx6*dq16*C3*CC4*C5*CC6*S2 - 2*Iyy6*dq15*C2*C3*CC5*CC6*S4 - 4*Iyy6*dq16*C2*CC4*C5*CC6*S3 - 4*Iyy6*dq16*C3*CC4*C5*CC6*S2 + 4*X6*a3*dq11*m_6*CC2*CC3*C6*S5 - 2*XX5*dq14*m_5*C2*CC4*CC5*S3 - 2*XX5*dq14*m_5*C3*CC4*CC5*S2 - 2*XX6*dq14*m_6*C2*CC4*CC6*S3 - 2*XX6*dq14*m_6*C3*CC4*CC6*S2 - 2*XX6*dq24*m_6*C4*CC5*CC6*S4 - 2*XX6*dq34*m_6*C4*CC5*CC6*S4 - 2*XX6*dq25*m_6*CC4*C5*CC6*S5 - 2*XX6*dq35*m_6*CC4*C5*CC6*S5 - 2*XX6*dq26*m_6*CC4*CC5*C6*S6 - 2*XX6*dq36*m_6*CC4*CC5*C6*S6 + 4*Y6*d4*dq11*m_6*CC2*CC3*C6*S4 - 4*Y6*d6*dq11*m_6*CC2*CC3*C4*S6 - 4*Y6*d6*dq11*m_6*CC2*C4*CC5*S6 - 4*Y6*d6*dq11*m_6*CC3*C4*CC5*S6 - 2*YY6*dq14*m_6*C2*CC4*CC5*S3 - 2*YY6*dq14*m_6*C3*CC4*CC5*S2 + 2*YY6*dq14*m_6*C2*CC4*CC6*S3 + 2*YY6*dq14*m_6*C3*CC4*CC6*S2 + 2*YY6*dq24*m_6*C4*CC5*CC6*S4 + 2*YY6*dq34*m_6*C4*CC5*CC6*S4 + 2*YY6*dq25*m_6*CC4*C5*CC6*S5 + 2*YY6*dq35*m_6*CC4*C5*CC6*S5 + 2*YY6*dq26*m_6*CC4*CC5*C6*S6 + 2*YY6*dq36*m_6*CC4*CC5*C6*S6 - 4*Z5*d4*dq11*m_5*CC2*CC3*C4*S5 + 4*Z6*d6*dq11*m_6*C2*CC3*CC4*S2 - 4*Z6*d4*dq11*m_6*CC2*CC3*C4*S5 - 4*Z6*d6*dq11*m_6*C2*CC3*CC5*S2 + 4*Z6*d6*dq11*m_6*CC2*C3*CC4*S3 + 2*Z6*d6*dq11*m_6*C2*CC4*CC5*S2 - 4*Z6*d6*dq11*m_6*CC2*C3*CC5*S3 + 2*Z6*d6*dq11*m_6*C3*CC4*CC5*S3 + 2*ZZ5*dq14*m_5*C2*CC4*CC5*S3 + 2*ZZ5*dq14*m_5*C3*CC4*CC5*S2 + 2*ZZ6*dq14*m_6*C2*CC4*CC5*S3 + 2*ZZ6*dq14*m_6*C3*CC4*CC5*S2 - 4*X5*Y5*dq11*m_5*CC2*CC3*S4*S5 + 4*X6*Y6*dq11*m_6*CC2*CC3*S4*S5 + 4*X6*Y6*dq11*m_6*CC2*CC6*S4*S5 + 4*X6*Y6*dq11*m_6*CC3*CC6*S4*S5 - 4*Ixy6*dq15*C2*CC4*CC6*S3*S5 - 4*Ixy6*dq15*C3*CC4*CC6*S2*S5 - 4*d4*d6*dq11*m_6*CC2*CC3*C4*S5 + 2*dd6*dq14*m_6*C2*CC4*CC5*S3 + 2*dd6*dq14*m_6*C3*CC4*CC5*S2 - 4*Y6*a3*dq11*m_6*CC2*CC3*S5*S6 + 4*X6*d4*dq11*m_6*CC2*CC3*S4*S6 - 8*X6*Y6*dq24*m_6*CC4*C5*CC6 - 8*X6*Y6*dq34*m_6*CC4*C5*CC6 + 4*X6*Z6*dq25*m_6*CC4*CC5*C6 + 4*X6*Z6*dq35*m_6*CC4*CC5*C6 - 2*Ixx6*dq15*CC5*CC6*S2*S3*S4 + 2*Iyy6*dq15*CC5*CC6*S2*S3*S4 + 4*Ixz6*dq11*C2*C3*C4*C6*S2*S3 + 4*X6*d6*dq25*m_6*CC4*CC5*C6 + 4*X6*d6*dq35*m_6*CC4*CC5*C6 - 4*Y6*Z6*dq25*m_6*CC4*CC5*S6 - 4*Y6*Z6*dq35*m_6*CC4*CC5*S6 - 4*Ixx6*dq11*CC2*CC3*C4*C5*CC6*S5 + 4*Iyy6*dq11*CC2*CC3*C4*C5*CC6*S5 + 4*Iyz5*dq11*C2*C3*C5*S2*S3*S4 - 4*Iyz6*dq11*C2*C3*C4*S2*S3*S6 - 2*Iyz6*dq11*C2*C4*C6*S2*S4*S5 - 2*Iyz6*dq11*C3*C4*C6*S3*S4*S5
 - 2*Ixz6*dq16*C2*C3*C4*C5*C6 + 2*XX5*dq11*m_5*C2*CC3*CC4*CC5*S2 + 2*XX5*dq11*m_5*CC2*C3*CC4*CC5*S3 + 2*XX6*dq11*m_6*C2*CC3*CC4*CC6*S2 + 2*XX6*dq11*m_6*C2*CC3*CC5*CC6*S2 + 2*XX6*dq11*m_6*CC2*C3*CC4*CC6*S3 - XX6*dq11*m_6*C2*CC4*CC5*CC6*S2 + 2*XX6*dq11*m_6*CC2*C3*CC5*CC6*S3 - XX6*dq11*m_6*C3*CC4*CC5*CC6*S3 + 2*YY6*dq11*m_6*C2*CC3*CC4*CC5*S2 - 2*YY6*dq11*m_6*C2*CC3*CC4*CC6*S2 + 2*YY6*dq11*m_6*CC2*C3*CC4*CC5*S3 - 2*YY6*dq11*m_6*C2*CC3*CC5*CC6*S2 - 2*YY6*dq11*m_6*CC2*C3*CC4*CC6*S3 + YY6*dq11*m_6*C2*CC4*CC5*CC6*S2 - 2*YY6*dq11*m_6*CC2*C3*CC5*CC6*S3 + YY6*dq11*m_6*C3*CC4*CC5*CC6*S3 - 2*ZZ5*dq11*m_5*C2*CC3*CC4*CC5*S2 - 2*ZZ5*dq11*m_5*CC2*C3*CC4*CC5*S3 - 2*ZZ6*dq11*m_6*C2*CC3*CC4*CC5*S2 - 2*ZZ6*dq11*m_6*CC2*C3*CC4*CC5*S3 - 4*Y6*d6*dq25*m_6*CC4*CC5*S6 - 4*Y6*d6*dq35*m_6*CC4*CC5*S6 - 4*Ixy5*dq11*C2*C3*S2*S3*S4*S5 + 4*Ixy6*dq11*C2*C3*S2*S3*S4*S5 - 2*Ixz6*dq11*C2*C4*S2*S4*S5*S6 - 2*Ixz6*dq11*C3*C4*S3*S4*S5*S6 + 2*Ixx5*dq14*C2*C3*C4*C5*S5 + 2*Iyy6*dq14*C2*C3*C4*C5*S5 + 2*Iyz6*dq14*C2*C3*C5*C6*S4 + 2*Iyz6*dq16*C2*C3*C4*C5*S6 - 2*Izz5*dq14*C2*C3*C4*C5*S5 - 2*Izz6*dq14*C2*C3*C4*C5*S5 - 2*dd6*dq11*m_6*C2*CC3*CC4*CC5*S2 - 2*dd6*dq11*m_6*CC2*C3*CC4*CC5*S3 + X4*a2*dq11*m_4*C2*C3*C4*S2 + X5*a1*dq11*m_5*C2*C4*C5*S3 + X5*a1*dq11*m_5*C3*C4*C5*S2 - 2*X5*a3*dq11*m_5*C2*C4*C5*S2 - 2*X5*a3*dq11*m_5*C3*C4*C5*S3 + X6*a1*dq11*m_6*C2*C3*C6*S5 + X6*a2*dq22*m_6*C4*C5*C6*S3 - 2*YY6*dq16*m_6*C2*C3*C4*S5 - 8*X5*Z5*dq11*m_5*CC2*CC3*C4*CC5 - 4*X6*Y6*dq11*m_6*C2*C6*S2*S6 - 4*X6*Y6*dq11*m_6*C3*C6*S3*S6 + 4*X3*Z3*dq11*m_3*C2*C3*S2*S3 + 2*X4*Z4*dq11*m_4*C2*C4*S2*S4 + 2*X4*Z4*dq11*m_4*C3*C4*S3*S4 - 2*X5*Z5*dq11*m_5*C2*C5*S2*S5 - 2*X5*Z5*dq11*m_5*C3*C5*S3*S5 - 4*Ixy5*dq14*C2*C4*C5*S3*S4 - 4*Ixy5*dq14*C3*C4*C5*S2*S4 + 4*Ixy6*dq14*C2*C4*C5*S3*S4 + 4*Ixy6*dq14*C3*C4*C5*S2*S4 + 2*Ixy6*dq16*C2*C3*C5*S4*S5 + 4*Ixy6*dq15*C2*C3*C6*S4*S6 + 4*Ixy6*dq16*C2*C5*C6*S3*S6 + 4*Ixy6*dq16*C3*C5*C6*S2*S6 - 8*Ixy6*dq26*C4*C5*C6*S4*S6 - 8*Ixy6*dq36*C4*C5*C6*S4*S6 + 4*Ixz5*dq15*C2*C3*C5*S4*S5 + 2*Ixz6*dq14*C2*C3*C5*S4*S6 - 2*Ixz6*dq15*C2*C4*C6*S3*S4 - 2*Ixz6*dq15*C3*C4*C6*S2*S4 + 2*Ixz6*dq16*C4*C5*C6*S2*S3 + 4*Ixz6*dq24*C4*C5*C6*S4*S5 + 4*Ixz6*dq34*C4*C5*C6*S4*S5 - 4*Y4*a3*dq11*m_4*C2*C3*S2*S3 - Y5*a2*dq11*m_5*C2*C3*S2*S4 - Y6*a1*dq11*m_6*C2*C6*S3*S4 - Y6*a1*dq11*m_6*C3*C6*S2*S4 - Y6*a1*dq11*m_6*C2*C3*S5*S6 + 2*Y6*a3*dq11*m_6*C2*C6*S2*S4 + 2*Y6*a3*dq11*m_6*C3*C6*S3*S4 - Y6*a2*dq22*m_6*C4*C5*S3*S6 + 4*Z3*a3*dq11*m_3*C2*C3*S2*S3 - Z4*a2*dq11*m_4*C2*C3*S2*S4 + Z5*a2*dq11*m_5*C2*C5*S2*S3 + Z5*a1*dq11*m_5*C2*C4*S3*S5 + Z5*a1*dq11*m_5*C3*C4*S2*S5 - 2*Z5*a3*dq11*m_5*C2*C4*S2*S5 + Z6*a2*dq11*m_6*C2*C5*S2*S3 + Z6*a1*dq11*m_6*C2*C4*S3*S5 + Z6*a1*dq11*m_6*C3*C4*S2*S5 - 2*Z5*a3*dq11*m_5*C3*C4*S3*S5 - 2*Z6*a3*dq11*m_6*C2*C4*S2*S5 - 2*Z6*a3*dq11*m_6*C3*C4*S3*S5 - 2*X6*d4*dq11*m_6*C2*C6*S2*S5 - 2*X6*d4*dq11*m_6*C3*C6*S3*S5 - 2*X4*Y4*dq14*m_4*C2*C3*C4 - 2*X5*Z5*dq14*m_5*C2*C3*C4 - 2*X6*Z6*dq46*m_6*C4*C5*C6 + 2*Ixx6*dq14*C2*CC4*CC5*CC6*S3 + 2*Ixx6*dq14*C3*CC4*CC5*CC6*S2 - 2*Iyy6*dq14*C2*CC4*CC5*CC6*S3 - 2*Iyy6*dq14*C3*CC4*CC5*CC6*S2 + 4*a3*d4*dq11*m_4*C2*C3*S2*S3 + 4*a3*d4*dq11*m_5*C2*C3*S2*S3 + 4*a3*d4*dq11*m_6*C2*C3*S2*S3 + a2*d6*dq11*m_6*C2*C5*S2*S3 + a1*d6*dq11*m_6*C2*C4*S3*S5 + a1*d6*dq11*m_6*C3*C4*S2*S5 - 2*a3*d6*dq11*m_6*C2*C4*S2*S5 - 2*a3*d6*dq11*m_6*C3*C4*S3*S5 - 2*Ixx5*dq14*C4*C5*S2*S3*S5 + 2*Ixx6*dq15*C2*C6*S3*S5*S6 + 2*Ixx6*dq15*C3*C6*S2*S5*S6 - 2*Ixx6*dq25*C4*C6*S4*S5*S6 - 2*Ixx6*dq35*C4*C6*S4*S5*S6 + 2*Ixx6*dq46*C5*C6*S4*S5*S6 - 2*Iyy6*dq14*C4*C5*S2*S3*S5 - 2*Iyy6*dq15*C2*C6*S3*S5*S6 - 2*Iyy6*dq15*C3*C6*S2*S5*S6 + 2*Iyy6*dq25*C4*C6*S4*S5*S6 + 2*Iyy6*dq35*C4*C6*S4*S5*S6 - 2*Iyy6*dq46*C5*C6*S4*S5*S6 - 4*Iyz5*dq14*C2*C4*S3*S4*S5 - 4*Iyz5*dq14*C3*C4*S2*S4*S5 - 2*Iyz6*dq14*C5*C6*S2*S3*S4 + 2*Iyz6*dq15*C2*C4*S3*S4*S6 + 2*Iyz6*dq15*C3*C4*S2*S4*S6 - 2*Iyz6*dq16*C4*C5*S2*S3*S6 - 4*Iyz6*dq24*C4*C5*S4*S5*S6 - 4*Iyz6*dq34*C4*C5*S4*S5*S6 + 2*Izz5*dq14*C4*C5*S2*S3*S5 + 2*Izz6*dq14*C4*C5*S2*S3*S5 - X5*a2*dq11*m_5*C2*S2*S3*S5 - X6*a1*dq11*m_6*C2*S3*S4*S6 - X6*a1*dq11*m_6*C3*S2*S4*S6 - X6*a1*dq11*m_6*C6*S2*S3*S5 + 2*X6*a3*dq11*m_6*C2*S2*S4*S6 + 2*X6*a3*dq11*m_6*C3*S3*S4*S6 - 2*Y6*a3*dq26*m_6*C4*C5*C6 - 2*Y6*a3*dq36*m_6*C4*C5*C6 + 2*X4*d4*dq14*m_4*C2*C3*C4 - 2*X6*d6*dq46*m_6*C4*C5*C6 + 2*Y6*d4*dq11*m_6*C2*S2*S5*S6 + 2*Y6*d4*dq11*m_6*C3*S3*S5*S6 + 2*YY6*dq16*m_6*C4*S2*S3*S5 + 2*Y4*Z4*dq14*m_4*C2*C3*S4 + 2*Y5*Z5*dq15*m_5*C2*C5*S3 + 2*Y5*Z5*dq15*m_5*C3*C5*S2 - 2*Y5*Z5*dq25*m_5*C4*C5*S4 - 2*Y5*Z5*dq35*m_5*C4*C5*S4 + 2*Y6*Z6*dq26*m_6*C5*C6*S5 + 2*Y6*Z6*dq36*m_6*C5*C6*S5 + 2*Y6*Z6*dq46*m_6*C4*C5*S6 - 2*Ixy6*dq16*C5*S2*S3*S4*S5 - 4*Ixy6*dq15*C6*S2*S3*S4*S6 - 4*Ixz5*dq15*C5*S2*S3*S4*S5 - 2*Ixz6*dq14*C5*S2*S3*S4*S6 - 2*X4*a3*dq14*m_4*C2*C4*S3 - 2*X4*a3*dq14*m_4*C3*C4*S2 - 2*X6*a3*dq24*m_6*C5*C6*S4 - 2*X6*a3*dq25*m_6*C4*C6*S5 - 2*X6*a3*dq34*m_6*C5*C6*S4 - 2*X6*a3*dq26*m_6*C4*C5*S6 - 2*X6*a3*dq35*m_6*C4*C6*S5 - 2*X6*a3*dq36*m_6*C4*C5*S6 + Y6*a1*dq11*m_6*S2*S3*S5*S6 - 2*Y5*d4*dq14*m_5*C2*C3*S4 + 2*Y6*d4*dq46*m_6*C5*C6*S4 + 2*Y6*d4*dq56*m_6*C4*C6*S5 + 2*Y6*d6*dq26*m_6*C5*C6*S5 + 2*Y6*d6*dq36*m_6*C5*C6*S5 + 2*Y6*d6*dq46*m_6*C4*C5*S6 - 2*Z4*d4*dq14*m_4*C2*C3*S4 - 4*X6*Y6*dq26*m_6*CC4*CC5*CC6 - 4*X6*Y6*dq36*m_6*CC4*CC5*CC6 + 2*X4*Y4*dq14*m_4*C4*S2*S3 - 2*X5*Y5*dq15*m_5*C2*S3*S5 - 2*X5*Y5*dq15*m_5*C3*S2*S5 + 2*X6*Y6*dq15*m_6*C2*S3*S5 + 2*X6*Y6*dq15*m_6*C3*S2*S5 + 2*X5*Y5*dq25*m_5*C4*S4*S5 + 2*X5*Y5*dq35*m_5*C4*S4*S5 - 2*X6*Y6*dq25*m_6*C4*S4*S5 - 2*X6*Y6*dq35*m_6*C4*S4*S5 + 2*X6*Y6*dq46*m_6*C5*S4*S5 + 4*X6*Y6*dq45*m_6*C6*S4*S6 + 2*X5*Z5*dq14*m_5*C4*S2*S3 + 4*X5*Z5*dq45*m_5*C5*S4*S5 + 2*X6*Z6*dq26*m_6*C5*S5*S6 + 2*X6*Z6*dq36*m_6*C5*S5*S6 + 4*Ixy5*dq11*C2*CC3*C4*C5*S2*S4 + 4*Ixy5*dq11*CC2*C3*C4*C5*S3*S4 - 4*Ixy6*dq11*C2*CC3*C4*C5*S2*S4 - 4*Ixy6*dq11*CC2*C3*C4*C5*S3*S4 - 4*Ixy6*dq11*C2*C4*C5*CC6*S2*S4 - 4*Ixy6*dq11*C3*C4*C5*CC6*S3*S4 - 4*Ixy6*dq11*CC2*C4*C5*C6*S5*S6 - 4*Ixy6*dq11*CC3*C4*C5*C6*S5*S6 - 8*Ixz5*dq11*C2*C3*C4*CC5*S2*S3 - 4*Ixz6*dq11*C2*CC3*C5*C6*S2*S5 + 2*Ixz6*dq11*C2*CC4*C5*C6*S2*S5 - 4*Ixz6*dq11*CC2*C3*C5*C6*S3*S5 + 2*Ixz6*dq11*C3*CC4*C5*C6*S3*S5 + 2*Y5*a3*dq14*m_5*C2*S3*S4 + 2*Y5*a3*dq14*m_5*C3*S2*S4 + 2*Y6*a3*dq24*m_6*C5*S4*S6 + 2*Y6*a3*dq25*m_6*C4*S5*S6 + 2*Y6*a3*dq34*m_6*C5*S4*S6 + 2*Y6*a3*dq35*m_6*C4*S5*S6 + 2*Z4*a3*dq14*m_4*C2*S3*S4 + 2*Z4*a3*dq14*m_4*C3*S2*S4 - 2*X4*d4*dq14*m_4*C4*S2*S3 + 2*X6*d4*dq45*m_6*C6*S4*S5 + 2*X6*d4*dq46*m_6*C5*S4*S6 + 2*X6*d4*dq56*m_6*C4*S5*S6 + 2*X6*d6*dq26*m_6*C5*S5*S6 + 2*X6*d6*dq36*m_6*C5*S5*S6 - 2*Ixx6*dq11*C2*CC3*CC4*CC5*CC6*S2 - 2*Ixx6*dq11*CC2*C3*CC4*CC5*CC6*S3 + 2*Iyy6*dq11*C2*CC3*CC4*CC5*CC6*S2 + 2*Iyy6*dq11*CC2*C3*CC4*CC5*CC6*S3 - 2*Y4*Z4*dq14*m_4*S2*S3*S4 + 4*Iyz5*dq11*C2*CC3*C4*S2*S4*S5 + 4*Iyz5*dq11*CC2*C3*C4*S3*S4*S5 + 4*Iyz6*dq11*C2*CC3*C5*S2*S5*S6 - 2*Iyz6*dq11*C2*CC4*C5*S2*S5*S6 + 4*Iyz6*dq11*CC2*C3*C5*S3*S5*S6 - 2*Iyz6*dq11*C3*CC4*C5*S3*S5*S6 - 4*Ixz6*dq14*C2*C3*C4*CC5*C6 + 2*XX6*dq11*m_6*CC2*C6*S4*S5*S6 + 2*XX6*dq11*m_6*CC3*C6*S4*S5*S6 + 2*X6*d4*dq11*m_6*CC2*C4*C5*C6 + 2*X6*d4*dq11*m_6*CC3*C4*C5*C6 - 2*YY6*dq11*m_6*CC2*C6*S4*S5*S6 - 2*YY6*dq11*m_6*CC3*C6*S4*S5*S6 + 2*Y5*d4*dq14*m_5*S2*S3*S4 - 2*Y6*d4*dq45*m_6*S4*S5*S6 + 2*XX6*dq16*m_6*C4*CC6*S2*S3*S5 - 4*Y6*d4*dq11*m_6*C2*CC3*S2*S5*S6 - 4*Y6*d4*dq11*m_6*CC2*C3*S3*S5*S6 - 2*YY6*dq16*m_6*C4*CC6*S2*S3*S5 - 2*Y5*Z5*dq15*m_5*C2*CC4*C5*S3 - 2*Y5*Z5*dq15*m_5*C3*CC4*C5*S2 - 2*Y6*Z6*dq26*m_6*CC4*C5*C6*S5 - 2*Y6*Z6*dq36*m_6*CC4*C5*C6*S5 + 4*Ixy6*dq15*CC5*C6*S2*S3*S4*S6 + 4*Ixy6*dq16*C5*CC6*S2*S3*S4*S5 - 2*Y6*d6*dq26*m_6*CC4*C5*C6*S5 - 2*Y6*d6*dq36*m_6*CC4*C5*C6*S5 + 4*Z6*d6*dq15*m_6*C2*C3*CC5*S4 + 2*X5*Y5*dq15*m_5*C2*CC4*S3*S5 + 2*X5*Y5*dq15*m_5*C3*CC4*S2*S5 - 2*X6*Y6*dq15*m_6*C2*CC4*S3*S5 - 2*X6*Y6*dq15*m_6*C3*CC4*S2*S5 - 4*X6*Y6*dq15*m_6*C2*CC6*S3*S5 - 4*X6*Y6*dq15*m_6*C3*CC6*S2*S5 + 4*X6*Y6*dq25*m_6*C4*CC6*S4*S5 + 4*X6*Y6*dq35*m_6*C4*CC6*S4*S5 - 4*X6*Y6*dq45*m_6*CC5*C6*S4*S6 - 4*X6*Y6*dq46*m_6*C5*CC6*S4*S5 - 4*X5*Z5*dq14*m_5*C4*CC5*S2*S3 - 2*X6*Z6*dq26*m_6*CC4*C5*S5*S6 - 2*X6*Z6*dq36*m_6*CC4*C5*S5*S6 + 8*Ixy6*dq11*C2*CC3*C4*C5*CC6*S2*S4 + 8*Ixy6*dq11*CC2*C3*C4*C5*CC6*S3*S4 + 8*Ixy6*dq11*CC2*CC3*C4*C5*C6*S5*S6 - 4*Ixz6*dq11*C2*CC3*CC4*C5*C6*S2*S5 - 4*Ixz6*dq11*CC2*C3*CC4*C5*C6*S3*S5 - 2*X6*d6*dq26*m_6*CC4*C5*S5*S6 - 2*X6*d6*dq36*m_6*CC4*C5*S5*S6 + 4*Iyz6*dq11*C2*CC3*CC4*C5*S2*S5*S6 + 4*Iyz6*dq11*CC2*C3*CC4*C5*S3*S5*S6 - 4*XX6*dq11*m_6*CC2*CC3*C6*S4*S5*S6 - 4*X6*d4*dq11*m_6*CC2*CC3*C4*C5*C6 + 4*YY6*dq11*m_6*CC2*CC3*C6*S4*S5*S6 - 4*Z6*d6*dq15*m_6*CC5*S2*S3*S4 + 4*Y6*Z6*dq11*m_6*CC2*CC3*C5*C6*S4 - 2*XX6*dq15*m_6*C2*C3*CC5*CC6*S4 - 4*XX6*dq16*m_6*C2*CC4*C5*CC6*S3 - 4*XX6*dq16*m_6*C3*CC4*C5*CC6*S2 + 4*Y6*d4*dq11*m_6*CC2*CC3*C4*C5*S6 + 4*Y6*d6*dq11*m_6*CC2*CC3*C5*C6*S4 + 2*YY6*dq15*m_6*C2*C3*CC5*CC6*S4 + 4*YY6*dq16*m_6*C2*CC4*C5*CC6*S3 + 4*YY6*dq16*m_6*C3*CC4*C5*CC6*S2 - 8*Z6*d6*dq11*m_6*CC2*CC3*C4*C5*S5 + 4*X6*Z6*dq11*m_6*CC2*CC3*C5*S4*S6 - 4*Ixy6*dq14*C2*CC4*CC5*C6*S3*S6 - 4*Ixy6*dq14*C3*CC4*CC5*C6*S2*S6 - 4*Ixy6*dq16*C2*C4*CC5*CC6*S3*S4 - 4*Ixy6*dq16*C3*C4*CC5*CC6*S2*S4 + 4*X6*d6*dq11*m_6*CC2*CC3*C5*S4*S6 + 2*XX6*dq15*m_6*CC5*CC6*S2*S3*S4 - 2*YY6*dq15*m_6*CC5*CC6*S2*S3*S4 + 4*Ixx5*dq11*C2*C3*C4*C5*S2*S3*S5 - 2*Ixx6*dq11*C2*C4*C5*C6*S2*S4*S6 - 2*Ixx6*dq11*C3*C4*C5*C6*S3*S4*S6 + 4*Iyy6*dq11*C2*C3*C4*C5*S2*S3*S5 + 2*Iyy6*dq11*C2*C4*C5*C6*S2*S4*S6 + 2*Iyy6*dq11*C3*C4*C5*C6*S3*S4*S6 + 4*Iyz6*dq11*C2*C3*C5*C6*S2*S3*S4 - 4*Izz5*dq11*C2*C3*C4*C5*S2*S3*S5 - 4*Izz6*dq11*C2*C3*C4*C5*S2*S3*S5 + 4*XX6*dq11*m_6*CC2*CC3*C4*C5*CC6*S5 - 4*YY6*dq11*m_6*CC2*CC3*C4*C5*CC6*S5 + 4*Z6*d6*dq14*m_6*C2*CC4*CC5*S3 + 4*Z6*d6*dq14*m_6*C3*CC4*CC5*S2 + 4*Ixy6*dq11*C2*CC3*CC4*CC5*C6*S2*S6 + 4*Ixy6*dq11*CC2*C3*CC4*CC5*C6*S3*S6 + 4*Ixz6*dq11*C2*C3*C5*S2*S3*S4*S6 + X5*a2*dq11*m_5*C2*C3*C4*C5*S2 + X6*a1*dq11*m_6*C2*C4*C5*C6*S3 + X6*a1*dq11*m_6*C3*C4*C5*C6*S2 - 2*X6*a3*dq11*m_6*C2*C4*C5*C6*S2 - 2*X6*a3*dq11*m_6*C3*C4*C5*C6*S3 - 2*XX5*dq14*m_5*C2*C3*C4*C5*S5 - 2*YY6*dq14*m_6*C2*C3*C4*C5*S5 + 2*ZZ5*dq14*m_5*C2*C3*C4*C5*S5 + 2*ZZ6*dq14*m_6*C2*C3*C4*C5*S5 - 8*X6*Z6*dq11*m_6*CC2*CC3*C4*CC5*C6 - 4*X4*Y4*dq11*m_4*C2*C3*C4*S2*S3 + 2*X5*Y5*dq11*m_5*C2*C4*C5*S2*S4
 + 2*X5*Y5*dq11*m_5*C3*C4*C5*S3*S4 - 2*X6*Y6*dq11*m_6*C2*C4*C5*S2*S4 - 2*X6*Y6*dq11*m_6*C3*C4*C5*S3*S4 - 2*X6*Y6*dq11*m_6*C4*C5*C6*S5*S6 - 2*X6*Y6*dq44*m_6*C4*C5*C6*S5*S6 - 4*X5*Z5*dq11*m_5*C2*C3*C4*S2*S3 - 2*X6*Z6*dq11*m_6*C2*C5*C6*S2*S5 - 2*X6*Z6*dq11*m_6*C3*C5*C6*S3*S5 - 4*Ixy6*dq16*C2*C3*C4*C6*S5*S6 + 4*Ixz6*dq15*C2*C3*C5*C6*S4*S5 + 2*dd6*dq14*m_6*C2*C3*C4*C5*S5 - Y6*a2*dq11*m_6*C2*C3*C6*S2*S4 - Y6*a1*dq11*m_6*C2*C4*C5*S3*S6 - Y6*a1*dq11*m_6*C3*C4*C5*S2*S6 + 2*Y6*a3*dq11*m_6*C2*C4*C5*S2*S6 + 2*Y6*a3*dq11*m_6*C3*C4*C5*S3*S6 - 8*X6*d6*dq11*m_6*CC2*CC3*C4*CC5*C6 + Z5*a2*dq11*m_5*C2*C3*C4*S2*S5 + 4*Z5*a3*dq11*m_5*C2*C3*C5*S2*S3 + Z6*a2*dq11*m_6*C2*C3*C4*S2*S5 + 4*Z6*a3*dq11*m_6*C2*C3*C5*S2*S3 + 4*X4*d4*dq11*m_4*C2*C3*C4*S2*S3 - 2*X6*d6*dq11*m_6*C2*C5*C6*S2*S5 - 2*X6*d6*dq11*m_6*C3*C5*C6*S3*S5 + 8*Y6*Z6*dq11*m_6*CC2*CC3*C4*CC5*S6 - 2*X6*Z6*dq14*m_6*C2*C3*C4*C6 + 4*Y4*Z4*dq11*m_4*C2*C3*S2*S3*S4 + 2*Y5*Z5*dq11*m_5*C2*C4*S2*S4*S5 + 2*Y5*Z5*dq11*m_5*C3*C4*S3*S4*S5 + 2*Y6*Z6*dq11*m_6*C2*C5*S2*S5*S6 + 2*Y6*Z6*dq11*m_6*C3*C5*S3*S5*S6 + a2*d6*dq11*m_6*C2*C3*C4*S2*S5 + 4*a3*d6*dq11*m_6*C2*C3*C5*S2*S3 - 2*Ixx5*dq15*C2*C4*C5*S3*S4*S5 - 2*Ixx5*dq15*C3*C4*C5*S2*S4*S5 - 2*Ixx6*dq14*C2*C3*C6*S4*S5*S6 - 2*Ixx6*dq16*C2*C4*C6*S3*S4*S6 - 2*Ixx6*dq16*C3*C4*C6*S2*S4*S6 - 2*Iyy6*dq15*C2*C4*C5*S3*S4*S5 - 2*Iyy6*dq15*C3*C4*C5*S2*S4*S5 + 2*Iyy6*dq14*C2*C3*C6*S4*S5*S6 + 2*Iyy6*dq16*C2*C4*C6*S3*S4*S6 + 2*Iyy6*dq16*C3*C4*C6*S2*S4*S6 - 4*Iyz6*dq14*C2*C4*C6*S3*S4*S5 - 4*Iyz6*dq14*C3*C4*C6*S2*S4*S5 - 4*Iyz6*dq15*C2*C3*C5*S4*S5*S6 + 2*Izz5*dq15*C2*C4*C5*S3*S4*S5 + 2*Izz5*dq15*C3*C4*C5*S2*S4*S5 + 2*Izz6*dq15*C2*C4*C5*S3*S4*S5 + 2*Izz6*dq15*C3*C4*C5*S2*S4*S5 - 4*X5*a3*dq11*m_5*C2*C3*S2*S3*S5 - X6*a2*dq11*m_6*C2*C3*S2*S4*S6 - X6*a2*dq11*m_6*C2*C6*S2*S3*S5 - 2*XX6*dq14*m_6*C2*CC4*CC5*CC6*S3 - 2*XX6*dq14*m_6*C3*CC4*CC5*CC6*S2 + 8*Y6*d6*dq11*m_6*CC2*CC3*C4*CC5*S6 + 2*YY6*dq14*m_6*C2*CC4*CC5*CC6*S3 + 2*YY6*dq14*m_6*C3*CC4*CC5*CC6*S2 - 4*Z6*d6*dq11*m_6*C2*CC3*CC4*CC5*S2 - 4*Z6*d6*dq11*m_6*CC2*C3*CC4*CC5*S3 + 2*XX5*dq14*m_5*C4*C5*S2*S3*S5 - 2*XX6*dq15*m_6*C2*C6*S3*S5*S6 - 2*XX6*dq15*m_6*C3*C6*S2*S5*S6 + 2*XX6*dq25*m_6*C4*C6*S4*S5*S6 + 2*XX6*dq35*m_6*C4*C6*S4*S5*S6 - 2*XX6*dq46*m_6*C5*C6*S4*S5*S6 + 2*X5*d4*dq14*m_5*C2*C3*C4*C5 + 2*X6*d4*dq16*m_6*C2*C3*C4*C6 - 2*X6*d6*dq14*m_6*C2*C3*C4*C6 - 4*Y5*d4*dq11*m_5*C2*C3*S2*S3*S4 + 2*Y6*d6*dq11*m_6*C2*C5*S2*S5*S6 + 2*Y6*d6*dq11*m_6*C3*C5*S3*S5*S6 + 2*YY6*dq14*m_6*C4*C5*S2*S3*S5 + 2*YY6*dq15*m_6*C2*C6*S3*S5*S6 + 2*YY6*dq15*m_6*C3*C6*S2*S5*S6 - 2*YY6*dq25*m_6*C4*C6*S4*S5*S6 - 2*YY6*dq35*m_6*C4*C6*S4*S5*S6 + 2*YY6*dq46*m_6*C5*C6*S4*S5*S6 - 4*Z4*d4*dq11*m_4*C2*C3*S2*S3*S4 - 2*ZZ5*dq14*m_5*C4*C5*S2*S3*S5 - 2*ZZ6*dq14*m_6*C4*C5*S2*S3*S5 - 8*X6*Y6*dq11*m_6*CC2*CC3*CC6*S4*S5 - 2*Y5*Z5*dq14*m_5*C2*C3*C5*S4 + 2*Y6*Z6*dq14*m_6*C2*C3*C4*S6 + 2*Y6*Z6*dq15*m_6*C2*C5*C6*S3 + 2*Y6*Z6*dq15*m_6*C3*C5*C6*S2 - 2*Y6*Z6*dq25*m_6*C4*C5*C6*S4 - 2*Y6*Z6*dq35*m_6*C4*C5*C6*S4 + 4*Ixy6*dq16*C4*C6*S2*S3*S5*S6 - 4*Ixz6*dq14*C2*C4*S3*S4*S5*S6 - 4*Ixz6*dq14*C3*C4*S2*S4*S5*S6 - 4*Ixz6*dq15*C5*C6*S2*S3*S4*S5 - 2*dd6*dq14*m_6*C4*C5*S2*S3*S5 - 2*X5*a3*dq14*m_5*C2*C4*C5*S3 - 2*X5*a3*dq14*m_5*C3*C4*C5*S2 - 2*X6*a3*dq16*m_6*C2*C4*C6*S3 - 2*X6*a3*dq16*m_6*C3*C4*C6*S2 + Y6*a2*dq11*m_6*C2*S2*S3*S5*S6 - 2*Y6*d4*dq14*m_6*C2*C3*C6*S4 - 2*Y6*d4*dq16*m_6*C2*C3*C4*S6 + 2*Y6*d6*dq14*m_6*C2*C3*C4*S6 + 2*Y6*d6*dq15*m_6*C2*C5*C6*S3 + 2*Y6*d6*dq15*m_6*C3*C5*C6*S2 - 2*Y6*d6*dq25*m_6*C4*C5*C6*S4 - 2*Y6*d6*dq35*m_6*C4*C5*C6*S4 + 2*Z5*d4*dq14*m_5*C2*C3*C4*S5 + 2*Z5*d4*dq15*m_5*C2*C3*C5*S4 + 2*Z6*d4*dq14*m_6*C2*C3*C4*S5 + 2*Z6*d4*dq15*m_6*C2*C3*C5*S4 + 2*X5*Y5*dq14*m_5*C2*C3*S4*S5 - 2*X6*Y6*dq14*m_6*C2*C3*S4*S5 - 2*X6*Y6*dq16*m_6*C2*C4*S3*S4 - 2*X6*Y6*dq16*m_6*C3*C4*S2*S4 - 4*X6*Y6*dq14*m_6*C2*C6*S3*S6 - 4*X6*Y6*dq14*m_6*C3*C6*S2*S6 + 4*X6*Y6*dq24*m_6*C4*C6*S4*S6 + 4*X6*Y6*dq34*m_6*C4*C6*S4*S6 - 4*X6*Y6*dq25*m_6*C5*C6*S5*S6 - 4*X6*Y6*dq35*m_6*C5*C6*S5*S6 - 4*X6*Y6*dq46*m_6*C4*C6*S5*S6 + 4*X6*Y6*dq56*m_6*C5*C6*S4*S6 + 4*X4*Z4*dq14*m_4*C2*C4*S3*S4 + 4*X4*Z4*dq14*m_4*C3*C4*S2*S4 + 2*X5*Z5*dq15*m_5*C2*C4*S3*S4 + 2*X5*Z5*dq15*m_5*C3*C4*S2*S4 + 2*X6*Z6*dq14*m_6*C4*C6*S2*S3 - 4*X5*Z5*dq24*m_5*C4*C5*S4*S5 - 4*X5*Z5*dq34*m_5*C4*C5*S4*S5 + 2*X6*Z6*dq15*m_6*C2*C5*S3*S6 + 2*X6*Z6*dq15*m_6*C3*C5*S2*S6 - 2*X6*Z6*dq25*m_6*C4*C5*S4*S6 - 2*X6*Z6*dq26*m_6*C4*C6*S4*S5 - 2*X6*Z6*dq35*m_6*C4*C5*S4*S6 - 2*X6*Z6*dq36*m_6*C4*C6*S4*S5 + 4*X6*Z6*dq45*m_6*C5*C6*S4*S5 - 8*Ixz6*dq11*C2*C3*C4*CC5*C6*S2*S3 + 2*Ixx6*dq14*C6*S2*S3*S4*S5*S6 - 2*Iyy6*dq14*C6*S2*S3*S4*S5*S6 + 4*Iyz6*dq15*C5*S2*S3*S4*S5*S6 + 2*d4*d6*dq14*m_6*C2*C3*C4*S5 + 2*d4*d6*dq15*m_6*C2*C3*C5*S4 + 2*Y6*a3*dq14*m_6*C2*C6*S3*S4 + 2*Y6*a3*dq14*m_6*C3*C6*S2*S4 + 2*Y6*a3*dq16*m_6*C2*C4*S3*S6 + 2*Y6*a3*dq16*m_6*C3*C4*S2*S6 - 2*Z5*a3*dq14*m_5*C2*C4*S3*S5 - 2*Z5*a3*dq14*m_5*C3*C4*S2*S5 - 2*Z5*a3*dq15*m_5*C2*C5*S3*S4 - 2*Z5*a3*dq15*m_5*C3*C5*S2*S4 - 2*Z6*a3*dq14*m_6*C2*C4*S3*S5 - 2*Z6*a3*dq14*m_6*C3*C4*S2*S5 - 2*Z6*a3*dq15*m_6*C2*C5*S3*S4 - 2*Z6*a3*dq15*m_6*C3*C5*S2*S4 - 2*X5*d4*dq14*m_5*C4*C5*S2*S3 - 2*X5*d4*dq15*m_5*C2*C3*S4*S5 - 2*X6*d4*dq14*m_6*C2*C3*S4*S6 - 2*X6*d4*dq16*m_6*C4*C6*S2*S3 + 2*X6*d6*dq14*m_6*C4*C6*S2*S3 + 2*X6*d6*dq15*m_6*C2*C5*S3*S6 + 2*X6*d6*dq15*m_6*C3*C5*S2*S6 - 2*X6*d6*dq25*m_6*C4*C5*S4*S6 - 2*X6*d6*dq26*m_6*C4*C6*S4*S5 - 2*X6*d6*dq35*m_6*C4*C5*S4*S6 - 2*X6*d6*dq36*m_6*C4*C6*S4*S5 + 4*X6*d6*dq45*m_6*C5*C6*S4*S5 + 2*Y5*Z5*dq14*m_5*C5*S2*S3*S4 - 2*Y6*Z6*dq14*m_6*C4*S2*S3*S6 + 2*Y6*Z6*dq26*m_6*C4*S4*S5*S6 + 2*Y6*Z6*dq36*m_6*C4*S4*S5*S6 - 4*Y6*Z6*dq45*m_6*C5*S4*S5*S6 + 8*Iyz6*dq11*C2*C3*C4*CC5*S2*S3*S6 + 4*Iyz6*dq11*C2*CC3*C4*C6*S2*S4*S5 + 4*Iyz6*dq11*CC2*C3*C4*C6*S3*S4*S5 - 2*a3*d6*dq14*m_6*C2*C4*S3*S5 - 2*a3*d6*dq14*m_6*C3*C4*S2*S5 - 2*a3*d6*dq15*m_6*C2*C5*S3*S4 - 2*a3*d6*dq15*m_6*C3*C5*S2*S4 + 2*X5*a3*dq15*m_5*C2*S3*S4*S5 + 2*X5*a3*dq15*m_5*C3*S2*S4*S5 + 2*X6*a3*dq14*m_6*C2*S3*S4*S6 + 2*X6*a3*dq14*m_6*C3*S2*S4*S6 + 2*XX6*dq11*m_6*C2*CC3*CC4*CC5*CC6*S2 + 2*XX6*dq11*m_6*CC2*C3*CC4*CC5*CC6*S3 - 2*YY6*dq11*m_6*C2*CC3*CC4*CC5*CC6*S2 - 2*YY6*dq11*m_6*CC2*C3*CC4*CC5*CC6*S3 + 2*Y6*d4*dq14*m_6*C6*S2*S3*S4 + 2*Y6*d4*dq16*m_6*C4*S2*S3*S6 - 2*Y6*d6*dq14*m_6*C4*S2*S3*S6 + 2*Y6*d6*dq26*m_6*C4*S4*S5*S6 + 2*Y6*d6*dq36*m_6*C4*S4*S5*S6 - 4*Y6*d6*dq45*m_6*C5*S4*S5*S6 - 2*Z5*d4*dq14*m_5*C4*S2*S3*S5 - 2*Z5*d4*dq15*m_5*C5*S2*S3*S4 - 2*Z6*d4*dq14*m_6*C4*S2*S3*S5 - 2*Z6*d4*dq15*m_6*C5*S2*S3*S4 - 2*X5*Y5*dq14*m_5*S2*S3*S4*S5 + 2*X6*Y6*dq14*m_6*S2*S3*S4*S5 - 8*Ixy6*dq11*C2*C3*CC6*S2*S3*S4*S5 + 4*Ixz6*dq11*C2*CC3*C4*S2*S4*S5*S6 + 4*Ixz6*dq11*CC2*C3*C4*S3*S4*S5*S6 + 2*Ixx6*dq14*C2*C3*C4*C5*CC6*S5 - 2*Iyy6*dq14*C2*C3*C4*C5*CC6*S5 + 4*X5*a3*dq11*m_5*C2*CC3*C4*C5*S2 + 4*X5*a3*dq11*m_5*CC2*C3*C4*C5*S3 + X6*a2*dq11*m_6*CC2*C4*C5*C6*S3 - 2*d4*d6*dq14*m_6*C4*S2*S3*S5 - 2*d4*d6*dq15*m_6*C5*S2*S3*S4 - 2*XX6*dq16*m_6*C2*C3*C4*CC6*S5 + 2*X5*d4*dq15*m_5*S2*S3*S4*S5 + 2*X6*d4*dq14*m_6*S2*S3*S4*S6 + 2*YY6*dq16*m_6*C2*C3*C4*CC6*S5 + 8*X6*Y6*dq11*m_6*C2*CC3*C6*S2*S6 + 2*X6*Y6*dq11*m_6*C2*CC4*C6*S2*S6 + 8*X6*Y6*dq11*m_6*CC2*C3*C6*S3*S6 + 2*X6*Y6*dq11*m_6*C2*CC5*C6*S2*S6 + 2*X6*Y6*dq11*m_6*C3*CC4*C6*S3*S6 + 2*X6*Y6*dq11*m_6*C3*CC5*C6*S3*S6 - 4*X4*Z4*dq11*m_4*C2*CC3*C4*S2*S4 - 4*X4*Z4*dq11*m_4*CC2*C3*C4*S3*S4 + 4*X5*Z5*dq11*m_5*C2*CC3*C5*S2*S5 - 2*X5*Z5*dq11*m_5*C2*CC4*C5*S2*S5 + 4*X5*Z5*dq11*m_5*CC2*C3*C5*S3*S5 - 2*X5*Z5*dq11*m_5*C3*CC4*C5*S3*S5 - 8*Ixy6*dq14*C2*C4*C5*CC6*S3*S4 - 8*Ixy6*dq14*C3*C4*C5*CC6*S2*S4 - 4*Ixy6*dq15*C2*C3*CC5*C6*S4*S6 - 4*Ixy6*dq16*C2*C3*C5*CC6*S4*S5 - 8*Ixy6*dq16*C2*CC4*C5*C6*S3*S6 - 8*Ixy6*dq16*C3*CC4*C5*C6*S2*S6 + 4*Ixz6*dq14*C2*CC4*C5*C6*S3*S5 + 4*Ixz6*dq14*C3*CC4*C5*C6*S2*S5 + 4*Ixz6*dq15*C2*C4*CC5*C6*S3*S4 + 4*Ixz6*dq15*C3*C4*CC5*C6*S2*S4 - 4*Y6*a3*dq11*m_6*C2*CC3*C6*S2*S4 - 4*Y6*a3*dq11*m_6*CC2*C3*C6*S3*S4 - Y6*a2*dq11*m_6*CC2*C4*C5*S3*S6 + 4*Z5*a3*dq11*m_5*C2*CC3*C4*S2*S5 + 4*Z5*a3*dq11*m_5*CC2*C3*C4*S3*S5 + 4*Z6*a3*dq11*m_6*C2*CC3*C4*S2*S5 + 4*Z6*a3*dq11*m_6*CC2*C3*C4*S3*S5 + 4*X6*d4*dq11*m_6*C2*CC3*C6*S2*S5 + 4*X6*d4*dq11*m_6*CC2*C3*C6*S3*S5 + 4*X5*Z5*dq14*m_5*C2*C3*C4*CC5 + 4*a3*d6*dq11*m_6*C2*CC3*C4*S2*S5 + 4*a3*d6*dq11*m_6*CC2*C3*C4*S3*S5 - 2*Ixx6*dq14*C4*C5*CC6*S2*S3*S5 - 2*Ixx6*dq15*C2*CC4*C6*S3*S5*S6 - 2*Ixx6*dq15*C3*CC4*C6*S2*S5*S6 + 2*Iyy6*dq14*C4*C5*CC6*S2*S3*S5 + 2*Iyy6*dq15*C2*CC4*C6*S3*S5*S6 + 2*Iyy6*dq15*C3*CC4*C6*S2*S5*S6 - 4*Iyz6*dq14*C2*CC4*C5*S3*S5*S6 - 4*Iyz6*dq14*C3*CC4*C5*S2*S5*S6 - 4*Iyz6*dq15*C2*C4*CC5*S3*S4*S6 - 4*Iyz6*dq15*C3*C4*CC5*S2*S4*S6 - 4*X6*a3*dq11*m_6*C2*CC3*S2*S4*S6 - 4*X6*a3*dq11*m_6*CC2*C3*S3*S4*S6 + 4*Y6*d6*dq14*m_6*C4*CC5*S2*S3*S6 + 2*Y6*d6*dq16*m_6*C2*CC4*S3*S5*S6 + 2*Y6*d6*dq16*m_6*C3*CC4*S2*S5*S6 + 2*Y6*d6*dq16*m_6*CC5*C6*S2*S3*S4 - 4*X6*Y6*dq14*m_6*CC6*S2*S3*S4*S5 + 2*X6*Z6*dq16*m_6*CC5*S2*S3*S4*S6 + 2*X6*d6*dq16*m_6*CC5*S2*S3*S4*S6 - 4*X6*Y6*dq11*m_6*C2*CC3*CC4*C6*S2*S6 - 4*X6*Y6*dq11*m_6*C2*CC3*CC5*C6*S2*S6 - 4*X6*Y6*dq11*m_6*CC2*C3*CC4*C6*S3*S6 + 2*X6*Y6*dq11*m_6*C2*CC4*CC5*C6*S2*S6 - 4*X6*Y6*dq11*m_6*CC2*C3*CC5*C6*S3*S6 + 2*X6*Y6*dq11*m_6*C3*CC4*CC5*C6*S3*S6 + 4*X5*Z5*dq11*m_5*C2*CC3*CC4*C5*S2*S5 + 4*X5*Z5*dq11*m_5*CC2*C3*CC4*C5*S3*S5 - 4*XX5*dq11*m_5*C2*C3*C4*C5*S2*S3*S5 + 2*XX6*dq11*m_6*C2*C4*C5*C6*S2*S4*S6 + 2*XX6*dq11*m_6*C3*C4*C5*C6*S3*S4*S6 - 4*YY6*dq11*m_6*C2*C3*C4*C5*S2*S3*S5 - 2*YY6*dq11*m_6*C2*C4*C5*C6*S2*S4*S6 - 2*YY6*dq11*m_6*C3*C4*C5*C6*S3*S4*S6 + 4*ZZ5*dq11*m_5*C2*C3*C4*C5*S2*S3*S5 + 4*ZZ6*dq11*m_6*C2*C3*C4*C5*S2*S3*S5 + 4*X6*Y6*dq15*m_6*C2*CC4*CC6*S3*S5 + 4*X6*Y6*dq15*m_6*C3*CC4*CC6*S2*S5 + 4*dd6*dq11*m_6*C2*C3*C4*C5*S2*S3*S5 + X6*a2*dq11*m_6*C2*C3*C4*C5*C6*S2 - 4*X6*Z6*dq11*m_6*C2*C3*C4*C6*S2*S3 - 4*Ixx6*dq11*C2*C3*C6*S2*S3*S4*S5*S6 + 4*Iyy6*dq11*C2*C3*C6*S2*S3*S4*S5*S6 - 4*Ixy6*dq14*C2*C3*C4*C5*C6*S5*S6 - Y6*a2*dq11*m_6*C2*C3*C4*C5*S2*S6 + 4*X5*d4*dq11*m_5*C2*C3*C4*C5*S2*S3 - 4*X6*d6*dq11*m_6*C2*C3*C4*C6*S2*S3 + 2*X6*Z6*dq16*m_6*C2*C3*C4*C5*C6 - 4*Y5*Z5*dq11*m_5*C2*C3*C5*S2*S3*S4 + 4*Y6*Z6*dq11*m_6*C2*C3*C4*S2*S3*S6 + 2*Y6*Z6*dq11*m_6*C2*C4*C6*S2*S4*S5 + 2*Y6*Z6*dq11*m_6*C3*C4*C6*S3*S4*S5 - 4*Ixx6*dq14*C2*C4*C5*C6*S3*S4*S6 - 4*Ixx6*dq14*C3*C4*C5*C6*S2*S4*S6 - 2*Ixx6*dq16*C2*C3*C5*C6*S4*S5*S6
 + 4*Iyy6*dq14*C2*C4*C5*C6*S3*S4*S6 + 4*Iyy6*dq14*C3*C4*C5*C6*S2*S4*S6 + 2*Iyy6*dq16*C2*C3*C5*C6*S4*S5*S6 - 2*Iyz6*dq16*C2*C4*C5*C6*S3*S4*S5 - 2*Iyz6*dq16*C3*C4*C5*C6*S2*S4*S5 - 4*X6*a3*dq11*m_6*C2*C3*C6*S2*S3*S5 + 2*XX5*dq15*m_5*C2*C4*C5*S3*S4*S5 + 2*XX5*dq15*m_5*C3*C4*C5*S2*S4*S5 + 2*XX6*dq14*m_6*C2*C3*C6*S4*S5*S6 + 2*XX6*dq16*m_6*C2*C4*C6*S3*S4*S6 + 2*XX6*dq16*m_6*C3*C4*C6*S2*S4*S6 + 2*X6*d4*dq14*m_6*C2*C3*C4*C5*C6 + 2*X6*d6*dq16*m_6*C2*C3*C4*C5*C6 - 4*Y6*d4*dq11*m_6*C2*C3*C6*S2*S3*S4 + 4*Y6*d6*dq11*m_6*C2*C3*C4*S2*S3*S6 + 2*Y6*d6*dq11*m_6*C2*C4*C6*S2*S4*S5 + 2*Y6*d6*dq11*m_6*C3*C4*C6*S3*S4*S5 + 2*YY6*dq15*m_6*C2*C4*C5*S3*S4*S5 + 2*YY6*dq15*m_6*C3*C4*C5*S2*S4*S5 - 2*YY6*dq14*m_6*C2*C3*C6*S4*S5*S6 - 2*YY6*dq16*m_6*C2*C4*C6*S3*S4*S6 - 2*YY6*dq16*m_6*C3*C4*C6*S2*S4*S6 + 4*Z5*d4*dq11*m_5*C2*C3*C4*S2*S3*S5 + 4*Z6*d4*dq11*m_6*C2*C3*C4*S2*S3*S5 - 2*ZZ5*dq15*m_5*C2*C4*C5*S3*S4*S5 - 2*ZZ5*dq15*m_5*C3*C4*C5*S2*S4*S5 - 2*ZZ6*dq15*m_6*C2*C4*C5*S3*S4*S5 - 2*ZZ6*dq15*m_6*C3*C4*C5*S2*S4*S5 + 4*X5*Y5*dq11*m_5*C2*C3*S2*S3*S4*S5 - 4*X6*Y6*dq11*m_6*C2*C3*S2*S3*S4*S5 + 2*X6*Z6*dq11*m_6*C2*C4*S2*S4*S5*S6 + 2*X6*Z6*dq11*m_6*C3*C4*S3*S4*S5*S6 - 2*Y6*Z6*dq14*m_6*C2*C3*C5*C6*S4 - 2*Y6*Z6*dq16*m_6*C2*C3*C4*C5*S6 + 4*Ixy6*dq14*C4*C5*C6*S2*S3*S5*S6 - 2*Ixz6*dq16*C2*C4*C5*S3*S4*S5*S6 - 2*Ixz6*dq16*C3*C4*C5*S2*S4*S5*S6 + 4*d4*d6*dq11*m_6*C2*C3*C4*S2*S3*S5 - 2*dd6*dq15*m_6*C2*C4*C5*S3*S4*S5 - 2*dd6*dq15*m_6*C3*C4*C5*S2*S4*S5 - 2*X6*a3*dq14*m_6*C2*C4*C5*C6*S3 - 2*X6*a3*dq14*m_6*C3*C4*C5*C6*S2 + 4*Y6*a3*dq11*m_6*C2*C3*S2*S3*S5*S6 - 4*X6*d4*dq11*m_6*C2*C3*S2*S3*S4*S6 + 2*X6*d6*dq11*m_6*C2*C4*S2*S4*S5*S6 + 2*X6*d6*dq11*m_6*C3*C4*S3*S4*S5*S6 - 2*Y6*d4*dq14*m_6*C2*C3*C4*C5*S6 - 2*Y6*d4*dq16*m_6*C2*C3*C5*C6*S4 - 2*Y6*d6*dq14*m_6*C2*C3*C5*C6*S4 - 2*Y6*d6*dq16*m_6*C2*C3*C4*C5*S6 + 4*Z6*d6*dq14*m_6*C2*C3*C4*C5*S5 + 4*X5*Y5*dq14*m_5*C2*C4*C5*S3*S4 + 4*X5*Y5*dq14*m_5*C3*C4*C5*S2*S4 - 4*X6*Y6*dq14*m_6*C2*C4*C5*S3*S4 - 4*X6*Y6*dq14*m_6*C3*C4*C5*S2*S4 - 2*X6*Y6*dq16*m_6*C2*C3*C5*S4*S5 - 4*X6*Y6*dq15*m_6*C2*C3*C6*S4*S6 - 4*X6*Y6*dq16*m_6*C2*C5*C6*S3*S6 - 4*X6*Y6*dq16*m_6*C3*C5*C6*S2*S6 + 8*X6*Y6*dq26*m_6*C4*C5*C6*S4*S6 + 8*X6*Y6*dq36*m_6*C4*C5*C6*S4*S6 - 4*X5*Z5*dq15*m_5*C2*C3*C5*S4*S5 - 2*X6*Z6*dq14*m_6*C2*C3*C5*S4*S6 + 2*X6*Z6*dq15*m_6*C2*C4*C6*S3*S4 + 2*X6*Z6*dq15*m_6*C3*C4*C6*S2*S4 - 2*X6*Z6*dq16*m_6*C4*C5*C6*S2*S3 - 4*X6*Z6*dq24*m_6*C4*C5*C6*S4*S5 - 4*X6*Z6*dq34*m_6*C4*C5*C6*S4*S5 + 2*Ixx6*dq16*C5*C6*S2*S3*S4*S5*S6 - 2*Iyy6*dq16*C5*C6*S2*S3*S4*S5*S6 + 2*Y6*a3*dq14*m_6*C2*C4*C5*S3*S6 + 2*Y6*a3*dq14*m_6*C3*C4*C5*S2*S6 + 2*Y6*a3*dq16*m_6*C2*C5*C6*S3*S4 + 2*Y6*a3*dq16*m_6*C3*C5*C6*S2*S4 - 2*XX6*dq14*m_6*C6*S2*S3*S4*S5*S6 - 2*X6*d4*dq14*m_6*C4*C5*C6*S2*S3 - 2*X6*d4*dq15*m_6*C2*C3*C6*S4*S5 - 2*X6*d4*dq16*m_6*C2*C3*C5*S4*S6 - 2*X6*d6*dq14*m_6*C2*C3*C5*S4*S6 + 2*X6*d6*dq15*m_6*C2*C4*C6*S3*S4 + 2*X6*d6*dq15*m_6*C3*C4*C6*S2*S4 - 2*X6*d6*dq16*m_6*C4*C5*C6*S2*S3 - 4*X6*d6*dq24*m_6*C4*C5*C6*S4*S5 - 4*X6*d6*dq34*m_6*C4*C5*C6*S4*S5 + 2*YY6*dq14*m_6*C6*S2*S3*S4*S5*S6 + 4*Y5*Z5*dq14*m_5*C2*C4*S3*S4*S5 + 4*Y5*Z5*dq14*m_5*C3*C4*S2*S4*S5 + 2*Y6*Z6*dq14*m_6*C5*C6*S2*S3*S4 - 2*Y6*Z6*dq15*m_6*C2*C4*S3*S4*S6 - 2*Y6*Z6*dq15*m_6*C3*C4*S2*S4*S6 + 2*Y6*Z6*dq16*m_6*C4*C5*S2*S3*S6 + 4*Y6*Z6*dq24*m_6*C4*C5*S4*S5*S6 + 4*Y6*Z6*dq34*m_6*C4*C5*S4*S5*S6 + 4*Ixx6*dq11*C2*C3*C4*C5*CC6*S2*S3*S5 + 4*Ixx6*dq11*C2*CC3*C4*C5*C6*S2*S4*S6 + 4*Ixx6*dq11*CC2*C3*C4*C5*C6*S3*S4*S6 - 4*Iyy6*dq11*C2*C3*C4*C5*CC6*S2*S3*S5 - 4*Iyy6*dq11*C2*CC3*C4*C5*C6*S2*S4*S6 - 4*Iyy6*dq11*CC2*C3*C4*C5*C6*S3*S4*S6 + 2*X6*a3*dq15*m_6*C2*C6*S3*S4*S5 + 2*X6*a3*dq15*m_6*C3*C6*S2*S4*S5 + 2*X6*a3*dq16*m_6*C2*C5*S3*S4*S6 + 2*X6*a3*dq16*m_6*C3*C5*S2*S4*S6 + 2*Y6*d4*dq14*m_6*C4*C5*S2*S3*S6 + 2*Y6*d4*dq15*m_6*C2*C3*S4*S5*S6 + 2*Y6*d4*dq16*m_6*C5*C6*S2*S3*S4 + 2*Y6*d6*dq14*m_6*C5*C6*S2*S3*S4 - 2*Y6*d6*dq15*m_6*C2*C4*S3*S4*S6 - 2*Y6*d6*dq15*m_6*C3*C4*S2*S4*S6 + 2*Y6*d6*dq16*m_6*C4*C5*S2*S3*S6 + 4*Y6*d6*dq24*m_6*C4*C5*S4*S5*S6 + 4*Y6*d6*dq34*m_6*C4*C5*S4*S5*S6 - 4*Z6*d6*dq14*m_6*C4*C5*S2*S3*S5 + 2*X6*Y6*dq16*m_6*C5*S2*S3*S4*S5 + 4*X6*Y6*dq15*m_6*C6*S2*S3*S4*S6 + 4*X5*Z5*dq15*m_5*C5*S2*S3*S4*S5 + 2*X6*Z6*dq14*m_6*C5*S2*S3*S4*S6 + 4*X6*a3*dq11*m_6*C2*CC3*C4*C5*C6*S2 + 4*X6*a3*dq11*m_6*CC2*C3*C4*C5*C6*S3 - 2*Y6*a3*dq15*m_6*C2*S3*S4*S5*S6 - 2*Y6*a3*dq15*m_6*C3*S2*S4*S5*S6 - 2*XX6*dq14*m_6*C2*C3*C4*C5*CC6*S5 + 2*X6*d4*dq15*m_6*C6*S2*S3*S4*S5 + 2*X6*d4*dq16*m_6*C5*S2*S3*S4*S6 + 2*X6*d6*dq14*m_6*C5*S2*S3*S4*S6 + 2*YY6*dq14*m_6*C2*C3*C4*C5*CC6*S5 - 4*X5*Y5*dq11*m_5*C2*CC3*C4*C5*S2*S4 - 4*X5*Y5*dq11*m_5*CC2*C3*C4*C5*S3*S4 + 4*X6*Y6*dq11*m_6*C2*CC3*C4*C5*S2*S4 + 4*X6*Y6*dq11*m_6*CC2*C3*C4*C5*S3*S4 + 4*X6*Y6*dq11*m_6*C2*C4*C5*CC6*S2*S4 + 4*X6*Y6*dq11*m_6*C3*C4*C5*CC6*S3*S4 + 4*X6*Y6*dq11*m_6*CC2*C4*C5*C6*S5*S6 + 4*X6*Y6*dq11*m_6*CC3*C4*C5*C6*S5*S6 + 8*X5*Z5*dq11*m_5*C2*C3*C4*CC5*S2*S3 + 4*X6*Z6*dq11*m_6*C2*CC3*C5*C6*S2*S5 - 2*X6*Z6*dq11*m_6*C2*CC4*C5*C6*S2*S5 + 4*X6*Z6*dq11*m_6*CC2*C3*C5*C6*S3*S5 - 2*X6*Z6*dq11*m_6*C3*CC4*C5*C6*S3*S5 - 4*Y6*a3*dq11*m_6*C2*CC3*C4*C5*S2*S6 - 4*Y6*a3*dq11*m_6*CC2*C3*C4*C5*S3*S6 + 4*X6*d6*dq11*m_6*C2*CC3*C5*C6*S2*S5 - 2*X6*d6*dq11*m_6*C2*CC4*C5*C6*S2*S5 + 4*X6*d6*dq11*m_6*CC2*C3*C5*C6*S3*S5 - 2*X6*d6*dq11*m_6*C3*CC4*C5*C6*S3*S5 - 2*Y6*d4*dq15*m_6*S2*S3*S4*S5*S6 + 4*X6*Z6*dq14*m_6*C2*C3*C4*CC5*C6 - 4*Y5*Z5*dq11*m_5*C2*CC3*C4*S2*S4*S5 - 4*Y5*Z5*dq11*m_5*CC2*C3*C4*S3*S4*S5 - 4*Y6*Z6*dq11*m_6*C2*CC3*C5*S2*S5*S6 + 2*Y6*Z6*dq11*m_6*C2*CC4*C5*S2*S5*S6 - 4*Y6*Z6*dq11*m_6*CC2*C3*C5*S3*S5*S6 + 2*Y6*Z6*dq11*m_6*C3*CC4*C5*S3*S5*S6 - 2*Ixx6*dq15*C2*C4*C5*CC6*S3*S4*S5 - 2*Ixx6*dq15*C3*C4*C5*CC6*S2*S4*S5 - 2*Ixx6*dq16*C2*C4*CC5*C6*S3*S4*S6 - 2*Ixx6*dq16*C3*C4*CC5*C6*S2*S4*S6 + 2*Iyy6*dq15*C2*C4*C5*CC6*S3*S4*S5 + 2*Iyy6*dq15*C3*C4*C5*CC6*S2*S4*S5 + 2*Iyy6*dq16*C2*C4*CC5*C6*S3*S4*S6 + 2*Iyy6*dq16*C3*C4*CC5*C6*S2*S4*S6 + 2*XX6*dq14*m_6*C4*C5*CC6*S2*S3*S5 + 2*XX6*dq15*m_6*C2*CC4*C6*S3*S5*S6 + 2*XX6*dq15*m_6*C3*CC4*C6*S2*S5*S6 + 4*X6*d6*dq14*m_6*C2*C3*C4*CC5*C6 - 4*Y6*d6*dq11*m_6*C2*CC3*C5*S2*S5*S6 + 2*Y6*d6*dq11*m_6*C2*CC4*C5*S2*S5*S6 - 4*Y6*d6*dq11*m_6*CC2*C3*C5*S3*S5*S6 + 2*Y6*d6*dq11*m_6*C3*CC4*C5*S3*S5*S6 - 2*YY6*dq14*m_6*C4*C5*CC6*S2*S3*S5 - 2*YY6*dq15*m_6*C2*CC4*C6*S3*S5*S6 - 2*YY6*dq15*m_6*C3*CC4*C6*S2*S5*S6 - 4*Y6*Z6*dq14*m_6*C2*C3*C4*CC5*S6 - 2*Y6*Z6*dq15*m_6*C2*CC4*C5*C6*S3 - 2*Y6*Z6*dq15*m_6*C3*CC4*C5*C6*S2 - 2*Y6*Z6*dq16*m_6*C2*C3*CC5*C6*S4 - 4*Y6*d6*dq14*m_6*C2*C3*C4*CC5*S6 - 2*Y6*d6*dq15*m_6*C2*CC4*C5*C6*S3 - 2*Y6*d6*dq15*m_6*C3*CC4*C5*C6*S2 - 2*Y6*d6*dq16*m_6*C2*C3*CC5*C6*S4 + 4*X6*Y6*dq14*m_6*C2*C3*CC6*S4*S5 - 2*X6*Y6*dq16*m_6*C2*C4*CC5*S3*S4 - 2*X6*Y6*dq16*m_6*C3*C4*CC5*S2*S4 + 4*X6*Y6*dq14*m_6*C2*CC4*C6*S3*S6 + 4*X6*Y6*dq14*m_6*C3*CC4*C6*S2*S6 + 4*X6*Y6*dq16*m_6*C2*C4*CC6*S3*S4 + 4*X6*Y6*dq16*m_6*C3*C4*CC6*S2*S4 + 4*X6*Y6*dq24*m_6*C4*CC5*C6*S4*S6 + 4*X6*Y6*dq34*m_6*C4*CC5*C6*S4*S6 + 4*X6*Y6*dq25*m_6*CC4*C5*C6*S5*S6 + 4*X6*Y6*dq35*m_6*CC4*C5*C6*S5*S6 - 4*X5*Z5*dq14*m_5*C2*CC4*C5*S3*S5 - 4*X5*Z5*dq14*m_5*C3*CC4*C5*S2*S5 - 4*X5*Z5*dq15*m_5*C2*C4*CC5*S3*S4 - 4*X5*Z5*dq15*m_5*C3*C4*CC5*S2*S4 - 4*X6*Z6*dq14*m_6*C4*CC5*C6*S2*S3 - 2*X6*Z6*dq15*m_6*C2*CC4*C5*S3*S6 - 2*X6*Z6*dq15*m_6*C3*CC4*C5*S2*S6 - 2*X6*Z6*dq16*m_6*C2*C3*CC5*S4*S6 - 2*X6*Z6*dq16*m_6*C2*CC4*C6*S3*S5 - 2*X6*Z6*dq16*m_6*C3*CC4*C6*S2*S5 - 4*X6*d6*dq14*m_6*C4*CC5*C6*S2*S3 - 2*X6*d6*dq15*m_6*C2*CC4*C5*S3*S6 - 2*X6*d6*dq15*m_6*C3*CC4*C5*S2*S6 - 2*X6*d6*dq16*m_6*C2*C3*CC5*S4*S6 - 2*X6*d6*dq16*m_6*C2*CC4*C6*S3*S5 - 2*X6*d6*dq16*m_6*C3*CC4*C6*S2*S5 + 4*Y6*Z6*dq14*m_6*C4*CC5*S2*S3*S6 + 2*Y6*Z6*dq16*m_6*C2*CC4*S3*S5*S6 + 2*Y6*Z6*dq16*m_6*C3*CC4*S2*S5*S6 + 2*Y6*Z6*dq16*m_6*CC5*C6*S2*S3*S4 - 4*Y6*Z6*dq11*m_6*C2*CC3*CC4*C5*S2*S5*S6 - 4*Y6*Z6*dq11*m_6*CC2*C3*CC4*C5*S3*S5*S6 - 4*Y6*d6*dq11*m_6*C2*CC3*CC4*C5*S2*S5*S6 - 4*Y6*d6*dq11*m_6*CC2*C3*CC4*C5*S3*S5*S6 + 4*X6*Y6*dq14*m_6*C2*CC4*CC5*C6*S3*S6 + 4*X6*Y6*dq14*m_6*C3*CC4*CC5*C6*S2*S6 + 4*X6*Y6*dq16*m_6*C2*C4*CC5*CC6*S3*S4 + 4*X6*Y6*dq16*m_6*C3*C4*CC5*CC6*S2*S4 - 8*Ixy6*dq11*C2*C3*C4*C5*C6*S2*S3*S5*S6 + 4*XX6*dq11*m_6*C2*C3*C6*S2*S3*S4*S5*S6 + 4*X6*d4*dq11*m_6*C2*C3*C4*C5*C6*S2*S3 - 4*YY6*dq11*m_6*C2*C3*C6*S2*S3*S4*S5*S6 - 4*Y6*Z6*dq11*m_6*C2*C3*C5*C6*S2*S3*S4 + 4*XX6*dq14*m_6*C2*C4*C5*C6*S3*S4*S6 + 4*XX6*dq14*m_6*C3*C4*C5*C6*S2*S4*S6 + 2*XX6*dq16*m_6*C2*C3*C5*C6*S4*S5*S6 - 4*Y6*d4*dq11*m_6*C2*C3*C4*C5*S2*S3*S6 - 4*Y6*d6*dq11*m_6*C2*C3*C5*C6*S2*S3*S4 - 4*YY6*dq14*m_6*C2*C4*C5*C6*S3*S4*S6 - 4*YY6*dq14*m_6*C3*C4*C5*C6*S2*S4*S6 - 2*YY6*dq16*m_6*C2*C3*C5*C6*S4*S5*S6 + 8*Z6*d6*dq11*m_6*C2*C3*C4*C5*S2*S3*S5 - 4*X6*Y6*dq11*m_6*C2*CC3*CC4*CC5*C6*S2*S6 - 4*X6*Y6*dq11*m_6*CC2*C3*CC4*CC5*C6*S3*S6 - 4*X6*Z6*dq11*m_6*C2*C3*C5*S2*S3*S4*S6 + 4*Ixy6*dq15*C2*C4*C5*C6*S3*S4*S5*S6 + 4*Ixy6*dq15*C3*C4*C5*C6*S2*S4*S5*S6 - 4*X6*d6*dq11*m_6*C2*C3*C5*S2*S3*S4*S6 + 4*X6*Y6*dq16*m_6*C2*C3*C4*C6*S5*S6 - 4*X6*Z6*dq15*m_6*C2*C3*C5*C6*S4*S5 - 2*XX6*dq16*m_6*C5*C6*S2*S3*S4*S5*S6 - 4*X6*d6*dq15*m_6*C2*C3*C5*C6*S4*S5 + 2*YY6*dq16*m_6*C5*C6*S2*S3*S4*S5*S6 + 4*Y6*Z6*dq14*m_6*C2*C4*C6*S3*S4*S5 + 4*Y6*Z6*dq14*m_6*C3*C4*C6*S2*S4*S5 + 4*Y6*Z6*dq15*m_6*C2*C3*C5*S4*S5*S6 - 4*XX6*dq11*m_6*C2*C3*C4*C5*CC6*S2*S3*S5 - 4*XX6*dq11*m_6*C2*CC3*C4*C5*C6*S2*S4*S6 - 4*XX6*dq11*m_6*CC2*C3*C4*C5*C6*S3*S4*S6 + 4*YY6*dq11*m_6*C2*C3*C4*C5*CC6*S2*S3*S5 + 4*YY6*dq11*m_6*C2*CC3*C4*C5*C6*S2*S4*S6 + 4*YY6*dq11*m_6*CC2*C3*C4*C5*C6*S3*S4*S6 + 4*Y6*d6*dq14*m_6*C2*C4*C6*S3*S4*S5 + 4*Y6*d6*dq14*m_6*C3*C4*C6*S2*S4*S5 + 4*Y6*d6*dq15*m_6*C2*C3*C5*S4*S5*S6 - 4*Z6*d6*dq15*m_6*C2*C4*C5*S3*S4*S5 - 4*Z6*d6*dq15*m_6*C3*C4*C5*S2*S4*S5 - 4*X6*Y6*dq16*m_6*C4*C6*S2*S3*S5*S6 + 4*X6*Z6*dq14*m_6*C2*C4*S3*S4*S5*S6 + 4*X6*Z6*dq14*m_6*C3*C4*S2*S4*S5*S6 + 4*X6*Z6*dq15*m_6*C5*C6*S2*S3*S4*S5 + 4*X6*d6*dq14*m_6*C2*C4*S3*S4*S5*S6 + 4*X6*d6*dq14*m_6*C3*C4*S2*S4*S5*S6 + 4*X6*d6*dq15*m_6*C5*C6*S2*S3*S4*S5 + 8*X6*Z6*dq11*m_6*C2*C3*C4*CC5*C6*S2*S3 - 4*Y6*Z6*dq15*m_6*C5*S2*S3*S4*S5*S6 + 8*X6*d6*dq11*m_6*C2*C3*C4*CC5*C6*S2*S3 - 4*Y6*d6*dq15*m_6*C5*S2*S3*S4*S5*S6 - 8*Y6*Z6*dq11*m_6*C2*C3*C4*CC5*S2*S3*S6 - 4*Y6*Z6*dq11*m_6*C2*CC3*C4*C6*S2*S4*S5 - 4*Y6*Z6*dq11*m_6*CC2*C3*C4*C6*S3*S4*S5 + 2*XX6*dq15*m_6*C2*C4*C5*CC6*S3*S4*S5
 + 2*XX6*dq15*m_6*C3*C4*C5*CC6*S2*S4*S5 + 2*XX6*dq16*m_6*C2*C4*CC5*C6*S3*S4*S6 + 2*XX6*dq16*m_6*C3*C4*CC5*C6*S2*S4*S6 - 8*Y6*d6*dq11*m_6*C2*C3*C4*CC5*S2*S3*S6 - 4*Y6*d6*dq11*m_6*C2*CC3*C4*C6*S2*S4*S5 - 4*Y6*d6*dq11*m_6*CC2*C3*C4*C6*S3*S4*S5 - 2*YY6*dq15*m_6*C2*C4*C5*CC6*S3*S4*S5 - 2*YY6*dq15*m_6*C3*C4*C5*CC6*S2*S4*S5 - 2*YY6*dq16*m_6*C2*C4*CC5*C6*S3*S4*S6 - 2*YY6*dq16*m_6*C3*C4*CC5*C6*S2*S4*S6 + 8*X6*Y6*dq11*m_6*C2*C3*CC6*S2*S3*S4*S5 - 4*X6*Z6*dq11*m_6*C2*CC3*C4*S2*S4*S5*S6 - 4*X6*Z6*dq11*m_6*CC2*C3*C4*S3*S4*S5*S6 - 4*X6*d6*dq11*m_6*C2*CC3*C4*S2*S4*S5*S6 - 4*X6*d6*dq11*m_6*CC2*C3*C4*S3*S4*S5*S6 + 8*X6*Y6*dq14*m_6*C2*C4*C5*CC6*S3*S4 + 8*X6*Y6*dq14*m_6*C3*C4*C5*CC6*S2*S4 + 4*X6*Y6*dq15*m_6*C2*C3*CC5*C6*S4*S6 + 4*X6*Y6*dq16*m_6*C2*C3*C5*CC6*S4*S5 + 8*X6*Y6*dq16*m_6*C2*CC4*C5*C6*S3*S6 + 8*X6*Y6*dq16*m_6*C3*CC4*C5*C6*S2*S6 - 4*X6*Z6*dq14*m_6*C2*CC4*C5*C6*S3*S5 - 4*X6*Z6*dq14*m_6*C3*CC4*C5*C6*S2*S5 - 4*X6*Z6*dq15*m_6*C2*C4*CC5*C6*S3*S4 - 4*X6*Z6*dq15*m_6*C3*C4*CC5*C6*S2*S4 - 4*X6*d6*dq14*m_6*C2*CC4*C5*C6*S3*S5 - 4*X6*d6*dq14*m_6*C3*CC4*C5*C6*S2*S5 - 4*X6*d6*dq15*m_6*C2*C4*CC5*C6*S3*S4 - 4*X6*d6*dq15*m_6*C3*C4*CC5*C6*S2*S4 + 4*Y6*Z6*dq14*m_6*C2*CC4*C5*S3*S5*S6 + 4*Y6*Z6*dq14*m_6*C3*CC4*C5*S2*S5*S6 + 4*Y6*Z6*dq15*m_6*C2*C4*CC5*S3*S4*S6 + 4*Y6*Z6*dq15*m_6*C3*C4*CC5*S2*S4*S6 + 4*Y6*d6*dq14*m_6*C2*CC4*C5*S3*S5*S6 + 4*Y6*d6*dq14*m_6*C3*CC4*C5*S2*S5*S6 + 4*Y6*d6*dq15*m_6*C2*C4*CC5*S3*S4*S6 + 4*Y6*d6*dq15*m_6*C3*C4*CC5*S2*S4*S6 - 4*X6*Y6*dq15*m_6*CC5*C6*S2*S3*S4*S6 - 4*X6*Y6*dq16*m_6*C5*CC6*S2*S3*S4*S5 - 8*X6*Y6*dq11*m_6*C2*CC3*C4*C5*CC6*S2*S4 - 8*X6*Y6*dq11*m_6*CC2*C3*C4*C5*CC6*S3*S4 - 8*X6*Y6*dq11*m_6*CC2*CC3*C4*C5*C6*S5*S6 + 4*X6*Z6*dq11*m_6*C2*CC3*CC4*C5*C6*S2*S5 + 4*X6*Z6*dq11*m_6*CC2*C3*CC4*C5*C6*S3*S5 + 4*X6*d6*dq11*m_6*C2*CC3*CC4*C5*C6*S2*S5 + 4*X6*d6*dq11*m_6*CC2*C3*CC4*C5*C6*S3*S5 + 4*X6*Y6*dq14*m_6*C2*C3*C4*C5*C6*S5*S6 + 2*Y6*Z6*dq16*m_6*C2*C4*C5*C6*S3*S4*S5 + 2*Y6*Z6*dq16*m_6*C3*C4*C5*C6*S2*S4*S5 + 2*Y6*d6*dq16*m_6*C2*C4*C5*C6*S3*S4*S5 + 2*Y6*d6*dq16*m_6*C3*C4*C5*C6*S2*S4*S5 - 4*X6*Y6*dq14*m_6*C4*C5*C6*S2*S3*S5*S6 + 2*X6*Z6*dq16*m_6*C2*C4*C5*S3*S4*S5*S6 + 2*X6*Z6*dq16*m_6*C3*C4*C5*S2*S4*S5*S6 + 2*X6*d6*dq16*m_6*C2*C4*C5*S3*S4*S5*S6 + 2*X6*d6*dq16*m_6*C3*C4*C5*S2*S4*S5*S6 - 4*X6*Y6*dq15*m_6*C2*C4*C5*C6*S3*S4*S5*S6 - 4*X6*Y6*dq15*m_6*C3*C4*C5*C6*S2*S4*S5*S6 + 8*X6*Y6*dq11*m_6*C2*C3*C4*C5*C6*S2*S3*S5*S6;
coriolis.array2d[3][0] = Ixz4*dq22 + Ixz4*dq33 + Ixy5*dq22*C5 + Ixy5*dq33*C5 - Ixy6*dq22*C5 - Ixy6*dq33*C5 - Ixy5*dq55*C5 + Ixy6*dq55*C5 + Iyz5*dq22*S5 + Iyz5*dq33*S5 - Iyz5*dq55*S5 + 2*Ixy6*dq46 + 2*Ixz4*dq23 + 2*Ixz5*dq45 - Ixz4*dq11*CC2 - Ixz4*dq11*CC3 - 2*Ixz4*dq22*CC4 - 2*Ixz4*dq33*CC4 - (Ixx4*dq22*S44)/2 - (Ixx4*dq33*S44)/2 + (Ixx6*dq22*S44)/2 + (Ixx6*dq33*S44)/2 + (Iyy5*dq22*S44)/2 + (Iyy5*dq33*S44)/2 + (Izz4*dq22*S44)/2 + (Izz4*dq33*S44)/2 - (Izz5*dq22*S44)/2 - (Izz5*dq33*S44)/2 - (Izz6*dq22*S44)/2 - (Izz6*dq33*S44)/2 + Iyz6*dq22*C6*S5 + Iyz6*dq33*C6*S5 - Iyz6*dq55*C6*S5 + Iyz6*dq66*C6*S5 + Ixz6*dq22*S5*S6 + Ixz6*dq33*S5*S6 - Ixz6*dq55*S5*S6 + Ixz6*dq66*S5*S6 - X4*Z4*dq22*m_4 - X4*Z4*dq33*m_4 + 2*Ixy5*dq23*C5 - 2*Ixy6*dq23*C5 + 2*Ixz6*dq45*C6 + Ixx5*dq25*S4 + Ixx5*dq35*S4 + Ixx6*dq25*S4 + Ixx6*dq35*S4 + Ixx6*dq56*S5 + Iyy5*dq25*S4 + Iyy5*dq35*S4 + Iyy6*dq25*S4 + Iyy6*dq35*S4 - Iyy6*dq56*S5 + 2*Iyz5*dq23*S5 - 2*Iyz6*dq45*S6 - Izz5*dq25*S4 - Izz5*dq35*S4 - Izz6*dq25*S4 - Izz6*dq35*S4 - Izz6*dq56*S5 - Ixy5*dq11*CC2*C5 - Ixy5*dq11*CC3*C5 + Ixy6*dq11*CC2*C5 + Ixy6*dq11*CC3*C5 - 2*Ixy5*dq22*CC4*C5 - 2*Ixy5*dq33*CC4*C5 + 2*Ixy6*dq22*CC4*C5 + 2*Ixy6*dq33*CC4*C5 + 2*Ixy6*dq22*C5*CC6 + 2*Ixy6*dq33*C5*CC6 - 2*Ixy6*dq55*C5*CC6 - Iyz5*dq11*CC2*S5 - Iyz5*dq11*CC3*S5 - 2*Iyz5*dq22*CC4*S5 - 2*Iyz5*dq33*CC4*S5 + (XX4*dq22*m_4*S44)/2 + (XX4*dq33*m_4*S44)/2 - (XX6*dq22*m_6*S44)/2 - (XX6*dq33*m_6*S44)/2 - (YY5*dq22*m_5*S44)/2 - (YY5*dq33*m_5*S44)/2 - (ZZ4*dq22*m_4*S44)/2 - (ZZ4*dq33*m_4*S44)/2 + (ZZ5*dq22*m_5*S44)/2 + (ZZ5*dq33*m_5*S44)/2 + (ZZ6*dq22*m_6*S44)/2 + (ZZ6*dq33*m_6*S44)/2 + (dd6*dq22*m_6*S44)/2 + (dd6*dq33*m_6*S44)/2 - 2*Ixy6*dq46*CC5 - 4*Ixy6*dq46*CC6 - 4*Ixz4*dq23*CC4 - 4*Ixz5*dq45*CC5 - Ixx4*dq23*S44 + Ixx6*dq23*S44 + Ixx5*dq45*S55 - Ixx6*dq46*S66 + Iyy5*dq23*S44 + Iyy6*dq45*S55 + Iyy6*dq46*S66 + Izz4*dq23*S44 - Izz5*dq23*S44 - Izz6*dq23*S44 - Izz5*dq45*S55 - Izz6*dq45*S55 + 2*Ixz4*dq11*CC2*CC3 + 2*Ixz4*dq11*CC2*CC4 + 2*Ixz4*dq11*CC3*CC4 - 4*Ixz4*dq11*CC2*CC3*CC4 - Ixy4*dq11*C2*S2*S4 - Ixy4*dq11*C3*S3*S4 - Ixz5*dq11*C2*S2*S4 - Ixz5*dq11*C3*S3*S4 - X5*Y5*dq22*m_5*C5 - X5*Y5*dq33*m_5*C5 + X5*Y5*dq55*m_5*C5 + X6*Y6*dq22*m_6*C5 + X6*Y6*dq33*m_6*C5 - X6*Y6*dq55*m_6*C5 - 2*Ixy6*dq16*C2*C3 - 2*Ixy5*dq25*C4*C5 - 2*Ixy5*dq35*C4*C5 + 2*Ixy6*dq25*C4*C5 + 2*Ixy6*dq35*C4*C5 - 2*Ixz5*dq15*C2*C3 + Y5*a3*dq11*m_5*C4 + Y5*a3*dq22*m_5*C4 + Y5*a3*dq33*m_5*C4 + Z4*a3*dq11*m_4*C4 + Z4*a3*dq22*m_4*C4 + Z4*a3*dq33*m_4*C4 - Y5*Z5*dq22*m_5*S5 - Y5*Z5*dq33*m_5*S5 + Y5*Z5*dq55*m_5*S5 + Ixx4*dq12*C2*S3 + Ixx4*dq12*C3*S2 + Ixx4*dq13*C2*S3 + Ixx4*dq13*C3*S2 + Ixx5*dq12*C2*S3 + Ixx5*dq12*C3*S2 + Ixx5*dq13*C2*S3 + Ixx5*dq13*C3*S2 - Ixx6*dq12*C2*S3 - Ixx6*dq12*C3*S2 - Ixx6*dq13*C2*S3 - Ixx6*dq13*C3*S2 + Ixx6*dq26*C4*S5 + Ixx6*dq36*C4*S5 + Iyy4*dq12*C2*S3 + Iyy4*dq12*C3*S2 + Iyy4*dq13*C2*S3 + Iyy4*dq13*C3*S2 - Iyy5*dq12*C2*S3 - Iyy5*dq12*C3*S2 - Iyy5*dq13*C2*S3 - Iyy5*dq13*C3*S2 + Iyy6*dq12*C2*S3 + Iyy6*dq12*C3*S2 + Iyy6*dq13*C2*S3 + Iyy6*dq13*C3*S2 - Iyy6*dq26*C4*S5 - Iyy6*dq36*C4*S5 - 2*Iyz5*dq25*C4*S5 - 2*Iyz5*dq35*C4*S5 + 2*Iyz6*dq23*C6*S5 + 2*Iyz6*dq26*C6*S4 + 2*Iyz6*dq36*C6*S4 - Izz4*dq12*C2*S3 - Izz4*dq12*C3*S2 - Izz4*dq13*C2*S3 - Izz4*dq13*C3*S2 + Izz5*dq12*C2*S3 + Izz5*dq12*C3*S2 + Izz5*dq13*C2*S3 + Izz5*dq13*C3*S2 + Izz6*dq12*C2*S3 + Izz6*dq12*C3*S2 + Izz6*dq13*C2*S3 + Izz6*dq13*C3*S2 - Izz6*dq26*C4*S5 - Izz6*dq36*C4*S5 + X4*a3*dq11*m_4*S4 + X4*a3*dq22*m_4*S4 + X4*a3*dq33*m_4*S4 - 2*XX6*dq56*m_6*S5 + 2*ZZ5*dq25*m_5*S4 + 2*ZZ5*dq35*m_5*S4 + 2*ZZ6*dq25*m_6*S4 + 2*ZZ6*dq35*m_6*S4 + 2*Ixy6*dq16*S2*S3 + 2*Ixz5*dq15*S2*S3 + 2*Ixz6*dq23*S5*S6 + 2*Ixz6*dq26*S4*S6 + 2*Ixz6*dq36*S4*S6 + 2*dd6*dq25*m_6*S4 + 2*dd6*dq35*m_6*S4 - 2*X6*Y6*dq46*m_6 - 2*X4*Z4*dq23*m_4 - 2*X5*Z5*dq45*m_5 + Ixx4*dq11*CC2*C4*S4 + Ixx4*dq11*CC3*C4*S4 - Ixx6*dq11*CC2*C4*S4 - Ixx6*dq11*CC3*C4*S4 - Ixx5*dq22*C4*CC5*S4 - Ixx5*dq33*C4*CC5*S4 - Ixx6*dq22*C4*CC6*S4 - Ixx6*dq33*C4*CC6*S4 - Iyy5*dq11*CC2*C4*S4 - Iyy5*dq11*CC3*C4*S4 - Iyy6*dq22*C4*CC5*S4 + Iyy6*dq22*C4*CC6*S4 - Iyy6*dq33*C4*CC5*S4 + Iyy6*dq33*C4*CC6*S4 - Iyz6*dq11*CC2*C6*S5 - Iyz6*dq11*CC3*C6*S5 - 2*Iyz6*dq22*CC4*C6*S5 - 2*Iyz6*dq33*CC4*C6*S5 - Izz4*dq11*CC2*C4*S4 - Izz4*dq11*CC3*C4*S4 + Izz5*dq11*CC2*C4*S4 + Izz5*dq11*CC3*C4*S4 + Izz6*dq11*CC2*C4*S4 + Izz6*dq11*CC3*C4*S4 + Izz5*dq22*C4*CC5*S4 + Izz5*dq33*C4*CC5*S4 + Izz6*dq22*C4*CC5*S4 + Izz6*dq33*C4*CC5*S4 - Ixz6*dq11*CC2*S5*S6 - Ixz6*dq11*CC3*S5*S6 - 2*Ixz6*dq22*CC4*S5*S6 - 2*Ixz6*dq33*CC4*S5*S6 + X4*Z4*dq11*m_4*CC2 + X4*Z4*dq11*m_4*CC3 + 2*X4*Z4*dq22*m_4*CC4 + 2*X4*Z4*dq33*m_4*CC4 - 4*Ixy5*dq23*CC4*C5 + 4*Ixy6*dq23*CC4*C5 + 4*Ixy6*dq23*C5*CC6 - 4*Ixz6*dq45*CC5*C6 - 2*Ixx5*dq25*CC5*S4 - 2*Ixx5*dq35*CC5*S4 - 2*Ixx6*dq56*CC6*S5 - 2*Iyy6*dq25*CC5*S4 - 2*Iyy6*dq35*CC5*S4 + 2*Iyy6*dq56*CC6*S5 - 4*Iyz5*dq23*CC4*S5 + 4*Iyz6*dq45*CC5*S6 + 2*Izz5*dq25*CC5*S4 + 2*Izz5*dq35*CC5*S4 + 2*Izz6*dq25*CC5*S4 + 2*Izz6*dq35*CC5*S4 + XX4*dq23*m_4*S44 - XX6*dq23*m_6*S44 - XX5*dq45*m_5*S55 + XX6*dq46*m_6*S66 - YY5*dq23*m_5*S44 - YY6*dq45*m_6*S55 - YY6*dq46*m_6*S66 + Z6*d6*dq22*m_6*S44 + Z6*d6*dq33*m_6*S44 - ZZ4*dq23*m_4*S44 + ZZ5*dq23*m_5*S44 + ZZ6*dq23*m_6*S44 + ZZ5*dq45*m_5*S55 + ZZ6*dq45*m_6*S55 + dd6*dq23*m_6*S44 + dd6*dq45*m_6*S55 + 2*Ixy5*dq11*CC2*CC3*C5 + 2*Ixy5*dq11*CC2*CC4*C5 - 2*Ixy6*dq11*CC2*CC3*C5 + 2*Ixy5*dq11*CC3*CC4*C5 - 2*Ixy6*dq11*CC2*CC4*C5 - 2*Ixy6*dq11*CC3*CC4*C5 - 2*Ixy6*dq11*CC2*C5*CC6 - 2*Ixy6*dq11*CC3*C5*CC6 - 4*Ixy6*dq22*CC4*C5*CC6 - 4*Ixy6*dq33*CC4*C5*CC6 + 2*Iyz5*dq11*CC2*CC3*S5 + 2*Iyz5*dq11*CC2*CC4*S5 + 2*Iyz5*dq11*CC3*CC4*S5 + 4*Ixy6*dq46*CC5*CC6 + Ixx6*dq22*C5*C6*S6 + Ixx6*dq33*C5*C6*S6 - Ixx6*dq55*C5*C6*S6 - Iyy6*dq22*C5*C6*S6 - Iyy6*dq33*C5*C6*S6 + Iyy6*dq55*C5*C6*S6 - Iyz4*dq11*C2*C4*S2 - Iyz4*dq11*C3*C4*S3 + X4*a2*dq22*m_4*C3*S4 + X5*a3*dq11*m_5*C5*S4 + X5*a3*dq22*m_5*C5*S4 + X5*a3*dq33*m_5*C5*S4 + X6*a3*dq11*m_6*C4*S6 + X6*a3*dq22*m_6*C4*S6 + X6*a3*dq33*m_6*C4*S6 + 2*XX6*dq12*m_6*C2*S3 + 2*XX6*dq12*m_6*C3*S2 + 2*XX6*dq13*m_6*C2*S3 + 2*XX6*dq13*m_6*C3*S2 - 2*XX6*dq26*m_6*C4*S5 - 2*XX6*dq36*m_6*C4*S5 - Y6*d6*dq22*m_6*C6*S5 - Y6*d6*dq33*m_6*C6*S5 + Y6*d6*dq55*m_6*C6*S5 - Y6*d6*dq66*m_6*C6*S5 + 2*YY5*dq12*m_5*C2*S3 + 2*YY5*dq12*m_5*C3*S2 + 2*YY5*dq13*m_5*C2*S3 + 2*YY5*dq13*m_5*C3*S2 + 2*ZZ4*dq12*m_4*C2*S3 + 2*ZZ4*dq12*m_4*C3*S2 + 2*ZZ4*dq13*m_4*C2*S3 + 2*ZZ4*dq13*m_4*C3*S2 - X6*Z6*dq22*m_6*S5*S6 - X6*Z6*dq33*m_6*S5*S6 + X6*Z6*dq55*m_6*S5*S6 - X6*Z6*dq66*m_6*S5*S6 + 2*Ixy4*dq12*C4*S2*S3 + 2*Ixy4*dq13*C4*S2*S3 - 2*Ixy6*dq26*C5*S4*S5 - 2*Ixy6*dq36*C5*S4*S5 + 4*Ixy6*dq56*C6*S5*S6 + 2*Ixz5*dq12*C4*S2*S3 + 2*Ixz5*dq13*C4*S2*S3 + 2*Ixz6*dq15*C6*S2*S3 - 4*Ixz5*dq25*C5*S4*S5 - 4*Ixz5*dq35*C5*S4*S5 - 2*Ixz6*dq25*C4*S5*S6 - 2*Ixz6*dq35*C4*S5*S6 + 2*Ixz6*dq46*C5*S5*S6 + Z5*a3*dq11*m_5*S4*S5 + Z5*a3*dq22*m_5*S4*S5 + Z5*a3*dq33*m_5*S4*S5 + Z6*a3*dq11*m_6*S4*S5 + Z6*a3*dq22*m_6*S4*S5 + Z6*a3*dq33*m_6*S4*S5 - X6*d6*dq22*m_6*S5*S6 - X6*d6*dq33*m_6*S5*S6 + X6*d6*dq55*m_6*S5*S6 - X6*d6*dq66*m_6*S5*S6 - 2*X5*Y5*dq23*m_5*C5 + 2*X6*Y6*dq23*m_6*C5 - 2*X6*Z6*dq45*m_6*C6 + a3*d6*dq11*m_6*S4*S5 + a3*d6*dq22*m_6*S4*S5 + a3*d6*dq33*m_6*S4*S5 - 2*Iyz4*dq12*S2*S3*S4 - 2*Iyz4*dq13*S2*S3*S4 - 2*Iyz6*dq15*S2*S3*S6 + 2*Y5*a3*dq23*m_5*C4 + 2*Z4*a3*dq23*m_4*C4 - 2*X6*d6*dq45*m_6*C6 - 2*Y5*Z5*dq23*m_5*S5 + 2*Y6*Z6*dq45*m_6*S6 - Ixx6*dq11*CC2*C5*C6*S6 - Ixx6*dq11*CC3*C5*C6*S6 - 2*Ixx6*dq22*CC4*C5*C6*S6 - 2*Ixx6*dq33*CC4*C5*C6*S6 + Iyy6*dq11*CC2*C5*C6*S6 + Iyy6*dq11*CC3*C5*C6*S6 + 2*Iyy6*dq22*CC4*C5*C6*S6 + 2*Iyy6*dq33*CC4*C5*C6*S6 + 2*Iyz4*dq11*C2*CC3*C4*S2 + 2*Iyz4*dq11*CC2*C3*C4*S3 + 2*X4*a3*dq23*m_4*S4 - XX4*dq11*m_4*CC2*C4*S4 - XX4*dq11*m_4*CC3*C4*S4 + XX6*dq11*m_6*CC2*C4*S4 + XX6*dq11*m_6*CC3*C4*S4 + XX5*dq22*m_5*C4*CC5*S4 + XX5*dq33*m_5*C4*CC5*S4 + XX6*dq22*m_6*C4*CC6*S4 + XX6*dq33*m_6*C4*CC6*S4 + YY5*dq11*m_5*CC2*C4*S4 + YY5*dq11*m_5*CC3*C4*S4 + YY6*dq22*m_6*C4*CC5*S4 - YY6*dq22*m_6*C4*CC6*S4 + YY6*dq33*m_6*C4*CC5*S4 - YY6*dq33*m_6*C4*CC6*S4 + ZZ4*dq11*m_4*CC2*C4*S4 + ZZ4*dq11*m_4*CC3*C4*S4 - ZZ5*dq11*m_5*CC2*C4*S4 - ZZ5*dq11*m_5*CC3*C4*S4 - ZZ6*dq11*m_6*CC2*C4*S4 - ZZ6*dq11*m_6*CC3*C4*S4 - ZZ5*dq22*m_5*C4*CC5*S4 - ZZ5*dq33*m_5*C4*CC5*S4 - ZZ6*dq22*m_6*C4*CC5*S4 - ZZ6*dq33*m_6*C4*CC5*S4 + 2*Y6*d6*dq45*m_6*S6 + 4*Z6*d6*dq25*m_6*S4 + 4*Z6*d6*dq35*m_6*S4 + 2*Ixy4*dq11*C2*CC3*S2*S4 + 2*Ixy4*dq11*CC2*C3*S3*S4 + 2*Ixz5*dq11*C2*CC3*S2*S4 + 2*Ixz5*dq11*CC2*C3*S3*S4 + 2*Ixz5*dq11*C2*CC5*S2*S4 + 2*Ixz5*dq11*C3*CC5*S3*S4 - dd6*dq11*m_6*CC2*C4*S4 - dd6*dq11*m_6*CC3*C4*S4 - dd6*dq22*m_6*C4*CC5*S4 - dd6*dq33*m_6*C4*CC5*S4 + X5*Y5*dq11*m_5*CC2*C5 + X5*Y5*dq11*m_5*CC3*C5 + 2*X5*Y5*dq22*m_5*CC4*C5 - X6*Y6*dq11*m_6*CC2*C5 + 2*X5*Y5*dq33*m_5*CC4*C5 - X6*Y6*dq11*m_6*CC3*C5 - 2*X6*Y6*dq22*m_6*CC4*C5 - 2*X6*Y6*dq33*m_6*CC4*C5 - 2*X6*Y6*dq22*m_6*C5*CC6 - 2*X6*Y6*dq33*m_6*C5*CC6 + 2*X6*Y6*dq55*m_6*C5*CC6 + 2*Ixy6*dq16*C2*C3*CC5 + 4*Ixy6*dq16*C2*C3*CC6 - 4*Ixy6*dq25*C4*C5*CC6 - 4*Ixy6*dq35*C4*C5*CC6 + 4*Ixz5*dq15*C2*C3*CC5 - Y5*a3*dq11*m_5*CC2*C4 - Y5*a3*dq11*m_5*CC3*C4 - Z4*a3*dq11*m_4*CC2*C4 - Z4*a3*dq11*m_4*CC3*C4 + Y5*Z5*dq11*m_5*CC2*S5 + Y5*Z5*dq11*m_5*CC3*S5 + 2*Y5*Z5*dq22*m_5*CC4*S5 + 2*Y5*Z5*dq33*m_5*CC4*S5 - 2*Ixx4*dq12*C2*CC4*S3 - 2*Ixx4*dq12*C3*CC4*S2 - 2*Ixx4*dq13*C2*CC4*S3 - 2*Ixx4*dq13*C3*CC4*S2 + 2*Ixx6*dq12*C2*CC4*S3 + 2*Ixx6*dq12*C3*CC4*S2 + 2*Ixx6*dq13*C2*CC4*S3 + 2*Ixx6*dq13*C3*CC4*S2 + 2*Ixx6*dq12*C2*CC6*S3 + 2*Ixx6*dq12*C3*CC6*S2 + 2*Ixx6*dq13*C2*CC6*S3 + 2*Ixx6*dq13*C3*CC6*S2 - 2*Ixx5*dq23*C4*CC5*S4 - 2*Ixx6*dq23*C4*CC6*S4 - 2*Ixx6*dq26*C4*CC6*S5 - 2*Ixx6*dq36*C4*CC6*S5 + 2*Ixx6*dq45*C5*CC6*S5 + 2*Ixx6*dq46*CC5*C6*S6 + 2*Iyy5*dq12*C2*CC4*S3 + 2*Iyy5*dq12*C3*CC4*S2 + 2*Iyy5*dq13*C2*CC4*S3 + 2*Iyy5*dq13*C3*CC4*S2 - 2*Iyy6*dq12*C2*CC6*S3 - 2*Iyy6*dq12*C3*CC6*S2 - 2*Iyy6*dq13*C2*CC6*S3 - 2*Iyy6*dq13*C3*CC6*S2 - 2*Iyy6*dq23*C4*CC5*S4 + 2*Iyy6*dq23*C4*CC6*S4 + 2*Iyy6*dq26*C4*CC6*S5 + 2*Iyy6*dq36*C4*CC6*S5 - 2*Iyy6*dq45*C5*CC6*S5 - 2*Iyy6*dq46*CC5*C6*S6 - 4*Iyz6*dq23*CC4*C6*S5 - 2*Iyz6*dq26*CC5*C6*S4 - 2*Iyz6*dq36*CC5*C6*S4 + 2*Izz4*dq12*C2*CC4*S3 + 2*Izz4*dq12*C3*CC4*S2 + 2*Izz4*dq13*C2*CC4*S3
 + 2*Izz4*dq13*C3*CC4*S2
 - 2*Izz5*dq12*C2*CC4*S3 - 2*Izz5*dq12*C3*CC4*S2 - 2*Izz5*dq13*C2*CC4*S3 - 2*Izz5*dq13*C3*CC4*S2 - 2*Izz6*dq12*C2*CC4*S3 - 2*Izz6*dq12*C3*CC4*S2 - 2*Izz6*dq13*C2*CC4*S3 - 2*Izz6*dq13*C3*CC4*S2 + 2*Izz5*dq23*C4*CC5*S4 + 2*Izz6*dq23*C4*CC5*S4 - X4*a3*dq11*m_4*CC2*S4 - X4*a3*dq11*m_4*CC3*S4 + 2*XX5*dq25*m_5*CC5*S4 + 2*XX5*dq35*m_5*CC5*S4 + 2*XX6*dq56*m_6*CC6*S5 + 2*YY6*dq25*m_6*CC5*S4 + 2*YY6*dq35*m_6*CC5*S4 - 2*YY6*dq56*m_6*CC6*S5 - 2*ZZ5*dq25*m_5*CC5*S4 - 2*ZZ5*dq35*m_5*CC5*S4 - 2*ZZ6*dq25*m_6*CC5*S4 - 2*ZZ6*dq35*m_6*CC5*S4 - 2*Ixy6*dq16*CC5*S2*S3 - 4*Ixy6*dq16*CC6*S2*S3 - 4*Ixz5*dq15*CC5*S2*S3 - 4*Ixz6*dq23*CC4*S5*S6 - 2*Ixz6*dq26*CC5*S4*S6 - 2*Ixz6*dq36*CC5*S4*S6 - 2*dd6*dq25*m_6*CC5*S4 - 2*dd6*dq35*m_6*CC5*S4 + 2*X6*Y6*dq46*m_6*CC5 + 4*X6*Y6*dq46*m_6*CC6 + 4*X4*Z4*dq23*m_4*CC4 + 4*X5*Z5*dq45*m_5*CC5 - 2*Ixx4*dq11*CC2*CC3*C4*S4 + 2*Ixx6*dq11*CC2*CC3*C4*S4 + Ixx5*dq11*CC2*C4*CC5*S4 + Ixx5*dq11*CC3*C4*CC5*S4 + Ixx6*dq11*CC2*C4*CC6*S4 + Ixx6*dq11*CC3*C4*CC6*S4 - Ixx6*dq22*C4*CC5*CC6*S4 - Ixx6*dq33*C4*CC5*CC6*S4 + 2*Iyy5*dq11*CC2*CC3*C4*S4 + Iyy6*dq11*CC2*C4*CC5*S4 - Iyy6*dq11*CC2*C4*CC6*S4 + Iyy6*dq11*CC3*C4*CC5*S4 - Iyy6*dq11*CC3*C4*CC6*S4 + Iyy6*dq22*C4*CC5*CC6*S4 + Iyy6*dq33*C4*CC5*CC6*S4 + 2*Iyz6*dq11*CC2*CC3*C6*S5 + 2*Iyz6*dq11*CC2*CC4*C6*S5 + 2*Iyz6*dq11*CC3*CC4*C6*S5 + 2*Izz4*dq11*CC2*CC3*C4*S4 - 2*Izz5*dq11*CC2*CC3*C4*S4 - 2*Izz6*dq11*CC2*CC3*C4*S4 - Izz5*dq11*CC2*C4*CC5*S4 - Izz5*dq11*CC3*C4*CC5*S4 - Izz6*dq11*CC2*C4*CC5*S4 - Izz6*dq11*CC3*C4*CC5*S4 + 2*Z6*d6*dq23*m_6*S44 + 2*Z6*d6*dq45*m_6*S55 + 2*Ixz6*dq11*CC2*CC3*S5*S6 + 2*Ixz6*dq11*CC2*CC4*S5*S6 + 2*Ixz6*dq11*CC3*CC4*S5*S6 - 2*X4*Z4*dq11*m_4*CC2*CC3 - 2*X4*Z4*dq11*m_4*CC2*CC4 - 2*X4*Z4*dq11*m_4*CC3*CC4 - 8*Ixy6*dq23*CC4*C5*CC6 - 2*Ixx6*dq25*CC5*CC6*S4 - 2*Ixx6*dq35*CC5*CC6*S4 + 2*Iyy6*dq25*CC5*CC6*S4 + 2*Iyy6*dq35*CC5*CC6*S4 + Iyz5*dq11*C2*C4*C5*S2 + Iyz5*dq11*C3*C4*C5*S3 - XX6*dq22*m_6*C5*C6*S6 - XX6*dq33*m_6*C5*C6*S6 + XX6*dq55*m_6*C5*C6*S6 + YY6*dq22*m_6*C5*C6*S6 + YY6*dq33*m_6*C5*C6*S6 - YY6*dq55*m_6*C5*C6*S6 - 4*Ixy5*dq11*CC2*CC3*CC4*C5 + 4*Ixy6*dq11*CC2*CC3*CC4*C5 + 4*Ixy6*dq11*CC2*CC3*C5*CC6 + 4*Ixy6*dq11*CC2*CC4*C5*CC6 + 4*Ixy6*dq11*CC3*CC4*C5*CC6 - Ixy5*dq11*C2*C4*S2*S5 + Ixy6*dq11*C2*C4*S2*S5 - Ixy5*dq11*C3*C4*S3*S5 + Ixy6*dq11*C3*C4*S3*S5 + 2*Ixy6*dq22*C4*C6*S4*S6 + 2*Ixy6*dq33*C4*C6*S4*S6 - 2*Ixz4*dq11*C2*C3*S2*S3 - Ixz6*dq11*C2*C6*S2*S4 - Ixz6*dq11*C3*C6*S3*S4 - 2*Ixz5*dq22*C4*C5*S4*S5 - 2*Ixz5*dq33*C4*C5*S4*S5 - 4*Iyz5*dq11*CC2*CC3*CC4*S5 + Iyz6*dq11*C2*S2*S4*S6 + Iyz6*dq11*C3*S3*S4*S6 - 2*Ixy4*dq12*C2*C3*C4 - 2*Ixy4*dq13*C2*C3*C4 - 2*Ixz5*dq12*C2*C3*C4 - 2*Ixz5*dq13*C2*C3*C4 - 2*Ixz6*dq15*C2*C3*C6 + Y5*a2*dq22*m_5*C3*C4 + Y6*a3*dq11*m_6*C4*C6 + Y6*a3*dq22*m_6*C4*C6 + Y6*a3*dq33*m_6*C4*C6 + Z4*a2*dq22*m_4*C3*C4 - Y6*Z6*dq22*m_6*C6*S5 - Y6*Z6*dq33*m_6*C6*S5 + Y6*Z6*dq55*m_6*C6*S5 - Y6*Z6*dq66*m_6*C6*S5 + Ixx5*dq15*C2*C4*S3 + Ixx5*dq15*C3*C4*S2 + Ixx6*dq15*C2*C4*S3 + Ixx6*dq15*C3*C4*S2 + 2*Ixx6*dq23*C5*C6*S6 + Iyy5*dq15*C2*C4*S3 + Iyy5*dq15*C3*C4*S2 + Iyy6*dq15*C2*C4*S3 + Iyy6*dq15*C3*C4*S2 - 2*Iyy6*dq23*C5*C6*S6 + 2*Iyz4*dq12*C2*C3*S4 + 2*Iyz4*dq13*C2*C3*S4 + 2*Iyz6*dq15*C2*C3*S6 - 2*Iyz6*dq25*C4*C6*S5 - 2*Iyz6*dq35*C4*C6*S5 + 2*Iyz6*dq46*C5*C6*S5 - Izz5*dq15*C2*C4*S3 - Izz5*dq15*C3*C4*S2 - Izz6*dq15*C2*C4*S3 - Izz6*dq15*C3*C4*S2 + 2*Y5*Z5*dq25*m_5*C4*S5 + 2*Y5*Z5*dq35*m_5*C4*S5 - 2*Y6*Z6*dq23*m_6*C6*S5 - 2*Y6*Z6*dq26*m_6*C6*S4 - 2*Y6*Z6*dq36*m_6*C6*S4 - 2*Iyz5*dq11*C2*CC3*C4*C5*S2 - 2*Iyz5*dq11*CC2*C3*C4*C5*S3 - 2*Ixy5*dq12*S2*S3*S4*S5 - 2*Ixy5*dq13*S2*S3*S4*S5 + 2*Ixy6*dq12*S2*S3*S4*S5 + 2*Ixy6*dq13*S2*S3*S4*S5 + 2*X4*a2*dq12*m_4*C4*S2 + 2*X5*a3*dq23*m_5*C5*S4 + 2*X6*a3*dq23*m_6*C4*S6 + XX6*dq11*m_6*CC2*C5*C6*S6 + XX6*dq11*m_6*CC3*C5*C6*S6 + 2*XX6*dq22*m_6*CC4*C5*C6*S6 + 2*XX6*dq33*m_6*CC4*C5*C6*S6 - YY6*dq11*m_6*CC2*C5*C6*S6 - YY6*dq11*m_6*CC3*C5*C6*S6 - 2*YY6*dq22*m_6*CC4*C5*C6*S6 - 2*YY6*dq33*m_6*CC4*C5*C6*S6 - 2*Y6*d6*dq23*m_6*C6*S5 - 2*Y6*d6*dq26*m_6*C6*S4 - 2*Y6*d6*dq36*m_6*C6*S4 - 2*X6*Y6*dq16*m_6*S2*S3 - 2*X5*Z5*dq15*m_5*S2*S3 - 2*X6*Z6*dq23*m_6*S5*S6 - 2*X6*Z6*dq26*m_6*S4*S6 - 2*X6*Z6*dq36*m_6*S4*S6 - 8*Ixy6*dq11*CC2*CC3*CC4*C5*CC6 + 2*Ixy5*dq11*C2*CC3*C4*S2*S5 + 2*Ixy5*dq11*CC2*C3*C4*S3*S5 - 2*Ixy6*dq11*C2*CC3*C4*S2*S5 - 2*Ixy6*dq11*CC2*C3*C4*S3*S5 - 2*Ixy6*dq11*C2*C4*CC6*S2*S5 - 2*Ixy6*dq11*C3*C4*CC6*S3*S5 - 2*Ixy6*dq11*CC2*C4*C6*S4*S6 - 2*Ixy6*dq11*CC3*C4*C6*S4*S6 + 2*Ixy6*dq22*C4*CC5*C6*S4*S6 + 2*Ixy6*dq33*C4*CC5*C6*S4*S6 + 4*Ixz4*dq11*C2*C3*CC4*S2*S3 + 2*Ixz6*dq11*C2*CC3*C6*S2*S4 + 2*Ixz6*dq11*CC2*C3*C6*S3*S4 + 2*Ixz5*dq11*CC2*C4*C5*S4*S5 + 2*Ixz6*dq11*C2*CC5*C6*S2*S4 + 2*Ixz5*dq11*CC3*C4*C5*S4*S5 + 2*Ixz6*dq11*C3*CC5*C6*S3*S4 - 2*Y5*a2*dq12*m_5*S2*S4 - 2*Z4*a2*dq12*m_4*S2*S4 + 2*Z5*a3*dq23*m_5*S4*S5 + 2*Z6*a3*dq23*m_6*S4*S5 - 2*X6*d6*dq23*m_6*S5*S6 - 2*X6*d6*dq26*m_6*S4*S6 - 2*X6*d6*dq36*m_6*S4*S6 - 2*Iyz6*dq11*C2*CC3*S2*S4*S6 - 2*Iyz6*dq11*CC2*C3*S3*S4*S6 - 2*Iyz6*dq11*C2*CC5*S2*S4*S6 - 2*Iyz6*dq11*C3*CC5*S3*S4*S6 + 4*Ixz5*dq12*C2*C3*C4*CC5 + 4*Ixz5*dq13*C2*C3*C4*CC5 + 4*Ixz6*dq15*C2*C3*CC5*C6 + 2*a3*d6*dq23*m_6*S4*S5 + Y5*a2*dq11*m_5*CC2*C3*C4 - Y6*a3*dq11*m_6*CC2*C4*C6 - Y6*a3*dq11*m_6*CC3*C4*C6 + Z4*a2*dq11*m_4*CC2*C3*C4 + Y6*Z6*dq11*m_6*CC2*C6*S5 + Y6*Z6*dq11*m_6*CC3*C6*S5 + 2*Y6*Z6*dq22*m_6*CC4*C6*S5 + 2*Y6*Z6*dq33*m_6*CC4*C6*S5 - 2*Ixx5*dq15*C2*C4*CC5*S3 - 2*Ixx5*dq15*C3*C4*CC5*S2 - 4*Ixx6*dq23*CC4*C5*C6*S6 - 2*Iyy6*dq15*C2*C4*CC5*S3 - 2*Iyy6*dq15*C3*C4*CC5*S2 + 4*Iyy6*dq23*CC4*C5*C6*S6 - 4*Iyz6*dq15*C2*C3*CC5*S6 + 2*Izz5*dq15*C2*C4*CC5*S3 + 2*Izz5*dq15*C3*C4*CC5*S2 + 2*Izz6*dq15*C2*C4*CC5*S3 + 2*Izz6*dq15*C3*C4*CC5*S2 + X4*a2*dq11*m_4*CC2*C3*S4 - X5*a3*dq11*m_5*CC2*C5*S4 - X5*a3*dq11*m_5*CC3*C5*S4 - X6*a3*dq11*m_6*CC2*C4*S6 - X6*a3*dq11*m_6*CC3*C4*S6 + 2*XX4*dq12*m_4*C2*CC4*S3 + 2*XX4*dq12*m_4*C3*CC4*S2 + 2*XX4*dq13*m_4*C2*CC4*S3 + 2*XX4*dq13*m_4*C3*CC4*S2 - 2*XX6*dq12*m_6*C2*CC4*S3 - 2*XX6*dq12*m_6*C3*CC4*S2 - 2*XX6*dq13*m_6*C2*CC4*S3 - 2*XX6*dq13*m_6*C3*CC4*S2 - 2*XX6*dq12*m_6*C2*CC6*S3 - 2*XX6*dq12*m_6*C3*CC6*S2 - 2*XX6*dq13*m_6*C2*CC6*S3 - 2*XX6*dq13*m_6*C3*CC6*S2 + 2*XX5*dq23*m_5*C4*CC5*S4 + 2*XX6*dq23*m_6*C4*CC6*S4 + 2*XX6*dq26*m_6*C4*CC6*S5 + 2*XX6*dq36*m_6*C4*CC6*S5 - 2*XX6*dq45*m_6*C5*CC6*S5 - 2*XX6*dq46*m_6*CC5*C6*S6 + Y6*d6*dq11*m_6*CC2*C6*S5 + Y6*d6*dq11*m_6*CC3*C6*S5 + 2*Y6*d6*dq22*m_6*CC4*C6*S5 + 2*Y6*d6*dq33*m_6*CC4*C6*S5 - 2*YY5*dq12*m_5*C2*CC4*S3 - 2*YY5*dq12*m_5*C3*CC4*S2 - 2*YY5*dq13*m_5*C2*CC4*S3 - 2*YY5*dq13*m_5*C3*CC4*S2 + 2*YY6*dq12*m_6*C2*CC6*S3 + 2*YY6*dq12*m_6*C3*CC6*S2 + 2*YY6*dq13*m_6*C2*CC6*S3 + 2*YY6*dq13*m_6*C3*CC6*S2 + 2*YY6*dq23*m_6*C4*CC5*S4 - 2*YY6*dq23*m_6*C4*CC6*S4 - 2*YY6*dq26*m_6*C4*CC6*S5 - 2*YY6*dq36*m_6*C4*CC6*S5 + 2*YY6*dq45*m_6*C5*CC6*S5 + 2*YY6*dq46*m_6*CC5*C6*S6 - 2*Z6*d6*dq11*m_6*CC2*C4*S4 - 2*Z6*d6*dq11*m_6*CC3*C4*S4 - 2*Z6*d6*dq22*m_6*C4*CC5*S4 - 2*Z6*d6*dq33*m_6*C4*CC5*S4 - 2*ZZ4*dq12*m_4*C2*CC4*S3 - 2*ZZ4*dq12*m_4*C3*CC4*S2 - 2*ZZ4*dq13*m_4*C2*CC4*S3 - 2*ZZ4*dq13*m_4*C3*CC4*S2 + 2*ZZ5*dq12*m_5*C2*CC4*S3 + 2*ZZ5*dq12*m_5*C3*CC4*S2 + 2*ZZ5*dq13*m_5*C2*CC4*S3 + 2*ZZ5*dq13*m_5*C3*CC4*S2 + 2*ZZ6*dq12*m_6*C2*CC4*S3 + 2*ZZ6*dq12*m_6*C3*CC4*S2 + 2*ZZ6*dq13*m_6*C2*CC4*S3 + 2*ZZ6*dq13*m_6*C3*CC4*S2 - 2*ZZ5*dq23*m_5*C4*CC5*S4 - 2*ZZ6*dq23*m_6*C4*CC5*S4 + X6*Z6*dq11*m_6*CC2*S5*S6 + X6*Z6*dq11*m_6*CC3*S5*S6 + 2*X6*Z6*dq22*m_6*CC4*S5*S6 + 2*X6*Z6*dq33*m_6*CC4*S5*S6 + 4*Ixy6*dq25*CC5*C6*S4*S6 + 4*Ixy6*dq26*C5*CC6*S4*S5 + 4*Ixy6*dq35*CC5*C6*S4*S6 + 4*Ixy6*dq36*C5*CC6*S4*S5 - 4*Ixz5*dq12*C4*CC5*S2*S3 - 4*Ixz5*dq13*C4*CC5*S2*S3 - 4*Ixz6*dq15*CC5*C6*S2*S3 + 2*dd6*dq12*m_6*C2*CC4*S3 + 2*dd6*dq12*m_6*C3*CC4*S2 + 2*dd6*dq13*m_6*C2*CC4*S3 + 2*dd6*dq13*m_6*C3*CC4*S2 - 2*dd6*dq23*m_6*C4*CC5*S4 - Z5*a3*dq11*m_5*CC2*S4*S5 - Z5*a3*dq11*m_5*CC3*S4*S5 - Z6*a3*dq11*m_6*CC2*S4*S5 - Z6*a3*dq11*m_6*CC3*S4*S5 + X6*d6*dq11*m_6*CC2*S5*S6 + X6*d6*dq11*m_6*CC3*S5*S6 + 2*X6*d6*dq22*m_6*CC4*S5*S6 + 2*X6*d6*dq33*m_6*CC4*S5*S6 + 4*X5*Y5*dq23*m_5*CC4*C5 - 4*X6*Y6*dq23*m_6*CC4*C5 - 4*X6*Y6*dq23*m_6*C5*CC6 + 4*X6*Z6*dq45*m_6*CC5*C6 - a3*d6*dq11*m_6*CC2*S4*S5 - a3*d6*dq11*m_6*CC3*S4*S5 + 4*Iyz6*dq15*CC5*S2*S3*S6 + 4*X6*d6*dq45*m_6*CC5*C6 + 4*Y5*Z5*dq23*m_5*CC4*S5 - 4*Y6*Z6*dq45*m_6*CC5*S6 + 2*Ixx6*dq11*CC2*CC3*C5*C6*S6 + 2*Ixx6*dq11*CC2*CC4*C5*C6*S6 + 2*Ixx6*dq11*CC3*CC4*C5*C6*S6 - 2*Iyy6*dq11*CC2*CC3*C5*C6*S6 - 2*Iyy6*dq11*CC2*CC4*C5*C6*S6 - 2*Iyy6*dq11*CC3*CC4*C5*C6*S6 + 2*XX4*dq11*m_4*CC2*CC3*C4*S4 - XX5*dq11*m_5*CC2*C4*CC5*S4 - 2*XX6*dq11*m_6*CC2*CC3*C4*S4 - XX5*dq11*m_5*CC3*C4*CC5*S4 - XX6*dq11*m_6*CC2*C4*CC6*S4 - XX6*dq11*m_6*CC3*C4*CC6*S4 + XX6*dq22*m_6*C4*CC5*CC6*S4 + XX6*dq33*m_6*C4*CC5*CC6*S4 - 2*YY5*dq11*m_5*CC2*CC3*C4*S4 - YY6*dq11*m_6*CC2*C4*CC5*S4 + YY6*dq11*m_6*CC2*C4*CC6*S4 - YY6*dq11*m_6*CC3*C4*CC5*S4 + YY6*dq11*m_6*CC3*C4*CC6*S4 - YY6*dq22*m_6*C4*CC5*CC6*S4 - YY6*dq33*m_6*C4*CC5*CC6*S4 - 2*ZZ4*dq11*m_4*CC2*CC3*C4*S4 + 2*ZZ5*dq11*m_5*CC2*CC3*C4*S4 + ZZ5*dq11*m_5*CC2*C4*CC5*S4 + 2*ZZ6*dq11*m_6*CC2*CC3*C4*S4 + ZZ5*dq11*m_5*CC3*C4*CC5*S4 + ZZ6*dq11*m_6*CC2*C4*CC5*S4 + ZZ6*dq11*m_6*CC3*C4*CC5*S4 - 4*Y6*d6*dq45*m_6*CC5*S6 - 4*Z6*d6*dq25*m_6*CC5*S4 - 4*Z6*d6*dq35*m_6*CC5*S4 - 4*Ixz5*dq11*C2*CC3*CC5*S2*S4 - 4*Ixz5*dq11*CC2*C3*CC5*S3*S4 + 2*dd6*dq11*m_6*CC2*CC3*C4*S4 + dd6*dq11*m_6*CC2*C4*CC5*S4 + dd6*dq11*m_6*CC3*C4*CC5*S4 - 2*X5*Y5*dq11*m_5*CC2*CC3*C5 - 2*X5*Y5*dq11*m_5*CC2*CC4*C5 - 2*X5*Y5*dq11*m_5*CC3*CC4*C5 + 2*X6*Y6*dq11*m_6*CC2*CC3*C5 + 2*X6*Y6*dq11*m_6*CC2*CC4*C5 + 2*X6*Y6*dq11*m_6*CC3*CC4*C5 + 2*X6*Y6*dq11*m_6*CC2*C5*CC6 + 2*X6*Y6*dq11*m_6*CC3*C5*CC6 + 4*X6*Y6*dq22*m_6*CC4*C5*CC6 + 4*X6*Y6*dq33*m_6*CC4*C5*CC6 - 4*Ixy6*dq16*C2*C3*CC5*CC6 + 2*Y5*a3*dq11*m_5*CC2*CC3*C4 + 2*Z4*a3*dq11*m_4*CC2*CC3*C4 - 2*Y5*Z5*dq11*m_5*CC2*CC3*S5 - 2*Y5*Z5*dq11*m_5*CC2*CC4*S5 - 2*Y5*Z5*dq11*m_5*CC3*CC4*S5 - 2*Ixx5*dq12*C2*CC4*CC5*S3 - 2*Ixx5*dq12*C3*CC4*CC5*S2 - 2*Ixx5*dq13*C2*CC4*CC5*S3 - 2*Ixx5*dq13*C3*CC4*CC5*S2 - 2*Ixx6*dq12*C2*CC4*CC6*S3 - 2*Ixx6*dq12*C3*CC4*CC6*S2 - 2*Ixx6*dq13*C2*CC4*CC6*S3 - 2*Ixx6*dq13*C3*CC4*CC6*S2 - 2*Ixx6*dq23*C4*CC5*CC6*S4 - 2*Iyy6*dq12*C2*CC4*CC5*S3 - 2*Iyy6*dq12*C3*CC4*CC5*S2 + 2*Iyy6*dq12*C2*CC4*CC6*S3
 + 2*Iyy6*dq12*C3*CC4*CC6*S2 - 2*Iyy6*dq13*C2*CC4*CC5*S3 - 2*Iyy6*dq13*C3*CC4*CC5*S2 + 2*Iyy6*dq13*C2*CC4*CC6*S3 + 2*Iyy6*dq13*C3*CC4*CC6*S2 + 2*Iyy6*dq23*C4*CC5*CC6*S4 + 2*Izz5*dq12*C2*CC4*CC5*S3 + 2*Izz5*dq12*C3*CC4*CC5*S2 + 2*Izz5*dq13*C2*CC4*CC5*S3 + 2*Izz5*dq13*C3*CC4*CC5*S2 + 2*Izz6*dq12*C2*CC4*CC5*S3 + 2*Izz6*dq12*C3*CC4*CC5*S2 + 2*Izz6*dq13*C2*CC4*CC5*S3 + 2*Izz6*dq13*C3*CC4*CC5*S2 + 2*X4*a3*dq11*m_4*CC2*CC3*S4 + 2*XX6*dq25*m_6*CC5*CC6*S4 + 2*XX6*dq35*m_6*CC5*CC6*S4 - 2*YY6*dq25*m_6*CC5*CC6*S4 - 2*YY6*dq35*m_6*CC5*CC6*S4 + 4*Ixy6*dq16*CC5*CC6*S2*S3 + Iyz6*dq11*C2*C4*C5*C6*S2 + Iyz6*dq11*C3*C4*C5*C6*S3 - 4*X6*Y6*dq46*m_6*CC5*CC6 - 2*Ixy5*dq11*C2*C3*C5*S2*S3 + 2*Ixy6*dq11*C2*C3*C5*S2*S3 + Ixz6*dq11*C2*C4*C5*S2*S6 + Ixz6*dq11*C3*C4*C5*S3*S6 - 2*Ixz6*dq22*C4*C5*C6*S4*S5 - 2*Ixz6*dq33*C4*C5*C6*S4*S5 - 2*Ixx5*dq11*CC2*CC3*C4*CC5*S4 - 2*Ixx6*dq11*CC2*CC3*C4*CC6*S4 + Ixx6*dq11*CC2*C4*CC5*CC6*S4 + Ixx6*dq11*CC3*C4*CC5*CC6*S4 - 2*Iyy6*dq11*CC2*CC3*C4*CC5*S4 + 2*Iyy6*dq11*CC2*CC3*C4*CC6*S4 - Iyy6*dq11*CC2*C4*CC5*CC6*S4 - Iyy6*dq11*CC3*C4*CC5*CC6*S4 - 4*Iyz6*dq11*CC2*CC3*CC4*C6*S5 + 2*Izz5*dq11*CC2*CC3*C4*CC5*S4 + 2*Izz6*dq11*CC2*CC3*C4*CC5*S4 - Ixx5*dq11*C2*C5*S2*S4*S5 - Ixx5*dq11*C3*C5*S3*S4*S5 - Iyy6*dq11*C2*C5*S2*S4*S5 - Iyy6*dq11*C3*C5*S3*S4*S5 - 2*Iyz5*dq11*C2*C3*S2*S3*S5 + 2*Iyz6*dq22*C4*C5*S4*S5*S6 + 2*Iyz6*dq33*C4*C5*S4*S5*S6 + Izz5*dq11*C2*C5*S2*S4*S5 + Izz6*dq11*C2*C5*S2*S4*S5 + Izz5*dq11*C3*C5*S3*S4*S5 + Izz6*dq11*C3*C5*S3*S4*S5 - 2*Ixz6*dq12*C2*C3*C4*C6 - 2*Ixz6*dq13*C2*C3*C4*C6 + Y5*a1*dq11*m_5*C2*C3*C4 + Y6*a2*dq22*m_6*C3*C4*C6 + Z4*a1*dq11*m_4*C2*C3*C4 + Y4*Z4*dq11*m_4*C2*C4*S2 + Y4*Z4*dq11*m_4*C3*C4*S3 - 4*Ixz6*dq11*CC2*CC3*CC4*S5*S6 - 2*Ixx5*dq15*C2*C3*C5*S5 + 2*Ixx6*dq16*C2*C3*C6*S6 - 2*Ixx6*dq25*C4*C5*C6*S6 - 2*Ixx6*dq35*C4*C5*C6*S6 - 2*Iyy6*dq15*C2*C3*C5*S5 - 2*Iyy6*dq16*C2*C3*C6*S6 + 2*Iyy6*dq25*C4*C5*C6*S6 + 2*Iyy6*dq35*C4*C5*C6*S6 - 2*Iyz5*dq12*C2*C3*C5*S4 - 2*Iyz5*dq13*C2*C3*C5*S4 + 2*Iyz6*dq12*C2*C3*C4*S6 + 2*Iyz6*dq13*C2*C3*C4*S6 + 2*Iyz6*dq16*C2*C4*C6*S3 + 2*Iyz6*dq16*C3*C4*C6*S2 + 2*Izz5*dq15*C2*C3*C5*S5 + 2*Izz6*dq15*C2*C3*C5*S5 + X4*a1*dq11*m_4*C2*C3*S4 + X5*a2*dq22*m_5*C3*C5*S4 + X6*a2*dq22*m_6*C3*C4*S6 + X6*a3*dq11*m_6*C5*C6*S4 + X6*a3*dq22*m_6*C5*C6*S4 + X6*a3*dq33*m_6*C5*C6*S4 - 2*XX6*dq23*m_6*C5*C6*S6 - Y5*d4*dq11*m_5*C2*C4*S2 - Y5*d4*dq11*m_5*C3*C4*S3 + 2*YY6*dq23*m_6*C5*C6*S6 - Z4*d4*dq11*m_4*C2*C4*S2 - Z4*d4*dq11*m_4*C3*C4*S3 + 2*ZZ5*dq15*m_5*C2*C4*S3 + 2*ZZ5*dq15*m_5*C3*C4*S2 + 2*ZZ6*dq15*m_6*C2*C4*S3 + 2*ZZ6*dq15*m_6*C3*C4*S2 + 4*X4*Z4*dq11*m_4*CC2*CC3*CC4 + X4*Y4*dq11*m_4*C2*S2*S4 + X4*Y4*dq11*m_4*C3*S3*S4 + X5*Z5*dq11*m_5*C2*S2*S4 + X5*Z5*dq11*m_5*C3*S3*S4 + 2*Ixy5*dq12*C2*C3*S4*S5 + 2*Ixy5*dq13*C2*C3*S4*S5 - 2*Ixy6*dq12*C2*C3*S4*S5 - 2*Ixy6*dq13*C2*C3*S4*S5 + 2*Ixy5*dq15*C2*C5*S3*S4 + 2*Ixy5*dq15*C3*C5*S2*S4 - 4*Ixy6*dq12*C2*C6*S3*S6 - 4*Ixy6*dq12*C3*C6*S2*S6 - 2*Ixy6*dq15*C2*C5*S3*S4 - 2*Ixy6*dq15*C3*C5*S2*S4 - 4*Ixy6*dq13*C2*C6*S3*S6 - 4*Ixy6*dq13*C3*C6*S2*S6 + 4*Ixy6*dq23*C4*C6*S4*S6 + 4*Ixy6*dq26*C4*C6*S5*S6 + 4*Ixy6*dq36*C4*C6*S5*S6 - 4*Ixy6*dq45*C5*C6*S5*S6 + 4*Ixz4*dq12*C2*C4*S3*S4 + 4*Ixz4*dq12*C3*C4*S2*S4 + 4*Ixz4*dq13*C2*C4*S3*S4 + 4*Ixz4*dq13*C3*C4*S2*S4 + 2*Ixz6*dq12*C4*C6*S2*S3 + 2*Ixz6*dq13*C4*C6*S2*S3 - 4*Ixz5*dq23*C4*C5*S4*S5 + 2*Ixz6*dq16*C2*C4*S3*S6 + 2*Ixz6*dq16*C3*C4*S2*S6 - 4*Ixz6*dq25*C5*C6*S4*S5 - 4*Ixz6*dq35*C5*C6*S4*S5 + 2*dd6*dq15*m_6*C2*C4*S3 + 2*dd6*dq15*m_6*C3*C4*S2 - Y5*a1*dq11*m_5*C4*S2*S3 - Y6*a3*dq11*m_6*C5*S4*S6 - Y6*a3*dq22*m_6*C5*S4*S6 - Y6*a3*dq33*m_6*C5*S4*S6 - Z4*a1*dq11*m_4*C4*S2*S3 + Z5*a2*dq22*m_5*C3*S4*S5 + Z6*a2*dq22*m_6*C3*S4*S5 - X4*d4*dq11*m_4*C2*S2*S4 - X4*d4*dq11*m_4*C3*S3*S4 + 2*X6*Y6*dq16*m_6*C2*C3 + 2*X5*Y5*dq25*m_5*C4*C5 + 2*X5*Y5*dq35*m_5*C4*C5 - 2*X6*Y6*dq25*m_6*C4*C5 - 2*X6*Y6*dq35*m_6*C4*C5 + 2*X5*Z5*dq15*m_5*C2*C3 + a2*d6*dq22*m_6*C3*S4*S5 + 2*Ixx5*dq15*C5*S2*S3*S5 - Ixx6*dq16*C2*S3*S4*S5 - Ixx6*dq16*C3*S2*S4*S5 - 2*Ixx6*dq16*C6*S2*S3*S6 + 2*Iyy6*dq15*C5*S2*S3*S5 + Iyy6*dq16*C2*S3*S4*S5 + Iyy6*dq16*C3*S2*S4*S5 + 2*Iyy6*dq16*C6*S2*S3*S6 + 2*Iyz5*dq12*C5*S2*S3*S4 + 2*Iyz5*dq13*C5*S2*S3*S4 - 2*Iyz6*dq12*C4*S2*S3*S6 + 2*Iyz5*dq15*C2*S3*S4*S5 + 2*Iyz5*dq15*C3*S2*S4*S5 - 2*Iyz6*dq13*C4*S2*S3*S6 + 4*Iyz6*dq25*C5*S4*S5*S6 + 4*Iyz6*dq35*C5*S4*S5*S6 - 2*Izz5*dq15*C5*S2*S3*S5 - 2*Izz6*dq15*C5*S2*S3*S5 + Izz6*dq16*C2*S3*S4*S5 + Izz6*dq16*C3*S2*S4*S5 - X4*a1*dq11*m_4*S2*S3*S4 + 2*Y6*a3*dq23*m_6*C4*C6 - 2*Z4*d4*dq12*m_4*S2*S3*S4 - 2*Z4*d4*dq13*m_4*S2*S3*S4 - 2*Y4*Z4*dq11*m_4*C2*CC3*C4*S2 - 2*Y4*Z4*dq11*m_4*CC2*C3*C4*S3 - 2*Ixx6*dq15*C2*C3*C5*CC6*S5 - 2*Ixx6*dq16*C2*C3*CC5*C6*S6 + 2*Iyy6*dq15*C2*C3*C5*CC6*S5 + 2*Iyy6*dq16*C2*C3*CC5*C6*S6 - 4*Iyz6*dq12*C2*C3*C4*CC5*S6 - 4*Iyz6*dq13*C2*C3*C4*CC5*S6 - 2*Iyz6*dq16*C2*C4*CC5*C6*S3 - 2*Iyz6*dq16*C3*C4*CC5*C6*S2 + X5*a2*dq11*m_5*CC2*C3*C5*S4 + X6*a2*dq11*m_6*CC2*C3*C4*S6 - X6*a3*dq11*m_6*CC2*C5*C6*S4 - X6*a3*dq11*m_6*CC3*C5*C6*S4 + 2*XX5*dq15*m_5*C2*C4*CC5*S3 + 2*XX5*dq15*m_5*C3*C4*CC5*S2 + 4*XX6*dq23*m_6*CC4*C5*C6*S6 + 2*Y5*d4*dq11*m_5*C2*CC3*C4*S2 + 2*Y5*d4*dq11*m_5*CC2*C3*C4*S3 + 2*YY6*dq15*m_6*C2*C4*CC5*S3 + 2*YY6*dq15*m_6*C3*C4*CC5*S2 - 4*YY6*dq23*m_6*CC4*C5*C6*S6 + 2*Z4*d4*dq11*m_4*C2*CC3*C4*S2 + 2*Z4*d4*dq11*m_4*CC2*C3*C4*S3 - 2*ZZ5*dq15*m_5*C2*C4*CC5*S3 - 2*ZZ5*dq15*m_5*C3*C4*CC5*S2 - 2*ZZ6*dq15*m_6*C2*C4*CC5*S3 - 2*ZZ6*dq15*m_6*C3*C4*CC5*S2 - 2*X4*Y4*dq11*m_4*C2*CC3*S2*S4 - 2*X4*Y4*dq11*m_4*CC2*C3*S3*S4 - 2*X5*Z5*dq11*m_5*C2*CC3*S2*S4 - 2*X5*Z5*dq11*m_5*CC2*C3*S3*S4 - 2*X5*Z5*dq11*m_5*C2*CC5*S2*S4 - 2*X5*Z5*dq11*m_5*C3*CC5*S3*S4 + 4*Ixy6*dq12*C2*C3*CC6*S4*S5 + 4*Ixy6*dq12*C2*CC4*C6*S3*S6 + 4*Ixy6*dq12*C3*CC4*C6*S2*S6 + 4*Ixy6*dq13*C2*C3*CC6*S4*S5 + 4*Ixy6*dq13*C2*CC4*C6*S3*S6 + 4*Ixy6*dq13*C3*CC4*C6*S2*S6 + 4*Ixy6*dq15*C2*C5*CC6*S3*S4 + 4*Ixy6*dq15*C3*C5*CC6*S2*S4 + 4*Ixy6*dq23*C4*CC5*C6*S4*S6 - 4*Ixz5*dq12*C2*CC4*C5*S3*S5 - 4*Ixz5*dq12*C3*CC4*C5*S2*S5 - 4*Ixz5*dq13*C2*CC4*C5*S3*S5 - 4*Ixz5*dq13*C3*CC4*C5*S2*S5 - 4*Ixz6*dq12*C4*CC5*C6*S2*S3 - 4*Ixz6*dq13*C4*CC5*C6*S2*S3 - 2*Ixz6*dq16*C2*C4*CC5*S3*S6 - 2*Ixz6*dq16*C3*C4*CC5*S2*S6 - 2*dd6*dq15*m_6*C2*C4*CC5*S3 - 2*dd6*dq15*m_6*C3*C4*CC5*S2 + Y6*a3*dq11*m_6*CC2*C5*S4*S6 + Y6*a3*dq11*m_6*CC3*C5*S4*S6 + Z5*a2*dq11*m_5*CC2*C3*S4*S5 + Z6*a2*dq11*m_6*CC2*C3*S4*S5 + 2*X4*d4*dq11*m_4*C2*CC3*S2*S4 + 2*X4*d4*dq11*m_4*CC2*C3*S3*S4 - 2*X6*Y6*dq16*m_6*C2*C3*CC5 - 4*X6*Y6*dq16*m_6*C2*C3*CC6 + 4*X6*Y6*dq25*m_6*C4*C5*CC6 + 4*X6*Y6*dq35*m_6*C4*C5*CC6 - 4*X5*Z5*dq15*m_5*C2*C3*CC5 + a2*d6*dq11*m_6*CC2*C3*S4*S5 + 2*Ixx6*dq15*C5*CC6*S2*S3*S5 + 2*Ixx6*dq16*C2*CC6*S3*S4*S5 + 2*Ixx6*dq16*C3*CC6*S2*S4*S5 + 2*Ixx6*dq16*CC5*C6*S2*S3*S6 - 2*Iyy6*dq15*C5*CC6*S2*S3*S5 - 2*Iyy6*dq16*C2*CC6*S3*S4*S5 - 2*Iyy6*dq16*C3*CC6*S2*S4*S5 - 2*Iyy6*dq16*CC5*C6*S2*S3*S6 + 4*Iyz6*dq12*C4*CC5*S2*S3*S6 + 4*Iyz6*dq13*C4*CC5*S2*S3*S6 + 4*Y6*Z6*dq23*m_6*CC4*C6*S5 + 2*Y6*Z6*dq26*m_6*CC5*C6*S4 + 2*Y6*Z6*dq36*m_6*CC5*C6*S4 - 4*Ixy6*dq12*CC6*S2*S3*S4*S5 - 4*Ixy6*dq13*CC6*S2*S3*S4*S5 - 2*XX6*dq11*m_6*CC2*CC3*C5*C6*S6 - 2*XX6*dq11*m_6*CC2*CC4*C5*C6*S6 - 2*XX6*dq11*m_6*CC3*CC4*C5*C6*S6 + 2*YY6*dq11*m_6*CC2*CC3*C5*C6*S6 + 2*YY6*dq11*m_6*CC2*CC4*C5*C6*S6 + 2*YY6*dq11*m_6*CC3*CC4*C5*C6*S6 + 4*Y6*d6*dq23*m_6*CC4*C6*S5 + 2*Y6*d6*dq26*m_6*CC5*C6*S4 + 2*Y6*d6*dq36*m_6*CC5*C6*S4 + 4*Z6*d6*dq12*m_6*C2*CC4*S3 + 4*Z6*d6*dq12*m_6*C3*CC4*S2 + 4*Z6*d6*dq13*m_6*C2*CC4*S3 + 4*Z6*d6*dq13*m_6*C3*CC4*S2 - 4*Z6*d6*dq23*m_6*C4*CC5*S4 + 2*X6*Y6*dq16*m_6*CC5*S2*S3 + 4*X6*Y6*dq16*m_6*CC6*S2*S3 + 4*X5*Z5*dq15*m_5*CC5*S2*S3 + 4*X6*Z6*dq23*m_6*CC4*S5*S6 + 2*X6*Z6*dq26*m_6*CC5*S4*S6 + 2*X6*Z6*dq36*m_6*CC5*S4*S6 + 4*Ixy6*dq11*C2*CC3*C4*CC6*S2*S5 + 4*Ixy6*dq11*CC2*C3*C4*CC6*S3*S5 + 4*Ixy6*dq11*CC2*CC3*C4*C6*S4*S6 - 2*Ixy6*dq11*CC2*C4*CC5*C6*S4*S6 - 2*Ixy6*dq11*CC3*C4*CC5*C6*S4*S6 - 4*Ixz5*dq11*CC2*CC3*C4*C5*S4*S5 - 4*Ixz6*dq11*C2*CC3*CC5*C6*S2*S4 - 4*Ixz6*dq11*CC2*C3*CC5*C6*S3*S4 + 4*X6*d6*dq23*m_6*CC4*S5*S6 + 2*X6*d6*dq26*m_6*CC5*S4*S6 + 2*X6*d6*dq36*m_6*CC5*S4*S6 + 4*Iyz6*dq11*C2*CC3*CC5*S2*S4*S6 + 4*Iyz6*dq11*CC2*C3*CC5*S3*S4*S6 + 2*Y6*a3*dq11*m_6*CC2*CC3*C4*C6 - 2*Y6*Z6*dq11*m_6*CC2*CC3*C6*S5 - 2*Y6*Z6*dq11*m_6*CC2*CC4*C6*S5 - 2*Y6*Z6*dq11*m_6*CC3*CC4*C6*S5 - 2*Ixx6*dq15*C2*C4*CC5*CC6*S3 - 2*Ixx6*dq15*C3*C4*CC5*CC6*S2 + 2*Iyy6*dq15*C2*C4*CC5*CC6*S3 + 2*Iyy6*dq15*C3*C4*CC5*CC6*S2 + 2*X5*a3*dq11*m_5*CC2*CC3*C5*S4 + 2*X6*a3*dq11*m_6*CC2*CC3*C4*S6 + 2*XX5*dq12*m_5*C2*CC4*CC5*S3 + 2*XX5*dq12*m_5*C3*CC4*CC5*S2 + 2*XX5*dq13*m_5*C2*CC4*CC5*S3 + 2*XX5*dq13*m_5*C3*CC4*CC5*S2 + 2*XX6*dq12*m_6*C2*CC4*CC6*S3 + 2*XX6*dq12*m_6*C3*CC4*CC6*S2 + 2*XX6*dq13*m_6*C2*CC4*CC6*S3 + 2*XX6*dq13*m_6*C3*CC4*CC6*S2 + 2*XX6*dq23*m_6*C4*CC5*CC6*S4 - 2*Y6*d6*dq11*m_6*CC2*CC3*C6*S5 - 2*Y6*d6*dq11*m_6*CC2*CC4*C6*S5 - 2*Y6*d6*dq11*m_6*CC3*CC4*C6*S5 + 2*YY6*dq12*m_6*C2*CC4*CC5*S3 + 2*YY6*dq12*m_6*C3*CC4*CC5*S2 - 2*YY6*dq12*m_6*C2*CC4*CC6*S3 - 2*YY6*dq12*m_6*C3*CC4*CC6*S2 + 2*YY6*dq13*m_6*C2*CC4*CC5*S3 + 2*YY6*dq13*m_6*C3*CC4*CC5*S2 - 2*YY6*dq13*m_6*C2*CC4*CC6*S3 - 2*YY6*dq13*m_6*C3*CC4*CC6*S2 - 2*YY6*dq23*m_6*C4*CC5*CC6*S4 + 4*Z6*d6*dq11*m_6*CC2*CC3*C4*S4 + 2*Z6*d6*dq11*m_6*CC2*C4*CC5*S4 + 2*Z6*d6*dq11*m_6*CC3*C4*CC5*S4 - 2*ZZ5*dq12*m_5*C2*CC4*CC5*S3 - 2*ZZ5*dq12*m_5*C3*CC4*CC5*S2 - 2*ZZ5*dq13*m_5*C2*CC4*CC5*S3 - 2*ZZ5*dq13*m_5*C3*CC4*CC5*S2 - 2*ZZ6*dq12*m_6*C2*CC4*CC5*S3 - 2*ZZ6*dq12*m_6*C3*CC4*CC5*S2 - 2*ZZ6*dq13*m_6*C2*CC4*CC5*S3 - 2*ZZ6*dq13*m_6*C3*CC4*CC5*S2 - 2*X6*Z6*dq11*m_6*CC2*CC3*S5*S6 - 2*X6*Z6*dq11*m_6*CC2*CC4*S5*S6 - 2*X6*Z6*dq11*m_6*CC3*CC4*S5*S6 - 2*dd6*dq12*m_6*C2*CC4*CC5*S3 - 2*dd6*dq12*m_6*C3*CC4*CC5*S2 - 2*dd6*dq13*m_6*C2*CC4*CC5*S3 - 2*dd6*dq13*m_6*C3*CC4*CC5*S2 + 2*Z5*a3*dq11*m_5*CC2*CC3*S4*S5 + 2*Z6*a3*dq11*m_6*CC2*CC3*S4*S5 - 2*X6*d6*dq11*m_6*CC2*CC3*S5*S6 - 2*X6*d6*dq11*m_6*CC2*CC4*S5*S6 - 2*X6*d6*dq11*m_6*CC3*CC4*S5*S6 + 8*X6*Y6*dq23*m_6*CC4*C5*CC6 + 2*a3*d6*dq11*m_6*CC2*CC3*S4*S5 - 4*Ixx6*dq11*CC2*CC3*CC4*C5*C6*S6 + 4*Iyy6*dq11*CC2*CC3*CC4*C5*C6*S6 + 2*Ixx4*dq11*C2*C3*C4*S2*S3*S4 - 2*Ixx6*dq11*C2*C3*C4*S2*S3*S4 - Ixx6*dq11*C2*C4*C6*S2*S5*S6 - Ixx6*dq11*C3*C4*C6*S3*S5*S6 - 2*Iyy5*dq11*C2*C3*C4*S2*S3*S4 + Iyy6*dq11*C2*C4*C6*S2*S5*S6
 + Iyy6*dq11*C3*C4*C6*S3*S5*S6 - 2*Iyz6*dq11*C2*C3*C6*S2*S3*S5 - 2*Izz4*dq11*C2*C3*C4*S2*S3*S4 + 2*Izz5*dq11*C2*C3*C4*S2*S3*S4 + 2*Izz6*dq11*C2*C3*C4*S2*S3*S4 + Y6*a1*dq11*m_6*C2*C3*C4*C6 + 2*XX5*dq11*m_5*CC2*CC3*C4*CC5*S4 + 2*XX6*dq11*m_6*CC2*CC3*C4*CC6*S4 - XX6*dq11*m_6*CC2*C4*CC5*CC6*S4 - XX6*dq11*m_6*CC3*C4*CC5*CC6*S4 + 2*YY6*dq11*m_6*CC2*CC3*C4*CC5*S4 - 2*YY6*dq11*m_6*CC2*CC3*C4*CC6*S4 + YY6*dq11*m_6*CC2*C4*CC5*CC6*S4 + YY6*dq11*m_6*CC3*C4*CC5*CC6*S4 + XX5*dq11*m_5*C2*C5*S2*S4*S5 + XX5*dq11*m_5*C3*C5*S3*S4*S5 - 2*ZZ5*dq11*m_5*CC2*CC3*C4*CC5*S4 - 2*ZZ6*dq11*m_6*CC2*CC3*C4*CC5*S4 + YY6*dq11*m_6*C2*C5*S2*S4*S5 + YY6*dq11*m_6*C3*C5*S3*S4*S5 - ZZ5*dq11*m_5*C2*C5*S2*S4*S5 - ZZ5*dq11*m_5*C3*C5*S3*S4*S5 - ZZ6*dq11*m_6*C2*C5*S2*S4*S5 - ZZ6*dq11*m_6*C3*C5*S3*S4*S5 - Y5*Z5*dq11*m_5*C2*C4*C5*S2 - Y5*Z5*dq11*m_5*C3*C4*C5*S3 - 2*Ixz6*dq11*C2*C3*S2*S3*S5*S6 - 2*Ixx5*dq12*C2*C3*C4*C5*S5 - 2*Ixx5*dq13*C2*C3*C4*C5*S5 - 2*Iyy6*dq12*C2*C3*C4*C5*S5 - 2*Iyy6*dq13*C2*C3*C4*C5*S5 - 2*Iyz6*dq12*C2*C3*C5*C6*S4 - 2*Iyz6*dq13*C2*C3*C5*C6*S4 - 2*Iyz6*dq16*C2*C3*C5*C6*S5 + 2*Izz5*dq12*C2*C3*C4*C5*S5 + 2*Izz5*dq13*C2*C3*C4*C5*S5 + 2*Izz6*dq12*C2*C3*C4*C5*S5 + 2*Izz6*dq13*C2*C3*C4*C5*S5 - 2*dd6*dq11*m_6*CC2*CC3*C4*CC5*S4 - dd6*dq11*m_6*C2*C5*S2*S4*S5 - dd6*dq11*m_6*C3*C5*S3*S4*S5 + X5*a1*dq11*m_5*C2*C3*C5*S4 + X6*a1*dq11*m_6*C2*C3*C4*S6 + X6*a2*dq22*m_6*C3*C5*C6*S4 + 2*XX5*dq15*m_5*C2*C3*C5*S5 - 2*XX6*dq16*m_6*C2*C3*C6*S6 + 2*XX6*dq25*m_6*C4*C5*C6*S6 + 2*XX6*dq35*m_6*C4*C5*C6*S6 - Y6*d4*dq11*m_6*C2*C4*C6*S2 - Y6*d4*dq11*m_6*C3*C4*C6*S3 + 2*YY6*dq15*m_6*C2*C3*C5*S5 + 2*YY6*dq16*m_6*C2*C3*C6*S6 - 2*YY6*dq25*m_6*C4*C5*C6*S6 - 2*YY6*dq35*m_6*C4*C5*C6*S6 - 2*ZZ5*dq15*m_5*C2*C3*C5*S5 - 2*ZZ6*dq15*m_6*C2*C3*C5*S5 + 4*X5*Y5*dq11*m_5*CC2*CC3*CC4*C5 - 4*X6*Y6*dq11*m_6*CC2*CC3*CC4*C5 - 4*X6*Y6*dq11*m_6*CC2*CC3*C5*CC6 - 4*X6*Y6*dq11*m_6*CC2*CC4*C5*CC6 - 4*X6*Y6*dq11*m_6*CC3*CC4*C5*CC6 + X5*Y5*dq11*m_5*C2*C4*S2*S5 + X5*Y5*dq11*m_5*C3*C4*S3*S5 - X6*Y6*dq11*m_6*C2*C4*S2*S5 - X6*Y6*dq11*m_6*C3*C4*S3*S5 - 2*X6*Y6*dq22*m_6*C4*C6*S4*S6 - 2*X6*Y6*dq33*m_6*C4*C6*S4*S6 + 2*X4*Z4*dq11*m_4*C2*C3*S2*S3 + X6*Z6*dq11*m_6*C2*C6*S2*S4 + 2*X5*Z5*dq22*m_5*C4*C5*S4*S5 + X6*Z6*dq11*m_6*C3*C6*S3*S4 + 2*X5*Z5*dq33*m_5*C4*C5*S4*S5 + 4*Ixy5*dq12*C2*C4*C5*S3*S4 + 4*Ixy5*dq12*C3*C4*C5*S2*S4 + 4*Ixy5*dq13*C2*C4*C5*S3*S4 + 4*Ixy5*dq13*C3*C4*C5*S2*S4 - 4*Ixy6*dq12*C2*C4*C5*S3*S4 - 4*Ixy6*dq12*C3*C4*C5*S2*S4 - 4*Ixy6*dq13*C2*C4*C5*S3*S4 - 4*Ixy6*dq13*C3*C4*C5*S2*S4 - 2*Ixy6*dq16*C2*C4*C5*S3*S5 - 2*Ixy6*dq16*C3*C4*C5*S2*S5 - 2*Ixz6*dq12*C2*C3*C5*S4*S6 - 4*Ixz5*dq15*C2*C4*C5*S3*S5 - 4*Ixz5*dq15*C3*C4*C5*S2*S5 - 2*Ixz6*dq13*C2*C3*C5*S4*S6 - 2*Ixz6*dq16*C2*C3*C5*S5*S6 - 4*Ixz6*dq23*C4*C5*C6*S4*S5 - 2*dd6*dq15*m_6*C2*C3*C5*S5 - Y5*a2*dq11*m_5*C2*C4*S2*S3 - Y6*a1*dq11*m_6*C4*C6*S2*S3 - Y6*a2*dq22*m_6*C3*C5*S4*S6 - Z4*a2*dq11*m_4*C2*C4*S2*S3 + Z5*a1*dq11*m_5*C2*C3*S4*S5 + Z6*a1*dq11*m_6*C2*C3*S4*S5 - X5*d4*dq11*m_5*C2*C5*S2*S4 - X5*d4*dq11*m_5*C3*C5*S3*S4 - X6*d4*dq11*m_6*C2*C4*S2*S6 - X6*d4*dq11*m_6*C3*C4*S3*S6 + X6*d6*dq11*m_6*C2*C6*S2*S4 + X6*d6*dq11*m_6*C3*C6*S3*S4 + 4*Y5*Z5*dq11*m_5*CC2*CC3*CC4*S5 + 2*X4*Y4*dq12*m_4*C2*C3*C4 + 2*X4*Y4*dq13*m_4*C2*C3*C4 + 2*X5*Z5*dq12*m_5*C2*C3*C4 + 2*X5*Z5*dq13*m_5*C2*C3*C4 + 2*X6*Z6*dq15*m_6*C2*C3*C6 - Y6*Z6*dq11*m_6*C2*S2*S4*S6 - Y6*Z6*dq11*m_6*C3*S3*S4*S6 - 2*Ixx6*dq12*C2*CC4*CC5*CC6*S3 - 2*Ixx6*dq12*C3*CC4*CC5*CC6*S2 - 2*Ixx6*dq13*C2*CC4*CC5*CC6*S3 - 2*Ixx6*dq13*C3*CC4*CC5*CC6*S2 + 2*Iyy6*dq12*C2*CC4*CC5*CC6*S3 + 2*Iyy6*dq12*C3*CC4*CC5*CC6*S2 + 2*Iyy6*dq13*C2*CC4*CC5*CC6*S3 + 2*Iyy6*dq13*C3*CC4*CC5*CC6*S2 + a1*d6*dq11*m_6*C2*C3*S4*S5 + 2*Ixx5*dq12*C4*C5*S2*S3*S5 + 2*Ixx5*dq13*C4*C5*S2*S3*S5 + 2*Ixx6*dq26*C5*C6*S4*S5*S6 + 2*Ixx6*dq36*C5*C6*S4*S5*S6 + 2*Iyy6*dq12*C4*C5*S2*S3*S5 + 2*Iyy6*dq13*C4*C5*S2*S3*S5 - 2*Iyy6*dq26*C5*C6*S4*S5*S6 - 2*Iyy6*dq36*C5*C6*S4*S5*S6 + 4*Iyz5*dq12*C2*C4*S3*S4*S5 + 4*Iyz5*dq12*C3*C4*S2*S4*S5 + 4*Iyz5*dq13*C2*C4*S3*S4*S5 + 4*Iyz5*dq13*C3*C4*S2*S4*S5 + 2*Iyz6*dq12*C5*C6*S2*S3*S4 + 2*Iyz6*dq13*C5*C6*S2*S3*S4 + 2*Iyz6*dq15*C2*C6*S3*S4*S5 + 2*Iyz6*dq15*C3*C6*S2*S4*S5 + 2*Iyz6*dq16*C5*C6*S2*S3*S5 + 4*Iyz6*dq23*C4*C5*S4*S5*S6 - 2*Izz5*dq12*C4*C5*S2*S3*S5 - 2*Izz5*dq13*C4*C5*S2*S3*S5 - 2*Izz6*dq12*C4*C5*S2*S3*S5 - 2*Izz6*dq13*C4*C5*S2*S3*S5 - X4*a2*dq11*m_4*C2*S2*S3*S4 - X5*a1*dq11*m_5*C5*S2*S3*S4 - X6*a1*dq11*m_6*C4*S2*S3*S6 - 2*XX5*dq15*m_5*C5*S2*S3*S5 + 2*XX6*dq16*m_6*C2*S3*S4*S5 + 2*XX6*dq16*m_6*C3*S2*S4*S5 + 2*XX6*dq16*m_6*C6*S2*S3*S6 - 2*X4*d4*dq12*m_4*C2*C3*C4 - 2*X4*d4*dq13*m_4*C2*C3*C4 + 2*X6*d6*dq15*m_6*C2*C3*C6 - Y6*d6*dq11*m_6*C2*S2*S4*S6 - Y6*d6*dq11*m_6*C3*S3*S4*S6 - 2*YY6*dq15*m_6*C5*S2*S3*S5 - 2*YY6*dq16*m_6*C6*S2*S3*S6 - Z5*d4*dq11*m_5*C2*S2*S4*S5 - Z5*d4*dq11*m_5*C3*S3*S4*S5 - Z6*d4*dq11*m_6*C2*S2*S4*S5 - Z6*d4*dq11*m_6*C3*S3*S4*S5 + 2*ZZ5*dq15*m_5*C5*S2*S3*S5 + 2*ZZ6*dq15*m_6*C5*S2*S3*S5 - 2*Y4*Z4*dq12*m_4*C2*C3*S4 - 2*Y4*Z4*dq13*m_4*C2*C3*S4 - 2*Y6*Z6*dq15*m_6*C2*C3*S6 + 2*Y6*Z6*dq25*m_6*C4*C6*S5 + 2*Y6*Z6*dq35*m_6*C4*C6*S5 - 2*Y6*Z6*dq46*m_6*C5*C6*S5 - 2*Iyz6*dq11*C2*CC3*C4*C5*C6*S2 - 2*Iyz6*dq11*CC2*C3*C4*C5*C6*S3 + 2*Ixz6*dq12*C5*S2*S3*S4*S6 + 2*Ixz6*dq13*C5*S2*S3*S4*S6 + 2*Ixz6*dq15*C2*S3*S4*S5*S6 + 2*Ixz6*dq15*C3*S2*S4*S5*S6 + 2*Ixz6*dq16*C5*S2*S3*S5*S6 - d4*d6*dq11*m_6*C2*S2*S4*S5 - d4*d6*dq11*m_6*C3*S3*S4*S5 + 2*dd6*dq15*m_6*C5*S2*S3*S5 + 2*X4*a3*dq12*m_4*C2*C4*S3 + 2*X4*a3*dq12*m_4*C3*C4*S2 + 2*X4*a3*dq13*m_4*C2*C4*S3 + 2*X4*a3*dq13*m_4*C3*C4*S2 + 2*X5*a2*dq12*m_5*C4*C5*S2 + 2*X6*a3*dq23*m_6*C5*C6*S4 - Z5*a1*dq11*m_5*S2*S3*S4*S5 - Z6*a1*dq11*m_6*S2*S3*S4*S5 + 2*Y5*d4*dq12*m_5*C2*C3*S4 + 2*Y5*d4*dq13*m_5*C2*C3*S4 - 2*Y6*d6*dq15*m_6*C2*C3*S6 + 2*Y6*d6*dq25*m_6*C4*C6*S5 + 2*Y6*d6*dq35*m_6*C4*C6*S5 - 2*Y6*d6*dq46*m_6*C5*C6*S5 + 2*Z4*d4*dq12*m_4*C2*C3*S4 + 2*Z4*d4*dq13*m_4*C2*C3*S4 + 4*Z6*d6*dq15*m_6*C2*C4*S3 + 4*Z6*d6*dq15*m_6*C3*C4*S2 - 2*X4*Y4*dq12*m_4*C4*S2*S3 - 2*X4*Y4*dq13*m_4*C4*S2*S3 + 2*X6*Y6*dq26*m_6*C5*S4*S5 + 2*X6*Y6*dq36*m_6*C5*S4*S5 - 4*X6*Y6*dq56*m_6*C6*S5*S6 - 2*X5*Z5*dq12*m_5*C4*S2*S3 - 2*X5*Z5*dq13*m_5*C4*S2*S3 - 2*X6*Z6*dq15*m_6*C6*S2*S3 + 4*X5*Z5*dq25*m_5*C5*S4*S5 + 4*X5*Z5*dq35*m_5*C5*S4*S5 + 2*X6*Z6*dq25*m_6*C4*S5*S6 + 2*X6*Z6*dq35*m_6*C4*S5*S6 - 2*X6*Z6*dq46*m_6*C5*S5*S6 + 4*Ixy5*dq11*C2*C3*CC4*C5*S2*S3 - 4*Ixy6*dq11*C2*C3*CC4*C5*S2*S3 - 4*Ixy6*dq11*C2*C3*C5*CC6*S2*S3 - 2*Ixz6*dq11*C2*CC3*C4*C5*S2*S6 - 2*Ixz6*dq11*CC2*C3*C4*C5*S3*S6 + 2*Ixz6*dq11*CC2*C4*C5*C6*S4*S5 + 2*Ixz6*dq11*CC3*C4*C5*C6*S4*S5 - a1*d6*dq11*m_6*S2*S3*S4*S5 - 2*Y5*a3*dq12*m_5*C2*S3*S4 - 2*Y5*a3*dq12*m_5*C3*S2*S4 - 2*Y5*a3*dq13*m_5*C2*S3*S4 - 2*Y5*a3*dq13*m_5*C3*S2*S4 - 2*Y6*a2*dq12*m_6*C6*S2*S4 - 2*Y6*a3*dq23*m_6*C5*S4*S6 - 2*Z4*a3*dq12*m_4*C2*S3*S4 - 2*Z4*a3*dq12*m_4*C3*S2*S4 - 2*Z4*a3*dq13*m_4*C2*S3*S4 - 2*Z4*a3*dq13*m_4*C3*S2*S4 + 2*Z5*a2*dq12*m_5*C4*S2*S5 + 2*Z6*a2*dq12*m_6*C4*S2*S5 + 2*X4*d4*dq12*m_4*C4*S2*S3 + 2*X4*d4*dq13*m_4*C4*S2*S3 - 2*X6*d6*dq15*m_6*C6*S2*S3 + 2*X6*d6*dq25*m_6*C4*S5*S6 + 2*X6*d6*dq35*m_6*C4*S5*S6 - 2*X6*d6*dq46*m_6*C5*S5*S6 - 2*Ixx6*dq11*CC2*CC3*C4*CC5*CC6*S4 + 2*Iyy6*dq11*CC2*CC3*C4*CC5*CC6*S4 + 2*Y4*Z4*dq12*m_4*S2*S3*S4 + 2*Y4*Z4*dq13*m_4*S2*S3*S4 + 2*Y6*Z6*dq15*m_6*S2*S3*S6 + 2*Ixx5*dq11*C2*CC3*C5*S2*S4*S5 + 2*Ixx5*dq11*CC2*C3*C5*S3*S4*S5 - Ixx6*dq11*C2*C5*CC6*S2*S4*S5 - Ixx6*dq11*C3*C5*CC6*S3*S4*S5 + 2*Iyy6*dq11*C2*CC3*C5*S2*S4*S5 + 2*Iyy6*dq11*CC2*C3*C5*S3*S4*S5 + Iyy6*dq11*C2*C5*CC6*S2*S4*S5 + Iyy6*dq11*C3*C5*CC6*S3*S4*S5 + 4*Iyz5*dq11*C2*C3*CC4*S2*S3*S5 - 2*Iyz6*dq11*CC2*C4*C5*S4*S5*S6 - 2*Iyz6*dq11*CC3*C4*C5*S4*S5*S6 - 2*Izz5*dq11*C2*CC3*C5*S2*S4*S5 - 2*Izz5*dq11*CC2*C3*C5*S3*S4*S5 - 2*Izz6*dq11*C2*CC3*C5*S2*S4*S5 - 2*Izz6*dq11*CC2*C3*C5*S3*S4*S5 + 4*Ixz6*dq12*C2*C3*C4*CC5*C6 + 4*Ixz6*dq13*C2*C3*C4*CC5*C6 + 2*a2*d6*dq12*m_6*C4*S2*S5 + Y6*a2*dq11*m_6*CC2*C3*C4*C6 - 2*X6*a2*dq12*m_6*S2*S4*S6 - 2*Y5*d4*dq12*m_5*S2*S3*S4 - 2*Y5*d4*dq13*m_5*S2*S3*S4 + 2*Y6*d6*dq15*m_6*S2*S3*S6 - 2*XX6*dq15*m_6*C5*CC6*S2*S3*S5 - 2*XX6*dq16*m_6*C2*CC6*S3*S4*S5 - 2*XX6*dq16*m_6*C3*CC6*S2*S4*S5 - 2*XX6*dq16*m_6*CC5*C6*S2*S3*S6 - 4*X6*d6*dq15*m_6*C2*C3*CC5*C6 + 2*Y6*d6*dq11*m_6*C2*CC3*S2*S4*S6 + 2*Y6*d6*dq11*m_6*CC2*C3*S3*S4*S6 + 2*Y6*d6*dq11*m_6*C2*CC5*S2*S4*S6 + 2*Y6*d6*dq11*m_6*C3*CC5*S3*S4*S6 + 2*YY6*dq15*m_6*C5*CC6*S2*S3*S5 + 2*YY6*dq16*m_6*C2*CC6*S3*S4*S5 + 2*YY6*dq16*m_6*C3*CC6*S2*S4*S5 + 2*YY6*dq16*m_6*CC5*C6*S2*S3*S6 + 2*Z5*d4*dq11*m_5*C2*CC3*S2*S4*S5 + 2*Z5*d4*dq11*m_5*CC2*C3*S3*S4*S5 + 2*Z6*d4*dq11*m_6*C2*CC3*S2*S4*S5 + 2*Z6*d4*dq11*m_6*CC2*C3*S3*S4*S5 + 4*Y6*Z6*dq15*m_6*C2*C3*CC5*S6 + 2*d4*d6*dq11*m_6*C2*CC3*S2*S4*S5 + 2*d4*d6*dq11*m_6*CC2*C3*S3*S4*S5 + 4*Y6*d6*dq15*m_6*C2*C3*CC5*S6 - 4*Z6*d6*dq15*m_6*C2*C4*CC5*S3 - 4*Z6*d6*dq15*m_6*C3*C4*CC5*S2 - 4*X6*Y6*dq25*m_6*CC5*C6*S4*S6 - 4*X6*Y6*dq26*m_6*C5*CC6*S4*S5 - 4*X6*Y6*dq35*m_6*CC5*C6*S4*S6 - 4*X6*Y6*dq36*m_6*C5*CC6*S4*S5 + 4*X5*Z5*dq12*m_5*C4*CC5*S2*S3 + 4*X5*Z5*dq13*m_5*C4*CC5*S2*S3 + 4*X6*Z6*dq15*m_6*CC5*C6*S2*S3 + 8*Ixy6*dq11*C2*C3*CC4*C5*CC6*S2*S3 - 4*Ixz6*dq11*CC2*CC3*C4*C5*C6*S4*S5 + 4*X6*d6*dq15*m_6*CC5*C6*S2*S3 - 4*Y6*Z6*dq15*m_6*CC5*S2*S3*S6 + 2*Ixx6*dq11*C2*CC3*C5*CC6*S2*S4*S5 + 2*Ixx6*dq11*CC2*C3*C5*CC6*S3*S4*S5 - 2*Iyy6*dq11*C2*CC3*C5*CC6*S2*S4*S5 - 2*Iyy6*dq11*CC2*C3*C5*CC6*S3*S4*S5 + 4*Iyz6*dq11*CC2*CC3*C4*C5*S4*S5*S6 - 4*Y6*d6*dq15*m_6*CC5*S2*S3*S6 + 2*X6*a3*dq11*m_6*CC2*CC3*C5*C6*S4 + 2*XX6*dq15*m_6*C2*C4*CC5*CC6*S3 + 2*XX6*dq15*m_6*C3*C4*CC5*CC6*S2 - 2*YY6*dq15*m_6*C2*C4*CC5*CC6*S3 - 2*YY6*dq15*m_6*C3*C4*CC5*CC6*S2 + 4*X5*Z5*dq11*m_5*C2*CC3*CC5*S2*S4 + 4*X5*Z5*dq11*m_5*CC2*C3*CC5*S3*S4 + 4*Ixy6*dq12*C2*CC4*CC5*C6*S3*S6 + 4*Ixy6*dq12*C3*CC4*CC5*C6*S2*S6 + 4*Ixy6*dq13*C2*CC4*CC5*C6*S3*S6 + 4*Ixy6*dq13*C3*CC4*CC5*C6*S2*S6 - 2*Y6*a3*dq11*m_6*CC2*CC3*C5*S4*S6 + 4*X6*Y6*dq16*m_6*C2*C3*CC5*CC6 - 2*Ixx6*dq11*C2*C3*C5*C6*S2*S3*S6 + 2*Iyy6*dq11*C2*C3*C5*C6*S2*S3*S6 + 4*XX6*dq11*m_6*CC2*CC3*CC4*C5*C6*S6 - 4*YY6*dq11*m_6*CC2*CC3*CC4*C5*C6*S6 - 2*XX4*dq11*m_4*C2*C3*C4*S2*S3*S4 + 2*XX6*dq11*m_6*C2*C3*C4*S2*S3*S4 + XX6*dq11*m_6*C2*C4*C6*S2*S5*S6 + XX6*dq11*m_6*C3*C4*C6*S3*S5*S6 + 2*YY5*dq11*m_5*C2*C3*C4*S2*S3*S4 - YY6*dq11*m_6*C2*C4*C6*S2*S5*S6
 - YY6*dq11*m_6*C3*C4*C6*S3*S5*S6 - 4*Z6*d6*dq12*m_6*C2*CC4*CC5*S3 - 4*Z6*d6*dq12*m_6*C3*CC4*CC5*S2 - 4*Z6*d6*dq13*m_6*C2*CC4*CC5*S3 - 4*Z6*d6*dq13*m_6*C3*CC4*CC5*S2 + 2*ZZ4*dq11*m_4*C2*C3*C4*S2*S3*S4 - 2*ZZ5*dq11*m_5*C2*C3*C4*S2*S3*S4 - 2*ZZ6*dq11*m_6*C2*C3*C4*S2*S3*S4 - 4*X6*Y6*dq16*m_6*CC5*CC6*S2*S3 - Y6*Z6*dq11*m_6*C2*C4*C5*C6*S2 - Y6*Z6*dq11*m_6*C3*C4*C5*C6*S3 + 4*Ixy6*dq11*CC2*CC3*C4*CC5*C6*S4*S6 + 2*Ixy6*dq11*C2*C5*C6*S2*S4*S5*S6 + 2*Ixy6*dq11*C3*C5*C6*S3*S4*S5*S6 - 2*dd6*dq11*m_6*C2*C3*C4*S2*S3*S4 + X6*a1*dq11*m_6*C2*C3*C5*C6*S4 + 2*XX5*dq12*m_5*C2*C3*C4*C5*S5 + 2*XX5*dq13*m_5*C2*C3*C4*C5*S5 - Y6*d6*dq11*m_6*C2*C4*C5*C6*S2 - Y6*d6*dq11*m_6*C3*C4*C5*C6*S3 + 2*YY6*dq12*m_6*C2*C3*C4*C5*S5 + 2*YY6*dq13*m_6*C2*C3*C4*C5*S5 - 2*ZZ5*dq12*m_5*C2*C3*C4*C5*S5 - 2*ZZ5*dq13*m_5*C2*C3*C4*C5*S5 - 2*ZZ6*dq12*m_6*C2*C3*C4*C5*S5 - 2*ZZ6*dq13*m_6*C2*C3*C4*C5*S5 + 2*X5*Y5*dq11*m_5*C2*C3*C5*S2*S3 - 2*X6*Y6*dq11*m_6*C2*C3*C5*S2*S3 - X6*Z6*dq11*m_6*C2*C4*C5*S2*S6 - X6*Z6*dq11*m_6*C3*C4*C5*S3*S6 + 2*X6*Z6*dq22*m_6*C4*C5*C6*S4*S5 + 2*X6*Z6*dq33*m_6*C4*C5*C6*S4*S5 + 4*Ixy6*dq15*C2*C3*C5*C6*S5*S6 - 4*Ixz6*dq15*C2*C4*C5*C6*S3*S5 - 4*Ixz6*dq15*C3*C4*C5*C6*S2*S5 - 2*dd6*dq12*m_6*C2*C3*C4*C5*S5 - 2*dd6*dq13*m_6*C2*C3*C4*C5*S5 - 2*Y5*a3*dq11*m_5*C2*C3*C4*S2*S3 - Y6*a2*dq11*m_6*C2*C4*C6*S2*S3 - Y6*a1*dq11*m_6*C2*C3*C5*S4*S6 - 2*Z4*a3*dq11*m_4*C2*C3*C4*S2*S3 - X6*d4*dq11*m_6*C2*C5*C6*S2*S4 - X6*d4*dq11*m_6*C3*C5*C6*S3*S4 - X6*d6*dq11*m_6*C2*C4*C5*S2*S6 - X6*d6*dq11*m_6*C3*C4*C5*S3*S6 + 2*X6*d6*dq22*m_6*C4*C5*C6*S4*S5 + 2*X6*d6*dq33*m_6*C4*C5*C6*S4*S5 + 4*Y6*Z6*dq11*m_6*CC2*CC3*CC4*C6*S5 + 2*X6*Z6*dq12*m_6*C2*C3*C4*C6 + 2*X6*Z6*dq13*m_6*C2*C3*C4*C6 + 2*Y5*Z5*dq11*m_5*C2*C3*S2*S3*S5 - 2*Y6*Z6*dq22*m_6*C4*C5*S4*S5*S6 - 2*Y6*Z6*dq33*m_6*C4*C5*S4*S5*S6 + 2*Ixx6*dq12*C2*C3*C6*S4*S5*S6 + 2*Ixx6*dq13*C2*C3*C6*S4*S5*S6 + 2*Ixx6*dq15*C2*C5*C6*S3*S4*S6 + 2*Ixx6*dq15*C3*C5*C6*S2*S4*S6 - 2*Iyy6*dq12*C2*C3*C6*S4*S5*S6 - 2*Iyy6*dq13*C2*C3*C6*S4*S5*S6 - 2*Iyy6*dq15*C2*C5*C6*S3*S4*S6 - 2*Iyy6*dq15*C3*C5*C6*S2*S4*S6 + 4*Iyz6*dq12*C2*C4*C6*S3*S4*S5 + 4*Iyz6*dq12*C3*C4*C6*S2*S4*S5 + 4*Iyz6*dq13*C2*C4*C6*S3*S4*S5 + 4*Iyz6*dq13*C3*C4*C6*S2*S4*S5 + 4*Iyz6*dq15*C2*C4*C5*S3*S5*S6 + 4*Iyz6*dq15*C3*C4*C5*S2*S5*S6 - 2*X4*a3*dq11*m_4*C2*C3*S2*S3*S4 - X5*a2*dq11*m_5*C2*C5*S2*S3*S4 - X6*a2*dq11*m_6*C2*C4*S2*S3*S6 - X6*a1*dq11*m_6*C5*C6*S2*S3*S4 + 2*XX6*dq12*m_6*C2*CC4*CC5*CC6*S3 + 2*XX6*dq12*m_6*C3*CC4*CC5*CC6*S2 + 2*XX6*dq13*m_6*C2*CC4*CC5*CC6*S3 + 2*XX6*dq13*m_6*C3*CC4*CC5*CC6*S2 + 4*Y6*d6*dq11*m_6*CC2*CC3*CC4*C6*S5 - 2*YY6*dq12*m_6*C2*CC4*CC5*CC6*S3 - 2*YY6*dq12*m_6*C3*CC4*CC5*CC6*S2 - 2*YY6*dq13*m_6*C2*CC4*CC5*CC6*S3 - 2*YY6*dq13*m_6*C3*CC4*CC5*CC6*S2 - 4*Z6*d6*dq11*m_6*CC2*CC3*C4*CC5*S4 - 2*XX5*dq12*m_5*C4*C5*S2*S3*S5 - 2*XX5*dq13*m_5*C4*C5*S2*S3*S5 - 2*XX6*dq26*m_6*C5*C6*S4*S5*S6 - 2*XX6*dq36*m_6*C5*C6*S4*S5*S6 - 2*X5*d4*dq12*m_5*C2*C3*C4*C5 - 2*X5*d4*dq13*m_5*C2*C3*C4*C5 + 2*X6*d6*dq12*m_6*C2*C3*C4*C6 + 2*X6*d6*dq13*m_6*C2*C3*C4*C6 + Y6*d4*dq11*m_6*C2*C5*S2*S4*S6 + Y6*d4*dq11*m_6*C3*C5*S3*S4*S6 - 2*Y6*d6*dq22*m_6*C4*C5*S4*S5*S6 - 2*Y6*d6*dq33*m_6*C4*C5*S4*S5*S6 - 2*YY6*dq12*m_6*C4*C5*S2*S3*S5 - 2*YY6*dq13*m_6*C4*C5*S2*S3*S5 + 2*YY6*dq26*m_6*C5*C6*S4*S5*S6 + 2*YY6*dq36*m_6*C5*C6*S4*S5*S6 - 2*Z6*d6*dq11*m_6*C2*C5*S2*S4*S5 - 2*Z6*d6*dq11*m_6*C3*C5*S3*S4*S5 + 2*ZZ5*dq12*m_5*C4*C5*S2*S3*S5 + 2*ZZ5*dq13*m_5*C4*C5*S2*S3*S5 + 2*ZZ6*dq12*m_6*C4*C5*S2*S3*S5 + 2*ZZ6*dq13*m_6*C4*C5*S2*S3*S5 + 4*X6*Z6*dq11*m_6*CC2*CC3*CC4*S5*S6 + 2*Y5*Z5*dq12*m_5*C2*C3*C5*S4 + 2*Y5*Z5*dq13*m_5*C2*C3*C5*S4 - 2*Y6*Z6*dq12*m_6*C2*C3*C4*S6 - 2*Y6*Z6*dq13*m_6*C2*C3*C4*S6 - 2*Y6*Z6*dq16*m_6*C2*C4*C6*S3 - 2*Y6*Z6*dq16*m_6*C3*C4*C6*S2 - 4*Ixy6*dq15*C5*C6*S2*S3*S5*S6 - 4*Ixy6*dq16*C2*C6*S3*S4*S5*S6 - 4*Ixy6*dq16*C3*C6*S2*S4*S5*S6 + 4*Ixz6*dq12*C2*C4*S3*S4*S5*S6 + 4*Ixz6*dq12*C3*C4*S2*S4*S5*S6 + 4*Ixz6*dq13*C2*C4*S3*S4*S5*S6 + 4*Ixz6*dq13*C3*C4*S2*S4*S5*S6 + 2*dd6*dq12*m_6*C4*C5*S2*S3*S5 + 2*dd6*dq13*m_6*C4*C5*S2*S3*S5 + 2*X5*a3*dq12*m_5*C2*C4*C5*S3 + 2*X5*a3*dq12*m_5*C3*C4*C5*S2 + 2*X5*a3*dq13*m_5*C2*C4*C5*S3 + 2*X5*a3*dq13*m_5*C3*C4*C5*S2 + 2*X6*a2*dq12*m_6*C4*C5*C6*S2 + Y6*a1*dq11*m_6*C5*S2*S3*S4*S6 + 4*X6*d6*dq11*m_6*CC2*CC3*CC4*S5*S6 - Z5*a2*dq11*m_5*C2*S2*S3*S4*S5 - Z6*a2*dq11*m_6*C2*S2*S3*S4*S5 + 2*Y6*d4*dq12*m_6*C2*C3*C6*S4 + 2*Y6*d4*dq13*m_6*C2*C3*C6*S4 - 2*Y6*d6*dq12*m_6*C2*C3*C4*S6 - 2*Y6*d6*dq13*m_6*C2*C3*C4*S6 - 2*Y6*d6*dq16*m_6*C2*C4*C6*S3 - 2*Y6*d6*dq16*m_6*C3*C4*C6*S2 - 2*Z5*d4*dq12*m_5*C2*C3*C4*S5 - 2*Z5*d4*dq13*m_5*C2*C3*C4*S5 - 2*Z6*d4*dq12*m_6*C2*C3*C4*S5 - 2*Z6*d4*dq13*m_6*C2*C3*C4*S5 - 4*Z6*d6*dq15*m_6*C2*C3*C5*S5 - 2*X5*Y5*dq12*m_5*C2*C3*S4*S5 - 2*X5*Y5*dq13*m_5*C2*C3*S4*S5 - 2*X5*Y5*dq15*m_5*C2*C5*S3*S4 - 2*X5*Y5*dq15*m_5*C3*C5*S2*S4 + 2*X6*Y6*dq12*m_6*C2*C3*S4*S5 + 2*X6*Y6*dq13*m_6*C2*C3*S4*S5 + 4*X6*Y6*dq12*m_6*C2*C6*S3*S6 + 4*X6*Y6*dq12*m_6*C3*C6*S2*S6 + 2*X6*Y6*dq15*m_6*C2*C5*S3*S4 + 2*X6*Y6*dq15*m_6*C3*C5*S2*S4 + 4*X6*Y6*dq13*m_6*C2*C6*S3*S6 + 4*X6*Y6*dq13*m_6*C3*C6*S2*S6 - 4*X6*Y6*dq23*m_6*C4*C6*S4*S6 - 4*X6*Y6*dq26*m_6*C4*C6*S5*S6 - 4*X6*Y6*dq36*m_6*C4*C6*S5*S6 + 4*X6*Y6*dq45*m_6*C5*C6*S5*S6 - 4*X4*Z4*dq12*m_4*C2*C4*S3*S4 - 4*X4*Z4*dq12*m_4*C3*C4*S2*S4 - 4*X4*Z4*dq13*m_4*C2*C4*S3*S4 - 4*X4*Z4*dq13*m_4*C3*C4*S2*S4 - 2*X6*Z6*dq12*m_6*C4*C6*S2*S3 - 2*X6*Z6*dq13*m_6*C4*C6*S2*S3 + 4*X5*Z5*dq23*m_5*C4*C5*S4*S5 - 2*X6*Z6*dq16*m_6*C2*C4*S3*S6 - 2*X6*Z6*dq16*m_6*C3*C4*S2*S6 + 4*X6*Z6*dq25*m_6*C5*C6*S4*S5 + 4*X6*Z6*dq35*m_6*C5*C6*S4*S5 - a2*d6*dq11*m_6*C2*S2*S3*S4*S5 - 2*Ixx6*dq12*C6*S2*S3*S4*S5*S6 - 2*Ixx6*dq13*C6*S2*S3*S4*S5*S6 + 2*Iyy6*dq12*C6*S2*S3*S4*S5*S6 + 2*Iyy6*dq13*C6*S2*S3*S4*S5*S6 - 2*d4*d6*dq12*m_6*C2*C3*C4*S5 - 2*d4*d6*dq13*m_6*C2*C3*C4*S5 - 2*Y6*a3*dq12*m_6*C2*C6*S3*S4 - 2*Y6*a3*dq12*m_6*C3*C6*S2*S4 - 2*Y6*a2*dq12*m_6*C4*C5*S2*S6 - 2*Y6*a3*dq13*m_6*C2*C6*S3*S4 - 2*Y6*a3*dq13*m_6*C3*C6*S2*S4 + 2*Z5*a3*dq12*m_5*C2*C4*S3*S5 + 2*Z5*a3*dq12*m_5*C3*C4*S2*S5 + 2*Z5*a3*dq13*m_5*C2*C4*S3*S5 + 2*Z5*a3*dq13*m_5*C3*C4*S2*S5 + 2*Z6*a3*dq12*m_6*C2*C4*S3*S5 + 2*Z6*a3*dq12*m_6*C3*C4*S2*S5 + 2*Z6*a3*dq13*m_6*C2*C4*S3*S5 + 2*Z6*a3*dq13*m_6*C3*C4*S2*S5 + 2*X5*d4*dq12*m_5*C4*C5*S2*S3 + 2*X5*d4*dq13*m_5*C4*C5*S2*S3 + 2*X6*d4*dq12*m_6*C2*C3*S4*S6 + 2*X6*d4*dq13*m_6*C2*C3*S4*S6 - 2*X6*d6*dq12*m_6*C4*C6*S2*S3 - 2*X6*d6*dq13*m_6*C4*C6*S2*S3 - 2*X6*d6*dq16*m_6*C2*C4*S3*S6 - 2*X6*d6*dq16*m_6*C3*C4*S2*S6 + 4*X6*d6*dq25*m_6*C5*C6*S4*S5 + 4*X6*d6*dq35*m_6*C5*C6*S4*S5 - 2*Y5*Z5*dq12*m_5*C5*S2*S3*S4 - 2*Y5*Z5*dq13*m_5*C5*S2*S3*S4 - 2*Y5*Z5*dq15*m_5*C2*S3*S4*S5 - 2*Y5*Z5*dq15*m_5*C3*S2*S4*S5 + 2*Y6*Z6*dq12*m_6*C4*S2*S3*S6 + 2*Y6*Z6*dq13*m_6*C4*S2*S3*S6 - 4*Y6*Z6*dq25*m_6*C5*S4*S5*S6 - 4*Y6*Z6*dq35*m_6*C5*S4*S5*S6 + 2*Ixx5*dq11*C2*C3*C4*CC5*S2*S3*S4 + 2*Ixx6*dq11*C2*C3*C4*CC6*S2*S3*S4 + 2*Ixx6*dq11*C2*CC3*C4*C6*S2*S5*S6 + 2*Ixx6*dq11*CC2*C3*C4*C6*S3*S5*S6 + 2*Iyy6*dq11*C2*C3*C4*CC5*S2*S3*S4 - 2*Iyy6*dq11*C2*C3*C4*CC6*S2*S3*S4 - 2*Iyy6*dq11*C2*CC3*C4*C6*S2*S5*S6 - 2*Iyy6*dq11*CC2*C3*C4*C6*S3*S5*S6 + 4*Iyz6*dq11*C2*C3*CC4*C6*S2*S3*S5 - 2*Izz5*dq11*C2*C3*C4*CC5*S2*S3*S4 - 2*Izz6*dq11*C2*C3*C4*CC5*S2*S3*S4 + 2*a3*d6*dq12*m_6*C2*C4*S3*S5 + 2*a3*d6*dq12*m_6*C3*C4*S2*S5 + 2*a3*d6*dq13*m_6*C2*C4*S3*S5 + 2*a3*d6*dq13*m_6*C3*C4*S2*S5 - 2*X6*a3*dq12*m_6*C2*S3*S4*S6 - 2*X6*a3*dq12*m_6*C3*S2*S4*S6 - 2*X6*a3*dq13*m_6*C2*S3*S4*S6 - 2*X6*a3*dq13*m_6*C3*S2*S4*S6 + 2*XX6*dq11*m_6*CC2*CC3*C4*CC5*CC6*S4 - 2*YY6*dq11*m_6*CC2*CC3*C4*CC5*CC6*S4 - 2*XX5*dq11*m_5*C2*CC3*C5*S2*S4*S5 - 2*XX5*dq11*m_5*CC2*C3*C5*S3*S4*S5 + XX6*dq11*m_6*C2*C5*CC6*S2*S4*S5 + XX6*dq11*m_6*C3*C5*CC6*S3*S4*S5 - 2*YY6*dq11*m_6*C2*CC3*C5*S2*S4*S5 - 2*YY6*dq11*m_6*CC2*C3*C5*S3*S4*S5 - YY6*dq11*m_6*C2*C5*CC6*S2*S4*S5 - YY6*dq11*m_6*C3*C5*CC6*S3*S4*S5 + 2*ZZ5*dq11*m_5*C2*CC3*C5*S2*S4*S5 + 2*ZZ5*dq11*m_5*CC2*C3*C5*S3*S4*S5 + 2*ZZ6*dq11*m_6*C2*CC3*C5*S2*S4*S5 + 2*ZZ6*dq11*m_6*CC2*C3*C5*S3*S4*S5 - 2*Y6*d4*dq12*m_6*C6*S2*S3*S4 - 2*Y6*d4*dq13*m_6*C6*S2*S3*S4 + 2*Y6*d6*dq12*m_6*C4*S2*S3*S6 + 2*Y6*d6*dq13*m_6*C4*S2*S3*S6 - 4*Y6*d6*dq25*m_6*C5*S4*S5*S6 - 4*Y6*d6*dq35*m_6*C5*S4*S5*S6 + 2*Z5*d4*dq12*m_5*C4*S2*S3*S5 + 2*Z5*d4*dq13*m_5*C4*S2*S3*S5 + 2*Z6*d4*dq12*m_6*C4*S2*S3*S5 + 2*Z6*d4*dq13*m_6*C4*S2*S3*S5 + 4*Z6*d6*dq15*m_6*C5*S2*S3*S5 + 2*X5*Y5*dq12*m_5*S2*S3*S4*S5 + 2*X5*Y5*dq13*m_5*S2*S3*S4*S5 - 2*X6*Y6*dq12*m_6*S2*S3*S4*S5 - 2*X6*Y6*dq13*m_6*S2*S3*S4*S5 + 2*Y5*Z5*dq11*m_5*C2*CC3*C4*C5*S2 + 2*Y5*Z5*dq11*m_5*CC2*C3*C4*C5*S3 + 4*Ixz6*dq11*C2*C3*CC4*S2*S3*S5*S6 - 2*Ixx6*dq12*C2*C3*C4*C5*CC6*S5 - 2*Ixx6*dq13*C2*C3*C4*C5*CC6*S5 + 2*Iyy6*dq12*C2*C3*C4*C5*CC6*S5 + 2*Iyy6*dq13*C2*C3*C4*C5*CC6*S5 + 2*dd6*dq11*m_6*C2*CC3*C5*S2*S4*S5 + 2*dd6*dq11*m_6*CC2*C3*C5*S3*S4*S5 + X6*a2*dq11*m_6*CC2*C3*C5*C6*S4 + 2*d4*d6*dq12*m_6*C4*S2*S3*S5 + 2*d4*d6*dq13*m_6*C4*S2*S3*S5 + 2*XX6*dq15*m_6*C2*C3*C5*CC6*S5 + 2*XX6*dq16*m_6*C2*C3*CC5*C6*S6 + 2*Y6*d4*dq11*m_6*C2*CC3*C4*C6*S2 + 2*Y6*d4*dq11*m_6*CC2*C3*C4*C6*S3 - 2*X6*d4*dq12*m_6*S2*S3*S4*S6 - 2*X6*d4*dq13*m_6*S2*S3*S4*S6 - 2*YY6*dq15*m_6*C2*C3*C5*CC6*S5 - 2*YY6*dq16*m_6*C2*C3*CC5*C6*S6 + 8*X6*Y6*dq11*m_6*CC2*CC3*CC4*C5*CC6 - 2*X5*Y5*dq11*m_5*C2*CC3*C4*S2*S5 - 2*X5*Y5*dq11*m_5*CC2*C3*C4*S3*S5 + 2*X6*Y6*dq11*m_6*C2*CC3*C4*S2*S5 + 2*X6*Y6*dq11*m_6*CC2*C3*C4*S3*S5 + 2*X6*Y6*dq11*m_6*C2*C4*CC6*S2*S5 + 2*X6*Y6*dq11*m_6*C3*C4*CC6*S3*S5 + 2*X6*Y6*dq11*m_6*CC2*C4*C6*S4*S6 + 2*X6*Y6*dq11*m_6*CC3*C4*C6*S4*S6 - 2*X6*Y6*dq22*m_6*C4*CC5*C6*S4*S6 - 2*X6*Y6*dq33*m_6*C4*CC5*C6*S4*S6 - 4*X4*Z4*dq11*m_4*C2*C3*CC4*S2*S3 - 2*X5*Z5*dq11*m_5*CC2*C4*C5*S4*S5 - 2*X6*Z6*dq11*m_6*C2*CC3*C6*S2*S4 - 2*X5*Z5*dq11*m_5*CC3*C4*C5*S4*S5 - 2*X6*Z6*dq11*m_6*CC2*C3*C6*S3*S4 - 2*X6*Z6*dq11*m_6*C2*CC5*C6*S2*S4 - 2*X6*Z6*dq11*m_6*C3*CC5*C6*S3*S4 + 8*Ixy6*dq12*C2*C4*C5*CC6*S3*S4 + 8*Ixy6*dq12*C3*C4*C5*CC6*S2*S4 + 8*Ixy6*dq13*C2*C4*C5*CC6*S3*S4 + 8*Ixy6*dq13*C3*C4*C5*CC6*S2*S4 + 4*Ixy6*dq15*C2*C4*CC5*C6*S3*S6 + 4*Ixy6*dq15*C3*C4*CC5*C6*S2*S6 + 4*Ixy6*dq16*C2*C4*C5*CC6*S3*S5 + 4*Ixy6*dq16*C3*C4*C5*CC6*S2*S5 - 4*Ixz6*dq12*C2*CC4*C5*C6*S3*S5 - 4*Ixz6*dq12*C3*CC4*C5*C6*S2*S5 - 4*Ixz6*dq13*C2*CC4*C5*C6*S3*S5 - 4*Ixz6*dq13*C3*CC4*C5*C6*S2*S5 - Y6*a2*dq11*m_6*CC2*C3*C5*S4*S6 + 2*X5*d4*dq11*m_5*C2*CC3*C5*S2*S4
 + 2*X5*d4*dq11*m_5*CC2*C3*C5*S3*S4 + 2*X6*d4*dq11*m_6*C2*CC3*C4*S2*S6 + 2*X6*d4*dq11*m_6*CC2*C3*C4*S3*S6 - 2*X6*d6*dq11*m_6*C2*CC3*C6*S2*S4 - 2*X6*d6*dq11*m_6*CC2*C3*C6*S3*S4 - 2*X6*d6*dq11*m_6*C2*CC5*C6*S2*S4 - 2*X6*d6*dq11*m_6*C3*CC5*C6*S3*S4 - 4*X5*Z5*dq12*m_5*C2*C3*C4*CC5 - 4*X5*Z5*dq13*m_5*C2*C3*C4*CC5 - 4*X6*Z6*dq15*m_6*C2*C3*CC5*C6 + 2*Y6*Z6*dq11*m_6*C2*CC3*S2*S4*S6 + 2*Y6*Z6*dq11*m_6*CC2*C3*S3*S4*S6 + 2*Y6*Z6*dq11*m_6*C2*CC5*S2*S4*S6 + 2*Y6*Z6*dq11*m_6*C3*CC5*S3*S4*S6 + 2*Ixx6*dq12*C4*C5*CC6*S2*S3*S5 + 2*Ixx6*dq13*C4*C5*CC6*S2*S3*S5 - 2*Iyy6*dq12*C4*C5*CC6*S2*S3*S5 - 2*Iyy6*dq13*C4*C5*CC6*S2*S3*S5 + 4*Iyz6*dq12*C2*CC4*C5*S3*S5*S6 + 4*Iyz6*dq12*C3*CC4*C5*S2*S5*S6 + 4*Iyz6*dq13*C2*CC4*C5*S3*S5*S6 + 4*Iyz6*dq13*C3*CC4*C5*S2*S5*S6 - 2*XX6*dq11*m_6*C2*CC3*C5*CC6*S2*S4*S5 - 2*XX6*dq11*m_6*CC2*C3*C5*CC6*S3*S4*S5 + 2*YY6*dq11*m_6*C2*CC3*C5*CC6*S2*S4*S5 + 2*YY6*dq11*m_6*CC2*C3*C5*CC6*S3*S4*S5 - 4*Y6*d6*dq12*m_6*C4*CC5*S2*S3*S6 - 4*Y6*d6*dq13*m_6*C4*CC5*S2*S3*S6 + 4*X6*Y6*dq12*m_6*CC6*S2*S3*S4*S5 + 4*X6*Y6*dq13*m_6*CC6*S2*S3*S4*S5 - 4*X6*Y6*dq11*m_6*C2*CC3*C4*CC6*S2*S5 - 4*X6*Y6*dq11*m_6*CC2*C3*C4*CC6*S3*S5 - 4*X6*Y6*dq11*m_6*CC2*CC3*C4*C6*S4*S6 + 2*X6*Y6*dq11*m_6*CC2*C4*CC5*C6*S4*S6 + 2*X6*Y6*dq11*m_6*CC3*C4*CC5*C6*S4*S6 + 4*X5*Z5*dq11*m_5*CC2*CC3*C4*C5*S4*S5 + 4*X6*Z6*dq11*m_6*C2*CC3*CC5*C6*S2*S4 + 4*X6*Z6*dq11*m_6*CC2*C3*CC5*C6*S3*S4 + 4*X6*d6*dq11*m_6*C2*CC3*CC5*C6*S2*S4 + 4*X6*d6*dq11*m_6*CC2*C3*CC5*C6*S3*S4 - 4*Y6*Z6*dq11*m_6*C2*CC3*CC5*S2*S4*S6 - 4*Y6*Z6*dq11*m_6*CC2*C3*CC5*S3*S4*S6 - 4*Y6*d6*dq11*m_6*C2*CC3*CC5*S2*S4*S6 - 4*Y6*d6*dq11*m_6*CC2*C3*CC5*S3*S4*S6 + 2*XX6*dq11*m_6*C2*C3*C5*C6*S2*S3*S6 - 2*YY6*dq11*m_6*C2*C3*C5*C6*S2*S3*S6 - 4*Ixy6*dq11*C2*C3*C4*C6*S2*S3*S4*S6 + 4*Ixz5*dq11*C2*C3*C4*C5*S2*S3*S4*S5 + 4*Ixy6*dq12*C2*C3*C4*C5*C6*S5*S6 + 4*Ixy6*dq13*C2*C3*C4*C5*C6*S5*S6 - 2*Y6*a3*dq11*m_6*C2*C3*C4*C6*S2*S3 + 2*Y6*Z6*dq11*m_6*C2*C3*C6*S2*S3*S5 + 4*Ixx6*dq12*C2*C4*C5*C6*S3*S4*S6 + 4*Ixx6*dq12*C3*C4*C5*C6*S2*S4*S6 + 4*Ixx6*dq13*C2*C4*C5*C6*S3*S4*S6 + 4*Ixx6*dq13*C3*C4*C5*C6*S2*S4*S6 + 2*Ixx6*dq16*C2*C4*C5*C6*S3*S5*S6 + 2*Ixx6*dq16*C3*C4*C5*C6*S2*S5*S6 - 4*Iyy6*dq12*C2*C4*C5*C6*S3*S4*S6 - 4*Iyy6*dq12*C3*C4*C5*C6*S2*S4*S6 - 4*Iyy6*dq13*C2*C4*C5*C6*S3*S4*S6 - 4*Iyy6*dq13*C3*C4*C5*C6*S2*S4*S6 - 2*Iyy6*dq16*C2*C4*C5*C6*S3*S5*S6 - 2*Iyy6*dq16*C3*C4*C5*C6*S2*S5*S6 - 2*X5*a3*dq11*m_5*C2*C3*C5*S2*S3*S4 - 2*X6*a3*dq11*m_6*C2*C3*C4*S2*S3*S6 - X6*a2*dq11*m_6*C2*C5*C6*S2*S3*S4 - 2*XX6*dq12*m_6*C2*C3*C6*S4*S5*S6 - 2*XX6*dq13*m_6*C2*C3*C6*S4*S5*S6 - 2*XX6*dq15*m_6*C2*C5*C6*S3*S4*S6 - 2*XX6*dq15*m_6*C3*C5*C6*S2*S4*S6 - 2*X6*d4*dq12*m_6*C2*C3*C4*C5*C6 - 2*X6*d4*dq13*m_6*C2*C3*C4*C5*C6 + 2*Y6*d6*dq11*m_6*C2*C3*C6*S2*S3*S5 + 2*YY6*dq12*m_6*C2*C3*C6*S4*S5*S6 + 2*YY6*dq13*m_6*C2*C3*C6*S4*S5*S6 + 2*YY6*dq15*m_6*C2*C5*C6*S3*S4*S6 + 2*YY6*dq15*m_6*C3*C5*C6*S2*S4*S6 - 4*Z6*d6*dq11*m_6*C2*C3*C4*S2*S3*S4 + 2*X6*Z6*dq11*m_6*C2*C3*S2*S3*S5*S6 + 2*Y6*Z6*dq12*m_6*C2*C3*C5*C6*S4 + 2*Y6*Z6*dq13*m_6*C2*C3*C5*C6*S4 + 2*Y6*Z6*dq16*m_6*C2*C3*C5*C6*S5 - 4*Ixy6*dq12*C4*C5*C6*S2*S3*S5*S6 - 4*Ixy6*dq13*C4*C5*C6*S2*S3*S5*S6 + 2*X6*a3*dq12*m_6*C2*C4*C5*C6*S3 + 2*X6*a3*dq12*m_6*C3*C4*C5*C6*S2 + 2*X6*a3*dq13*m_6*C2*C4*C5*C6*S3 + 2*X6*a3*dq13*m_6*C3*C4*C5*C6*S2 + Y6*a2*dq11*m_6*C2*C5*S2*S3*S4*S6 - 2*Z5*a3*dq11*m_5*C2*C3*S2*S3*S4*S5 - 2*Z6*a3*dq11*m_6*C2*C3*S2*S3*S4*S5 + 2*X6*d6*dq11*m_6*C2*C3*S2*S3*S5*S6 + 2*Y6*d4*dq12*m_6*C2*C3*C4*C5*S6 + 2*Y6*d4*dq13*m_6*C2*C3*C4*C5*S6 + 2*Y6*d6*dq12*m_6*C2*C3*C5*C6*S4 + 2*Y6*d6*dq13*m_6*C2*C3*C5*C6*S4 + 2*Y6*d6*dq16*m_6*C2*C3*C5*C6*S5 - 4*Z6*d6*dq12*m_6*C2*C3*C4*C5*S5 - 4*Z6*d6*dq13*m_6*C2*C3*C4*C5*S5 - 4*X5*Y5*dq12*m_5*C2*C4*C5*S3*S4 - 4*X5*Y5*dq12*m_5*C3*C4*C5*S2*S4 - 4*X5*Y5*dq13*m_5*C2*C4*C5*S3*S4 - 4*X5*Y5*dq13*m_5*C3*C4*C5*S2*S4 + 4*X6*Y6*dq12*m_6*C2*C4*C5*S3*S4 + 4*X6*Y6*dq12*m_6*C3*C4*C5*S2*S4 + 4*X6*Y6*dq13*m_6*C2*C4*C5*S3*S4 + 4*X6*Y6*dq13*m_6*C3*C4*C5*S2*S4 + 2*X6*Y6*dq16*m_6*C2*C4*C5*S3*S5 + 2*X6*Y6*dq16*m_6*C3*C4*C5*S2*S5 + 4*X5*Z5*dq15*m_5*C2*C4*C5*S3*S5 + 4*X5*Z5*dq15*m_5*C3*C4*C5*S2*S5 + 2*X6*Z6*dq12*m_6*C2*C3*C5*S4*S6 + 2*X6*Z6*dq13*m_6*C2*C3*C5*S4*S6 + 2*X6*Z6*dq16*m_6*C2*C3*C5*S5*S6 + 4*X6*Z6*dq23*m_6*C4*C5*C6*S4*S5 - 2*a3*d6*dq11*m_6*C2*C3*S2*S3*S4*S5 - 2*Y6*a3*dq12*m_6*C2*C4*C5*S3*S6 - 2*Y6*a3*dq12*m_6*C3*C4*C5*S2*S6 - 2*Y6*a3*dq13*m_6*C2*C4*C5*S3*S6 - 2*Y6*a3*dq13*m_6*C3*C4*C5*S2*S6 + 2*XX6*dq12*m_6*C6*S2*S3*S4*S5*S6 + 2*XX6*dq13*m_6*C6*S2*S3*S4*S5*S6 + 2*X6*d4*dq12*m_6*C4*C5*C6*S2*S3 + 2*X6*d4*dq13*m_6*C4*C5*C6*S2*S3 + 2*X6*d6*dq12*m_6*C2*C3*C5*S4*S6 + 2*X6*d6*dq13*m_6*C2*C3*C5*S4*S6 + 2*X6*d6*dq16*m_6*C2*C3*C5*S5*S6 + 4*X6*d6*dq23*m_6*C4*C5*C6*S4*S5 - 2*YY6*dq12*m_6*C6*S2*S3*S4*S5*S6 - 2*YY6*dq13*m_6*C6*S2*S3*S4*S5*S6 - 4*Y5*Z5*dq12*m_5*C2*C4*S3*S4*S5 - 4*Y5*Z5*dq12*m_5*C3*C4*S2*S4*S5 - 4*Y5*Z5*dq13*m_5*C2*C4*S3*S4*S5 - 4*Y5*Z5*dq13*m_5*C3*C4*S2*S4*S5 - 2*Y6*Z6*dq12*m_6*C5*C6*S2*S3*S4 - 2*Y6*Z6*dq13*m_6*C5*C6*S2*S3*S4 - 2*Y6*Z6*dq15*m_6*C2*C6*S3*S4*S5 - 2*Y6*Z6*dq15*m_6*C3*C6*S2*S4*S5 - 2*Y6*Z6*dq16*m_6*C5*C6*S2*S3*S5 - 4*Y6*Z6*dq23*m_6*C4*C5*S4*S5*S6 + 4*Ixx6*dq11*C2*C3*CC4*C5*C6*S2*S3*S6 - 4*Iyy6*dq11*C2*C3*CC4*C5*C6*S2*S3*S6 - 2*XX5*dq11*m_5*C2*C3*C4*CC5*S2*S3*S4 - 2*XX6*dq11*m_6*C2*C3*C4*CC6*S2*S3*S4 - 2*XX6*dq11*m_6*C2*CC3*C4*C6*S2*S5*S6 - 2*XX6*dq11*m_6*CC2*C3*C4*C6*S3*S5*S6 - 2*YY6*dq11*m_6*C2*C3*C4*CC5*S2*S3*S4 + 2*YY6*dq11*m_6*C2*C3*C4*CC6*S2*S3*S4 + 2*YY6*dq11*m_6*C2*CC3*C4*C6*S2*S5*S6 + 2*YY6*dq11*m_6*CC2*C3*C4*C6*S3*S5*S6 + 2*ZZ5*dq11*m_5*C2*C3*C4*CC5*S2*S3*S4 + 2*ZZ6*dq11*m_6*C2*C3*C4*CC5*S2*S3*S4 - 2*Y6*d4*dq12*m_6*C4*C5*S2*S3*S6 - 2*Y6*d4*dq13*m_6*C4*C5*S2*S3*S6 - 2*Y6*d6*dq12*m_6*C5*C6*S2*S3*S4 - 2*Y6*d6*dq13*m_6*C5*C6*S2*S3*S4 - 2*Y6*d6*dq15*m_6*C2*C6*S3*S4*S5 - 2*Y6*d6*dq15*m_6*C3*C6*S2*S4*S5 - 2*Y6*d6*dq16*m_6*C5*C6*S2*S3*S5 - 4*Y6*d6*dq23*m_6*C4*C5*S4*S5*S6 + 4*Z6*d6*dq12*m_6*C4*C5*S2*S3*S5 + 4*Z6*d6*dq13*m_6*C4*C5*S2*S3*S5 + 2*Y6*Z6*dq11*m_6*C2*CC3*C4*C5*C6*S2 + 2*Y6*Z6*dq11*m_6*CC2*C3*C4*C5*C6*S3 - 2*X6*Z6*dq12*m_6*C5*S2*S3*S4*S6 - 2*X6*Z6*dq13*m_6*C5*S2*S3*S4*S6 - 2*X6*Z6*dq15*m_6*C2*S3*S4*S5*S6 - 2*X6*Z6*dq15*m_6*C3*S2*S4*S5*S6 - 2*X6*Z6*dq16*m_6*C5*S2*S3*S5*S6 - 4*Ixy6*dq11*C2*CC3*C5*C6*S2*S4*S5*S6 - 4*Ixy6*dq11*CC2*C3*C5*C6*S3*S4*S5*S6 + 2*dd6*dq11*m_6*C2*C3*C4*CC5*S2*S3*S4 + 2*XX6*dq12*m_6*C2*C3*C4*C5*CC6*S5 + 2*XX6*dq13*m_6*C2*C3*C4*C5*CC6*S5 + 2*Y6*d6*dq11*m_6*C2*CC3*C4*C5*C6*S2 + 2*Y6*d6*dq11*m_6*CC2*C3*C4*C5*C6*S3 - 2*X6*d6*dq12*m_6*C5*S2*S3*S4*S6 - 2*X6*d6*dq13*m_6*C5*S2*S3*S4*S6 - 2*X6*d6*dq15*m_6*C2*S3*S4*S5*S6 - 2*X6*d6*dq15*m_6*C3*S2*S4*S5*S6 - 2*X6*d6*dq16*m_6*C5*S2*S3*S5*S6 - 2*YY6*dq12*m_6*C2*C3*C4*C5*CC6*S5 - 2*YY6*dq13*m_6*C2*C3*C4*C5*CC6*S5 - 4*X5*Y5*dq11*m_5*C2*C3*CC4*C5*S2*S3 + 4*X6*Y6*dq11*m_6*C2*C3*CC4*C5*S2*S3 + 4*X6*Y6*dq11*m_6*C2*C3*C5*CC6*S2*S3 + 2*X6*Z6*dq11*m_6*C2*CC3*C4*C5*S2*S6 + 2*X6*Z6*dq11*m_6*CC2*C3*C4*C5*S3*S6 - 2*X6*Z6*dq11*m_6*CC2*C4*C5*C6*S4*S5 - 2*X6*Z6*dq11*m_6*CC3*C4*C5*C6*S4*S5 + 2*X6*d4*dq11*m_6*C2*CC3*C5*C6*S2*S4 + 2*X6*d4*dq11*m_6*CC2*C3*C5*C6*S3*S4 + 2*X6*d6*dq11*m_6*C2*CC3*C4*C5*S2*S6 + 2*X6*d6*dq11*m_6*CC2*C3*C4*C5*S3*S6 - 2*X6*d6*dq11*m_6*CC2*C4*C5*C6*S4*S5 - 2*X6*d6*dq11*m_6*CC3*C4*C5*C6*S4*S5 - 4*X6*Z6*dq12*m_6*C2*C3*C4*CC5*C6 - 4*X6*Z6*dq13*m_6*C2*C3*C4*CC5*C6 - 4*Y5*Z5*dq11*m_5*C2*C3*CC4*S2*S3*S5 + 2*Y6*Z6*dq11*m_6*CC2*C4*C5*S4*S5*S6 + 2*Y6*Z6*dq11*m_6*CC3*C4*C5*S4*S5*S6 - 2*XX6*dq12*m_6*C4*C5*CC6*S2*S3*S5 - 2*XX6*dq13*m_6*C4*C5*CC6*S2*S3*S5 - 4*X6*d6*dq12*m_6*C2*C3*C4*CC5*C6 - 4*X6*d6*dq13*m_6*C2*C3*C4*CC5*C6 - 2*Y6*d4*dq11*m_6*C2*CC3*C5*S2*S4*S6 - 2*Y6*d4*dq11*m_6*CC2*C3*C5*S3*S4*S6 + 2*Y6*d6*dq11*m_6*CC2*C4*C5*S4*S5*S6 + 2*Y6*d6*dq11*m_6*CC3*C4*C5*S4*S5*S6 + 2*YY6*dq12*m_6*C4*C5*CC6*S2*S3*S5 + 2*YY6*dq13*m_6*C4*C5*CC6*S2*S3*S5 + 4*Z6*d6*dq11*m_6*C2*CC3*C5*S2*S4*S5 + 4*Z6*d6*dq11*m_6*CC2*C3*C5*S3*S4*S5 + 4*Y6*Z6*dq12*m_6*C2*C3*C4*CC5*S6 + 4*Y6*Z6*dq13*m_6*C2*C3*C4*CC5*S6 + 2*Y6*Z6*dq16*m_6*C2*C4*CC5*C6*S3 + 2*Y6*Z6*dq16*m_6*C3*C4*CC5*C6*S2 + 4*Y6*d6*dq12*m_6*C2*C3*C4*CC5*S6 + 4*Y6*d6*dq13*m_6*C2*C3*C4*CC5*S6 + 2*Y6*d6*dq16*m_6*C2*C4*CC5*C6*S3 + 2*Y6*d6*dq16*m_6*C3*C4*CC5*C6*S2 - 4*X6*Y6*dq12*m_6*C2*C3*CC6*S4*S5 - 4*X6*Y6*dq12*m_6*C2*CC4*C6*S3*S6 - 4*X6*Y6*dq12*m_6*C3*CC4*C6*S2*S6 - 4*X6*Y6*dq13*m_6*C2*C3*CC6*S4*S5 - 4*X6*Y6*dq13*m_6*C2*CC4*C6*S3*S6 - 4*X6*Y6*dq13*m_6*C3*CC4*C6*S2*S6 - 4*X6*Y6*dq15*m_6*C2*C5*CC6*S3*S4 - 4*X6*Y6*dq15*m_6*C3*C5*CC6*S2*S4 - 4*X6*Y6*dq23*m_6*C4*CC5*C6*S4*S6 + 4*X5*Z5*dq12*m_5*C2*CC4*C5*S3*S5 + 4*X5*Z5*dq12*m_5*C3*CC4*C5*S2*S5 + 4*X5*Z5*dq13*m_5*C2*CC4*C5*S3*S5 + 4*X5*Z5*dq13*m_5*C3*CC4*C5*S2*S5 + 4*X6*Z6*dq12*m_6*C4*CC5*C6*S2*S3 + 4*X6*Z6*dq13*m_6*C4*CC5*C6*S2*S3 + 2*X6*Z6*dq16*m_6*C2*C4*CC5*S3*S6 + 2*X6*Z6*dq16*m_6*C3*C4*CC5*S2*S6 + 4*X6*d6*dq12*m_6*C4*CC5*C6*S2*S3 + 4*X6*d6*dq13*m_6*C4*CC5*C6*S2*S3 + 2*X6*d6*dq16*m_6*C2*C4*CC5*S3*S6 + 2*X6*d6*dq16*m_6*C3*C4*CC5*S2*S6 - 4*Y6*Z6*dq12*m_6*C4*CC5*S2*S3*S6 - 4*Y6*Z6*dq13*m_6*C4*CC5*S2*S3*S6 + 2*Ixx6*dq11*C2*C3*C4*CC5*CC6*S2*S3*S4 - 2*Iyy6*dq11*C2*C3*C4*CC5*CC6*S2*S3*S4 - 4*Y6*Z6*dq11*m_6*CC2*CC3*C4*C5*S4*S5*S6 - 4*Y6*d6*dq11*m_6*CC2*CC3*C4*C5*S4*S5*S6 - 4*X6*Y6*dq12*m_6*C2*CC4*CC5*C6*S3*S6 - 4*X6*Y6*dq12*m_6*C3*CC4*CC5*C6*S2*S6 - 4*X6*Y6*dq13*m_6*C2*CC4*CC5*C6*S3*S6 - 4*X6*Y6*dq13*m_6*C3*CC4*CC5*C6*S2*S6 + 4*Ixz6*dq11*C2*C3*C4*C5*C6*S2*S3*S4*S5 - 4*Iyz6*dq11*C2*C3*C4*C5*S2*S3*S4*S5*S6 - 2*X6*a3*dq11*m_6*C2*C3*C5*C6*S2*S3*S4 - 4*XX6*dq12*m_6*C2*C4*C5*C6*S3*S4*S6 - 4*XX6*dq12*m_6*C3*C4*C5*C6*S2*S4*S6 - 4*XX6*dq13*m_6*C2*C4*C5*C6*S3*S4*S6 - 4*XX6*dq13*m_6*C3*C4*C5*C6*S2*S4*S6 - 2*XX6*dq16*m_6*C2*C4*C5*C6*S3*S5*S6 - 2*XX6*dq16*m_6*C3*C4*C5*C6*S2*S5*S6 + 4*YY6*dq12*m_6*C2*C4*C5*C6*S3*S4*S6 + 4*YY6*dq12*m_6*C3*C4*C5*C6*S2*S4*S6 + 4*YY6*dq13*m_6*C2*C4*C5*C6*S3*S4*S6 + 4*YY6*dq13*m_6*C3*C4*C5*C6*S2*S4*S6 + 2*YY6*dq16*m_6*C2*C4*C5*C6*S3*S5*S6 + 2*YY6*dq16*m_6*C3*C4*C5*C6*S2*S5*S6 - 4*X6*Y6*dq11*m_6*CC2*CC3*C4*CC5*C6*S4*S6 - 2*X6*Y6*dq11*m_6*C2*C5*C6*S2*S4*S5*S6 - 2*X6*Y6*dq11*m_6*C3*C5*C6*S3*S4*S5*S6 + 2*Y6*a3*dq11*m_6*C2*C3*C5*S2*S3*S4*S6 - 4*X6*Y6*dq15*m_6*C2*C3*C5*C6*S5*S6 + 4*X6*Z6*dq15*m_6*C2*C4*C5*C6*S3*S5 + 4*X6*Z6*dq15*m_6*C3*C4*C5*C6*S2*S5
 + 4*X6*d6*dq15*m_6*C2*C4*C5*C6*S3*S5 + 4*X6*d6*dq15*m_6*C3*C4*C5*C6*S2*S5 - 4*Y6*Z6*dq12*m_6*C2*C4*C6*S3*S4*S5 - 4*Y6*Z6*dq12*m_6*C3*C4*C6*S2*S4*S5 - 4*Y6*Z6*dq13*m_6*C2*C4*C6*S3*S4*S5 - 4*Y6*Z6*dq13*m_6*C3*C4*C6*S2*S4*S5 - 4*Y6*Z6*dq15*m_6*C2*C4*C5*S3*S5*S6 - 4*Y6*Z6*dq15*m_6*C3*C4*C5*S2*S5*S6 - 4*XX6*dq11*m_6*C2*C3*CC4*C5*C6*S2*S3*S6 + 4*YY6*dq11*m_6*C2*C3*CC4*C5*C6*S2*S3*S6 - 4*Y6*d6*dq12*m_6*C2*C4*C6*S3*S4*S5 - 4*Y6*d6*dq12*m_6*C3*C4*C6*S2*S4*S5 - 4*Y6*d6*dq13*m_6*C2*C4*C6*S3*S4*S5 - 4*Y6*d6*dq13*m_6*C3*C4*C6*S2*S4*S5 - 4*Y6*d6*dq15*m_6*C2*C4*C5*S3*S5*S6 - 4*Y6*d6*dq15*m_6*C3*C4*C5*S2*S5*S6 + 4*X6*Y6*dq15*m_6*C5*C6*S2*S3*S5*S6 + 4*X6*Y6*dq16*m_6*C2*C6*S3*S4*S5*S6 + 4*X6*Y6*dq16*m_6*C3*C6*S2*S4*S5*S6 - 4*X6*Z6*dq12*m_6*C2*C4*S3*S4*S5*S6 - 4*X6*Z6*dq12*m_6*C3*C4*S2*S4*S5*S6 - 4*X6*Z6*dq13*m_6*C2*C4*S3*S4*S5*S6 - 4*X6*Z6*dq13*m_6*C3*C4*S2*S4*S5*S6 - 4*Ixy6*dq11*C2*C3*C4*CC5*C6*S2*S3*S4*S6 - 4*X6*d6*dq12*m_6*C2*C4*S3*S4*S5*S6 - 4*X6*d6*dq12*m_6*C3*C4*S2*S4*S5*S6 - 4*X6*d6*dq13*m_6*C2*C4*S3*S4*S5*S6 - 4*X6*d6*dq13*m_6*C3*C4*S2*S4*S5*S6 - 4*Y6*Z6*dq11*m_6*C2*C3*CC4*C6*S2*S3*S5 - 4*Y6*d6*dq11*m_6*C2*C3*CC4*C6*S2*S3*S5 + 4*Z6*d6*dq11*m_6*C2*C3*C4*CC5*S2*S3*S4 - 4*X6*Z6*dq11*m_6*C2*C3*CC4*S2*S3*S5*S6 - 4*X6*d6*dq11*m_6*C2*C3*CC4*S2*S3*S5*S6 - 8*X6*Y6*dq12*m_6*C2*C4*C5*CC6*S3*S4 - 8*X6*Y6*dq12*m_6*C3*C4*C5*CC6*S2*S4 - 8*X6*Y6*dq13*m_6*C2*C4*C5*CC6*S3*S4 - 8*X6*Y6*dq13*m_6*C3*C4*C5*CC6*S2*S4 - 4*X6*Y6*dq15*m_6*C2*C4*CC5*C6*S3*S6 - 4*X6*Y6*dq15*m_6*C3*C4*CC5*C6*S2*S6 - 4*X6*Y6*dq16*m_6*C2*C4*C5*CC6*S3*S5 - 4*X6*Y6*dq16*m_6*C3*C4*C5*CC6*S2*S5 + 4*X6*Z6*dq12*m_6*C2*CC4*C5*C6*S3*S5 + 4*X6*Z6*dq12*m_6*C3*CC4*C5*C6*S2*S5 + 4*X6*Z6*dq13*m_6*C2*CC4*C5*C6*S3*S5 + 4*X6*Z6*dq13*m_6*C3*CC4*C5*C6*S2*S5 + 4*X6*d6*dq12*m_6*C2*CC4*C5*C6*S3*S5 + 4*X6*d6*dq12*m_6*C3*CC4*C5*C6*S2*S5 + 4*X6*d6*dq13*m_6*C2*CC4*C5*C6*S3*S5 + 4*X6*d6*dq13*m_6*C3*CC4*C5*C6*S2*S5 - 4*Y6*Z6*dq12*m_6*C2*CC4*C5*S3*S5*S6 - 4*Y6*Z6*dq12*m_6*C3*CC4*C5*S2*S5*S6 - 4*Y6*Z6*dq13*m_6*C2*CC4*C5*S3*S5*S6 - 4*Y6*Z6*dq13*m_6*C3*CC4*C5*S2*S5*S6 - 2*XX6*dq11*m_6*C2*C3*C4*CC5*CC6*S2*S3*S4 + 2*YY6*dq11*m_6*C2*C3*C4*CC5*CC6*S2*S3*S4 - 4*Y6*d6*dq12*m_6*C2*CC4*C5*S3*S5*S6 - 4*Y6*d6*dq12*m_6*C3*CC4*C5*S2*S5*S6 - 4*Y6*d6*dq13*m_6*C2*CC4*C5*S3*S5*S6 - 4*Y6*d6*dq13*m_6*C3*CC4*C5*S2*S5*S6 - 8*X6*Y6*dq11*m_6*C2*C3*CC4*C5*CC6*S2*S3 + 4*X6*Z6*dq11*m_6*CC2*CC3*C4*C5*C6*S4*S5 + 4*X6*d6*dq11*m_6*CC2*CC3*C4*C5*C6*S4*S5 + 4*X6*Y6*dq11*m_6*C2*C3*C4*C6*S2*S3*S4*S6 - 4*X5*Z5*dq11*m_5*C2*C3*C4*C5*S2*S3*S4*S5 - 4*X6*Y6*dq12*m_6*C2*C3*C4*C5*C6*S5*S6 - 4*X6*Y6*dq13*m_6*C2*C3*C4*C5*C6*S5*S6 + 4*X6*Y6*dq12*m_6*C4*C5*C6*S2*S3*S5*S6 + 4*X6*Y6*dq13*m_6*C4*C5*C6*S2*S3*S5*S6 + 4*X6*Y6*dq11*m_6*C2*CC3*C5*C6*S2*S4*S5*S6 + 4*X6*Y6*dq11*m_6*CC2*C3*C5*C6*S3*S4*S5*S6 - 4*X6*d6*dq11*m_6*C2*C3*C4*C5*C6*S2*S3*S4*S5 + 4*Y6*Z6*dq11*m_6*C2*C3*C4*C5*S2*S3*S4*S5*S6 + 4*Y6*d6*dq11*m_6*C2*C3*C4*C5*S2*S3*S4*S5*S6 + 4*X6*Y6*dq11*m_6*C2*C3*C4*CC5*C6*S2*S3*S4*S6 - 4*X6*Z6*dq11*m_6*C2*C3*C4*C5*C6*S2*S3*S4*S5;
coriolis.array2d[4][0] = Ixz5*dq22 - Ixz5*dq11 + Ixz5*dq33 - Ixz5*dq44 - Ixz6*dq11*C6 + Ixz6*dq22*C6 + Ixz6*dq33*C6 - Ixz6*dq44*C6 + Ixz6*dq66*C6 + Iyz6*dq11*S6 - Iyz6*dq22*S6 - Iyz6*dq33*S6 + Iyz6*dq44*S6 - Iyz6*dq66*S6 - 2*Ixy6*dq56 + 2*Ixz5*dq23 + Ixz5*dq11*CC2 + Ixz5*dq11*CC3 + 2*Ixz5*dq11*CC5 - Ixz5*dq22*CC4 - 2*Ixz5*dq22*CC5 - Ixz5*dq33*CC4 - 2*Ixz5*dq33*CC5 + 2*Ixz5*dq44*CC5 - (Ixx5*dq11*S55)/2 + (Ixx5*dq22*S55)/2 + (Ixx5*dq33*S55)/2 - (Ixx5*dq44*S55)/2 - (Iyy6*dq11*S55)/2 + (Iyy6*dq22*S55)/2 + (Iyy6*dq33*S55)/2 - (Iyy6*dq44*S55)/2 + (Izz5*dq11*S55)/2 - (Izz5*dq22*S55)/2 + (Izz6*dq11*S55)/2 - (Izz5*dq33*S55)/2 - (Izz6*dq22*S55)/2 + (Izz5*dq44*S55)/2 - (Izz6*dq33*S55)/2 + (Izz6*dq44*S55)/2 + X5*Z5*dq11*m_5 - X5*Z5*dq22*m_5 - X5*Z5*dq33*m_5 + X5*Z5*dq44*m_5 - 2*Ixy6*dq26*C4 - 2*Ixy6*dq36*C4 + 2*Ixz6*dq23*C6 - Ixx5*dq24*S4 - Ixx5*dq34*S4 - Ixx6*dq24*S4 - Ixx6*dq34*S4 + Ixx6*dq46*S5 - Iyy5*dq24*S4 - Iyy5*dq34*S4 - Iyy6*dq24*S4 - Iyy6*dq34*S4 - Iyy6*dq46*S5 - 2*Iyz6*dq23*S6 + Izz5*dq24*S4 + Izz5*dq34*S4 + Izz6*dq24*S4 + Izz6*dq34*S4 + Izz6*dq46*S5 + Ixz6*dq11*CC2*C6 + Ixz6*dq11*CC3*C6 + 2*Ixz6*dq11*CC5*C6 - Ixz6*dq22*CC4*C6 - 2*Ixz6*dq22*CC5*C6 - Ixz6*dq33*CC4*C6 - 2*Ixz6*dq33*CC5*C6 + 2*Ixz6*dq44*CC5*C6 - Iyz6*dq11*CC2*S6 - Iyz6*dq11*CC3*S6 - 2*Iyz6*dq11*CC5*S6 + Iyz6*dq22*CC4*S6 + 2*Iyz6*dq22*CC5*S6 + Iyz6*dq33*CC4*S6 + 2*Iyz6*dq33*CC5*S6 - 2*Iyz6*dq44*CC5*S6 + (XX5*dq11*m_5*S55)/2 - (XX5*dq22*m_5*S55)/2 - (XX5*dq33*m_5*S55)/2 + (XX5*dq44*m_5*S55)/2 + (YY6*dq11*m_6*S55)/2 - (YY6*dq22*m_6*S55)/2 - (YY6*dq33*m_6*S55)/2 + (YY6*dq44*m_6*S55)/2 - (ZZ5*dq11*m_5*S55)/2 + (ZZ5*dq22*m_5*S55)/2 + (ZZ5*dq33*m_5*S55)/2 - (ZZ6*dq11*m_6*S55)/2 - (ZZ5*dq44*m_5*S55)/2 + (ZZ6*dq22*m_6*S55)/2 + (ZZ6*dq33*m_6*S55)/2 - (ZZ6*dq44*m_6*S55)/2 - (dd6*dq11*m_6*S55)/2 + (dd6*dq22*m_6*S55)/2 + (dd6*dq33*m_6*S55)/2 - (dd6*dq44*m_6*S55)/2 + 4*Ixy6*dq56*CC6 - 2*Ixz5*dq23*CC4 - 4*Ixz5*dq23*CC5 + Ixx5*dq23*S55 + Ixx6*dq56*S66 + Iyy6*dq23*S55 - Iyy6*dq56*S66 - Izz5*dq23*S55 - Izz6*dq23*S55 - 2*Ixz5*dq11*CC2*CC3 + Ixz5*dq11*CC2*CC4 - 2*Ixz5*dq11*CC2*CC5 + Ixz5*dq11*CC3*CC4 - 2*Ixz5*dq11*CC3*CC5 + 2*Ixz5*dq22*CC4*CC5 + 2*Ixz5*dq33*CC4*CC5 - 2*Ixz5*dq11*CC2*CC3*CC4 + 4*Ixz5*dq11*CC2*CC3*CC5 - 2*Ixz5*dq11*CC2*CC4*CC5 - 2*Ixz5*dq11*CC3*CC4*CC5 + Ixy5*dq22*C4*S4*S5 + Ixy5*dq33*C4*S4*S5 - Ixy6*dq22*C4*S4*S5 - Ixy6*dq33*C4*S4*S5 + X6*Z6*dq11*m_6*C6 - X6*Z6*dq22*m_6*C6 - X6*Z6*dq33*m_6*C6 + X6*Z6*dq44*m_6*C6 - X6*Z6*dq66*m_6*C6 + 2*Ixy5*dq24*C4*C5 + 2*Ixy5*dq34*C4*C5 - 2*Ixy6*dq24*C4*C5 - 2*Ixy6*dq34*C4*C5 + 2*Ixz5*dq14*C2*C3 + 2*Ixz6*dq46*C5*C6 + X5*d4*dq22*m_5*C5 + X5*d4*dq33*m_5*C5 + X6*d6*dq11*m_6*C6 - X6*d6*dq22*m_6*C6 - X6*d6*dq33*m_6*C6 + X6*d6*dq44*m_6*C6 - X6*d6*dq66*m_6*C6 - Y6*Z6*dq11*m_6*S6 + Y6*Z6*dq22*m_6*S6 + Y6*Z6*dq33*m_6*S6 - Y6*Z6*dq44*m_6*S6 + Y6*Z6*dq66*m_6*S6 - Ixx6*dq26*C5*S4 - Ixx6*dq36*C5*S4 + Iyy6*dq26*C5*S4 + Iyy6*dq36*C5*S4 + 2*Iyz5*dq24*C4*S5 + 2*Iyz5*dq34*C4*S5 - 2*Iyz6*dq46*C5*S6 - Izz6*dq26*C5*S4 - Izz6*dq36*C5*S4 - Y6*d6*dq11*m_6*S6 + Y6*d6*dq22*m_6*S6 + Y6*d6*dq33*m_6*S6 - Y6*d6*dq44*m_6*S6 + Y6*d6*dq66*m_6*S6 + 2*YY6*dq46*m_6*S5 + Z5*d4*dq22*m_5*S5 + Z5*d4*dq33*m_5*S5 + Z6*d4*dq22*m_6*S5 + Z6*d4*dq33*m_6*S5 - 2*ZZ5*dq24*m_5*S4 - 2*ZZ5*dq34*m_5*S4 - 2*ZZ6*dq24*m_6*S4 - 2*ZZ6*dq34*m_6*S4 - 2*Ixz5*dq14*S2*S3 + d4*d6*dq22*m_6*S5 + d4*d6*dq33*m_6*S5 - 2*dd6*dq24*m_6*S4 - 2*dd6*dq34*m_6*S4 + 2*X6*Y6*dq56*m_6 - 2*X5*Z5*dq23*m_5 + Ixx5*dq11*CC2*C5*S5 + Ixx5*dq11*CC3*C5*S5 - Ixx5*dq22*CC4*C5*S5 - Ixx5*dq33*CC4*C5*S5 - Ixx6*dq11*C5*CC6*S5 + Ixx6*dq22*C5*CC6*S5 + Ixx6*dq33*C5*CC6*S5 - Ixx6*dq44*C5*CC6*S5 + Iyy6*dq11*CC2*C5*S5 + Iyy6*dq11*CC3*C5*S5 - Iyy6*dq22*CC4*C5*S5 + Iyy6*dq11*C5*CC6*S5 - Iyy6*dq33*CC4*C5*S5 - Iyy6*dq22*C5*CC6*S5 - Iyy6*dq33*C5*CC6*S5 + Iyy6*dq44*C5*CC6*S5 - Izz5*dq11*CC2*C5*S5 - Izz5*dq11*CC3*C5*S5 - Izz6*dq11*CC2*C5*S5 - Izz6*dq11*CC3*C5*S5 + Izz5*dq22*CC4*C5*S5 + Izz5*dq33*CC4*C5*S5 + Izz6*dq22*CC4*C5*S5 + Izz6*dq33*CC4*C5*S5 - X5*Z5*dq11*m_5*CC2 - X5*Z5*dq11*m_5*CC3 - 2*X5*Z5*dq11*m_5*CC5 + X5*Z5*dq22*m_5*CC4 + 2*X5*Z5*dq22*m_5*CC5 + X5*Z5*dq33*m_5*CC4 + 2*X5*Z5*dq33*m_5*CC5 - 2*X5*Z5*dq44*m_5*CC5 + 4*Ixy6*dq26*C4*CC6 + 4*Ixy6*dq36*C4*CC6 - 2*Ixz6*dq23*CC4*C6 - 4*Ixz6*dq23*CC5*C6 + 2*Ixx5*dq24*CC5*S4 + 2*Ixx5*dq34*CC5*S4 - 2*Ixx6*dq46*CC6*S5 + 2*Iyy6*dq24*CC5*S4 + 2*Iyy6*dq34*CC5*S4 + 2*Iyy6*dq46*CC6*S5 + 2*Iyz6*dq23*CC4*S6 + 4*Iyz6*dq23*CC5*S6 - 2*Izz5*dq24*CC5*S4 - 2*Izz5*dq34*CC5*S4 - 2*Izz6*dq24*CC5*S4 - 2*Izz6*dq34*CC5*S4 - XX5*dq23*m_5*S55 - XX6*dq56*m_6*S66 - YY6*dq23*m_6*S55 + YY6*dq56*m_6*S66 - Z6*d6*dq11*m_6*S55 + Z6*d6*dq22*m_6*S55 + Z6*d6*dq33*m_6*S55 - Z6*d6*dq44*m_6*S55 + ZZ5*dq23*m_5*S55 + ZZ6*dq23*m_6*S55 + dd6*dq23*m_6*S55 - 2*Ixz6*dq11*CC2*CC3*C6 + Ixz6*dq11*CC2*CC4*C6 - 2*Ixz6*dq11*CC2*CC5*C6 + Ixz6*dq11*CC3*CC4*C6 - 2*Ixz6*dq11*CC3*CC5*C6 + 2*Ixz6*dq22*CC4*CC5*C6 + 2*Ixz6*dq33*CC4*CC5*C6 + 2*Iyz6*dq11*CC2*CC3*S6 - Iyz6*dq11*CC2*CC4*S6 + 2*Iyz6*dq11*CC2*CC5*S6 - Iyz6*dq11*CC3*CC4*S6 + 2*Iyz6*dq11*CC3*CC5*S6 - 2*Iyz6*dq22*CC4*CC5*S6 - 2*Iyz6*dq33*CC4*CC5*S6 + 4*Ixz5*dq23*CC4*CC5 - Ixx5*dq11*C2*C4*S2 - Ixx5*dq11*C3*C4*S3 - Iyy6*dq11*C2*C4*S2 - Iyy6*dq11*C3*C4*S3 - Iyz5*dq22*C4*C5*S4 - Iyz5*dq33*C4*C5*S4 + Izz5*dq11*C2*C4*S2 + Izz6*dq11*C2*C4*S2 + Izz5*dq11*C3*C4*S3 + Izz6*dq11*C3*C4*S3 + X5*a2*dq22*m_5*C5*S3 + X5*a3*dq11*m_5*C4*S5 + X5*a3*dq22*m_5*C4*S5 + X5*a3*dq33*m_5*C4*S5 - Y6*d4*dq22*m_6*C5*S6 - Y6*d4*dq33*m_6*C5*S6 - 2*YY6*dq26*m_6*C5*S4 - 2*YY6*dq36*m_6*C5*S4 - 2*Ixy5*dq12*C2*S3*S5 - 2*Ixy5*dq12*C3*S2*S5 - 2*Ixy5*dq13*C2*S3*S5 - 2*Ixy5*dq13*C3*S2*S5 + 2*Ixy6*dq12*C2*S3*S5 + 2*Ixy6*dq12*C3*S2*S5 + 2*Ixy6*dq13*C2*S3*S5 + 2*Ixy6*dq13*C3*S2*S5 + 2*Ixy6*dq16*C2*S3*S4 + 2*Ixy6*dq16*C3*S2*S4 + 2*Ixy5*dq23*C4*S4*S5 - 2*Ixy6*dq23*C4*S4*S5 + 4*Ixy6*dq46*C6*S5*S6 - 2*Ixz6*dq14*C6*S2*S3 + 4*Ixz5*dq24*C5*S4*S5 + 4*Ixz5*dq34*C5*S4*S5 + 2*Ixz6*dq24*C4*S5*S6 + 2*Ixz6*dq34*C4*S5*S6 + 2*Ixz6*dq26*C6*S4*S5 + 2*Ixz6*dq36*C6*S4*S5 + Z5*a2*dq22*m_5*S3*S5 + Z6*a2*dq22*m_6*S3*S5 + 2*X6*Y6*dq26*m_6*C4 + 2*X6*Y6*dq36*m_6*C4 - 2*X6*Z6*dq23*m_6*C6 + a2*d6*dq22*m_6*S3*S5 - Ixx5*dq12*S2*S3*S4 - Ixx5*dq13*S2*S3*S4 + Ixx6*dq12*S2*S3*S4 + Ixx6*dq13*S2*S3*S4 + Ixx6*dq16*S2*S3*S5 + Iyy5*dq12*S2*S3*S4 + Iyy5*dq13*S2*S3*S4 - Iyy6*dq12*S2*S3*S4 - Iyy6*dq13*S2*S3*S4 - Iyy6*dq16*S2*S3*S5 + 2*Iyz6*dq14*S2*S3*S6 - 2*Iyz6*dq26*S4*S5*S6 - 2*Iyz6*dq36*S4*S5*S6 + Izz5*dq12*S2*S3*S4 + Izz5*dq13*S2*S3*S4 + Izz6*dq12*S2*S3*S4 + Izz6*dq13*S2*S3*S4 + Izz6*dq16*S2*S3*S5 + 2*X5*d4*dq23*m_5*C5 - 2*X6*d6*dq23*m_6*C6 + 2*Y6*Z6*dq23*m_6*S6 + 2*Ixx5*dq11*C2*CC3*C4*S2 + 2*Ixx5*dq11*CC2*C3*C4*S3 + 2*Ixx5*dq11*C2*C4*CC5*S2 + 2*Ixx5*dq11*C3*C4*CC5*S3 - Ixx6*dq11*C2*C4*CC6*S2 - Ixx6*dq11*C3*C4*CC6*S3 + 2*Iyy6*dq11*C2*CC3*C4*S2 + 2*Iyy6*dq11*CC2*C3*C4*S3 + 2*Iyy6*dq11*C2*C4*CC5*S2 + Iyy6*dq11*C2*C4*CC6*S2 + 2*Iyy6*dq11*C3*C4*CC5*S3 + Iyy6*dq11*C3*C4*CC6*S3 + Iyz5*dq11*CC2*C4*C5*S4 + Iyz5*dq11*CC3*C4*C5*S4 - 2*Izz5*dq11*C2*CC3*C4*S2 - 2*Izz5*dq11*CC2*C3*C4*S3 - 2*Izz6*dq11*C2*CC3*C4*S2 - 2*Izz5*dq11*C2*C4*CC5*S2 - 2*Izz6*dq11*CC2*C3*C4*S3 - 2*Izz6*dq11*C2*C4*CC5*S2 - 2*Izz5*dq11*C3*C4*CC5*S3 - 2*Izz6*dq11*C3*C4*CC5*S3 - XX5*dq11*m_5*CC2*C5*S5 - XX5*dq11*m_5*CC3*C5*S5 + XX5*dq22*m_5*CC4*C5*S5 + XX5*dq33*m_5*CC4*C5*S5 + XX6*dq11*m_6*C5*CC6*S5 - XX6*dq22*m_6*C5*CC6*S5 - XX6*dq33*m_6*C5*CC6*S5 + XX6*dq44*m_6*C5*CC6*S5 - YY6*dq11*m_6*CC2*C5*S5 - YY6*dq11*m_6*CC3*C5*S5 + YY6*dq22*m_6*CC4*C5*S5 - YY6*dq11*m_6*C5*CC6*S5 + YY6*dq33*m_6*CC4*C5*S5 + YY6*dq22*m_6*C5*CC6*S5 + YY6*dq33*m_6*C5*CC6*S5 - YY6*dq44*m_6*C5*CC6*S5 + ZZ5*dq11*m_5*CC2*C5*S5 + ZZ5*dq11*m_5*CC3*C5*S5 + ZZ6*dq11*m_6*CC2*C5*S5 - ZZ5*dq22*m_5*CC4*C5*S5 + ZZ6*dq11*m_6*CC3*C5*S5 - ZZ5*dq33*m_5*CC4*C5*S5 - ZZ6*dq22*m_6*CC4*C5*S5 - ZZ6*dq33*m_6*CC4*C5*S5 + 2*Y6*d6*dq23*m_6*S6 + 2*Z5*d4*dq23*m_5*S5 + 2*Z6*d4*dq23*m_6*S5 - 4*Z6*d6*dq24*m_6*S4 - 4*Z6*d6*dq34*m_6*S4 + 4*Ixz5*dq11*CC2*CC3*CC4*CC5 - Ixy5*dq11*CC2*C4*S4*S5 - Ixy5*dq11*CC3*C4*S4*S5 + Ixy6*dq11*CC2*C4*S4*S5 + Ixy6*dq11*CC3*C4*S4*S5 + 2*Ixy6*dq22*C4*CC6*S4*S5 + 2*Ixy6*dq33*C4*CC6*S4*S5 + dd6*dq11*m_6*CC2*C5*S5 + dd6*dq11*m_6*CC3*C5*S5 - dd6*dq22*m_6*CC4*C5*S5 - dd6*dq33*m_6*CC4*C5*S5 + 2*d4*d6*dq23*m_6*S5 - X6*Z6*dq11*m_6*CC2*C6 - X6*Z6*dq11*m_6*CC3*C6 - 2*X6*Z6*dq11*m_6*CC5*C6 + X6*Z6*dq22*m_6*CC4*C6 + 2*X6*Z6*dq22*m_6*CC5*C6 + X6*Z6*dq33*m_6*CC4*C6 + 2*X6*Z6*dq33*m_6*CC5*C6 - 2*X6*Z6*dq44*m_6*CC5*C6 + 4*Ixy6*dq24*C4*C5*CC6 + 4*Ixy6*dq34*C4*C5*CC6 - 4*Ixz5*dq14*C2*C3*CC5 + X5*d4*dq11*m_5*CC2*C5 + X5*d4*dq11*m_5*CC3*C5 - X6*d6*dq11*m_6*CC2*C6 - X6*d6*dq11*m_6*CC3*C6 - 2*X6*d6*dq11*m_6*CC5*C6 + X6*d6*dq22*m_6*CC4*C6 + 2*X6*d6*dq22*m_6*CC5*C6 + X6*d6*dq33*m_6*CC4*C6 + 2*X6*d6*dq33*m_6*CC5*C6 - 2*X6*d6*dq44*m_6*CC5*C6 + Y6*Z6*dq11*m_6*CC2*S6 + Y6*Z6*dq11*m_6*CC3*S6 + 2*Y6*Z6*dq11*m_6*CC5*S6 - Y6*Z6*dq22*m_6*CC4*S6 - 2*Y6*Z6*dq22*m_6*CC5*S6 - Y6*Z6*dq33*m_6*CC4*S6 - 2*Y6*Z6*dq33*m_6*CC5*S6 + 2*Y6*Z6*dq44*m_6*CC5*S6 - 2*Ixx5*dq23*CC4*C5*S5 + 2*Ixx6*dq23*C5*CC6*S5 + 2*Ixx6*dq26*C5*CC6*S4 + 2*Ixx6*dq36*C5*CC6*S4 - 2*Iyy6*dq23*CC4*C5*S5 - 2*Iyy6*dq23*C5*CC6*S5 - 2*Iyy6*dq26*C5*CC6*S4 - 2*Iyy6*dq36*C5*CC6*S4 + 2*Izz5*dq23*CC4*C5*S5 + 2*Izz6*dq23*CC4*C5*S5 - 2*XX5*dq24*m_5*CC5*S4 - 2*XX5*dq34*m_5*CC5*S4 + 2*XX6*dq46*m_6*CC6*S5 + Y6*d6*dq11*m_6*CC2*S6 + Y6*d6*dq11*m_6*CC3*S6 + 2*Y6*d6*dq11*m_6*CC5*S6 - Y6*d6*dq22*m_6*CC4*S6 - 2*Y6*d6*dq22*m_6*CC5*S6 - Y6*d6*dq33*m_6*CC4*S6 - 2*Y6*d6*dq33*m_6*CC5*S6 + 2*Y6*d6*dq44*m_6*CC5*S6 - 2*YY6*dq24*m_6*CC5*S4 - 2*YY6*dq34*m_6*CC5*S4 - 2*YY6*dq46*m_6*CC6*S5 + Z5*d4*dq11*m_5*CC2*S5 + Z5*d4*dq11*m_5*CC3*S5 + Z6*d4*dq11*m_6*CC2*S5 + Z6*d4*dq11*m_6*CC3*S5 + 2*ZZ5*dq24*m_5*CC5*S4 + 2*ZZ5*dq34*m_5*CC5*S4 + 2*ZZ6*dq24*m_6*CC5*S4 + 2*ZZ6*dq34*m_6*CC5*S4 + 4*Ixz5*dq14*CC5*S2*S3 + d4*d6*dq11*m_6*CC2*S5 + d4*d6*dq11*m_6*CC3*S5 + 2*dd6*dq24*m_6*CC5*S4 + 2*dd6*dq34*m_6*CC5*S4 - 4*X6*Y6*dq56*m_6*CC6 + 2*X5*Z5*dq23*m_5*CC4 + 4*X5*Z5*dq23*m_5*CC5 - 2*Ixx5*dq11*CC2*CC3*C5*S5 + Ixx5*dq11*CC2*CC4*C5*S5 + Ixx5*dq11*CC3*CC4*C5*S5 + Ixx6*dq11*CC2*C5*CC6*S5 + Ixx6*dq11*CC3*C5*CC6*S5 - Ixx6*dq22*CC4*C5*CC6*S5 - Ixx6*dq33*CC4*C5*CC6*S5
 -
 2*Iyy6*dq11*CC2*CC3*C5*S5 + Iyy6*dq11*CC2*CC4*C5*S5 + Iyy6*dq11*CC3*CC4*C5*S5 - Iyy6*dq11*CC2*C5*CC6*S5 - Iyy6*dq11*CC3*C5*CC6*S5 + Iyy6*dq22*CC4*C5*CC6*S5 + Iyy6*dq33*CC4*C5*CC6*S5 + 2*Izz5*dq11*CC2*CC3*C5*S5 - Izz5*dq11*CC2*CC4*C5*S5 + 2*Izz6*dq11*CC2*CC3*C5*S5 - Izz5*dq11*CC3*CC4*C5*S5 - Izz6*dq11*CC2*CC4*C5*S5 - Izz6*dq11*CC3*CC4*C5*S5 + 2*Z6*d6*dq23*m_6*S55 + 2*X5*Z5*dq11*m_5*CC2*CC3 - X5*Z5*dq11*m_5*CC2*CC4 + 2*X5*Z5*dq11*m_5*CC2*CC5 - X5*Z5*dq11*m_5*CC3*CC4 + 2*X5*Z5*dq11*m_5*CC3*CC5 - 2*X5*Z5*dq22*m_5*CC4*CC5 - 2*X5*Z5*dq33*m_5*CC4*CC5 + 4*Ixz6*dq23*CC4*CC5*C6 + 2*Ixx6*dq24*CC5*CC6*S4 + 2*Ixx6*dq34*CC5*CC6*S4 - 2*Iyy6*dq24*CC5*CC6*S4 - 2*Iyy6*dq34*CC5*CC6*S4 - 4*Iyz6*dq23*CC4*CC5*S6 - Iyz6*dq22*C4*C5*C6*S4 - Iyz6*dq33*C4*C5*C6*S4 + XX5*dq11*m_5*C2*C4*S2 + XX5*dq11*m_5*C3*C4*S3 + YY6*dq11*m_6*C2*C4*S2 + YY6*dq11*m_6*C3*C4*S3 - ZZ5*dq11*m_5*C2*C4*S2 - ZZ5*dq11*m_5*C3*C4*S3 - ZZ6*dq11*m_6*C2*C4*S2 - ZZ6*dq11*m_6*C3*C4*S3 - 2*Ixz6*dq11*CC2*CC3*CC4*C6 + 4*Ixz6*dq11*CC2*CC3*CC5*C6 - 2*Ixz6*dq11*CC2*CC4*CC5*C6 - 2*Ixz6*dq11*CC3*CC4*CC5*C6 - Ixy5*dq11*C2*C5*S2*S4 + Ixy6*dq11*C2*C5*S2*S4 - Ixy5*dq11*C3*C5*S3*S4 + Ixy6*dq11*C3*C5*S3*S4 + 2*Ixy6*dq11*C5*C6*S5*S6 - 2*Ixy6*dq22*C5*C6*S5*S6 - 2*Ixy6*dq33*C5*C6*S5*S6 + 2*Ixy6*dq44*C5*C6*S5*S6 + 2*Ixz5*dq11*C2*C3*S2*S3 - Ixz6*dq22*C4*C5*S4*S6 - Ixz6*dq33*C4*C5*S4*S6 - dd6*dq11*m_6*C2*C4*S2 - dd6*dq11*m_6*C3*C4*S3 + 2*Iyz6*dq11*CC2*CC3*CC4*S6 - 4*Iyz6*dq11*CC2*CC3*CC5*S6 + 2*Iyz6*dq11*CC2*CC4*CC5*S6 + 2*Iyz6*dq11*CC3*CC4*CC5*S6 - Iyz5*dq11*C2*S2*S4*S5 - Iyz5*dq11*C3*S3*S4*S5 + 2*Ixz6*dq14*C2*C3*C6 - Z5*a3*dq11*m_5*C4*C5 - Z5*a3*dq22*m_5*C4*C5 - Z5*a3*dq33*m_5*C4*C5 - Z6*a3*dq11*m_6*C4*C5 - Z6*a3*dq22*m_6*C4*C5 - Z6*a3*dq33*m_6*C4*C5 + X6*d4*dq22*m_6*C5*C6 + X6*d4*dq33*m_6*C5*C6 - a3*d6*dq11*m_6*C4*C5 - a3*d6*dq22*m_6*C4*C5 - a3*d6*dq33*m_6*C4*C5 + Ixx5*dq12*C2*C3*S4 + Ixx5*dq13*C2*C3*S4 - Ixx6*dq12*C2*C3*S4 - Ixx5*dq14*C2*C4*S3 - Ixx5*dq14*C3*C4*S2 - Ixx6*dq13*C2*C3*S4 - Ixx6*dq14*C2*C4*S3 - Ixx6*dq14*C3*C4*S2 - Ixx6*dq16*C2*C3*S5 + 2*Ixx6*dq26*C4*C6*S6 + 2*Ixx6*dq36*C4*C6*S6 - Iyy5*dq12*C2*C3*S4 - Iyy5*dq13*C2*C3*S4 + Iyy6*dq12*C2*C3*S4 - Iyy5*dq14*C2*C4*S3 - Iyy5*dq14*C3*C4*S2 + Iyy6*dq13*C2*C3*S4 - Iyy6*dq14*C2*C4*S3 - Iyy6*dq14*C3*C4*S2 + Iyy6*dq16*C2*C3*S5 - 2*Iyy6*dq26*C4*C6*S6 - 2*Iyy6*dq36*C4*C6*S6 + 2*Iyz5*dq12*C2*C5*S3 + 2*Iyz5*dq12*C3*C5*S2 + 2*Iyz5*dq13*C2*C5*S3 + 2*Iyz5*dq13*C3*C5*S2 - 2*Iyz6*dq14*C2*C3*S6 - 2*Iyz5*dq23*C4*C5*S4 + 2*Iyz6*dq24*C4*C6*S5 + 2*Iyz6*dq34*C4*C6*S5 - Izz5*dq12*C2*C3*S4 - Izz5*dq13*C2*C3*S4 - Izz6*dq12*C2*C3*S4 + Izz5*dq14*C2*C4*S3 + Izz5*dq14*C3*C4*S2 - Izz6*dq13*C2*C3*S4 + Izz6*dq14*C2*C4*S3 + Izz6*dq14*C3*C4*S2 - Izz6*dq16*C2*C3*S5 - 2*Y5*Z5*dq24*m_5*C4*S5 - 2*Y5*Z5*dq34*m_5*C4*S5 + 2*Y6*Z6*dq46*m_6*C5*S6 + Iyz6*dq11*CC2*C4*C5*C6*S4 + Iyz6*dq11*CC3*C4*C5*C6*S4 - 2*a3*d6*dq23*m_6*C4*C5 + 2*X5*a3*dq23*m_5*C4*S5 - 2*XX5*dq11*m_5*C2*CC3*C4*S2 - 2*XX5*dq11*m_5*CC2*C3*C4*S3 - 2*XX5*dq11*m_5*C2*C4*CC5*S2 - 2*XX5*dq11*m_5*C3*C4*CC5*S3 + XX6*dq11*m_6*C2*C4*CC6*S2 + XX6*dq11*m_6*C3*C4*CC6*S3 - 2*YY6*dq11*m_6*C2*CC3*C4*S2 - 2*YY6*dq11*m_6*CC2*C3*C4*S3 - 2*YY6*dq11*m_6*C2*C4*CC5*S2 - YY6*dq11*m_6*C2*C4*CC6*S2 - 2*YY6*dq11*m_6*C3*C4*CC5*S3 - YY6*dq11*m_6*C3*C4*CC6*S3 + 2*ZZ5*dq11*m_5*C2*CC3*C4*S2 + 2*ZZ5*dq11*m_5*CC2*C3*C4*S3 + 2*ZZ5*dq11*m_5*C2*C4*CC5*S2 + 2*ZZ6*dq11*m_6*C2*CC3*C4*S2 + 2*ZZ6*dq11*m_6*CC2*C3*C4*S3 + 2*ZZ5*dq11*m_5*C3*C4*CC5*S3 + 2*ZZ6*dq11*m_6*C2*C4*CC5*S2 + 2*ZZ6*dq11*m_6*C3*C4*CC5*S3 - 2*Y6*d4*dq23*m_6*C5*S6 + 2*Y6*d6*dq46*m_6*C5*S6 + 2*X5*Z5*dq14*m_5*S2*S3 + 4*Ixz6*dq11*CC2*CC3*CC4*CC5*C6 + 2*Ixy5*dq11*C2*CC3*C5*S2*S4 + 2*Ixy5*dq11*CC2*C3*C5*S3*S4 - 2*Ixy6*dq11*C2*CC3*C5*S2*S4 - 2*Ixy6*dq11*CC2*C3*C5*S3*S4 - 2*Ixy6*dq11*C2*C5*CC6*S2*S4 - 2*Ixy6*dq11*C3*C5*CC6*S3*S4 - 2*Ixy6*dq11*CC2*C5*C6*S5*S6 - 2*Ixy6*dq11*CC3*C5*C6*S5*S6 + 2*Ixy6*dq22*CC4*C5*C6*S5*S6 + 2*Ixy6*dq33*CC4*C5*C6*S5*S6 + 2*Ixz5*dq11*C2*C3*CC4*S2*S3 - 4*Ixz5*dq11*C2*C3*CC5*S2*S3 + Ixz6*dq11*CC2*C4*C5*S4*S6 + Ixz6*dq11*CC3*C4*C5*S4*S6 + 2*dd6*dq11*m_6*C2*CC3*C4*S2 + 2*dd6*dq11*m_6*CC2*C3*C4*S3 + 2*dd6*dq11*m_6*C2*C4*CC5*S2 + 2*dd6*dq11*m_6*C3*C4*CC5*S3 - 4*Iyz6*dq11*CC2*CC3*CC4*CC5*S6 + 2*Iyz5*dq11*C2*CC3*S2*S4*S5 + 2*Iyz5*dq11*CC2*C3*S3*S4*S5 - 4*Ixz6*dq14*C2*C3*CC5*C6 + Z5*a3*dq11*m_5*CC2*C4*C5 + Z5*a3*dq11*m_5*CC3*C4*C5 + Z6*a3*dq11*m_6*CC2*C4*C5 + Z6*a3*dq11*m_6*CC3*C4*C5 + X6*d4*dq11*m_6*CC2*C5*C6 + X6*d4*dq11*m_6*CC3*C5*C6 + a3*d6*dq11*m_6*CC2*C4*C5 + a3*d6*dq11*m_6*CC3*C4*C5 - 2*Ixx5*dq12*C2*C3*CC5*S4 - 2*Ixx5*dq13*C2*C3*CC5*S4 + 2*Ixx5*dq14*C2*C4*CC5*S3 + 2*Ixx5*dq14*C3*C4*CC5*S2 + 2*Ixx6*dq12*C2*C3*CC6*S4 + 2*Ixx6*dq13*C2*C3*CC6*S4 + 2*Ixx6*dq16*C2*C3*CC6*S5 - 2*Iyy6*dq12*C2*C3*CC5*S4 - 2*Iyy6*dq12*C2*C3*CC6*S4 - 2*Iyy6*dq13*C2*C3*CC5*S4 - 2*Iyy6*dq13*C2*C3*CC6*S4 + 2*Iyy6*dq14*C2*C4*CC5*S3 + 2*Iyy6*dq14*C3*C4*CC5*S2 - 2*Iyy6*dq16*C2*C3*CC6*S5 - 2*Iyz5*dq12*C2*CC4*C5*S3 - 2*Iyz5*dq12*C3*CC4*C5*S2 - 2*Iyz5*dq13*C2*CC4*C5*S3 - 2*Iyz5*dq13*C3*CC4*C5*S2 + 4*Iyz6*dq14*C2*C3*CC5*S6 + 2*Izz5*dq12*C2*C3*CC5*S4 + 2*Izz5*dq13*C2*C3*CC5*S4 + 2*Izz6*dq12*C2*C3*CC5*S4 - 2*Izz5*dq14*C2*C4*CC5*S3 - 2*Izz5*dq14*C3*C4*CC5*S2 + 2*Izz6*dq13*C2*C3*CC5*S4 - 2*Izz6*dq14*C2*C4*CC5*S3 - 2*Izz6*dq14*C3*C4*CC5*S2 + X5*a2*dq11*m_5*CC2*C5*S3 - X5*a3*dq11*m_5*CC2*C4*S5 - X5*a3*dq11*m_5*CC3*C4*S5 + 2*XX5*dq23*m_5*CC4*C5*S5 - 2*XX6*dq23*m_6*C5*CC6*S5 - 2*XX6*dq26*m_6*C5*CC6*S4 - 2*XX6*dq36*m_6*C5*CC6*S4 - Y6*d4*dq11*m_6*CC2*C5*S6 - Y6*d4*dq11*m_6*CC3*C5*S6 + 2*YY6*dq23*m_6*CC4*C5*S5 + 2*YY6*dq23*m_6*C5*CC6*S5 + 2*YY6*dq26*m_6*C5*CC6*S4 + 2*YY6*dq36*m_6*C5*CC6*S4 + 2*Z6*d6*dq11*m_6*CC2*C5*S5 + 2*Z6*d6*dq11*m_6*CC3*C5*S5 - 2*Z6*d6*dq22*m_6*CC4*C5*S5 - 2*Z6*d6*dq33*m_6*CC4*C5*S5 - 2*ZZ5*dq23*m_5*CC4*C5*S5 - 2*ZZ6*dq23*m_6*CC4*C5*S5 + 2*Ixy5*dq12*C2*CC4*S3*S5 + 2*Ixy5*dq12*C3*CC4*S2*S5 + 2*Ixy5*dq13*C2*CC4*S3*S5 + 2*Ixy5*dq13*C3*CC4*S2*S5 - 2*Ixy6*dq12*C2*CC4*S3*S5 - 2*Ixy6*dq12*C3*CC4*S2*S5 - 2*Ixy6*dq13*C2*CC4*S3*S5 - 2*Ixy6*dq13*C3*CC4*S2*S5 - 4*Ixy6*dq12*C2*CC6*S3*S5 - 4*Ixy6*dq12*C3*CC6*S2*S5 - 4*Ixy6*dq13*C2*CC6*S3*S5 - 4*Ixy6*dq13*C3*CC6*S2*S5 - 4*Ixy6*dq16*C2*CC6*S3*S4 - 4*Ixy6*dq16*C3*CC6*S2*S4 + 4*Ixy6*dq23*C4*CC6*S4*S5 - 4*Ixy6*dq24*CC5*C6*S4*S6 - 4*Ixy6*dq34*CC5*C6*S4*S6 + 4*Ixz6*dq14*CC5*C6*S2*S3 - 2*dd6*dq23*m_6*CC4*C5*S5 + Z5*a2*dq11*m_5*CC2*S3*S5 + Z6*a2*dq11*m_6*CC2*S3*S5 - 4*X6*Y6*dq26*m_6*C4*CC6 - 4*X6*Y6*dq36*m_6*C4*CC6 + 2*X6*Z6*dq23*m_6*CC4*C6 + 4*X6*Z6*dq23*m_6*CC5*C6 + a2*d6*dq11*m_6*CC2*S3*S5 + 2*Ixx5*dq12*CC5*S2*S3*S4 + 2*Ixx5*dq13*CC5*S2*S3*S4 - 2*Ixx6*dq12*CC6*S2*S3*S4 - 2*Ixx6*dq13*CC6*S2*S3*S4 - 2*Ixx6*dq16*CC6*S2*S3*S5 + 2*Iyy6*dq12*CC5*S2*S3*S4 + 2*Iyy6*dq12*CC6*S2*S3*S4 + 2*Iyy6*dq13*CC5*S2*S3*S4 + 2*Iyy6*dq13*CC6*S2*S3*S4 + 2*Iyy6*dq16*CC6*S2*S3*S5 - 4*Iyz6*dq14*CC5*S2*S3*S6 - 2*Izz5*dq12*CC5*S2*S3*S4 - 2*Izz5*dq13*CC5*S2*S3*S4 - 2*Izz6*dq12*CC5*S2*S3*S4 - 2*Izz6*dq13*CC5*S2*S3*S4 + 2*X6*d6*dq23*m_6*CC4*C6 + 4*X6*d6*dq23*m_6*CC5*C6 - 2*Y6*Z6*dq23*m_6*CC4*S6 - 4*Y6*Z6*dq23*m_6*CC5*S6 - 4*Ixx5*dq11*C2*CC3*C4*CC5*S2 - 4*Ixx5*dq11*CC2*C3*C4*CC5*S3 + 2*Ixx6*dq11*C2*CC3*C4*CC6*S2 + 2*Ixx6*dq11*CC2*C3*C4*CC6*S3 + 2*Ixx6*dq11*C2*C4*CC5*CC6*S2 + 2*Ixx6*dq11*C3*C4*CC5*CC6*S3 - 4*Iyy6*dq11*C2*CC3*C4*CC5*S2 - 2*Iyy6*dq11*C2*CC3*C4*CC6*S2 - 4*Iyy6*dq11*CC2*C3*C4*CC5*S3 - 2*Iyy6*dq11*CC2*C3*C4*CC6*S3 - 2*Iyy6*dq11*C2*C4*CC5*CC6*S2 - 2*Iyy6*dq11*C3*C4*CC5*CC6*S3 - 2*Iyz5*dq11*CC2*CC3*C4*C5*S4 + 4*Izz5*dq11*C2*CC3*C4*CC5*S2 + 4*Izz5*dq11*CC2*C3*C4*CC5*S3 + 4*Izz6*dq11*C2*CC3*C4*CC5*S2 + 4*Izz6*dq11*CC2*C3*C4*CC5*S3 + 2*XX5*dq11*m_5*CC2*CC3*C5*S5 - XX5*dq11*m_5*CC2*CC4*C5*S5 - XX5*dq11*m_5*CC3*CC4*C5*S5 - XX6*dq11*m_6*CC2*C5*CC6*S5 - XX6*dq11*m_6*CC3*C5*CC6*S5 + XX6*dq22*m_6*CC4*C5*CC6*S5 + XX6*dq33*m_6*CC4*C5*CC6*S5 + 2*YY6*dq11*m_6*CC2*CC3*C5*S5 - YY6*dq11*m_6*CC2*CC4*C5*S5 - YY6*dq11*m_6*CC3*CC4*C5*S5 + YY6*dq11*m_6*CC2*C5*CC6*S5 + YY6*dq11*m_6*CC3*C5*CC6*S5 - YY6*dq22*m_6*CC4*C5*CC6*S5 - YY6*dq33*m_6*CC4*C5*CC6*S5 - 2*ZZ5*dq11*m_5*CC2*CC3*C5*S5 + ZZ5*dq11*m_5*CC2*CC4*C5*S5 + ZZ5*dq11*m_5*CC3*CC4*C5*S5 - 2*ZZ6*dq11*m_6*CC2*CC3*C5*S5 + ZZ6*dq11*m_6*CC2*CC4*C5*S5 + ZZ6*dq11*m_6*CC3*CC4*C5*S5 - 2*Y6*d6*dq23*m_6*CC4*S6 - 4*Y6*d6*dq23*m_6*CC5*S6 + 4*Z6*d6*dq24*m_6*CC5*S4 + 4*Z6*d6*dq34*m_6*CC5*S4 + 2*Ixy5*dq11*CC2*CC3*C4*S4*S5 - 2*Ixy6*dq11*CC2*CC3*C4*S4*S5 - 2*Ixy6*dq11*CC2*C4*CC6*S4*S5 - 2*Ixy6*dq11*CC3*C4*CC6*S4*S5 - 2*dd6*dq11*m_6*CC2*CC3*C5*S5 + dd6*dq11*m_6*CC2*CC4*C5*S5 + dd6*dq11*m_6*CC3*CC4*C5*S5 + 2*X6*Z6*dq11*m_6*CC2*CC3*C6 - X6*Z6*dq11*m_6*CC2*CC4*C6 + 2*X6*Z6*dq11*m_6*CC2*CC5*C6 - X6*Z6*dq11*m_6*CC3*CC4*C6 + 2*X6*Z6*dq11*m_6*CC3*CC5*C6 - 2*X6*Z6*dq22*m_6*CC4*CC5*C6 - 2*X6*Z6*dq33*m_6*CC4*CC5*C6 - 2*X5*d4*dq11*m_5*CC2*CC3*C5 + 2*X6*d6*dq11*m_6*CC2*CC3*C6 - X6*d6*dq11*m_6*CC2*CC4*C6 + 2*X6*d6*dq11*m_6*CC2*CC5*C6 - X6*d6*dq11*m_6*CC3*CC4*C6 + 2*X6*d6*dq11*m_6*CC3*CC5*C6 - 2*X6*d6*dq22*m_6*CC4*CC5*C6 - 2*X6*d6*dq33*m_6*CC4*CC5*C6 - 2*Y6*Z6*dq11*m_6*CC2*CC3*S6 + Y6*Z6*dq11*m_6*CC2*CC4*S6 - 2*Y6*Z6*dq11*m_6*CC2*CC5*S6 + Y6*Z6*dq11*m_6*CC3*CC4*S6 - 2*Y6*Z6*dq11*m_6*CC3*CC5*S6 + 2*Y6*Z6*dq22*m_6*CC4*CC5*S6 + 2*Y6*Z6*dq33*m_6*CC4*CC5*S6 - 2*Ixx6*dq23*CC4*C5*CC6*S5 + 2*Iyy6*dq23*CC4*C5*CC6*S5 - 2*XX6*dq24*m_6*CC5*CC6*S4 - 2*XX6*dq34*m_6*CC5*CC6*S4 - 2*Y6*d6*dq11*m_6*CC2*CC3*S6 + Y6*d6*dq11*m_6*CC2*CC4*S6 - 2*Y6*d6*dq11*m_6*CC2*CC5*S6 + Y6*d6*dq11*m_6*CC3*CC4*S6 - 2*Y6*d6*dq11*m_6*CC3*CC5*S6 + 2*Y6*d6*dq22*m_6*CC4*CC5*S6 + 2*Y6*d6*dq33*m_6*CC4*CC5*S6 + 2*YY6*dq24*m_6*CC5*CC6*S4 + 2*YY6*dq34*m_6*CC5*CC6*S4 - 2*Z5*d4*dq11*m_5*CC2*CC3*S5 - 2*Z6*d4*dq11*m_6*CC2*CC3*S5 - 2*d4*d6*dq11*m_6*CC2*CC3*S5 - 4*X5*Z5*dq23*m_5*CC4*CC5 + 2*Ixy6*dq11*C2*C4*C6*S2*S6 + 2*Ixy6*dq11*C3*C4*C6*S3*S6 + 2*Ixz6*dq11*C2*C3*C6*S2*S3 + 4*Ixz5*dq11*C2*C4*C5*S2*S5 + 4*Ixz5*dq11*C3*C4*C5*S3*S5 - 2*Ixx5*dq11*CC2*CC3*CC4*C5*S5 - 2*Ixx6*dq11*CC2*CC3*C5*CC6*S5 + Ixx6*dq11*CC2*CC4*C5*CC6*S5 + Ixx6*dq11*CC3*CC4*C5*CC6*S5 - 2*Iyy6*dq11*CC2*CC3*CC4*C5*S5 + 2*Iyy6*dq11*CC2*CC3*C5*CC6*S5 - Iyy6*dq11*CC2*CC4*C5*CC6*S5 - Iyy6*dq11*CC3*CC4*C5*CC6*S5 + 2*Izz5*dq11*CC2*CC3*CC4*C5*S5 + 2*Izz6*dq11*CC2*CC3*CC4*C5*S5 +
 Ixx6*dq22*C4*C6*S4*S5*S6 + Ixx6*dq33*C4*C6*S4*S5*S6 - Iyy6*dq22*C4*C6*S4*S5*S6 - Iyy6*dq33*C4*C6*S4*S5*S6 - 2*Iyz6*dq11*C2*C3*S2*S3*S6 - Iyz6*dq11*C2*C6*S2*S4*S5 - Iyz6*dq11*C3*C6*S3*S4*S5 - 2*Ixz6*dq16*C2*C3*C5*C6 - Z5*a2*dq22*m_5*C3*C4*C5 - Z6*a2*dq22*m_6*C3*C4*C5 + Y5*Z5*dq22*m_5*C4*C5*S4 + Y5*Z5*dq33*m_5*C4*C5*S4 - Ixz6*dq11*C2*S2*S4*S5*S6 - Ixz6*dq11*C3*S3*S4*S5*S6 - a2*d6*dq22*m_6*C3*C4*C5 + 2*Ixx5*dq14*C2*C3*C5*S5 - Ixx6*dq16*C2*C4*C5*S3 - Ixx6*dq16*C3*C4*C5*S2 + 2*Ixx6*dq24*C4*C5*C6*S6 + 2*Ixx6*dq34*C4*C5*C6*S6 + 2*Iyy6*dq14*C2*C3*C5*S5 + Iyy6*dq16*C2*C4*C5*S3 + Iyy6*dq16*C3*C4*C5*S2 - 2*Iyy6*dq24*C4*C5*C6*S6 - 2*Iyy6*dq34*C4*C5*C6*S6 + 2*Iyz6*dq12*C2*C5*C6*S3 + 2*Iyz6*dq12*C3*C5*C6*S2 + 2*Iyz6*dq13*C2*C5*C6*S3 + 2*Iyz6*dq13*C3*C5*C6*S2 + 2*Iyz6*dq16*C2*C3*C5*S6 - 2*Iyz6*dq23*C4*C5*C6*S4 - 2*Izz5*dq14*C2*C3*C5*S5 - 2*Izz6*dq14*C2*C3*C5*S5 - Izz6*dq16*C2*C4*C5*S3 - Izz6*dq16*C3*C4*C5*S2 + X5*a1*dq11*m_5*C2*C5*S3 + X5*a1*dq11*m_5*C3*C5*S2 - X5*a3*dq11*m_5*C2*C5*S2 - X5*a3*dq11*m_5*C3*C5*S3 + X5*a2*dq22*m_5*C3*C4*S5 + X6*a2*dq22*m_6*C5*C6*S3 + X6*a3*dq11*m_6*C4*C6*S5 + X6*a3*dq22*m_6*C4*C6*S5 + X6*a3*dq33*m_6*C4*C6*S5 - 2*XX5*dq12*m_5*C2*C3*S4 - 2*XX5*dq13*m_5*C2*C3*S4 - 2*XX6*dq26*m_6*C4*C6*S6 - 2*XX6*dq36*m_6*C4*C6*S6 - 2*YY6*dq12*m_6*C2*C3*S4 - 2*YY6*dq13*m_6*C2*C3*S4 - 2*YY6*dq16*m_6*C2*C3*S5 + 2*YY6*dq26*m_6*C4*C6*S6 + 2*YY6*dq36*m_6*C4*C6*S6 - 2*Z6*d6*dq11*m_6*C2*C4*S2 - 2*Z6*d6*dq11*m_6*C3*C4*S3 - 2*ZZ5*dq14*m_5*C2*C4*S3 - 2*ZZ5*dq14*m_5*C3*C4*S2 - 2*ZZ6*dq14*m_6*C2*C4*S3 - 2*ZZ6*dq14*m_6*C3*C4*S2 + 2*X5*Z5*dq11*m_5*CC2*CC3*CC4 - 4*X5*Z5*dq11*m_5*CC2*CC3*CC5 + 2*X5*Z5*dq11*m_5*CC2*CC4*CC5 + 2*X5*Z5*dq11*m_5*CC3*CC4*CC5 - X5*Y5*dq22*m_5*C4*S4*S5 - X5*Y5*dq33*m_5*C4*S4*S5 + X6*Y6*dq22*m_6*C4*S4*S5 + X6*Y6*dq33*m_6*C4*S4*S5 - 2*Ixy5*dq14*C2*C5*S3*S4 - 2*Ixy5*dq14*C3*C5*S2*S4 + 2*Ixy6*dq14*C2*C5*S3*S4 + 2*Ixy6*dq14*C3*C5*S2*S4 - 4*Ixy6*dq23*C5*C6*S5*S6 - 4*Ixy6*dq26*C5*C6*S4*S6 - 4*Ixy6*dq36*C5*C6*S4*S6 + 2*Ixz5*dq12*C2*C4*S3*S4 + 2*Ixz5*dq12*C3*C4*S2*S4 + 2*Ixz5*dq13*C2*C4*S3*S4 + 2*Ixz5*dq13*C3*C4*S2*S4 + 2*Ixz6*dq12*C2*C5*S3*S6 + 2*Ixz6*dq12*C3*C5*S2*S6 + 2*Ixz6*dq13*C2*C5*S3*S6 + 2*Ixz6*dq13*C3*C5*S2*S6 + 2*Ixz6*dq16*C5*C6*S2*S3 - 2*Ixz6*dq23*C4*C5*S4*S6 + 4*Ixz6*dq24*C5*C6*S4*S5 + 4*Ixz6*dq34*C5*C6*S4*S5 - 2*dd6*dq14*m_6*C2*C4*S3 - 2*dd6*dq14*m_6*C3*C4*S2 - Y6*a2*dq22*m_6*C5*S3*S6 - Y6*a3*dq11*m_6*C4*S5*S6 - Y6*a3*dq22*m_6*C4*S5*S6 - Y6*a3*dq33*m_6*C4*S5*S6 + Z5*a1*dq11*m_5*C2*S3*S5 + Z5*a1*dq11*m_5*C3*S2*S5 - Z5*a3*dq11*m_5*C2*S2*S5 + Z6*a1*dq11*m_6*C2*S3*S5 + Z6*a1*dq11*m_6*C3*S2*S5 - Z5*a3*dq11*m_5*C3*S3*S5 - Z6*a3*dq11*m_6*C2*S2*S5 - Z6*a3*dq11*m_6*C3*S3*S5 - 2*X5*Y5*dq24*m_5*C4*C5 - 2*X5*Y5*dq34*m_5*C4*C5 + 2*X6*Y6*dq24*m_6*C4*C5 + 2*X6*Y6*dq34*m_6*C4*C5 - 2*X5*Z5*dq14*m_5*C2*C3 - 2*X6*Z6*dq46*m_6*C5*C6 + a1*d6*dq11*m_6*C2*S3*S5 + a1*d6*dq11*m_6*C3*S2*S5 - a3*d6*dq11*m_6*C2*S2*S5 - a3*d6*dq11*m_6*C3*S3*S5 - 2*Ixx5*dq14*C5*S2*S3*S5 - 2*Iyy6*dq14*C5*S2*S3*S5 - 2*Iyz5*dq14*C2*S3*S4*S5 - 2*Iyz5*dq14*C3*S2*S4*S5 - 2*Iyz6*dq16*C5*S2*S3*S6 - 4*Iyz6*dq24*C5*S4*S5*S6 - 4*Iyz6*dq34*C5*S4*S5*S6 + 2*Izz5*dq14*C5*S2*S3*S5 + 2*Izz6*dq14*C5*S2*S3*S5 - 2*Z5*a3*dq23*m_5*C4*C5 - 2*Z6*a3*dq23*m_6*C4*C5 + 2*XX5*dq12*m_5*S2*S3*S4 + 2*XX5*dq13*m_5*S2*S3*S4 + 2*X6*d4*dq23*m_6*C5*C6 - 2*X6*d6*dq46*m_6*C5*C6 + 2*YY6*dq12*m_6*S2*S3*S4 + 2*YY6*dq13*m_6*S2*S3*S4 + 2*YY6*dq16*m_6*S2*S3*S5 - Y5*Z5*dq11*m_5*CC2*C4*C5*S4 - Y5*Z5*dq11*m_5*CC3*C4*C5*S4 + 2*Ixz6*dq11*C2*CC3*S2*S4*S5*S6 + 2*Ixz6*dq11*CC2*C3*S3*S4*S5*S6 - a2*d6*dq11*m_6*CC2*C3*C4*C5 + 2*Ixx6*dq14*C2*C3*C5*CC6*S5 + 2*Ixx6*dq16*C2*C4*C5*CC6*S3 + 2*Ixx6*dq16*C3*C4*C5*CC6*S2 - 2*Iyy6*dq14*C2*C3*C5*CC6*S5 - 2*Iyy6*dq16*C2*C4*C5*CC6*S3 - 2*Iyy6*dq16*C3*C4*C5*CC6*S2 - 2*Iyz6*dq12*C2*CC4*C5*C6*S3 - 2*Iyz6*dq12*C3*CC4*C5*C6*S2 - 2*Iyz6*dq13*C2*CC4*C5*C6*S3 - 2*Iyz6*dq13*C3*CC4*C5*C6*S2 + 2*X5*a3*dq11*m_5*C2*CC3*C5*S2 + X5*a2*dq11*m_5*CC2*C3*C4*S5 + 2*X5*a3*dq11*m_5*CC2*C3*C5*S3 + X6*a2*dq11*m_6*CC2*C5*C6*S3 - X6*a3*dq11*m_6*CC2*C4*C6*S5 - X6*a3*dq11*m_6*CC3*C4*C6*S5 + 2*XX5*dq12*m_5*C2*C3*CC5*S4 + 2*XX5*dq13*m_5*C2*C3*CC5*S4 - 2*XX5*dq14*m_5*C2*C4*CC5*S3 - 2*XX5*dq14*m_5*C3*C4*CC5*S2 - 2*XX6*dq12*m_6*C2*C3*CC6*S4 - 2*XX6*dq13*m_6*C2*C3*CC6*S4 - 2*XX6*dq16*m_6*C2*C3*CC6*S5 + 2*YY6*dq12*m_6*C2*C3*CC5*S4 + 2*YY6*dq12*m_6*C2*C3*CC6*S4 + 2*YY6*dq13*m_6*C2*C3*CC5*S4 + 2*YY6*dq13*m_6*C2*C3*CC6*S4 - 2*YY6*dq14*m_6*C2*C4*CC5*S3 - 2*YY6*dq14*m_6*C3*C4*CC5*S2 + 2*YY6*dq16*m_6*C2*C3*CC6*S5 + 4*Z6*d6*dq11*m_6*C2*CC3*C4*S2 + 4*Z6*d6*dq11*m_6*CC2*C3*C4*S3 + 4*Z6*d6*dq11*m_6*C2*C4*CC5*S2 + 4*Z6*d6*dq11*m_6*C3*C4*CC5*S3 - 2*ZZ5*dq12*m_5*C2*C3*CC5*S4 - 2*ZZ5*dq13*m_5*C2*C3*CC5*S4 + 2*ZZ5*dq14*m_5*C2*C4*CC5*S3 + 2*ZZ5*dq14*m_5*C3*C4*CC5*S2 - 2*ZZ6*dq12*m_6*C2*C3*CC5*S4 - 2*ZZ6*dq13*m_6*C2*C3*CC5*S4 + 2*ZZ6*dq14*m_6*C2*C4*CC5*S3 + 2*ZZ6*dq14*m_6*C3*C4*CC5*S2 - 4*X5*Z5*dq11*m_5*CC2*CC3*CC4*CC5 + X5*Y5*dq11*m_5*CC2*C4*S4*S5 + X5*Y5*dq11*m_5*CC3*C4*S4*S5 - X6*Y6*dq11*m_6*CC2*C4*S4*S5 - X6*Y6*dq11*m_6*CC3*C4*S4*S5 - 2*X6*Y6*dq22*m_6*C4*CC6*S4*S5 - 2*X6*Y6*dq33*m_6*C4*CC6*S4*S5 - 4*Ixy6*dq14*C2*C5*CC6*S3*S4 - 4*Ixy6*dq14*C3*C5*CC6*S2*S4 + 4*Ixy6*dq23*CC4*C5*C6*S5*S6 - 4*Ixz5*dq12*C2*C4*CC5*S3*S4 - 4*Ixz5*dq12*C3*C4*CC5*S2*S4 - 4*Ixz5*dq13*C2*C4*CC5*S3*S4 - 4*Ixz5*dq13*C3*C4*CC5*S2*S4 - 2*Ixz6*dq12*C2*CC4*C5*S3*S6 - 2*Ixz6*dq12*C3*CC4*C5*S2*S6 - 2*Ixz6*dq13*C2*CC4*C5*S3*S6 - 2*Ixz6*dq13*C3*CC4*C5*S2*S6 - 2*dd6*dq12*m_6*C2*C3*CC5*S4 - 2*dd6*dq13*m_6*C2*C3*CC5*S4 + 2*dd6*dq14*m_6*C2*C4*CC5*S3 + 2*dd6*dq14*m_6*C3*C4*CC5*S2 - Y6*a2*dq11*m_6*CC2*C5*S3*S6 + Y6*a3*dq11*m_6*CC2*C4*S5*S6 + Y6*a3*dq11*m_6*CC3*C4*S5*S6 + 2*Z5*a3*dq11*m_5*C2*CC3*S2*S5 + 2*Z5*a3*dq11*m_5*CC2*C3*S3*S5 + 2*Z6*a3*dq11*m_6*C2*CC3*S2*S5 + 2*Z6*a3*dq11*m_6*CC2*C3*S3*S5 - 4*X6*Y6*dq24*m_6*C4*C5*CC6 - 4*X6*Y6*dq34*m_6*C4*C5*CC6 + 4*X5*Z5*dq14*m_5*C2*C3*CC5 + 2*a3*d6*dq11*m_6*C2*CC3*S2*S5 + 2*a3*d6*dq11*m_6*CC2*C3*S3*S5 - 2*Ixx6*dq14*C5*CC6*S2*S3*S5 + 2*Iyy6*dq14*C5*CC6*S2*S3*S5 - 2*XX5*dq12*m_5*CC5*S2*S3*S4 - 2*XX5*dq13*m_5*CC5*S2*S3*S4 + 2*XX6*dq12*m_6*CC6*S2*S3*S4 + 2*XX6*dq13*m_6*CC6*S2*S3*S4 + 2*XX6*dq16*m_6*CC6*S2*S3*S5 - 2*YY6*dq12*m_6*CC5*S2*S3*S4 - 2*YY6*dq12*m_6*CC6*S2*S3*S4 - 2*YY6*dq13*m_6*CC5*S2*S3*S4 - 2*YY6*dq13*m_6*CC6*S2*S3*S4 - 2*YY6*dq16*m_6*CC6*S2*S3*S5 + 2*ZZ5*dq12*m_5*CC5*S2*S3*S4 + 2*ZZ5*dq13*m_5*CC5*S2*S3*S4 + 2*ZZ6*dq12*m_6*CC5*S2*S3*S4 + 2*ZZ6*dq13*m_6*CC5*S2*S3*S4 - 2*Iyz6*dq11*CC2*CC3*C4*C5*C6*S4 + 2*dd6*dq12*m_6*CC5*S2*S3*S4 + 2*dd6*dq13*m_6*CC5*S2*S3*S4 + 4*XX5*dq11*m_5*C2*CC3*C4*CC5*S2 + 4*XX5*dq11*m_5*CC2*C3*C4*CC5*S3 - 2*XX6*dq11*m_6*C2*CC3*C4*CC6*S2 - 2*XX6*dq11*m_6*CC2*C3*C4*CC6*S3 - 2*XX6*dq11*m_6*C2*C4*CC5*CC6*S2 - 2*XX6*dq11*m_6*C3*C4*CC5*CC6*S3 + 4*YY6*dq11*m_6*C2*CC3*C4*CC5*S2 + 2*YY6*dq11*m_6*C2*CC3*C4*CC6*S2 + 4*YY6*dq11*m_6*CC2*C3*C4*CC5*S3 + 2*YY6*dq11*m_6*CC2*C3*C4*CC6*S3 + 2*YY6*dq11*m_6*C2*C4*CC5*CC6*S2 + 2*YY6*dq11*m_6*C3*C4*CC5*CC6*S3 - 4*ZZ5*dq11*m_5*C2*CC3*C4*CC5*S2 - 4*ZZ5*dq11*m_5*CC2*C3*C4*CC5*S3 - 4*ZZ6*dq11*m_6*C2*CC3*C4*CC5*S2 - 4*ZZ6*dq11*m_6*CC2*C3*C4*CC5*S3 - 4*Z6*d6*dq23*m_6*CC4*C5*S5 - 4*X5*Z5*dq14*m_5*CC5*S2*S3 + 4*Ixy6*dq11*C2*CC3*C5*CC6*S2*S4 + 4*Ixy6*dq11*CC2*C3*C5*CC6*S3*S4 + 4*Ixy6*dq11*CC2*CC3*C5*C6*S5*S6 - 2*Ixy6*dq11*CC2*CC4*C5*C6*S5*S6 - 2*Ixy6*dq11*CC3*CC4*C5*C6*S5*S6 - 4*Ixz5*dq11*C2*C3*CC4*CC5*S2*S3 - 2*Ixz6*dq11*CC2*CC3*C4*C5*S4*S6 - 4*dd6*dq11*m_6*C2*CC3*C4*CC5*S2 - 4*dd6*dq11*m_6*CC2*C3*C4*CC5*S3 - 2*Z5*a3*dq11*m_5*CC2*CC3*C4*C5 - 2*Z6*a3*dq11*m_6*CC2*CC3*C4*C5 - 2*X6*d4*dq11*m_6*CC2*CC3*C5*C6 - 2*a3*d6*dq11*m_6*CC2*CC3*C4*C5 - 2*Ixx6*dq12*C2*C3*CC5*CC6*S4 - 2*Ixx6*dq13*C2*C3*CC5*CC6*S4 + 2*Ixx6*dq14*C2*C4*CC5*CC6*S3 + 2*Ixx6*dq14*C3*C4*CC5*CC6*S2 + 2*Iyy6*dq12*C2*C3*CC5*CC6*S4 + 2*Iyy6*dq13*C2*C3*CC5*CC6*S4 - 2*Iyy6*dq14*C2*C4*CC5*CC6*S3 - 2*Iyy6*dq14*C3*C4*CC5*CC6*S2 + 2*X5*a3*dq11*m_5*CC2*CC3*C4*S5 + 2*XX6*dq23*m_6*CC4*C5*CC6*S5 + 2*Y6*d4*dq11*m_6*CC2*CC3*C5*S6 - 2*YY6*dq23*m_6*CC4*C5*CC6*S5 - 4*Z6*d6*dq11*m_6*CC2*CC3*C5*S5 + 2*Z6*d6*dq11*m_6*CC2*CC4*C5*S5 + 2*Z6*d6*dq11*m_6*CC3*CC4*C5*S5 + 4*Ixy6*dq12*C2*CC4*CC6*S3*S5 + 4*Ixy6*dq12*C3*CC4*CC6*S2*S5 + 4*Ixy6*dq13*C2*CC4*CC6*S3*S5 + 4*Ixy6*dq13*C3*CC4*CC6*S2*S5 - 4*X6*Z6*dq23*m_6*CC4*CC5*C6 + 2*Ixx6*dq12*CC5*CC6*S2*S3*S4 + 2*Ixx6*dq13*CC5*CC6*S2*S3*S4 - 2*Iyy6*dq12*CC5*CC6*S2*S3*S4 - 2*Iyy6*dq13*CC5*CC6*S2*S3*S4 + 4*Ixz6*dq11*C2*C4*C5*C6*S2*S5 + 4*Ixz6*dq11*C3*C4*C5*C6*S3*S5 - 4*X6*d6*dq23*m_6*CC4*CC5*C6 + 4*Y6*Z6*dq23*m_6*CC4*CC5*S6 - 4*Ixx6*dq11*C2*CC3*C4*CC5*CC6*S2 - 4*Ixx6*dq11*CC2*C3*C4*CC5*CC6*S3 + 4*Iyy6*dq11*C2*CC3*C4*CC5*CC6*S2 + 4*Iyy6*dq11*CC2*C3*C4*CC5*CC6*S3 + 2*Ixx5*dq11*C2*C3*C5*S2*S3*S5 - Ixx6*dq11*C2*C5*C6*S2*S4*S6 - Ixx6*dq11*C3*C5*C6*S3*S4*S6 + 2*Iyy6*dq11*C2*C3*C5*S2*S3*S5 + Iyy6*dq11*C2*C5*C6*S2*S4*S6 + Iyy6*dq11*C3*C5*C6*S3*S4*S6 - 4*Iyz6*dq11*C2*C4*C5*S2*S5*S6 - 4*Iyz6*dq11*C3*C4*C5*S3*S5*S6 - 2*Izz5*dq11*C2*C3*C5*S2*S3*S5 - 2*Izz6*dq11*C2*C3*C5*S2*S3*S5 + 2*XX5*dq11*m_5*CC2*CC3*CC4*C5*S5 + 2*XX6*dq11*m_6*CC2*CC3*C5*CC6*S5 - XX6*dq11*m_6*CC2*CC4*C5*CC6*S5 - XX6*dq11*m_6*CC3*CC4*C5*CC6*S5 - Z5*a1*dq11*m_5*C2*C3*C4*C5 - Z6*a1*dq11*m_6*C2*C3*C4*C5 + 2*YY6*dq11*m_6*CC2*CC3*CC4*C5*S5 - 2*YY6*dq11*m_6*CC2*CC3*C5*CC6*S5 + YY6*dq11*m_6*CC2*CC4*C5*CC6*S5 + YY6*dq11*m_6*CC3*CC4*C5*CC6*S5 - XX6*dq22*m_6*C4*C6*S4*S5*S6 - XX6*dq33*m_6*C4*C6*S4*S5*S6 - 2*ZZ5*dq11*m_5*CC2*CC3*CC4*C5*S5 - 2*ZZ6*dq11*m_6*CC2*CC3*CC4*C5*S5 + 4*Y6*d6*dq23*m_6*CC4*CC5*S6 + YY6*dq22*m_6*C4*C6*S4*S5*S6 + YY6*dq33*m_6*C4*C6*S4*S5*S6 + Y6*Z6*dq22*m_6*C4*C5*C6*S4 + Y6*Z6*dq33*m_6*C4*C5*C6*S4 + 4*Ixy6*dq11*CC2*CC3*C4*CC6*S4*S5 - a1*d6*dq11*m_6*C2*C3*C4*C5 - 2*dd6*dq11*m_6*CC2*CC3*CC4*C5*S5 + X5*a2*dq11*m_5*C2*C3*C5*S2 + X5*a1*dq11*m_5*C2*C3*C4*S5 + X6*a1*dq11*m_6*C2*C5*C6*S3 + X6*a1*dq11*m_6*C3*C5*C6*S2 - X6*a3*dq11*m_6*C2*C5*C6*S2 - X6*a3*dq11*m_6*C3*C5*C6*S3 + X6*a2*dq22*m_6*C3*C4*C6*S5 - 2*XX5*dq14*m_5*C2*C3*C5*S5 - 2*XX6*dq24*m_6*C4*C5*C6*S6 - 2*XX6*dq34*m_6*C4*C5*C6*S6 + Y6*d6*dq22*m_6*C4*C5*C6*S4 + Y6*d6*dq33*m_6*C4*C5*C6*S4 - 2*YY6*dq14*m_6*C2*C3*C5*S5 - 2*YY6*dq16*m_6*C2*C4*C5*S3 - 2*YY6*dq16*m_6*C3*C4*C5*S2 + 2*YY6*dq24*m_6*C4*C5*C6*S6
 + 2*YY6*dq34*m_6*C4*C5*C6*S6 + Z5*d4*dq11*m_5*C2*C4*C5*S2 + Z5*d4*dq11*m_5*C3*C4*C5*S3 + Z6*d4*dq11*m_6*C2*C4*C5*S2 + Z6*d4*dq11*m_6*C3*C4*C5*S3 + 2*ZZ5*dq14*m_5*C2*C3*C5*S5 + 2*ZZ6*dq14*m_6*C2*C3*C5*S5 + 2*X6*Z6*dq11*m_6*CC2*CC3*CC4*C6 - 4*X6*Z6*dq11*m_6*CC2*CC3*CC5*C6 + 2*X6*Z6*dq11*m_6*CC2*CC4*CC5*C6 + 2*X6*Z6*dq11*m_6*CC3*CC4*CC5*C6 + X5*Y5*dq11*m_5*C2*C5*S2*S4 + X5*Y5*dq11*m_5*C3*C5*S3*S4 - X6*Y6*dq11*m_6*C2*C5*S2*S4 - X6*Y6*dq11*m_6*C3*C5*S3*S4 - 2*X6*Y6*dq11*m_6*C5*C6*S5*S6 + 2*X6*Y6*dq22*m_6*C5*C6*S5*S6 + 2*X6*Y6*dq33*m_6*C5*C6*S5*S6 - 2*X6*Y6*dq44*m_6*C5*C6*S5*S6 - 2*X5*Z5*dq11*m_5*C2*C3*S2*S3 + X6*Z6*dq22*m_6*C4*C5*S4*S6 + X6*Z6*dq33*m_6*C4*C5*S4*S6 - 4*Ixy6*dq12*C2*C3*C6*S4*S6 - 4*Ixy6*dq13*C2*C3*C6*S4*S6 - 4*Ixy6*dq16*C2*C3*C6*S5*S6 - 4*Ixz5*dq12*C2*C3*C5*S4*S5 - 4*Ixz5*dq13*C2*C3*C5*S4*S5 + 2*Ixz6*dq12*C2*C4*C6*S3*S4 + 2*Ixz6*dq12*C3*C4*C6*S2*S4 + 4*Ixz5*dq14*C2*C4*C5*S3*S5 + 4*Ixz5*dq14*C3*C4*C5*S2*S5 + 2*Ixz6*dq13*C2*C4*C6*S3*S4 + 2*Ixz6*dq13*C3*C4*C6*S2*S4 + 2*Ixz6*dq16*C2*C4*C6*S3*S5 + 2*Ixz6*dq16*C3*C4*C6*S2*S5 + d4*d6*dq11*m_6*C2*C4*C5*S2 + d4*d6*dq11*m_6*C3*C4*C5*S3 + 2*dd6*dq14*m_6*C2*C3*C5*S5 - Y6*a1*dq11*m_6*C2*C5*S3*S6 - Y6*a1*dq11*m_6*C3*C5*S2*S6 + Y6*a3*dq11*m_6*C2*C5*S2*S6 + Y6*a3*dq11*m_6*C3*C5*S3*S6 - Y6*a2*dq22*m_6*C3*C4*S5*S6 + 2*X6*d6*dq11*m_6*CC2*CC3*CC4*C6 - 4*X6*d6*dq11*m_6*CC2*CC3*CC5*C6 + 2*X6*d6*dq11*m_6*CC2*CC4*CC5*C6 + 2*X6*d6*dq11*m_6*CC3*CC4*CC5*C6 + Z5*a2*dq11*m_5*C2*C3*S2*S5 + Z5*a1*dq11*m_5*C4*C5*S2*S3 + Z6*a2*dq11*m_6*C2*C3*S2*S5 + Z6*a1*dq11*m_6*C4*C5*S2*S3 - X5*d4*dq11*m_5*C2*C4*S2*S5 - X5*d4*dq11*m_5*C3*C4*S3*S5 + X6*d6*dq22*m_6*C4*C5*S4*S6 + X6*d6*dq33*m_6*C4*C5*S4*S6 - 2*Y6*Z6*dq11*m_6*CC2*CC3*CC4*S6 + 4*Y6*Z6*dq11*m_6*CC2*CC3*CC5*S6 - 2*Y6*Z6*dq11*m_6*CC2*CC4*CC5*S6 - 2*Y6*Z6*dq11*m_6*CC3*CC4*CC5*S6 - 2*X6*Z6*dq14*m_6*C2*C3*C6 + Y5*Z5*dq11*m_5*C2*S2*S4*S5 + Y5*Z5*dq11*m_5*C3*S3*S4*S5 + a2*d6*dq11*m_6*C2*C3*S2*S5 + a1*d6*dq11*m_6*C4*C5*S2*S3 - 2*Ixx6*dq12*C2*C6*S3*S5*S6 - 2*Ixx6*dq12*C3*C6*S2*S5*S6 - 2*Ixx6*dq13*C2*C6*S3*S5*S6 - 2*Ixx6*dq13*C3*C6*S2*S5*S6 - 2*Ixx6*dq16*C2*C6*S3*S4*S6 - 2*Ixx6*dq16*C3*C6*S2*S4*S6 + 2*Ixx6*dq23*C4*C6*S4*S5*S6 + 2*Iyy6*dq12*C2*C6*S3*S5*S6 + 2*Iyy6*dq12*C3*C6*S2*S5*S6 + 2*Iyy6*dq13*C2*C6*S3*S5*S6 + 2*Iyy6*dq13*C3*C6*S2*S5*S6 + 2*Iyy6*dq16*C2*C6*S3*S4*S6 + 2*Iyy6*dq16*C3*C6*S2*S4*S6 - 2*Iyy6*dq23*C4*C6*S4*S5*S6 - 2*Iyz6*dq12*C2*C4*S3*S4*S6 - 2*Iyz6*dq12*C3*C4*S2*S4*S6 - 2*Iyz6*dq13*C2*C4*S3*S4*S6 - 2*Iyz6*dq13*C3*C4*S2*S4*S6 - 2*Iyz6*dq14*C2*C6*S3*S4*S5 - 2*Iyz6*dq14*C3*C6*S2*S4*S5 - 2*Iyz6*dq16*C2*C4*S3*S5*S6 - 2*Iyz6*dq16*C3*C4*S2*S5*S6 - X5*a1*dq11*m_5*C4*S2*S3*S5 - 2*Y6*d6*dq11*m_6*CC2*CC3*CC4*S6 + 4*Y6*d6*dq11*m_6*CC2*CC3*CC5*S6 - 2*Y6*d6*dq11*m_6*CC2*CC4*CC5*S6 - 2*Y6*d6*dq11*m_6*CC3*CC4*CC5*S6 + 2*XX5*dq14*m_5*C5*S2*S3*S5 - 2*X6*d6*dq14*m_6*C2*C3*C6 + 2*YY6*dq14*m_6*C5*S2*S3*S5 - 2*ZZ5*dq14*m_5*C5*S2*S3*S5 - 2*ZZ6*dq14*m_6*C5*S2*S3*S5 - 2*Y5*Z5*dq12*m_5*C2*C5*S3 - 2*Y5*Z5*dq12*m_5*C3*C5*S2 - 2*Y5*Z5*dq13*m_5*C2*C5*S3 - 2*Y5*Z5*dq13*m_5*C3*C5*S2 + 2*Y5*Z5*dq23*m_5*C4*C5*S4 + 2*Y6*Z6*dq14*m_6*C2*C3*S6 - 2*Y6*Z6*dq24*m_6*C4*C6*S5 - 2*Y6*Z6*dq34*m_6*C4*C6*S5 + 4*Ixy6*dq12*C6*S2*S3*S4*S6 + 4*Ixy6*dq13*C6*S2*S3*S4*S6 + 4*Ixy6*dq16*C6*S2*S3*S5*S6 + 4*Ixz5*dq12*C5*S2*S3*S4*S5 + 4*Ixz5*dq13*C5*S2*S3*S4*S5 - 2*Ixz6*dq14*C2*S3*S4*S5*S6 - 2*Ixz6*dq14*C3*S2*S4*S5*S6 - 2*dd6*dq14*m_6*C5*S2*S3*S5 + 2*X6*a3*dq23*m_6*C4*C6*S5 + 2*Y6*d6*dq14*m_6*C2*C3*S6 - 2*Y6*d6*dq24*m_6*C4*C6*S5 - 2*Y6*d6*dq34*m_6*C4*C6*S5 - 4*Z6*d6*dq14*m_6*C2*C4*S3 - 4*Z6*d6*dq14*m_6*C3*C4*S2 + 2*X5*Y5*dq12*m_5*C2*S3*S5 + 2*X5*Y5*dq12*m_5*C3*S2*S5 + 2*X5*Y5*dq13*m_5*C2*S3*S5 + 2*X5*Y5*dq13*m_5*C3*S2*S5 - 2*X6*Y6*dq12*m_6*C2*S3*S5 - 2*X6*Y6*dq12*m_6*C3*S2*S5 - 2*X6*Y6*dq13*m_6*C2*S3*S5 - 2*X6*Y6*dq13*m_6*C3*S2*S5 - 2*X5*Y5*dq23*m_5*C4*S4*S5 - 2*X6*Y6*dq16*m_6*C2*S3*S4 - 2*X6*Y6*dq16*m_6*C3*S2*S4 + 2*X6*Y6*dq23*m_6*C4*S4*S5 - 4*X6*Y6*dq46*m_6*C6*S5*S6 + 2*X6*Z6*dq14*m_6*C6*S2*S3 - 4*X5*Z5*dq24*m_5*C5*S4*S5 - 4*X5*Z5*dq34*m_5*C5*S4*S5 - 2*X6*Z6*dq24*m_6*C4*S5*S6 - 2*X6*Z6*dq34*m_6*C4*S5*S6 - 2*X6*Z6*dq26*m_6*C6*S4*S5 - 2*X6*Z6*dq36*m_6*C6*S4*S5 - 4*Ixy6*dq11*C2*CC3*C4*C6*S2*S6 - 4*Ixy6*dq11*CC2*C3*C4*C6*S3*S6 - 4*Ixy6*dq11*C2*C4*CC5*C6*S2*S6 - 4*Ixy6*dq11*C3*C4*CC5*C6*S3*S6 - 8*Ixz5*dq11*C2*CC3*C4*C5*S2*S5 + 2*Ixz6*dq11*C2*C3*CC4*C6*S2*S3 - 8*Ixz5*dq11*CC2*C3*C4*C5*S3*S5 - 4*Ixz6*dq11*C2*C3*CC5*C6*S2*S3 - 2*Y6*a3*dq23*m_6*C4*S5*S6 + 2*Z5*a2*dq12*m_5*C5*S2*S4 + 2*Z6*a2*dq12*m_6*C5*S2*S4 + 2*X6*d6*dq14*m_6*C6*S2*S3 - 2*X6*d6*dq24*m_6*C4*S5*S6 - 2*X6*d6*dq34*m_6*C4*S5*S6 - 2*X6*d6*dq26*m_6*C6*S4*S5 - 2*X6*d6*dq36*m_6*C6*S4*S5 - 2*Ixx6*dq11*CC2*CC3*CC4*C5*CC6*S5 + 2*Iyy6*dq11*CC2*CC3*CC4*C5*CC6*S5 - 2*Y6*Z6*dq14*m_6*S2*S3*S6 + 2*Y6*Z6*dq26*m_6*S4*S5*S6 + 2*Y6*Z6*dq36*m_6*S4*S5*S6 - Ixx6*dq11*CC2*C4*C6*S4*S5*S6 - Ixx6*dq11*CC3*C4*C6*S4*S5*S6 + Iyy6*dq11*CC2*C4*C6*S4*S5*S6 + Iyy6*dq11*CC3*C4*C6*S4*S5*S6 - 2*Iyz6*dq11*C2*C3*CC4*S2*S3*S6 + 4*Iyz6*dq11*C2*C3*CC5*S2*S3*S6 + 2*Iyz6*dq11*C2*CC3*C6*S2*S4*S5 + 2*Iyz6*dq11*CC2*C3*C6*S3*S4*S5 + 2*a2*d6*dq12*m_6*C5*S2*S4 - 2*X5*a2*dq12*m_5*S2*S4*S5 - Z5*a2*dq11*m_5*CC2*C3*C4*C5 - Z6*a2*dq11*m_6*CC2*C3*C4*C5 - 2*Y6*d6*dq14*m_6*S2*S3*S6 + 2*Y6*d6*dq26*m_6*S4*S5*S6 + 2*Y6*d6*dq36*m_6*S4*S5*S6 + 4*Y6*d6*dq11*m_6*CC2*CC3*CC4*CC5*S6 + 2*XX6*dq14*m_6*C5*CC6*S2*S3*S5 + 4*X6*d6*dq14*m_6*C2*C3*CC5*C6 - 2*YY6*dq14*m_6*C5*CC6*S2*S3*S5 + 2*Y5*Z5*dq12*m_5*C2*CC4*C5*S3 + 2*Y5*Z5*dq12*m_5*C3*CC4*C5*S2 + 2*Y5*Z5*dq13*m_5*C2*CC4*C5*S3 + 2*Y5*Z5*dq13*m_5*C3*CC4*C5*S2 - 4*Y6*Z6*dq14*m_6*C2*C3*CC5*S6 - 4*Ixy6*dq12*CC5*C6*S2*S3*S4*S6 - 4*Ixy6*dq13*CC5*C6*S2*S3*S4*S6 - 4*Y6*d6*dq14*m_6*C2*C3*CC5*S6 - 4*Z6*d6*dq12*m_6*C2*C3*CC5*S4 - 4*Z6*d6*dq13*m_6*C2*C3*CC5*S4 + 4*Z6*d6*dq14*m_6*C2*C4*CC5*S3 + 4*Z6*d6*dq14*m_6*C3*C4*CC5*S2 - 2*X5*Y5*dq12*m_5*C2*CC4*S3*S5 - 2*X5*Y5*dq12*m_5*C3*CC4*S2*S5 - 2*X5*Y5*dq13*m_5*C2*CC4*S3*S5 - 2*X5*Y5*dq13*m_5*C3*CC4*S2*S5 + 2*X6*Y6*dq12*m_6*C2*CC4*S3*S5 + 2*X6*Y6*dq12*m_6*C3*CC4*S2*S5 + 2*X6*Y6*dq13*m_6*C2*CC4*S3*S5 + 2*X6*Y6*dq13*m_6*C3*CC4*S2*S5 + 4*X6*Y6*dq12*m_6*C2*CC6*S3*S5 + 4*X6*Y6*dq12*m_6*C3*CC6*S2*S5 + 4*X6*Y6*dq13*m_6*C2*CC6*S3*S5 + 4*X6*Y6*dq13*m_6*C3*CC6*S2*S5 + 4*X6*Y6*dq16*m_6*C2*CC6*S3*S4 + 4*X6*Y6*dq16*m_6*C3*CC6*S2*S4 - 4*X6*Y6*dq23*m_6*C4*CC6*S4*S5 + 4*X6*Y6*dq24*m_6*CC5*C6*S4*S6 + 4*X6*Y6*dq34*m_6*CC5*C6*S4*S6 - 4*X6*Z6*dq14*m_6*CC5*C6*S2*S3 + 8*Ixy6*dq11*C2*CC3*C4*CC5*C6*S2*S6 + 8*Ixy6*dq11*CC2*C3*C4*CC5*C6*S3*S6 - 4*Ixz6*dq11*C2*C3*CC4*CC5*C6*S2*S3 - 4*X6*d6*dq14*m_6*CC5*C6*S2*S3 + 4*Y6*Z6*dq14*m_6*CC5*S2*S3*S6 + 2*Ixx6*dq11*CC2*CC3*C4*C6*S4*S5*S6 - 2*Iyy6*dq11*CC2*CC3*C4*C6*S4*S5*S6 + 4*Iyz6*dq11*C2*C3*CC4*CC5*S2*S3*S6 + 4*Y6*d6*dq14*m_6*CC5*S2*S3*S6 + 4*Z6*d6*dq12*m_6*CC5*S2*S3*S4 + 4*Z6*d6*dq13*m_6*CC5*S2*S3*S4 + 2*Y5*Z5*dq11*m_5*CC2*CC3*C4*C5*S4 + 2*X6*a3*dq11*m_6*CC2*CC3*C4*C6*S5 + 2*XX6*dq12*m_6*C2*C3*CC5*CC6*S4 + 2*XX6*dq13*m_6*C2*C3*CC5*CC6*S4 - 2*XX6*dq14*m_6*C2*C4*CC5*CC6*S3 - 2*XX6*dq14*m_6*C3*C4*CC5*CC6*S2 - 2*YY6*dq12*m_6*C2*C3*CC5*CC6*S4 - 2*YY6*dq13*m_6*C2*C3*CC5*CC6*S4 + 2*YY6*dq14*m_6*C2*C4*CC5*CC6*S3 + 2*YY6*dq14*m_6*C3*C4*CC5*CC6*S2 - 8*Z6*d6*dq11*m_6*C2*CC3*C4*CC5*S2 - 8*Z6*d6*dq11*m_6*CC2*C3*C4*CC5*S3 - 2*X5*Y5*dq11*m_5*CC2*CC3*C4*S4*S5 + 2*X6*Y6*dq11*m_6*CC2*CC3*C4*S4*S5 + 2*X6*Y6*dq11*m_6*CC2*C4*CC6*S4*S5 + 2*X6*Y6*dq11*m_6*CC3*C4*CC6*S4*S5 - 2*Y6*a3*dq11*m_6*CC2*CC3*C4*S5*S6 - 2*XX6*dq12*m_6*CC5*CC6*S2*S3*S4 - 2*XX6*dq13*m_6*CC5*CC6*S2*S3*S4 + 2*YY6*dq12*m_6*CC5*CC6*S2*S3*S4 + 2*YY6*dq13*m_6*CC5*CC6*S2*S3*S4 + 2*Iyz5*dq11*C2*C3*C4*C5*S2*S3*S4 + 4*XX6*dq11*m_6*C2*CC3*C4*CC5*CC6*S2 + 4*XX6*dq11*m_6*CC2*C3*C4*CC5*CC6*S3 - 4*YY6*dq11*m_6*C2*CC3*C4*CC5*CC6*S2 - 4*YY6*dq11*m_6*CC2*C3*C4*CC5*CC6*S3 - 2*XX5*dq11*m_5*C2*C3*C5*S2*S3*S5 + XX6*dq11*m_6*C2*C5*C6*S2*S4*S6 + XX6*dq11*m_6*C3*C5*C6*S3*S4*S6 - 2*YY6*dq11*m_6*C2*C3*C5*S2*S3*S5 - YY6*dq11*m_6*C2*C5*C6*S2*S4*S6 - YY6*dq11*m_6*C3*C5*C6*S3*S4*S6 + 2*ZZ5*dq11*m_5*C2*C3*C5*S2*S3*S5 + 2*ZZ6*dq11*m_6*C2*C3*C5*S2*S3*S5 + 4*Ixy6*dq11*CC2*CC3*CC4*C5*C6*S5*S6 - 2*Ixy5*dq11*C2*C3*C4*S2*S3*S4*S5 + 2*Ixy6*dq11*C2*C3*C4*S2*S3*S4*S5 + 2*dd6*dq11*m_6*C2*C3*C5*S2*S3*S5 + X6*a2*dq11*m_6*C2*C3*C5*C6*S2 + X6*a1*dq11*m_6*C2*C3*C4*C6*S5 - 2*X6*Y6*dq11*m_6*C2*C4*C6*S2*S6 - 2*X6*Y6*dq11*m_6*C3*C4*C6*S3*S6 - 4*X5*Z5*dq11*m_5*C2*C4*C5*S2*S5 - 2*X6*Z6*dq11*m_6*C2*C3*C6*S2*S3 - 4*X5*Z5*dq11*m_5*C3*C4*C5*S3*S5 - 4*Ixy6*dq14*C2*C3*C5*C6*S5*S6 - 4*Ixy6*dq16*C2*C4*C5*C6*S3*S6 - 4*Ixy6*dq16*C3*C4*C5*C6*S2*S6 - 4*Ixz6*dq12*C2*C3*C5*C6*S4*S5 - 4*Ixz6*dq13*C2*C3*C5*C6*S4*S5 + 4*Ixz6*dq14*C2*C4*C5*C6*S3*S5 + 4*Ixz6*dq14*C3*C4*C5*C6*S2*S5 - Y6*a2*dq11*m_6*C2*C3*C5*S2*S6 - Y6*a1*dq11*m_6*C2*C3*C4*S5*S6 + Z5*a2*dq11*m_5*C2*C4*C5*S2*S3 + Z6*a2*dq11*m_6*C2*C4*C5*S2*S3 + 2*X5*d4*dq11*m_5*C2*C3*C5*S2*S3 - 2*X6*d6*dq11*m_6*C2*C3*C6*S2*S3 - X6*d4*dq11*m_6*C2*C4*C6*S2*S5 - X6*d4*dq11*m_6*C3*C4*C6*S3*S5 + 2*X6*Z6*dq16*m_6*C2*C3*C5*C6 + 2*Y6*Z6*dq11*m_6*C2*C3*S2*S3*S6 + Y6*Z6*dq11*m_6*C2*C6*S2*S4*S5 + Y6*Z6*dq11*m_6*C3*C6*S3*S4*S5 + a2*d6*dq11*m_6*C2*C4*C5*S2*S3 + 2*Ixx5*dq12*C2*C4*C5*S3*S4*S5 + 2*Ixx5*dq12*C3*C4*C5*S2*S4*S5 + 2*Ixx5*dq13*C2*C4*C5*S3*S4*S5 + 2*Ixx5*dq13*C3*C4*C5*S2*S4*S5 - 2*Ixx6*dq14*C2*C5*C6*S3*S4*S6 - 2*Ixx6*dq14*C3*C5*C6*S2*S4*S6 + 2*Iyy6*dq12*C2*C4*C5*S3*S4*S5 + 2*Iyy6*dq12*C3*C4*C5*S2*S4*S5 + 2*Iyy6*dq13*C2*C4*C5*S3*S4*S5 + 2*Iyy6*dq13*C3*C4*C5*S2*S4*S5 + 2*Iyy6*dq14*C2*C5*C6*S3*S4*S6 + 2*Iyy6*dq14*C3*C5*C6*S2*S4*S6 + 4*Iyz6*dq12*C2*C3*C5*S4*S5*S6 + 4*Iyz6*dq13*C2*C3*C5*S4*S5*S6 - 4*Iyz6*dq14*C2*C4*C5*S3*S5*S6 - 4*Iyz6*dq14*C3*C4*C5*S2*S5*S6 - 2*Izz5*dq12*C2*C4*C5*S3*S4*S5 - 2*Izz5*dq12*C3*C4*C5*S2*S4*S5 - 2*Izz5*dq13*C2*C4*C5*S3*S4*S5 - 2*Izz5*dq13*C3*C4*C5*S2*S4*S5 - 2*Izz6*dq12*C2*C4*C5*S3*S4*S5 - 2*Izz6*dq12*C3*C4*C5*S2*S4*S5 - 2*Izz6*dq13*C2*C4*C5*S3*S4*S5 - 2*Izz6*dq13*C3*C4*C5*S2*S4*S5 - X5*a2*dq11*m_5*C2*C4*S2*S3*S5 - X6*a1*dq11*m_6*C4*C6*S2*S3*S5 - 4*Z6*d6*dq11*m_6*CC2*CC3*CC4*C5*S5 + 2*XX6*dq12*m_6*C2*C6*S3*S5*S6 + 2*XX6*dq12*m_6*C3*C6*S2*S5*S6 + 2*XX6*dq13*m_6*C2*C6*S3*S5*S6 + 2*XX6*dq13*m_6*C3*C6*S2*S5*S6 + 2*XX6*dq16*m_6*C2*C6*S3*S4*S6 + 2*XX6*dq16*m_6*C3*C6*S2*S4*S6
 - 2*XX6*dq23*m_6*C4*C6*S4*S5*S6 + 2*X6*d6*dq16*m_6*C2*C3*C5*C6 + 2*Y6*d6*dq11*m_6*C2*C3*S2*S3*S6 + Y6*d4*dq11*m_6*C2*C4*S2*S5*S6 + Y6*d4*dq11*m_6*C3*C4*S3*S5*S6 + Y6*d6*dq11*m_6*C2*C6*S2*S4*S5 + Y6*d6*dq11*m_6*C3*C6*S3*S4*S5 - 2*YY6*dq12*m_6*C2*C6*S3*S5*S6 - 2*YY6*dq12*m_6*C3*C6*S2*S5*S6 - 2*YY6*dq13*m_6*C2*C6*S3*S5*S6 - 2*YY6*dq13*m_6*C3*C6*S2*S5*S6 - 2*YY6*dq16*m_6*C2*C6*S3*S4*S6 - 2*YY6*dq16*m_6*C3*C6*S2*S4*S6 + 2*YY6*dq23*m_6*C4*C6*S4*S5*S6 + 2*Z5*d4*dq11*m_5*C2*C3*S2*S3*S5 + 2*Z6*d4*dq11*m_6*C2*C3*S2*S3*S5 + X6*Z6*dq11*m_6*C2*S2*S4*S5*S6 + X6*Z6*dq11*m_6*C3*S3*S4*S5*S6 - 2*Y6*Z6*dq12*m_6*C2*C5*C6*S3 - 2*Y6*Z6*dq12*m_6*C3*C5*C6*S2 - 2*Y6*Z6*dq13*m_6*C2*C5*C6*S3 - 2*Y6*Z6*dq13*m_6*C3*C5*C6*S2 - 2*Y6*Z6*dq16*m_6*C2*C3*C5*S6 + 2*Y6*Z6*dq23*m_6*C4*C5*C6*S4 + 4*Ixy6*dq14*C5*C6*S2*S3*S5*S6 + 4*Ixz6*dq12*C5*C6*S2*S3*S4*S5 + 4*Ixz6*dq13*C5*C6*S2*S3*S4*S5 + 2*d4*d6*dq11*m_6*C2*C3*S2*S3*S5 + Y6*a1*dq11*m_6*C4*S2*S3*S5*S6 + X6*d6*dq11*m_6*C2*S2*S4*S5*S6 + X6*d6*dq11*m_6*C3*S3*S4*S5*S6 - 2*Y6*d6*dq12*m_6*C2*C5*C6*S3 - 2*Y6*d6*dq12*m_6*C3*C5*C6*S2 - 2*Y6*d6*dq13*m_6*C2*C5*C6*S3 - 2*Y6*d6*dq13*m_6*C3*C5*C6*S2 - 2*Y6*d6*dq16*m_6*C2*C3*C5*S6 + 2*Y6*d6*dq23*m_6*C4*C5*C6*S4 - 2*Z5*d4*dq12*m_5*C2*C3*C5*S4 - 2*Z5*d4*dq13*m_5*C2*C3*C5*S4 - 2*Z6*d4*dq12*m_6*C2*C3*C5*S4 - 2*Z6*d4*dq13*m_6*C2*C3*C5*S4 + 4*Z6*d6*dq14*m_6*C2*C3*C5*S5 + 2*X5*Y5*dq14*m_5*C2*C5*S3*S4 + 2*X5*Y5*dq14*m_5*C3*C5*S2*S4 - 2*X6*Y6*dq14*m_6*C2*C5*S3*S4 - 2*X6*Y6*dq14*m_6*C3*C5*S2*S4 + 4*X6*Y6*dq23*m_6*C5*C6*S5*S6 + 4*X6*Y6*dq26*m_6*C5*C6*S4*S6 + 4*X6*Y6*dq36*m_6*C5*C6*S4*S6 - 2*X5*Z5*dq12*m_5*C2*C4*S3*S4 - 2*X5*Z5*dq12*m_5*C3*C4*S2*S4 - 2*X5*Z5*dq13*m_5*C2*C4*S3*S4 - 2*X5*Z5*dq13*m_5*C3*C4*S2*S4 - 2*X6*Z6*dq12*m_6*C2*C5*S3*S6 - 2*X6*Z6*dq12*m_6*C3*C5*S2*S6 - 2*X6*Z6*dq13*m_6*C2*C5*S3*S6 - 2*X6*Z6*dq13*m_6*C3*C5*S2*S6 - 2*X6*Z6*dq16*m_6*C5*C6*S2*S3 + 2*X6*Z6*dq23*m_6*C4*C5*S4*S6 - 4*X6*Z6*dq24*m_6*C5*C6*S4*S5 - 4*X6*Z6*dq34*m_6*C5*C6*S4*S5 - 8*Ixz6*dq11*C2*CC3*C4*C5*C6*S2*S5 - 8*Ixz6*dq11*CC2*C3*C4*C5*C6*S3*S5 - 4*Iyz6*dq12*C5*S2*S3*S4*S5*S6 - 4*Iyz6*dq13*C5*S2*S3*S4*S5*S6 - 2*d4*d6*dq12*m_6*C2*C3*C5*S4 - 2*d4*d6*dq13*m_6*C2*C3*C5*S4 + 2*Z5*a3*dq12*m_5*C2*C5*S3*S4 + 2*Z5*a3*dq12*m_5*C3*C5*S2*S4 + 2*Z5*a3*dq13*m_5*C2*C5*S3*S4 + 2*Z5*a3*dq13*m_5*C3*C5*S2*S4 + 2*Z6*a3*dq12*m_6*C2*C5*S3*S4 + 2*Z6*a3*dq12*m_6*C3*C5*S2*S4 + 2*Z6*a3*dq13*m_6*C2*C5*S3*S4 + 2*Z6*a3*dq13*m_6*C3*C5*S2*S4 + 2*X5*d4*dq12*m_5*C2*C3*S4*S5 + 2*X5*d4*dq13*m_5*C2*C3*S4*S5 - 2*X6*d6*dq12*m_6*C2*C5*S3*S6 - 2*X6*d6*dq12*m_6*C3*C5*S2*S6 - 2*X6*d6*dq13*m_6*C2*C5*S3*S6 - 2*X6*d6*dq13*m_6*C3*C5*S2*S6 - 2*X6*d6*dq16*m_6*C5*C6*S2*S3 + 2*X6*d6*dq23*m_6*C4*C5*S4*S6 - 4*X6*d6*dq24*m_6*C5*C6*S4*S5 - 4*X6*d6*dq34*m_6*C5*C6*S4*S5 + 2*Y5*Z5*dq14*m_5*C2*S3*S4*S5 + 2*Y5*Z5*dq14*m_5*C3*S2*S4*S5 + 2*Y6*Z6*dq16*m_6*C5*S2*S3*S6 + 4*Y6*Z6*dq24*m_6*C5*S4*S5*S6 + 4*Y6*Z6*dq34*m_6*C5*S4*S5*S6 + 2*Ixx5*dq11*C2*C3*CC4*C5*S2*S3*S5 + 2*Ixx6*dq11*C2*C3*C5*CC6*S2*S3*S5 + 2*Ixx6*dq11*C2*CC3*C5*C6*S2*S4*S6 + 2*Ixx6*dq11*CC2*C3*C5*C6*S3*S4*S6 + 2*Iyy6*dq11*C2*C3*CC4*C5*S2*S3*S5 - 2*Iyy6*dq11*C2*C3*C5*CC6*S2*S3*S5 - 2*Iyy6*dq11*C2*CC3*C5*C6*S2*S4*S6 - 2*Iyy6*dq11*CC2*C3*C5*C6*S3*S4*S6 + 8*Iyz6*dq11*C2*CC3*C4*C5*S2*S5*S6 + 8*Iyz6*dq11*CC2*C3*C4*C5*S3*S5*S6 - 2*Izz5*dq11*C2*C3*CC4*C5*S2*S3*S5 - 2*Izz6*dq11*C2*C3*CC4*C5*S2*S3*S5 + 2*a3*d6*dq12*m_6*C2*C5*S3*S4 + 2*a3*d6*dq12*m_6*C3*C5*S2*S4 + 2*a3*d6*dq13*m_6*C2*C5*S3*S4 + 2*a3*d6*dq13*m_6*C3*C5*S2*S4 - 2*X5*a3*dq12*m_5*C2*S3*S4*S5 - 2*X5*a3*dq12*m_5*C3*S2*S4*S5 - 2*X5*a3*dq13*m_5*C2*S3*S4*S5 - 2*X5*a3*dq13*m_5*C3*S2*S4*S5 - 2*X6*a2*dq12*m_6*C6*S2*S4*S5 + 2*XX6*dq11*m_6*CC2*CC3*CC4*C5*CC6*S5 - 2*YY6*dq11*m_6*CC2*CC3*CC4*C5*CC6*S5 + XX6*dq11*m_6*CC2*C4*C6*S4*S5*S6 + XX6*dq11*m_6*CC3*C4*C6*S4*S5*S6 - YY6*dq11*m_6*CC2*C4*C6*S4*S5*S6 - YY6*dq11*m_6*CC3*C4*C6*S4*S5*S6 + 2*Y6*d6*dq16*m_6*C5*S2*S3*S6 + 4*Y6*d6*dq24*m_6*C5*S4*S5*S6 + 4*Y6*d6*dq34*m_6*C5*S4*S5*S6 + 2*Z5*d4*dq12*m_5*C5*S2*S3*S4 + 2*Z5*d4*dq13*m_5*C5*S2*S3*S4 + 2*Z6*d4*dq12*m_6*C5*S2*S3*S4 + 2*Z6*d4*dq13*m_6*C5*S2*S3*S4 - 4*Z6*d6*dq14*m_6*C5*S2*S3*S5 - Y6*Z6*dq11*m_6*CC2*C4*C5*C6*S4 - Y6*Z6*dq11*m_6*CC3*C4*C5*C6*S4 + 2*X6*a3*dq11*m_6*C2*CC3*C5*C6*S2 + X6*a2*dq11*m_6*CC2*C3*C4*C6*S5 + 2*X6*a3*dq11*m_6*CC2*C3*C5*C6*S3 + 2*d4*d6*dq12*m_6*C5*S2*S3*S4 + 2*d4*d6*dq13*m_6*C5*S2*S3*S4 + 2*Y6*a2*dq12*m_6*S2*S4*S5*S6 - 2*XX6*dq14*m_6*C2*C3*C5*CC6*S5 - 2*XX6*dq16*m_6*C2*C4*C5*CC6*S3 - 2*XX6*dq16*m_6*C3*C4*C5*CC6*S2 - Y6*d6*dq11*m_6*CC2*C4*C5*C6*S4 - Y6*d6*dq11*m_6*CC3*C4*C5*C6*S4 - 2*X5*d4*dq12*m_5*S2*S3*S4*S5 - 2*X5*d4*dq13*m_5*S2*S3*S4*S5 + 2*YY6*dq14*m_6*C2*C3*C5*CC6*S5 + 2*YY6*dq16*m_6*C2*C4*C5*CC6*S3 + 2*YY6*dq16*m_6*C3*C4*C5*CC6*S2 - 2*Z5*d4*dq11*m_5*C2*CC3*C4*C5*S2 - 2*Z5*d4*dq11*m_5*CC2*C3*C4*C5*S3 - 2*Z6*d4*dq11*m_6*C2*CC3*C4*C5*S2 - 2*Z6*d4*dq11*m_6*CC2*C3*C4*C5*S3 - 4*X6*Z6*dq11*m_6*CC2*CC3*CC4*CC5*C6 - 2*X5*Y5*dq11*m_5*C2*CC3*C5*S2*S4 - 2*X5*Y5*dq11*m_5*CC2*C3*C5*S3*S4 + 2*X6*Y6*dq11*m_6*C2*CC3*C5*S2*S4 + 2*X6*Y6*dq11*m_6*CC2*C3*C5*S3*S4 + 2*X6*Y6*dq11*m_6*C2*C5*CC6*S2*S4 + 2*X6*Y6*dq11*m_6*C3*C5*CC6*S3*S4 + 2*X6*Y6*dq11*m_6*CC2*C5*C6*S5*S6 + 2*X6*Y6*dq11*m_6*CC3*C5*C6*S5*S6 - 2*X6*Y6*dq22*m_6*CC4*C5*C6*S5*S6 - 2*X6*Y6*dq33*m_6*CC4*C5*C6*S5*S6 - 2*X5*Z5*dq11*m_5*C2*C3*CC4*S2*S3 + 4*X5*Z5*dq11*m_5*C2*C3*CC5*S2*S3 - X6*Z6*dq11*m_6*CC2*C4*C5*S4*S6 - X6*Z6*dq11*m_6*CC3*C4*C5*S4*S6 + 4*Ixy6*dq12*C2*C3*CC5*C6*S4*S6 + 4*Ixy6*dq13*C2*C3*CC5*C6*S4*S6 - 4*Ixy6*dq14*C2*C4*CC5*C6*S3*S6 - 4*Ixy6*dq14*C3*C4*CC5*C6*S2*S6 - 4*Ixz6*dq12*C2*C4*CC5*C6*S3*S4 - 4*Ixz6*dq12*C3*C4*CC5*C6*S2*S4 - 4*Ixz6*dq13*C2*C4*CC5*C6*S3*S4 - 4*Ixz6*dq13*C3*C4*CC5*C6*S2*S4 - 2*d4*d6*dq11*m_6*C2*CC3*C4*C5*S2 - 2*d4*d6*dq11*m_6*CC2*C3*C4*C5*S3 - 2*Y6*a3*dq11*m_6*C2*CC3*C5*S2*S6 - Y6*a2*dq11*m_6*CC2*C3*C4*S5*S6 - 2*Y6*a3*dq11*m_6*CC2*C3*C5*S3*S6 - 4*X6*d6*dq11*m_6*CC2*CC3*CC4*CC5*C6 + 2*X5*d4*dq11*m_5*C2*CC3*C4*S2*S5 + 2*X5*d4*dq11*m_5*CC2*C3*C4*S3*S5 - X6*d6*dq11*m_6*CC2*C4*C5*S4*S6 - X6*d6*dq11*m_6*CC3*C4*C5*S4*S6 + 4*Y6*Z6*dq11*m_6*CC2*CC3*CC4*CC5*S6 + 4*X6*Z6*dq14*m_6*C2*C3*CC5*C6 - 2*Y5*Z5*dq11*m_5*C2*CC3*S2*S4*S5 - 2*Y5*Z5*dq11*m_5*CC2*C3*S3*S4*S5 + 2*Ixx6*dq12*C2*CC4*C6*S3*S5*S6 + 2*Ixx6*dq12*C3*CC4*C6*S2*S5*S6 + 2*Ixx6*dq13*C2*CC4*C6*S3*S5*S6 + 2*Ixx6*dq13*C3*CC4*C6*S2*S5*S6 - 2*Iyy6*dq12*C2*CC4*C6*S3*S5*S6 - 2*Iyy6*dq12*C3*CC4*C6*S2*S5*S6 - 2*Iyy6*dq13*C2*CC4*C6*S3*S5*S6 - 2*Iyy6*dq13*C3*CC4*C6*S2*S5*S6 + 4*Iyz6*dq12*C2*C4*CC5*S3*S4*S6 + 4*Iyz6*dq12*C3*C4*CC5*S2*S4*S6 + 4*Iyz6*dq13*C2*C4*CC5*S3*S4*S6 + 4*Iyz6*dq13*C3*C4*CC5*S2*S4*S6 - 2*XX6*dq11*m_6*CC2*CC3*C4*C6*S4*S5*S6 + 2*YY6*dq11*m_6*CC2*CC3*C4*C6*S4*S5*S6 + 2*Y6*Z6*dq11*m_6*CC2*CC3*C4*C5*C6*S4 + 2*Y6*d6*dq11*m_6*CC2*CC3*C4*C5*C6*S4 - 4*X6*Y6*dq11*m_6*C2*CC3*C5*CC6*S2*S4 - 4*X6*Y6*dq11*m_6*CC2*C3*C5*CC6*S3*S4 - 4*X6*Y6*dq11*m_6*CC2*CC3*C5*C6*S5*S6 + 2*X6*Y6*dq11*m_6*CC2*CC4*C5*C6*S5*S6 + 2*X6*Y6*dq11*m_6*CC3*CC4*C5*C6*S5*S6 + 4*X5*Z5*dq11*m_5*C2*C3*CC4*CC5*S2*S3 + 2*X6*Z6*dq11*m_6*CC2*CC3*C4*C5*S4*S6 + 2*X6*d6*dq11*m_6*CC2*CC3*C4*C5*S4*S6 + 2*Iyz6*dq11*C2*C3*C4*C5*C6*S2*S3*S4 - 4*X6*Y6*dq12*m_6*C2*CC4*CC6*S3*S5 - 4*X6*Y6*dq12*m_6*C3*CC4*CC6*S2*S5 - 4*X6*Y6*dq13*m_6*C2*CC4*CC6*S3*S5 - 4*X6*Y6*dq13*m_6*C3*CC4*CC6*S2*S5 - 4*Ixy6*dq11*C2*C3*C5*C6*S2*S3*S5*S6 + 2*Ixz6*dq11*C2*C3*C4*C5*S2*S3*S4*S6 - 4*X6*Z6*dq11*m_6*C2*C4*C5*C6*S2*S5 - 4*X6*Z6*dq11*m_6*C3*C4*C5*C6*S3*S5 + 2*Z5*a3*dq11*m_5*C2*C3*C4*C5*S2*S3 + 2*Z6*a3*dq11*m_6*C2*C3*C4*C5*S2*S3 + 2*X6*d4*dq11*m_6*C2*C3*C5*C6*S2*S3 - 4*X6*d6*dq11*m_6*C2*C4*C5*C6*S2*S5 - 4*X6*d6*dq11*m_6*C3*C4*C5*C6*S3*S5 + 4*Y6*Z6*dq11*m_6*C2*C4*C5*S2*S5*S6 + 4*Y6*Z6*dq11*m_6*C3*C4*C5*S3*S5*S6 + 2*a3*d6*dq11*m_6*C2*C3*C4*C5*S2*S3 - 2*X5*a3*dq11*m_5*C2*C3*C4*S2*S3*S5 - X6*a2*dq11*m_6*C2*C4*C6*S2*S3*S5 - 2*XX5*dq12*m_5*C2*C4*C5*S3*S4*S5 - 2*XX5*dq12*m_5*C3*C4*C5*S2*S4*S5 - 2*XX5*dq13*m_5*C2*C4*C5*S3*S4*S5 - 2*XX5*dq13*m_5*C3*C4*C5*S2*S4*S5 + 2*XX6*dq14*m_6*C2*C5*C6*S3*S4*S6 + 2*XX6*dq14*m_6*C3*C5*C6*S2*S4*S6 - 2*Y6*d4*dq11*m_6*C2*C3*C5*S2*S3*S6 + 4*Y6*d6*dq11*m_6*C2*C4*C5*S2*S5*S6 + 4*Y6*d6*dq11*m_6*C3*C4*C5*S3*S5*S6 - 2*YY6*dq12*m_6*C2*C4*C5*S3*S4*S5 - 2*YY6*dq12*m_6*C3*C4*C5*S2*S4*S5 - 2*YY6*dq13*m_6*C2*C4*C5*S3*S4*S5 - 2*YY6*dq13*m_6*C3*C4*C5*S2*S4*S5 - 2*YY6*dq14*m_6*C2*C5*C6*S3*S4*S6 - 2*YY6*dq14*m_6*C3*C5*C6*S2*S4*S6 + 4*Z6*d6*dq11*m_6*C2*C3*C5*S2*S3*S5 + 2*ZZ5*dq12*m_5*C2*C4*C5*S3*S4*S5 + 2*ZZ5*dq12*m_5*C3*C4*C5*S2*S4*S5 + 2*ZZ5*dq13*m_5*C2*C4*C5*S3*S4*S5 + 2*ZZ5*dq13*m_5*C3*C4*C5*S2*S4*S5 + 2*ZZ6*dq12*m_6*C2*C4*C5*S3*S4*S5 + 2*ZZ6*dq12*m_6*C3*C4*C5*S2*S4*S5 + 2*ZZ6*dq13*m_6*C2*C4*C5*S3*S4*S5 + 2*ZZ6*dq13*m_6*C3*C4*C5*S2*S4*S5 - 4*X6*Y6*dq11*m_6*CC2*CC3*C4*CC6*S4*S5 + 2*dd6*dq12*m_6*C2*C4*C5*S3*S4*S5 + 2*dd6*dq12*m_6*C3*C4*C5*S2*S4*S5 + 2*dd6*dq13*m_6*C2*C4*C5*S3*S4*S5 + 2*dd6*dq13*m_6*C3*C4*C5*S2*S4*S5 + Y6*a2*dq11*m_6*C2*C4*S2*S3*S5*S6 + 4*X6*Y6*dq12*m_6*C2*C3*C6*S4*S6 + 4*X6*Y6*dq13*m_6*C2*C3*C6*S4*S6 + 4*X6*Y6*dq16*m_6*C2*C3*C6*S5*S6 + 4*X5*Z5*dq12*m_5*C2*C3*C5*S4*S5 + 4*X5*Z5*dq13*m_5*C2*C3*C5*S4*S5 - 4*X5*Z5*dq14*m_5*C2*C4*C5*S3*S5 - 4*X5*Z5*dq14*m_5*C3*C4*C5*S2*S5 - 2*X6*Z6*dq12*m_6*C2*C4*C6*S3*S4 - 2*X6*Z6*dq12*m_6*C3*C4*C6*S2*S4 - 2*X6*Z6*dq13*m_6*C2*C4*C6*S3*S4 - 2*X6*Z6*dq13*m_6*C3*C4*C6*S2*S4 - 2*X6*Z6*dq16*m_6*C2*C4*C6*S3*S5 - 2*X6*Z6*dq16*m_6*C3*C4*C6*S2*S5 + 2*X6*d4*dq12*m_6*C2*C3*C6*S4*S5 + 2*X6*d4*dq13*m_6*C2*C3*C6*S4*S5 - 2*X6*d6*dq12*m_6*C2*C4*C6*S3*S4 - 2*X6*d6*dq12*m_6*C3*C4*C6*S2*S4 - 2*X6*d6*dq13*m_6*C2*C4*C6*S3*S4 - 2*X6*d6*dq13*m_6*C3*C4*C6*S2*S4 - 2*X6*d6*dq16*m_6*C2*C4*C6*S3*S5 - 2*X6*d6*dq16*m_6*C3*C4*C6*S2*S5 + 2*Y6*Z6*dq12*m_6*C2*C4*S3*S4*S6 + 2*Y6*Z6*dq12*m_6*C3*C4*S2*S4*S6 + 2*Y6*Z6*dq13*m_6*C2*C4*S3*S4*S6 + 2*Y6*Z6*dq13*m_6*C3*C4*S2*S4*S6 + 2*Y6*Z6*dq14*m_6*C2*C6*S3*S4*S5 + 2*Y6*Z6*dq14*m_6*C3*C6*S2*S4*S5 + 2*Y6*Z6*dq16*m_6*C2*C4*S3*S5*S6 + 2*Y6*Z6*dq16*m_6*C3*C4*S2*S5*S6 - 2*X6*a3*dq12*m_6*C2*C6*S3*S4*S5 - 2*X6*a3*dq12*m_6*C3*C6*S2*S4*S5 - 2*X6*a3*dq13*m_6*C2*C6*S3*S4*S5 - 2*X6*a3*dq13*m_6*C3*C6*S2*S4*S5 - 2*XX5*dq11*m_5*C2*C3*CC4*C5*S2*S3*S5 - 2*XX6*dq11*m_6*C2*C3*C5*CC6*S2*S3*S5 - 2*XX6*dq11*m_6*C2*CC3*C5*C6*S2*S4*S6 - 2*XX6*dq11*m_6*CC2*C3*C5*C6*S3*S4*S6
 - 2*YY6*dq11*m_6*C2*C3*CC4*C5*S2*S3*S5 + 2*YY6*dq11*m_6*C2*C3*C5*CC6*S2*S3*S5 + 2*YY6*dq11*m_6*C2*CC3*C5*C6*S2*S4*S6 + 2*YY6*dq11*m_6*CC2*C3*C5*C6*S3*S4*S6 + 2*ZZ5*dq11*m_5*C2*C3*CC4*C5*S2*S3*S5 + 2*ZZ6*dq11*m_6*C2*C3*CC4*C5*S2*S3*S5 - 2*Y6*d4*dq12*m_6*C2*C3*S4*S5*S6 - 2*Y6*d4*dq13*m_6*C2*C3*S4*S5*S6 + 2*Y6*d6*dq12*m_6*C2*C4*S3*S4*S6 + 2*Y6*d6*dq12*m_6*C3*C4*S2*S4*S6 + 2*Y6*d6*dq13*m_6*C2*C4*S3*S4*S6 + 2*Y6*d6*dq13*m_6*C3*C4*S2*S4*S6 + 2*Y6*d6*dq14*m_6*C2*C6*S3*S4*S5 + 2*Y6*d6*dq14*m_6*C3*C6*S2*S4*S5 + 2*Y6*d6*dq16*m_6*C2*C4*S3*S5*S6 + 2*Y6*d6*dq16*m_6*C3*C4*S2*S5*S6 - 4*X6*Y6*dq12*m_6*C6*S2*S3*S4*S6 - 4*X6*Y6*dq13*m_6*C6*S2*S3*S4*S6 - 4*X6*Y6*dq16*m_6*C6*S2*S3*S5*S6 - 4*X5*Z5*dq12*m_5*C5*S2*S3*S4*S5 - 4*X5*Z5*dq13*m_5*C5*S2*S3*S4*S5 + 2*X6*Z6*dq14*m_6*C2*S3*S4*S5*S6 + 2*X6*Z6*dq14*m_6*C3*S2*S4*S5*S6 - 4*Ixy6*dq11*C2*C3*C4*CC6*S2*S3*S4*S5 + 2*dd6*dq11*m_6*C2*C3*CC4*C5*S2*S3*S5 + 2*Y6*a3*dq12*m_6*C2*S3*S4*S5*S6 + 2*Y6*a3*dq12*m_6*C3*S2*S4*S5*S6 + 2*Y6*a3*dq13*m_6*C2*S3*S4*S5*S6 + 2*Y6*a3*dq13*m_6*C3*S2*S4*S5*S6 - 2*X6*d4*dq12*m_6*C6*S2*S3*S4*S5 - 2*X6*d4*dq13*m_6*C6*S2*S3*S4*S5 + 2*X6*d6*dq14*m_6*C2*S3*S4*S5*S6 + 2*X6*d6*dq14*m_6*C3*S2*S4*S5*S6 + 4*X6*Y6*dq11*m_6*C2*CC3*C4*C6*S2*S6 + 4*X6*Y6*dq11*m_6*CC2*C3*C4*C6*S3*S6 + 4*X6*Y6*dq11*m_6*C2*C4*CC5*C6*S2*S6 + 4*X6*Y6*dq11*m_6*C3*C4*CC5*C6*S3*S6 + 8*X5*Z5*dq11*m_5*C2*CC3*C4*C5*S2*S5 + 8*X5*Z5*dq11*m_5*CC2*C3*C4*C5*S3*S5 - 2*X6*Z6*dq11*m_6*C2*C3*CC4*C6*S2*S3 + 4*X6*Z6*dq11*m_6*C2*C3*CC5*C6*S2*S3 + 2*X6*d4*dq11*m_6*C2*CC3*C4*C6*S2*S5 - 2*X6*d6*dq11*m_6*C2*C3*CC4*C6*S2*S3 + 2*X6*d4*dq11*m_6*CC2*C3*C4*C6*S3*S5 + 4*X6*d6*dq11*m_6*C2*C3*CC5*C6*S2*S3 + 2*Y6*d4*dq12*m_6*S2*S3*S4*S5*S6 + 2*Y6*d4*dq13*m_6*S2*S3*S4*S5*S6 + 2*Y6*Z6*dq11*m_6*C2*C3*CC4*S2*S3*S6 - 4*Y6*Z6*dq11*m_6*C2*C3*CC5*S2*S3*S6 - 2*Y6*Z6*dq11*m_6*C2*CC3*C6*S2*S4*S5 - 2*Y6*Z6*dq11*m_6*CC2*C3*C6*S3*S4*S5 + 2*Ixx6*dq12*C2*C4*C5*CC6*S3*S4*S5 + 2*Ixx6*dq12*C3*C4*C5*CC6*S2*S4*S5 + 2*Ixx6*dq13*C2*C4*C5*CC6*S3*S4*S5 + 2*Ixx6*dq13*C3*C4*C5*CC6*S2*S4*S5 - 2*Iyy6*dq12*C2*C4*C5*CC6*S3*S4*S5 - 2*Iyy6*dq12*C3*C4*C5*CC6*S2*S4*S5 - 2*Iyy6*dq13*C2*C4*C5*CC6*S3*S4*S5 - 2*Iyy6*dq13*C3*C4*C5*CC6*S2*S4*S5 - 2*XX6*dq12*m_6*C2*CC4*C6*S3*S5*S6 - 2*XX6*dq12*m_6*C3*CC4*C6*S2*S5*S6 - 2*XX6*dq13*m_6*C2*CC4*C6*S3*S5*S6 - 2*XX6*dq13*m_6*C3*CC4*C6*S2*S5*S6 - 2*Y6*d4*dq11*m_6*C2*CC3*C4*S2*S5*S6 + 2*Y6*d6*dq11*m_6*C2*C3*CC4*S2*S3*S6 - 2*Y6*d4*dq11*m_6*CC2*C3*C4*S3*S5*S6 - 4*Y6*d6*dq11*m_6*C2*C3*CC5*S2*S3*S6 - 2*Y6*d6*dq11*m_6*C2*CC3*C6*S2*S4*S5 - 2*Y6*d6*dq11*m_6*CC2*C3*C6*S3*S4*S5 + 2*YY6*dq12*m_6*C2*CC4*C6*S3*S5*S6 + 2*YY6*dq12*m_6*C3*CC4*C6*S2*S5*S6 + 2*YY6*dq13*m_6*C2*CC4*C6*S3*S5*S6 + 2*YY6*dq13*m_6*C3*CC4*C6*S2*S5*S6 - 2*X6*Z6*dq11*m_6*C2*CC3*S2*S4*S5*S6 - 2*X6*Z6*dq11*m_6*CC2*C3*S3*S4*S5*S6 + 2*Y6*Z6*dq12*m_6*C2*CC4*C5*C6*S3 + 2*Y6*Z6*dq12*m_6*C3*CC4*C5*C6*S2 + 2*Y6*Z6*dq13*m_6*C2*CC4*C5*C6*S3 + 2*Y6*Z6*dq13*m_6*C3*CC4*C5*C6*S2 - 2*X6*d6*dq11*m_6*C2*CC3*S2*S4*S5*S6 - 2*X6*d6*dq11*m_6*CC2*C3*S3*S4*S5*S6 + 2*Y6*d6*dq12*m_6*C2*CC4*C5*C6*S3 + 2*Y6*d6*dq12*m_6*C3*CC4*C5*C6*S2 + 2*Y6*d6*dq13*m_6*C2*CC4*C5*C6*S3 + 2*Y6*d6*dq13*m_6*C3*CC4*C5*C6*S2 + 4*X6*Y6*dq14*m_6*C2*C5*CC6*S3*S4 + 4*X6*Y6*dq14*m_6*C3*C5*CC6*S2*S4 - 4*X6*Y6*dq23*m_6*CC4*C5*C6*S5*S6 + 4*X5*Z5*dq12*m_5*C2*C4*CC5*S3*S4 + 4*X5*Z5*dq12*m_5*C3*C4*CC5*S2*S4 + 4*X5*Z5*dq13*m_5*C2*C4*CC5*S3*S4 + 4*X5*Z5*dq13*m_5*C3*C4*CC5*S2*S4 + 2*X6*Z6*dq12*m_6*C2*CC4*C5*S3*S6 + 2*X6*Z6*dq12*m_6*C3*CC4*C5*S2*S6 + 2*X6*Z6*dq13*m_6*C2*CC4*C5*S3*S6 + 2*X6*Z6*dq13*m_6*C3*CC4*C5*S2*S6 + 2*X6*d6*dq12*m_6*C2*CC4*C5*S3*S6 + 2*X6*d6*dq12*m_6*C3*CC4*C5*S2*S6 + 2*X6*d6*dq13*m_6*C2*CC4*C5*S3*S6 + 2*X6*d6*dq13*m_6*C3*CC4*C5*S2*S6 + 2*Ixx6*dq11*C2*C3*CC4*C5*CC6*S2*S3*S5 - 2*Iyy6*dq11*C2*C3*CC4*C5*CC6*S2*S3*S5 - 4*Y6*Z6*dq11*m_6*C2*C3*CC4*CC5*S2*S3*S6 - 4*Y6*d6*dq11*m_6*C2*C3*CC4*CC5*S2*S3*S6 - 2*Ixx6*dq11*C2*C3*C4*C6*S2*S3*S4*S5*S6 + 2*Iyy6*dq11*C2*C3*C4*C6*S2*S3*S4*S5*S6 - 2*Y5*Z5*dq11*m_5*C2*C3*C4*C5*S2*S3*S4 - 2*X6*a3*dq11*m_6*C2*C3*C4*C6*S2*S3*S5 - 4*X6*Y6*dq11*m_6*CC2*CC3*CC4*C5*C6*S5*S6 + 2*X5*Y5*dq11*m_5*C2*C3*C4*S2*S3*S4*S5 - 2*X6*Y6*dq11*m_6*C2*C3*C4*S2*S3*S4*S5 - 4*Ixy6*dq12*C2*C4*C5*C6*S3*S4*S5*S6 - 4*Ixy6*dq12*C3*C4*C5*C6*S2*S4*S5*S6 - 4*Ixy6*dq13*C2*C4*C5*C6*S3*S4*S5*S6 - 4*Ixy6*dq13*C3*C4*C5*C6*S2*S4*S5*S6 + 2*Y6*a3*dq11*m_6*C2*C3*C4*S2*S3*S5*S6 + 4*X6*Y6*dq14*m_6*C2*C3*C5*C6*S5*S6 + 4*X6*Y6*dq16*m_6*C2*C4*C5*C6*S3*S6 + 4*X6*Y6*dq16*m_6*C3*C4*C5*C6*S2*S6 + 4*X6*Z6*dq12*m_6*C2*C3*C5*C6*S4*S5 + 4*X6*Z6*dq13*m_6*C2*C3*C5*C6*S4*S5 - 4*X6*Z6*dq14*m_6*C2*C4*C5*C6*S3*S5 - 4*X6*Z6*dq14*m_6*C3*C4*C5*C6*S2*S5 + 4*X6*d6*dq12*m_6*C2*C3*C5*C6*S4*S5 + 4*X6*d6*dq13*m_6*C2*C3*C5*C6*S4*S5 - 4*X6*d6*dq14*m_6*C2*C4*C5*C6*S3*S5 - 4*X6*d6*dq14*m_6*C3*C4*C5*C6*S2*S5 - 4*Y6*Z6*dq12*m_6*C2*C3*C5*S4*S5*S6 - 4*Y6*Z6*dq13*m_6*C2*C3*C5*S4*S5*S6 + 4*Y6*Z6*dq14*m_6*C2*C4*C5*S3*S5*S6 + 4*Y6*Z6*dq14*m_6*C3*C4*C5*S2*S5*S6 - 4*Y6*d6*dq12*m_6*C2*C3*C5*S4*S5*S6 - 4*Y6*d6*dq13*m_6*C2*C3*C5*S4*S5*S6 + 4*Y6*d6*dq14*m_6*C2*C4*C5*S3*S5*S6 + 4*Y6*d6*dq14*m_6*C3*C4*C5*S2*S5*S6 + 4*Z6*d6*dq12*m_6*C2*C4*C5*S3*S4*S5 + 4*Z6*d6*dq12*m_6*C3*C4*C5*S2*S4*S5 + 4*Z6*d6*dq13*m_6*C2*C4*C5*S3*S4*S5 + 4*Z6*d6*dq13*m_6*C3*C4*C5*S2*S4*S5 - 4*X6*Y6*dq14*m_6*C5*C6*S2*S3*S5*S6 - 4*X6*Z6*dq12*m_6*C5*C6*S2*S3*S4*S5 - 4*X6*Z6*dq13*m_6*C5*C6*S2*S3*S4*S5 - 4*Ixy6*dq11*C2*C3*CC4*C5*C6*S2*S3*S5*S6 - 4*X6*d6*dq12*m_6*C5*C6*S2*S3*S4*S5 - 4*X6*d6*dq13*m_6*C5*C6*S2*S3*S4*S5 + 8*X6*Z6*dq11*m_6*C2*CC3*C4*C5*C6*S2*S5 + 8*X6*Z6*dq11*m_6*CC2*C3*C4*C5*C6*S3*S5 + 4*Y6*Z6*dq12*m_6*C5*S2*S3*S4*S5*S6 + 4*Y6*Z6*dq13*m_6*C5*S2*S3*S4*S5*S6 + 8*X6*d6*dq11*m_6*C2*CC3*C4*C5*C6*S2*S5 + 8*X6*d6*dq11*m_6*CC2*C3*C4*C5*C6*S3*S5 + 4*Y6*d6*dq12*m_6*C5*S2*S3*S4*S5*S6 + 4*Y6*d6*dq13*m_6*C5*S2*S3*S4*S5*S6 - 8*Y6*Z6*dq11*m_6*C2*CC3*C4*C5*S2*S5*S6 - 8*Y6*Z6*dq11*m_6*CC2*C3*C4*C5*S3*S5*S6 - 2*XX6*dq12*m_6*C2*C4*C5*CC6*S3*S4*S5 - 2*XX6*dq12*m_6*C3*C4*C5*CC6*S2*S4*S5 - 2*XX6*dq13*m_6*C2*C4*C5*CC6*S3*S4*S5 - 2*XX6*dq13*m_6*C3*C4*C5*CC6*S2*S4*S5 - 8*Y6*d6*dq11*m_6*C2*CC3*C4*C5*S2*S5*S6 - 8*Y6*d6*dq11*m_6*CC2*C3*C4*C5*S3*S5*S6 + 2*YY6*dq12*m_6*C2*C4*C5*CC6*S3*S4*S5 + 2*YY6*dq12*m_6*C3*C4*C5*CC6*S2*S4*S5 + 2*YY6*dq13*m_6*C2*C4*C5*CC6*S3*S4*S5 + 2*YY6*dq13*m_6*C3*C4*C5*CC6*S2*S4*S5 + 4*Z6*d6*dq11*m_6*C2*C3*CC4*C5*S2*S3*S5 - 4*X6*Y6*dq12*m_6*C2*C3*CC5*C6*S4*S6 - 4*X6*Y6*dq13*m_6*C2*C3*CC5*C6*S4*S6 + 4*X6*Y6*dq14*m_6*C2*C4*CC5*C6*S3*S6 + 4*X6*Y6*dq14*m_6*C3*C4*CC5*C6*S2*S6 + 4*X6*Z6*dq12*m_6*C2*C4*CC5*C6*S3*S4 + 4*X6*Z6*dq12*m_6*C3*C4*CC5*C6*S2*S4 + 4*X6*Z6*dq13*m_6*C2*C4*CC5*C6*S3*S4 + 4*X6*Z6*dq13*m_6*C3*C4*CC5*C6*S2*S4 + 4*X6*d6*dq12*m_6*C2*C4*CC5*C6*S3*S4 + 4*X6*d6*dq12*m_6*C3*C4*CC5*C6*S2*S4 + 4*X6*d6*dq13*m_6*C2*C4*CC5*C6*S3*S4 + 4*X6*d6*dq13*m_6*C3*C4*CC5*C6*S2*S4 - 4*Y6*Z6*dq12*m_6*C2*C4*CC5*S3*S4*S6 - 4*Y6*Z6*dq12*m_6*C3*C4*CC5*S2*S4*S6 - 4*Y6*Z6*dq13*m_6*C2*C4*CC5*S3*S4*S6 - 4*Y6*Z6*dq13*m_6*C3*C4*CC5*S2*S4*S6 - 2*XX6*dq11*m_6*C2*C3*CC4*C5*CC6*S2*S3*S5 + 2*YY6*dq11*m_6*C2*C3*CC4*C5*CC6*S2*S3*S5 - 4*Y6*d6*dq12*m_6*C2*C4*CC5*S3*S4*S6 - 4*Y6*d6*dq12*m_6*C3*C4*CC5*S2*S4*S6 - 4*Y6*d6*dq13*m_6*C2*C4*CC5*S3*S4*S6 - 4*Y6*d6*dq13*m_6*C3*C4*CC5*S2*S4*S6 + 4*X6*Y6*dq12*m_6*CC5*C6*S2*S3*S4*S6 + 4*X6*Y6*dq13*m_6*CC5*C6*S2*S3*S4*S6 - 8*X6*Y6*dq11*m_6*C2*CC3*C4*CC5*C6*S2*S6 - 8*X6*Y6*dq11*m_6*CC2*C3*C4*CC5*C6*S3*S6 + 4*X6*Z6*dq11*m_6*C2*C3*CC4*CC5*C6*S2*S3 + 4*X6*d6*dq11*m_6*C2*C3*CC4*CC5*C6*S2*S3 + 2*XX6*dq11*m_6*C2*C3*C4*C6*S2*S3*S4*S5*S6 - 2*YY6*dq11*m_6*C2*C3*C4*C6*S2*S3*S4*S5*S6 - 2*Y6*Z6*dq11*m_6*C2*C3*C4*C5*C6*S2*S3*S4 - 2*Y6*d6*dq11*m_6*C2*C3*C4*C5*C6*S2*S3*S4 + 4*X6*Y6*dq11*m_6*C2*C3*C5*C6*S2*S3*S5*S6 - 2*X6*Z6*dq11*m_6*C2*C3*C4*C5*S2*S3*S4*S6 - 2*X6*d6*dq11*m_6*C2*C3*C4*C5*S2*S3*S4*S6 + 4*X6*Y6*dq11*m_6*C2*C3*C4*CC6*S2*S3*S4*S5 + 4*X6*Y6*dq12*m_6*C2*C4*C5*C6*S3*S4*S5*S6 + 4*X6*Y6*dq12*m_6*C3*C4*C5*C6*S2*S4*S5*S6 + 4*X6*Y6*dq13*m_6*C2*C4*C5*C6*S3*S4*S5*S6 + 4*X6*Y6*dq13*m_6*C3*C4*C5*C6*S2*S4*S5*S6 + 4*X6*Y6*dq11*m_6*C2*C3*CC4*C5*C6*S2*S3*S5*S6;
coriolis.array2d[5][0] = Ixy6*dq55 - Ixy6*dq44 - Ixy6*dq11 + 2*Ixy6*dq11*CC2 + 2*Ixy6*dq11*CC3 + Ixy6*dq11*CC5 + Ixy6*dq22*CC4 + 2*Ixy6*dq11*CC6 - Ixy6*dq22*CC5 + Ixy6*dq33*CC4 - Ixy6*dq33*CC5 + Ixy6*dq44*CC5 + 2*Ixy6*dq44*CC6 - 2*Ixy6*dq55*CC6 + (Ixx6*dq11*S66)/2 + (Ixx6*dq44*S66)/2 - (Ixx6*dq55*S66)/2 - (Iyy6*dq11*S66)/2 - (Iyy6*dq44*S66)/2 + (Iyy6*dq55*S66)/2 + X6*Y6*dq11*m_6 + X6*Y6*dq44*m_6 - X6*Y6*dq55*m_6 + 2*Ixy6*dq25*C4 + 2*Ixy6*dq35*C4 - Ixx6*dq45*S5 + Iyy6*dq45*S5 - Izz6*dq45*S5 - (XX6*dq11*m_6*S66)/2 - (XX6*dq44*m_6*S66)/2 + (XX6*dq55*m_6*S66)/2 + (YY6*dq11*m_6*S66)/2 + (YY6*dq44*m_6*S66)/2 - (YY6*dq55*m_6*S66)/2 + 2*Ixy6*dq23*CC4 - 2*Ixy6*dq23*CC5 - 4*Ixy6*dq11*CC2*CC3 - Ixy6*dq11*CC2*CC4 - Ixy6*dq11*CC2*CC5 - Ixy6*dq11*CC3*CC4 - 4*Ixy6*dq11*CC2*CC6 - Ixy6*dq11*CC3*CC5 - 4*Ixy6*dq11*CC3*CC6 + Ixy6*dq22*CC4*CC5 - 2*Ixy6*dq11*CC5*CC6 - 2*Ixy6*dq22*CC4*CC6 + Ixy6*dq33*CC4*CC5 + 2*Ixy6*dq22*CC5*CC6 - 2*Ixy6*dq33*CC4*CC6 + 2*Ixy6*dq33*CC5*CC6 - 2*Ixy6*dq44*CC5*CC6 + 2*Ixy6*dq11*CC2*CC3*CC4 + 2*Ixy6*dq11*CC2*CC3*CC5 + 8*Ixy6*dq11*CC2*CC3*CC6 - Ixy6*dq11*CC2*CC4*CC5 + 2*Ixy6*dq11*CC2*CC4*CC6 - Ixy6*dq11*CC3*CC4*CC5 + 2*Ixy6*dq11*CC2*CC5*CC6 + 2*Ixy6*dq11*CC3*CC4*CC6 + 2*Ixy6*dq11*CC3*CC5*CC6 - 2*Ixy6*dq22*CC4*CC5*CC6 - 2*Ixy6*dq33*CC4*CC5*CC6 - Ixz6*dq11*C5*S5*S6 + Ixz6*dq22*C5*S5*S6 + Ixz6*dq33*C5*S5*S6 - Ixz6*dq44*C5*S5*S6 + 2*Ixy6*dq14*C2*C3 - 2*Ixz6*dq45*C5*C6 - Ixx6*dq24*C4*S5 + Ixx6*dq25*C5*S4 - Ixx6*dq34*C4*S5 + Ixx6*dq35*C5*S4 + Iyy6*dq24*C4*S5 - Iyy6*dq25*C5*S4 + Iyy6*dq34*C4*S5 - Iyy6*dq35*C5*S4 - 2*Iyz6*dq24*C6*S4 - 2*Iyz6*dq34*C6*S4 + 2*Iyz6*dq45*C5*S6 + Izz6*dq24*C4*S5 + Izz6*dq25*C5*S4 + Izz6*dq34*C4*S5 + Izz6*dq35*C5*S4 - 2*YY6*dq45*m_6*S5 - 2*Ixy6*dq14*S2*S3 - 2*Ixz6*dq24*S4*S6 - 2*Ixz6*dq34*S4*S6 - 2*Ixx6*dq11*CC2*C6*S6 - 2*Ixx6*dq11*CC3*C6*S6 - Ixx6*dq11*CC5*C6*S6 - Ixx6*dq22*CC4*C6*S6 + Ixx6*dq22*CC5*C6*S6 - Ixx6*dq33*CC4*C6*S6 + Ixx6*dq33*CC5*C6*S6 - Ixx6*dq44*CC5*C6*S6 + 2*Iyy6*dq11*CC2*C6*S6 + 2*Iyy6*dq11*CC3*C6*S6 + Iyy6*dq11*CC5*C6*S6 + Iyy6*dq22*CC4*C6*S6 - Iyy6*dq22*CC5*C6*S6 + Iyy6*dq33*CC4*C6*S6 - Iyy6*dq33*CC5*C6*S6 + Iyy6*dq44*CC5*C6*S6 - 2*X6*Y6*dq11*m_6*CC2 - 2*X6*Y6*dq11*m_6*CC3 - X6*Y6*dq11*m_6*CC5 - X6*Y6*dq22*m_6*CC4 - 2*X6*Y6*dq11*m_6*CC6 + X6*Y6*dq22*m_6*CC5 - X6*Y6*dq33*m_6*CC4 + X6*Y6*dq33*m_6*CC5 - X6*Y6*dq44*m_6*CC5 - 2*X6*Y6*dq44*m_6*CC6 + 2*X6*Y6*dq55*m_6*CC6 - 4*Ixy6*dq25*C4*CC6 - 4*Ixy6*dq35*C4*CC6 + 2*Ixx6*dq45*CC6*S5 - 2*Iyy6*dq45*CC6*S5 + 2*Ixy6*dq23*CC4*CC5 - 4*Ixy6*dq23*CC4*CC6 + 4*Ixy6*dq23*CC5*CC6 + Ixx6*dq22*C4*C5*S4 + Ixx6*dq33*C4*C5*S4 - Iyy6*dq22*C4*C5*S4 - Iyy6*dq33*C4*C5*S4 - Iyz6*dq11*C5*C6*S5 + Iyz6*dq22*C5*C6*S5 + Iyz6*dq33*C5*C6*S5 - Iyz6*dq44*C5*C6*S5 + X6*a3*dq11*m_6*C6*S4 + X6*a3*dq22*m_6*C6*S4 + X6*a3*dq33*m_6*C6*S4 + 2*XX6*dq24*m_6*C4*S5 + 2*XX6*dq34*m_6*C4*S5 - Y6*d4*dq22*m_6*C6*S5 - Y6*d4*dq33*m_6*C6*S5 + 2*YY6*dq25*m_6*C5*S4 + 2*YY6*dq35*m_6*C5*S4 - 4*Ixy6*dq23*CC4*CC5*CC6 - 2*Ixy6*dq15*C2*S3*S4 - 2*Ixy6*dq15*C3*S2*S4 + 2*Ixy6*dq24*C5*S4*S5 + 2*Ixy6*dq34*C5*S4*S5 - 4*Ixy6*dq45*C6*S5*S6 + 2*Ixz6*dq23*C5*S5*S6 - 2*Ixz6*dq25*C6*S4*S5 - 2*Ixz6*dq35*C6*S4*S5 - Y6*a3*dq11*m_6*S4*S6 - Y6*a3*dq22*m_6*S4*S6 - Y6*a3*dq33*m_6*S4*S6 - X6*d4*dq22*m_6*S5*S6 - X6*d4*dq33*m_6*S5*S6 - 2*X6*Y6*dq25*m_6*C4 - 2*X6*Y6*dq35*m_6*C4 - Ixx6*dq15*S2*S3*S5 + Iyy6*dq15*S2*S3*S5 + 2*Iyz6*dq25*S4*S5*S6 + 2*Iyz6*dq35*S4*S5*S6 - Izz6*dq15*S2*S3*S5 - Ixx6*dq11*CC2*C4*C5*S4 - Ixx6*dq11*CC3*C4*C5*S4 - 2*Ixx6*dq22*C4*C5*CC6*S4 - 2*Ixx6*dq33*C4*C5*CC6*S4 + Iyy6*dq11*CC2*C4*C5*S4 + Iyy6*dq11*CC3*C4*C5*S4 + 2*Iyy6*dq22*C4*C5*CC6*S4 + 2*Iyy6*dq33*C4*C5*CC6*S4 + Iyz6*dq11*CC2*C5*C6*S5 + Iyz6*dq11*CC3*C5*C6*S5 - Iyz6*dq22*CC4*C5*C6*S5 - Iyz6*dq33*CC4*C5*C6*S5 + 2*XX6*dq11*m_6*CC2*C6*S6 + 2*XX6*dq11*m_6*CC3*C6*S6 + XX6*dq11*m_6*CC5*C6*S6 + XX6*dq22*m_6*CC4*C6*S6 - XX6*dq22*m_6*CC5*C6*S6 + XX6*dq33*m_6*CC4*C6*S6 - XX6*dq33*m_6*CC5*C6*S6 + XX6*dq44*m_6*CC5*C6*S6 - 2*YY6*dq11*m_6*CC2*C6*S6 - 2*YY6*dq11*m_6*CC3*C6*S6 - YY6*dq11*m_6*CC5*C6*S6 - YY6*dq22*m_6*CC4*C6*S6 + YY6*dq22*m_6*CC5*C6*S6 - YY6*dq33*m_6*CC4*C6*S6 + YY6*dq33*m_6*CC5*C6*S6 - YY6*dq44*m_6*CC5*C6*S6 + 2*Ixy6*dq11*CC2*CC3*CC4*CC5 - 4*Ixy6*dq11*CC2*CC3*CC4*CC6 - 4*Ixy6*dq11*CC2*CC3*CC5*CC6 + 2*Ixy6*dq11*CC2*CC4*CC5*CC6 + 2*Ixy6*dq11*CC3*CC4*CC5*CC6 + Ixz6*dq11*CC2*C5*S5*S6 + Ixz6*dq11*CC3*C5*S5*S6 - Ixz6*dq22*CC4*C5*S5*S6 - Ixz6*dq33*CC4*C5*S5*S6 - 2*Ixy6*dq14*C2*C3*CC5 - 4*Ixy6*dq14*C2*C3*CC6 - 2*Ixx6*dq23*CC4*C6*S6 + 2*Ixx6*dq24*C4*CC6*S5 + 2*Ixx6*dq23*CC5*C6*S6 - 2*Ixx6*dq25*C5*CC6*S4 + 2*Ixx6*dq34*C4*CC6*S5 - 2*Ixx6*dq35*C5*CC6*S4 + 2*Iyy6*dq23*CC4*C6*S6 - 2*Iyy6*dq24*C4*CC6*S5 - 2*Iyy6*dq23*CC5*C6*S6 + 2*Iyy6*dq25*C5*CC6*S4 - 2*Iyy6*dq34*C4*CC6*S5 + 2*Iyy6*dq35*C5*CC6*S4 + 2*Iyz6*dq24*CC5*C6*S4 + 2*Iyz6*dq34*CC5*C6*S4 - 2*XX6*dq45*m_6*CC6*S5 + 2*YY6*dq45*m_6*CC6*S5 + 2*Ixy6*dq14*CC5*S2*S3 + 4*Ixy6*dq14*CC6*S2*S3 + 2*Ixz6*dq24*CC5*S4*S6 + 2*Ixz6*dq34*CC5*S4*S6 - 2*X6*Y6*dq23*m_6*CC4 + 2*X6*Y6*dq23*m_6*CC5 + 4*Ixx6*dq11*CC2*CC3*C6*S6 + Ixx6*dq11*CC2*CC4*C6*S6 + Ixx6*dq11*CC2*CC5*C6*S6 + Ixx6*dq11*CC3*CC4*C6*S6 + Ixx6*dq11*CC3*CC5*C6*S6 - Ixx6*dq22*CC4*CC5*C6*S6 - Ixx6*dq33*CC4*CC5*C6*S6 - 4*Iyy6*dq11*CC2*CC3*C6*S6 - Iyy6*dq11*CC2*CC4*C6*S6 - Iyy6*dq11*CC2*CC5*C6*S6 - Iyy6*dq11*CC3*CC4*C6*S6 - Iyy6*dq11*CC3*CC5*C6*S6 + Iyy6*dq22*CC4*CC5*C6*S6 + Iyy6*dq33*CC4*CC5*C6*S6 + 4*X6*Y6*dq11*m_6*CC2*CC3 + X6*Y6*dq11*m_6*CC2*CC4 + X6*Y6*dq11*m_6*CC2*CC5 + X6*Y6*dq11*m_6*CC3*CC4 + 4*X6*Y6*dq11*m_6*CC2*CC6 + X6*Y6*dq11*m_6*CC3*CC5 + 4*X6*Y6*dq11*m_6*CC3*CC6 - X6*Y6*dq22*m_6*CC4*CC5 + 2*X6*Y6*dq11*m_6*CC5*CC6 + 2*X6*Y6*dq22*m_6*CC4*CC6 - X6*Y6*dq33*m_6*CC4*CC5 - 2*X6*Y6*dq22*m_6*CC5*CC6 + 2*X6*Y6*dq33*m_6*CC4*CC6 - 2*X6*Y6*dq33*m_6*CC5*CC6 + 2*X6*Y6*dq44*m_6*CC5*CC6 - Iyz6*dq11*C2*C4*C6*S2 - Iyz6*dq11*C3*C4*C6*S3 - XX6*dq22*m_6*C4*C5*S4 - XX6*dq33*m_6*C4*C5*S4 + YY6*dq22*m_6*C4*C5*S4 + YY6*dq33*m_6*C4*C5*S4 + 4*Ixy6*dq11*C2*C3*S2*S3 - Ixz6*dq11*C2*C4*S2*S6 - Ixz6*dq11*C3*C4*S3*S6 - Ixz6*dq22*C4*C6*S4*S5 - Ixz6*dq33*C4*C6*S4*S5 + Ixx6*dq11*C2*S2*S4*S5 + Ixx6*dq11*C3*S3*S4*S5 - Iyy6*dq11*C2*S2*S4*S5 - Iyy6*dq11*C3*S3*S4*S5 + Iyz6*dq22*C4*S4*S5*S6 + Iyz6*dq33*C4*S4*S5*S6 - Ixx6*dq12*C2*C5*S3 - Ixx6*dq12*C3*C5*S2 - Ixx6*dq13*C2*C5*S3 - Ixx6*dq13*C3*C5*S2 + Ixx6*dq15*C2*C3*S5 + 2*Ixx6*dq23*C4*C5*S4 - 2*Ixx6*dq25*C4*C6*S6 - 2*Ixx6*dq35*C4*C6*S6 + Iyy6*dq12*C2*C5*S3 + Iyy6*dq12*C3*C5*S2 + Iyy6*dq13*C2*C5*S3 + Iyy6*dq13*C3*C5*S2 - Iyy6*dq15*C2*C3*S5 - 2*Iyy6*dq23*C4*C5*S4 + 2*Iyy6*dq25*C4*C6*S6 + 2*Iyy6*dq35*C4*C6*S6 + 2*Iyz6*dq23*C5*C6*S5 + Izz6*dq12*C2*C5*S3 + Izz6*dq12*C3*C5*S2 + Izz6*dq13*C2*C5*S3 + Izz6*dq13*C3*C5*S2 + Izz6*dq15*C2*C3*S5 + 2*Y6*Z6*dq24*m_6*C6*S4 + 2*Y6*Z6*dq34*m_6*C6*S4 - 2*Y6*Z6*dq45*m_6*C5*S6 + 2*Iyz6*dq11*C2*CC3*C4*C6*S2 + 2*Iyz6*dq11*CC2*C3*C4*C6*S3 + 2*Iyz6*dq11*C2*C4*CC5*C6*S2 + 2*Iyz6*dq11*C3*C4*CC5*C6*S3 + 2*X6*a3*dq23*m_6*C6*S4 + XX6*dq11*m_6*CC2*C4*C5*S4 + XX6*dq11*m_6*CC3*C4*C5*S4 + 2*XX6*dq22*m_6*C4*C5*CC6*S4 + 2*XX6*dq33*m_6*C4*C5*CC6*S4 - YY6*dq11*m_6*CC2*C4*C5*S4 - YY6*dq11*m_6*CC3*C4*C5*S4 - 2*YY6*dq22*m_6*C4*C5*CC6*S4 - 2*YY6*dq33*m_6*C4*C5*CC6*S4 - 2*Y6*d4*dq23*m_6*C6*S5 + 2*Y6*d6*dq24*m_6*C6*S4 + 2*Y6*d6*dq34*m_6*C6*S4 - 2*Y6*d6*dq45*m_6*C5*S6 + 2*X6*Y6*dq14*m_6*S2*S3 + 2*X6*Z6*dq24*m_6*S4*S6 + 2*X6*Z6*dq34*m_6*S4*S6 - 2*Ixy6*dq11*C2*C3*CC4*S2*S3 - 2*Ixy6*dq11*C2*C3*CC5*S2*S3 - 8*Ixy6*dq11*C2*C3*CC6*S2*S3 + 2*Ixz6*dq11*C2*CC3*C4*S2*S6 + 2*Ixz6*dq11*CC2*C3*C4*S3*S6 + 2*Ixz6*dq11*C2*C4*CC5*S2*S6 + 2*Ixz6*dq11*C3*C4*CC5*S3*S6 + Ixz6*dq11*CC2*C4*C6*S4*S5 + Ixz6*dq11*CC3*C4*C6*S4*S5 - 2*Y6*a3*dq23*m_6*S4*S6 - 2*X6*d4*dq23*m_6*S5*S6 + 2*X6*d6*dq24*m_6*S4*S6 + 2*X6*d6*dq34*m_6*S4*S6 - 2*Ixx6*dq11*C2*CC3*S2*S4*S5 - 2*Ixx6*dq11*CC2*C3*S3*S4*S5 - 2*Ixx6*dq11*C2*CC6*S2*S4*S5 - 2*Ixx6*dq11*C3*CC6*S3*S4*S5 + 2*Iyy6*dq11*C2*CC3*S2*S4*S5 + 2*Iyy6*dq11*CC2*C3*S3*S4*S5 + 2*Iyy6*dq11*C2*CC6*S2*S4*S5 + 2*Iyy6*dq11*C3*CC6*S3*S4*S5 - Iyz6*dq11*CC2*C4*S4*S5*S6 - Iyz6*dq11*CC3*C4*S4*S5*S6 + 2*Ixx6*dq12*C2*CC4*C5*S3 + 2*Ixx6*dq12*C3*CC4*C5*S2 + 2*Ixx6*dq13*C2*CC4*C5*S3 + 2*Ixx6*dq13*C3*CC4*C5*S2 + 2*Ixx6*dq12*C2*C5*CC6*S3 + 2*Ixx6*dq12*C3*C5*CC6*S2 + 2*Ixx6*dq13*C2*C5*CC6*S3 + 2*Ixx6*dq13*C3*C5*CC6*S2 - 2*Ixx6*dq15*C2*C3*CC6*S5 - 4*Ixx6*dq23*C4*C5*CC6*S4 - 2*Iyy6*dq12*C2*CC4*C5*S3 - 2*Iyy6*dq12*C3*CC4*C5*S2 - 2*Iyy6*dq13*C2*CC4*C5*S3 - 2*Iyy6*dq13*C3*CC4*C5*S2 - 2*Iyy6*dq12*C2*C5*CC6*S3 - 2*Iyy6*dq12*C3*C5*CC6*S2 - 2*Iyy6*dq13*C2*C5*CC6*S3 - 2*Iyy6*dq13*C3*C5*CC6*S2 + 2*Iyy6*dq15*C2*C3*CC6*S5 + 4*Iyy6*dq23*C4*C5*CC6*S4 - 2*Iyz6*dq23*CC4*C5*C6*S5 - X6*a3*dq11*m_6*CC2*C6*S4 - X6*a3*dq11*m_6*CC3*C6*S4 + 2*XX6*dq23*m_6*CC4*C6*S6 - 2*XX6*dq24*m_6*C4*CC6*S5 - 2*XX6*dq23*m_6*CC5*C6*S6 + 2*XX6*dq25*m_6*C5*CC6*S4 - 2*XX6*dq34*m_6*C4*CC6*S5 + 2*XX6*dq35*m_6*C5*CC6*S4 - Y6*d4*dq11*m_6*CC2*C6*S5 - Y6*d4*dq11*m_6*CC3*C6*S5 - 2*YY6*dq23*m_6*CC4*C6*S6 + 2*YY6*dq24*m_6*C4*CC6*S5 + 2*YY6*dq23*m_6*CC5*C6*S6 - 2*YY6*dq25*m_6*C5*CC6*S4 + 2*YY6*dq34*m_6*C4*CC6*S5 - 2*YY6*dq35*m_6*C5*CC6*S4 + 4*Ixy6*dq15*C2*CC6*S3*S4 + 4*Ixy6*dq15*C3*CC6*S2*S4 - 4*Ixy6*dq24*C5*CC6*S4*S5 - 4*Ixy6*dq34*C5*CC6*S4*S5 - 2*Ixz6*dq23*CC4*C5*S5*S6 + Y6*a3*dq11*m_6*CC2*S4*S6 + Y6*a3*dq11*m_6*CC3*S4*S6 - X6*d4*dq11*m_6*CC2*S5*S6 - X6*d4*dq11*m_6*CC3*S5*S6 + 4*X6*Y6*dq25*m_6*C4*CC6 + 4*X6*Y6*dq35*m_6*C4*CC6 + 2*Ixx6*dq15*CC6*S2*S3*S5 - 2*Iyy6*dq15*CC6*S2*S3*S5 + 2*Ixx6*dq11*CC2*CC3*C4*C5*S4 + 2*Ixx6*dq11*CC2*C4*C5*CC6*S4 + 2*Ixx6*dq11*CC3*C4*C5*CC6*S4 - 2*Iyy6*dq11*CC2*CC3*C4*C5*S4 - 2*Iyy6*dq11*CC2*C4*C5*CC6*S4 - 2*Iyy6*dq11*CC3*C4*C5*CC6*S4 - 2*Iyz6*dq11*CC2*CC3*C5*C6*S5 + Iyz6*dq11*CC2*CC4*C5*C6*S5 + Iyz6*dq11*CC3*CC4*C5*C6*S5 - 4*XX6*dq11*m_6*CC2*CC3*C6*S6 - XX6*dq11*m_6*CC2*CC4*C6*S6 - XX6*dq11*m_6*CC2*CC5*C6*S6 - XX6*dq11*m_6*CC3*CC4*C6*S6 - XX6*dq11*m_6*CC3*CC5*C6*S6 + XX6*dq22*m_6*CC4*CC5*C6*S6 + XX6*dq33*m_6*CC4*CC5*C6*S6 + 4*YY6*dq11*m_6*CC2*CC3*C6*S6 + YY6*dq11*m_6*CC2*CC4*C6*S6 + YY6*dq11*m_6*CC2*CC5*C6*S6 + YY6*dq11*m_6*CC3*CC4*C6*S6 + YY6*dq11*m_6*CC3*CC5*C6*S6 - YY6*dq22*m_6*CC4*CC5*C6*S6 - YY6*dq33*m_6*CC4*CC5*C6*S6 - 4*Ixy6*dq11*CC2*CC3*CC4*CC5*CC6 - 2*Ixz6*dq11*CC2*CC3*C5*S5*S6
 + Ixz6*dq11*CC2*CC4*C5*S5*S6 + Ixz6*dq11*CC3*CC4*C5*S5*S6 + 4*Ixy6*dq14*C2*C3*CC5*CC6 - 2*Ixx6*dq23*CC4*CC5*C6*S6 + 2*Iyy6*dq23*CC4*CC5*C6*S6 - 4*Ixy6*dq14*CC5*CC6*S2*S3 - 2*X6*Y6*dq23*m_6*CC4*CC5 + 4*X6*Y6*dq23*m_6*CC4*CC6 - 4*X6*Y6*dq23*m_6*CC5*CC6 + 2*Ixy6*dq11*C2*C4*C5*S2*S5 + 2*Ixy6*dq11*C3*C4*C5*S3*S5 + 4*Ixy6*dq22*C4*C5*C6*S4*S6 + 4*Ixy6*dq33*C4*C5*C6*S4*S6 + Ixz6*dq11*C2*C5*C6*S2*S4 + Ixz6*dq11*C3*C5*C6*S3*S4 - 2*Ixx6*dq11*CC2*CC3*CC4*C6*S6 - 2*Ixx6*dq11*CC2*CC3*CC5*C6*S6 + Ixx6*dq11*CC2*CC4*CC5*C6*S6 + Ixx6*dq11*CC3*CC4*CC5*C6*S6 + 2*Iyy6*dq11*CC2*CC3*CC4*C6*S6 + 2*Iyy6*dq11*CC2*CC3*CC5*C6*S6 - Iyy6*dq11*CC2*CC4*CC5*C6*S6 - Iyy6*dq11*CC3*CC4*CC5*C6*S6 - Iyz6*dq11*C2*C5*S2*S4*S6 - Iyz6*dq11*C3*C5*S3*S4*S6 + 2*Ixz6*dq15*C2*C3*C5*C6 + Y6*a3*dq11*m_6*C4*C5*C6 + Y6*a3*dq22*m_6*C4*C5*C6 + Y6*a3*dq33*m_6*C4*C5*C6 - XX6*dq11*m_6*C2*S2*S4*S5 - XX6*dq11*m_6*C3*S3*S4*S5 + YY6*dq11*m_6*C2*S2*S4*S5 + YY6*dq11*m_6*C3*S3*S4*S5 + Y6*Z6*dq11*m_6*C5*C6*S5 - Y6*Z6*dq22*m_6*C5*C6*S5 - Y6*Z6*dq33*m_6*C5*C6*S5 + Y6*Z6*dq44*m_6*C5*C6*S5 + Ixx6*dq12*C2*C3*C4*S5 + Ixx6*dq13*C2*C3*C4*S5 + Ixx6*dq15*C2*C4*C5*S3 + Ixx6*dq15*C3*C4*C5*S2 - 2*Ixx6*dq14*C2*C3*C6*S6 - Iyy6*dq12*C2*C3*C4*S5 - Iyy6*dq13*C2*C3*C4*S5 - Iyy6*dq15*C2*C4*C5*S3 - Iyy6*dq15*C3*C4*C5*S2 + 2*Iyy6*dq14*C2*C3*C6*S6 - 2*Iyz6*dq14*C2*C4*C6*S3 - 2*Iyz6*dq14*C3*C4*C6*S2 - 2*Iyz6*dq15*C2*C3*C5*S6 + Izz6*dq12*C2*C3*C4*S5 + Izz6*dq13*C2*C3*C4*S5 + Izz6*dq15*C2*C4*C5*S3 + Izz6*dq15*C3*C4*C5*S2 + X6*a2*dq22*m_6*C3*C6*S4 + X6*a3*dq11*m_6*C4*C5*S6 + X6*a3*dq22*m_6*C4*C5*S6 + X6*a3*dq33*m_6*C4*C5*S6 + 2*XX6*dq12*m_6*C2*C5*S3 + 2*XX6*dq12*m_6*C3*C5*S2 + 2*XX6*dq13*m_6*C2*C5*S3 + 2*XX6*dq13*m_6*C3*C5*S2 - 2*XX6*dq23*m_6*C4*C5*S4 + 2*XX6*dq25*m_6*C4*C6*S6 + 2*XX6*dq35*m_6*C4*C6*S6 + Y6*d6*dq11*m_6*C5*C6*S5 - Y6*d6*dq22*m_6*C5*C6*S5 - Y6*d6*dq33*m_6*C5*C6*S5 + Y6*d6*dq44*m_6*C5*C6*S5 + 2*YY6*dq15*m_6*C2*C3*S5 + 2*YY6*dq23*m_6*C4*C5*S4 - 2*YY6*dq25*m_6*C4*C6*S6 - 2*YY6*dq35*m_6*C4*C6*S6 - 2*X6*Y6*dq11*m_6*CC2*CC3*CC4 - 2*X6*Y6*dq11*m_6*CC2*CC3*CC5 - 8*X6*Y6*dq11*m_6*CC2*CC3*CC6 + X6*Y6*dq11*m_6*CC2*CC4*CC5 - 2*X6*Y6*dq11*m_6*CC2*CC4*CC6 + X6*Y6*dq11*m_6*CC3*CC4*CC5 - 2*X6*Y6*dq11*m_6*CC2*CC5*CC6 - 2*X6*Y6*dq11*m_6*CC3*CC4*CC6 - 2*X6*Y6*dq11*m_6*CC3*CC5*CC6 + 2*X6*Y6*dq22*m_6*CC4*CC5*CC6 + 2*X6*Y6*dq33*m_6*CC4*CC5*CC6 + X6*Z6*dq11*m_6*C5*S5*S6 - X6*Z6*dq22*m_6*C5*S5*S6 - X6*Z6*dq33*m_6*C5*S5*S6 + X6*Z6*dq44*m_6*C5*S5*S6 - 2*Ixy6*dq12*C2*C4*S3*S4 - 2*Ixy6*dq12*C3*C4*S2*S4 - 2*Ixy6*dq13*C2*C4*S3*S4 - 2*Ixy6*dq13*C3*C4*S2*S4 - 4*Ixy6*dq24*C4*C6*S5*S6 + 4*Ixy6*dq25*C5*C6*S4*S6 - 4*Ixy6*dq34*C4*C6*S5*S6 + 4*Ixy6*dq35*C5*C6*S4*S6 - 2*Ixz6*dq14*C2*C4*S3*S6 - 2*Ixz6*dq14*C3*C4*S2*S6 - 2*Ixz6*dq15*C5*C6*S2*S3 - 2*Ixz6*dq23*C4*C6*S4*S5 - Y6*a2*dq22*m_6*C3*S4*S6 - Y6*a2*dq22*m_6*C6*S3*S5 + X6*d6*dq11*m_6*C5*S5*S6 - X6*d6*dq22*m_6*C5*S5*S6 - X6*d6*dq33*m_6*C5*S5*S6 + X6*d6*dq44*m_6*C5*S5*S6 - 2*X6*Y6*dq14*m_6*C2*C3 + 2*X6*Z6*dq45*m_6*C5*C6 - Ixx6*dq12*C4*S2*S3*S5 - Ixx6*dq13*C4*S2*S3*S5 + Ixx6*dq14*C2*S3*S4*S5 + Ixx6*dq14*C3*S2*S4*S5 + 2*Ixx6*dq14*C6*S2*S3*S6 + Iyy6*dq12*C4*S2*S3*S5 + Iyy6*dq13*C4*S2*S3*S5 - Iyy6*dq14*C2*S3*S4*S5 - Iyy6*dq14*C3*S2*S4*S5 - 2*Iyy6*dq14*C6*S2*S3*S6 + 2*Iyz6*dq15*C5*S2*S3*S6 + 2*Iyz6*dq23*C4*S4*S5*S6 - Izz6*dq12*C4*S2*S3*S5 - Izz6*dq13*C4*S2*S3*S5 - Izz6*dq14*C2*S3*S4*S5 - Izz6*dq14*C3*S2*S4*S5 - X6*a2*dq22*m_6*S3*S5*S6 + 2*X6*d6*dq45*m_6*C5*C6 - 2*YY6*dq15*m_6*S2*S3*S5 - Y6*Z6*dq11*m_6*CC2*C5*C6*S5 - Y6*Z6*dq11*m_6*CC3*C5*C6*S5 + Y6*Z6*dq22*m_6*CC4*C5*C6*S5 + Y6*Z6*dq33*m_6*CC4*C5*C6*S5 - 2*Ixx6*dq12*C2*C3*C4*CC6*S5 - 2*Ixx6*dq13*C2*C3*C4*CC6*S5 - 2*Ixx6*dq15*C2*C4*C5*CC6*S3 - 2*Ixx6*dq15*C3*C4*C5*CC6*S2 + 2*Ixx6*dq14*C2*C3*CC5*C6*S6 + 2*Iyy6*dq12*C2*C3*C4*CC6*S5 + 2*Iyy6*dq13*C2*C3*C4*CC6*S5 + 2*Iyy6*dq15*C2*C4*C5*CC6*S3 + 2*Iyy6*dq15*C3*C4*C5*CC6*S2 - 2*Iyy6*dq14*C2*C3*CC5*C6*S6 - 2*Iyz6*dq12*C2*C3*CC5*C6*S4 - 2*Iyz6*dq13*C2*C3*CC5*C6*S4 + 2*Iyz6*dq14*C2*C4*CC5*C6*S3 + 2*Iyz6*dq14*C3*C4*CC5*C6*S2 + X6*a2*dq11*m_6*CC2*C3*C6*S4 - X6*a3*dq11*m_6*CC2*C4*C5*S6 - X6*a3*dq11*m_6*CC3*C4*C5*S6 - 2*XX6*dq12*m_6*C2*CC4*C5*S3 - 2*XX6*dq12*m_6*C3*CC4*C5*S2 - 2*XX6*dq13*m_6*C2*CC4*C5*S3 - 2*XX6*dq13*m_6*C3*CC4*C5*S2 - 2*XX6*dq12*m_6*C2*C5*CC6*S3 - 2*XX6*dq12*m_6*C3*C5*CC6*S2 - 2*XX6*dq13*m_6*C2*C5*CC6*S3 - 2*XX6*dq13*m_6*C3*C5*CC6*S2 + 2*XX6*dq15*m_6*C2*C3*CC6*S5 + 4*XX6*dq23*m_6*C4*C5*CC6*S4 - Y6*d6*dq11*m_6*CC2*C5*C6*S5 - Y6*d6*dq11*m_6*CC3*C5*C6*S5 + Y6*d6*dq22*m_6*CC4*C5*C6*S5 + Y6*d6*dq33*m_6*CC4*C5*C6*S5 + 2*YY6*dq12*m_6*C2*CC4*C5*S3 + 2*YY6*dq12*m_6*C3*CC4*C5*S2 + 2*YY6*dq13*m_6*C2*CC4*C5*S3 + 2*YY6*dq13*m_6*C3*CC4*C5*S2 + 2*YY6*dq12*m_6*C2*C5*CC6*S3 + 2*YY6*dq12*m_6*C3*C5*CC6*S2 + 2*YY6*dq13*m_6*C2*C5*CC6*S3 + 2*YY6*dq13*m_6*C3*C5*CC6*S2 - 2*YY6*dq15*m_6*C2*C3*CC6*S5 - 4*YY6*dq23*m_6*C4*C5*CC6*S4 - 2*X6*Y6*dq11*m_6*CC2*CC3*CC4*CC5 + 4*X6*Y6*dq11*m_6*CC2*CC3*CC4*CC6 + 4*X6*Y6*dq11*m_6*CC2*CC3*CC5*CC6 - 2*X6*Y6*dq11*m_6*CC2*CC4*CC5*CC6 - 2*X6*Y6*dq11*m_6*CC3*CC4*CC5*CC6 - X6*Z6*dq11*m_6*CC2*C5*S5*S6 - X6*Z6*dq11*m_6*CC3*C5*S5*S6 + X6*Z6*dq22*m_6*CC4*C5*S5*S6 + X6*Z6*dq33*m_6*CC4*C5*S5*S6 - 2*Ixy6*dq12*C2*C4*CC5*S3*S4 - 2*Ixy6*dq12*C3*C4*CC5*S2*S4 + 4*Ixy6*dq12*C2*C4*CC6*S3*S4 + 4*Ixy6*dq12*C3*C4*CC6*S2*S4 - 2*Ixy6*dq13*C2*C4*CC5*S3*S4 - 2*Ixy6*dq13*C3*C4*CC5*S2*S4 + 4*Ixy6*dq13*C2*C4*CC6*S3*S4 + 4*Ixy6*dq13*C3*C4*CC6*S2*S4 - 2*Ixz6*dq12*C2*C3*CC5*S4*S6 - 2*Ixz6*dq12*C2*CC4*C6*S3*S5 - 2*Ixz6*dq12*C3*CC4*C6*S2*S5 - 2*Ixz6*dq13*C2*C3*CC5*S4*S6 - 2*Ixz6*dq13*C2*CC4*C6*S3*S5 - 2*Ixz6*dq13*C3*CC4*C6*S2*S5 + 2*Ixz6*dq14*C2*C4*CC5*S3*S6 + 2*Ixz6*dq14*C3*C4*CC5*S2*S6 - Y6*a2*dq11*m_6*CC2*C3*S4*S6 - Y6*a2*dq11*m_6*CC2*C6*S3*S5 - X6*d6*dq11*m_6*CC2*C5*S5*S6 - X6*d6*dq11*m_6*CC3*C5*S5*S6 + X6*d6*dq22*m_6*CC4*C5*S5*S6 + X6*d6*dq33*m_6*CC4*C5*S5*S6 + 2*X6*Y6*dq14*m_6*C2*C3*CC5 + 4*X6*Y6*dq14*m_6*C2*C3*CC6 + 2*Ixx6*dq12*C4*CC6*S2*S3*S5 + 2*Ixx6*dq13*C4*CC6*S2*S3*S5 - 2*Ixx6*dq14*C2*CC6*S3*S4*S5 - 2*Ixx6*dq14*C3*CC6*S2*S4*S5 - 2*Ixx6*dq14*CC5*C6*S2*S3*S6 - 2*Iyy6*dq12*C4*CC6*S2*S3*S5 - 2*Iyy6*dq13*C4*CC6*S2*S3*S5 + 2*Iyy6*dq14*C2*CC6*S3*S4*S5 + 2*Iyy6*dq14*C3*CC6*S2*S4*S5 + 2*Iyy6*dq14*CC5*C6*S2*S3*S6 + 2*Iyz6*dq12*C2*CC4*S3*S5*S6 + 2*Iyz6*dq12*C3*CC4*S2*S5*S6 + 2*Iyz6*dq12*CC5*C6*S2*S3*S4 + 2*Iyz6*dq13*C2*CC4*S3*S5*S6 + 2*Iyz6*dq13*C3*CC4*S2*S5*S6 + 2*Iyz6*dq13*CC5*C6*S2*S3*S4 - X6*a2*dq11*m_6*CC2*S3*S5*S6 - 2*XX6*dq15*m_6*CC6*S2*S3*S5 + 2*YY6*dq15*m_6*CC6*S2*S3*S5 - 2*Y6*Z6*dq24*m_6*CC5*C6*S4 - 2*Y6*Z6*dq34*m_6*CC5*C6*S4 - 4*Iyz6*dq11*C2*CC3*C4*CC5*C6*S2 - 4*Iyz6*dq11*CC2*C3*C4*CC5*C6*S3 + 2*Ixz6*dq12*CC5*S2*S3*S4*S6 + 2*Ixz6*dq13*CC5*S2*S3*S4*S6 - 2*XX6*dq11*m_6*CC2*CC3*C4*C5*S4 - 2*XX6*dq11*m_6*CC2*C4*C5*CC6*S4 - 2*XX6*dq11*m_6*CC3*C4*C5*CC6*S4 + 2*YY6*dq11*m_6*CC2*CC3*C4*C5*S4 + 2*YY6*dq11*m_6*CC2*C4*C5*CC6*S4 + 2*YY6*dq11*m_6*CC3*C4*C5*CC6*S4 - 2*Y6*d6*dq24*m_6*CC5*C6*S4 - 2*Y6*d6*dq34*m_6*CC5*C6*S4 - 2*X6*Y6*dq14*m_6*CC5*S2*S3 - 4*X6*Y6*dq14*m_6*CC6*S2*S3 - 2*X6*Z6*dq24*m_6*CC5*S4*S6 - 2*X6*Z6*dq34*m_6*CC5*S4*S6 - 2*Ixy6*dq11*C2*C3*CC4*CC5*S2*S3 + 4*Ixy6*dq11*C2*C3*CC4*CC6*S2*S3 + 4*Ixy6*dq11*C2*C3*CC5*CC6*S2*S3 - 4*Ixz6*dq11*C2*CC3*C4*CC5*S2*S6 - 4*Ixz6*dq11*CC2*C3*C4*CC5*S3*S6 - 2*Ixz6*dq11*CC2*CC3*C4*C6*S4*S5 - 2*X6*d6*dq24*m_6*CC5*S4*S6 - 2*X6*d6*dq34*m_6*CC5*S4*S6 + 4*Ixx6*dq11*C2*CC3*CC6*S2*S4*S5 + 4*Ixx6*dq11*CC2*C3*CC6*S3*S4*S5 - 4*Iyy6*dq11*C2*CC3*CC6*S2*S4*S5 - 4*Iyy6*dq11*CC2*C3*CC6*S3*S4*S5 + 2*Iyz6*dq11*CC2*CC3*C4*S4*S5*S6 - 4*Ixx6*dq12*C2*CC4*C5*CC6*S3 - 4*Ixx6*dq12*C3*CC4*C5*CC6*S2 - 4*Ixx6*dq13*C2*CC4*C5*CC6*S3 - 4*Ixx6*dq13*C3*CC4*C5*CC6*S2 + 4*Iyy6*dq12*C2*CC4*C5*CC6*S3 + 4*Iyy6*dq12*C3*CC4*C5*CC6*S2 + 4*Iyy6*dq13*C2*CC4*C5*CC6*S3 + 4*Iyy6*dq13*C3*CC4*C5*CC6*S2 + 2*X6*a3*dq11*m_6*CC2*CC3*C6*S4 + 2*XX6*dq23*m_6*CC4*CC5*C6*S6 + 2*Y6*d4*dq11*m_6*CC2*CC3*C6*S5 - 2*YY6*dq23*m_6*CC4*CC5*C6*S6 - 2*Y6*a3*dq11*m_6*CC2*CC3*S4*S6 + 2*X6*d4*dq11*m_6*CC2*CC3*S5*S6 - 4*Ixx6*dq11*CC2*CC3*C4*C5*CC6*S4 + 4*Iyy6*dq11*CC2*CC3*C4*C5*CC6*S4 - 2*Iyz6*dq11*CC2*CC3*CC4*C5*C6*S5 - 4*Ixx6*dq11*C2*C3*C6*S2*S3*S6 + 4*Iyy6*dq11*C2*C3*C6*S2*S3*S6 + 2*Ixz6*dq12*C2*C3*C4*C5*C6 + 2*Ixz6*dq13*C2*C3*C4*C5*C6 + Y6*a2*dq22*m_6*C3*C4*C5*C6 + 2*XX6*dq11*m_6*CC2*CC3*CC4*C6*S6 + 2*XX6*dq11*m_6*CC2*CC3*CC5*C6*S6 - XX6*dq11*m_6*CC2*CC4*CC5*C6*S6 - XX6*dq11*m_6*CC3*CC4*CC5*C6*S6 - 2*YY6*dq11*m_6*CC2*CC3*CC4*C6*S6 - 2*YY6*dq11*m_6*CC2*CC3*CC5*C6*S6 + YY6*dq11*m_6*CC2*CC4*CC5*C6*S6 + YY6*dq11*m_6*CC3*CC4*CC5*C6*S6 + Y6*Z6*dq11*m_6*C2*C4*C6*S2 + Y6*Z6*dq11*m_6*C3*C4*C6*S3 - 2*Ixz6*dq11*CC2*CC3*CC4*C5*S5*S6 + 4*Ixy6*dq11*C2*C6*S2*S4*S5*S6 + 4*Ixy6*dq11*C3*C6*S3*S4*S5*S6 - 2*Iyz6*dq12*C2*C3*C4*C5*S6 - 2*Iyz6*dq13*C2*C3*C4*C5*S6 + 2*Iyz6*dq14*C2*C3*C5*C6*S5 + X6*a1*dq11*m_6*C2*C3*C6*S4 + X6*a2*dq22*m_6*C3*C4*C5*S6 + 2*XX6*dq14*m_6*C2*C3*C6*S6 + Y6*d6*dq11*m_6*C2*C4*C6*S2 + Y6*d6*dq11*m_6*C3*C4*C6*S3 + 2*YY6*dq12*m_6*C2*C3*C4*S5 + 2*YY6*dq13*m_6*C2*C3*C4*S5 + 2*YY6*dq15*m_6*C2*C4*C5*S3 + 2*YY6*dq15*m_6*C3*C4*C5*S2 - 2*YY6*dq14*m_6*C2*C3*C6*S6 - 4*X6*Y6*dq11*m_6*C2*C3*S2*S3 + X6*Z6*dq11*m_6*C2*C4*S2*S6 + X6*Z6*dq11*m_6*C3*C4*S3*S6 + X6*Z6*dq22*m_6*C4*C6*S4*S5 + X6*Z6*dq33*m_6*C4*C6*S4*S5 - 2*Ixy6*dq12*C2*C3*C5*S4*S5 - 2*Ixy6*dq13*C2*C3*C5*S4*S5 + 2*Ixy6*dq14*C2*C4*C5*S3*S5 + 2*Ixy6*dq14*C3*C4*C5*S2*S5 - 4*Ixy6*dq12*C2*C5*C6*S3*S6 - 4*Ixy6*dq12*C3*C5*C6*S2*S6 - 4*Ixy6*dq13*C2*C5*C6*S3*S6 - 4*Ixy6*dq13*C3*C5*C6*S2*S6 + 4*Ixy6*dq15*C2*C3*C6*S5*S6 + 8*Ixy6*dq23*C4*C5*C6*S4*S6 - 2*Ixz6*dq12*C4*C5*C6*S2*S3 - 2*Ixz6*dq13*C4*C5*C6*S2*S3 + 2*Ixz6*dq14*C2*C3*C5*S5*S6 - 2*Ixz6*dq15*C2*C4*C6*S3*S5 - 2*Ixz6*dq15*C3*C4*C6*S2*S5 - Y6*a1*dq11*m_6*C2*C3*S4*S6 - Y6*a1*dq11*m_6*C2*C6*S3*S5 - Y6*a1*dq11*m_6*C3*C6*S2*S5 + Y6*a3*dq11*m_6*C2*C6*S2*S5 + Y6*a3*dq11*m_6*C3*C6*S3*S5 - X6*d4*dq11*m_6*C2*C6*S2*S4 - X6*d4*dq11*m_6*C3*C6*S3*S4 + X6*d6*dq11*m_6*C2*C4*S2*S6 + X6*d6*dq11*m_6*C3*C4*S3*S6 + X6*d6*dq22*m_6*C4*C6*S4*S5 + X6*d6*dq33*m_6*C4*C6*S4*S5 - Y6*Z6*dq22*m_6*C4*S4*S5*S6 - Y6*Z6*dq33*m_6*C4*S4*S5*S6 + 2*Ixx6*dq15*C2*C6*S3*S4*S6 + 2*Ixx6*dq15*C3*C6*S2*S4*S6 - 2*Ixx6*dq24*C5*C6*S4*S5*S6 - 2*Ixx6*dq34*C5*C6*S4*S5*S6 - 2*Iyy6*dq15*C2*C6*S3*S4*S6
 - 2*Iyy6*dq15*C3*C6*S2*S4*S6 + 2*Iyy6*dq24*C5*C6*S4*S5*S6 + 2*Iyy6*dq34*C5*C6*S4*S5*S6 + 2*Iyz6*dq12*C4*C5*S2*S3*S6 + 2*Iyz6*dq13*C4*C5*S2*S3*S6 - 2*Iyz6*dq14*C5*C6*S2*S3*S5 + 2*Iyz6*dq15*C2*C4*S3*S5*S6 + 2*Iyz6*dq15*C3*C4*S2*S5*S6 - X6*a1*dq11*m_6*C6*S2*S3*S4 - X6*a1*dq11*m_6*C2*S3*S5*S6 - X6*a1*dq11*m_6*C3*S2*S5*S6 + X6*a3*dq11*m_6*C2*S2*S5*S6 + X6*a3*dq11*m_6*C3*S3*S5*S6 + 2*Y6*a3*dq23*m_6*C4*C5*C6 - 2*XX6*dq14*m_6*C2*S3*S4*S5 - 2*XX6*dq14*m_6*C3*S2*S4*S5 - 2*XX6*dq14*m_6*C6*S2*S3*S6 + Y6*d4*dq11*m_6*C2*S2*S4*S6 + Y6*d4*dq11*m_6*C3*S3*S4*S6 - Y6*d6*dq22*m_6*C4*S4*S5*S6 - Y6*d6*dq33*m_6*C4*S4*S5*S6 - 2*YY6*dq12*m_6*C4*S2*S3*S5 - 2*YY6*dq13*m_6*C4*S2*S3*S5 + 2*YY6*dq14*m_6*C6*S2*S3*S6 - 2*Y6*Z6*dq23*m_6*C5*C6*S5 + 2*Ixy6*dq12*C5*S2*S3*S4*S5 + 2*Ixy6*dq13*C5*S2*S3*S4*S5 - 4*Ixy6*dq15*C6*S2*S3*S5*S6 - 2*Ixz6*dq14*C5*S2*S3*S5*S6 + 2*X6*a2*dq12*m_6*C4*C6*S2 + 2*X6*a3*dq23*m_6*C4*C5*S6 + Y6*a1*dq11*m_6*S2*S3*S4*S6 - 2*Y6*d6*dq23*m_6*C5*C6*S5 + 4*X6*Y6*dq23*m_6*CC4*CC5*CC6 + 2*X6*Y6*dq15*m_6*C2*S3*S4 + 2*X6*Y6*dq15*m_6*C3*S2*S4 - 2*X6*Y6*dq24*m_6*C5*S4*S5 - 2*X6*Y6*dq34*m_6*C5*S4*S5 + 4*X6*Y6*dq45*m_6*C6*S5*S6 - 2*X6*Z6*dq23*m_6*C5*S5*S6 + 2*X6*Z6*dq25*m_6*C6*S4*S5 + 2*X6*Z6*dq35*m_6*C6*S4*S5 - 4*Ixy6*dq11*C2*CC3*C4*C5*S2*S5 - 4*Ixy6*dq11*CC2*C3*C4*C5*S3*S5 - 4*Ixy6*dq11*C2*C4*C5*CC6*S2*S5 - 4*Ixy6*dq11*C3*C4*C5*CC6*S3*S5 - 4*Ixy6*dq11*CC2*C4*C5*C6*S4*S6 - 4*Ixy6*dq11*CC3*C4*C5*C6*S4*S6 - 2*Ixz6*dq11*C2*CC3*C5*C6*S2*S4 - 2*Ixz6*dq11*CC2*C3*C5*C6*S3*S4 - 2*Y6*a2*dq12*m_6*C4*S2*S6 - 2*X6*d6*dq23*m_6*C5*S5*S6 + 2*X6*d6*dq25*m_6*C6*S4*S5 + 2*X6*d6*dq35*m_6*C6*S4*S5 - 2*Ixx6*dq11*CC2*CC3*CC4*CC5*C6*S6 + 2*Iyy6*dq11*CC2*CC3*CC4*CC5*C6*S6 - 2*Y6*Z6*dq25*m_6*S4*S5*S6 - 2*Y6*Z6*dq35*m_6*S4*S5*S6 + 2*Iyz6*dq11*C2*CC3*C5*S2*S4*S6 + 2*Iyz6*dq11*CC2*C3*C5*S3*S4*S6 - Y6*a3*dq11*m_6*CC2*C4*C5*C6 - Y6*a3*dq11*m_6*CC3*C4*C5*C6 + 2*XX6*dq11*m_6*C2*CC3*S2*S4*S5 + 2*XX6*dq11*m_6*CC2*C3*S3*S4*S5 + 2*XX6*dq11*m_6*C2*CC6*S2*S4*S5 + 2*XX6*dq11*m_6*C3*CC6*S3*S4*S5 - 2*YY6*dq11*m_6*C2*CC3*S2*S4*S5 - 2*YY6*dq11*m_6*CC2*C3*S3*S4*S5 - 2*YY6*dq11*m_6*C2*CC6*S2*S4*S5 - 2*YY6*dq11*m_6*C3*CC6*S3*S4*S5 - 2*Y6*d6*dq25*m_6*S4*S5*S6 - 2*Y6*d6*dq35*m_6*S4*S5*S6 - 2*XX6*dq12*m_6*C4*CC6*S2*S3*S5 - 2*XX6*dq13*m_6*C4*CC6*S2*S3*S5 + 2*XX6*dq14*m_6*C2*CC6*S3*S4*S5 + 2*XX6*dq14*m_6*C3*CC6*S2*S4*S5 + 2*XX6*dq14*m_6*CC5*C6*S2*S3*S6 - 2*Y6*d4*dq11*m_6*C2*CC3*S2*S4*S6 - 2*Y6*d4*dq11*m_6*CC2*C3*S3*S4*S6 + Y6*d6*dq11*m_6*CC2*C4*S4*S5*S6 + Y6*d6*dq11*m_6*CC3*C4*S4*S5*S6 + 2*YY6*dq12*m_6*C4*CC6*S2*S3*S5 + 2*YY6*dq13*m_6*C4*CC6*S2*S3*S5 - 2*YY6*dq14*m_6*C2*CC6*S3*S4*S5 - 2*YY6*dq14*m_6*C3*CC6*S2*S4*S5 - 2*YY6*dq14*m_6*CC5*C6*S2*S3*S6 + 2*Y6*Z6*dq23*m_6*CC4*C5*C6*S5 - 4*Ixy6*dq12*C5*CC6*S2*S3*S4*S5 - 4*Ixy6*dq13*C5*CC6*S2*S3*S4*S5 + 2*Y6*d6*dq23*m_6*CC4*C5*C6*S5 - 4*X6*Y6*dq15*m_6*C2*CC6*S3*S4 - 4*X6*Y6*dq15*m_6*C3*CC6*S2*S4 + 4*X6*Y6*dq24*m_6*C5*CC6*S4*S5 + 4*X6*Y6*dq34*m_6*C5*CC6*S4*S5 + 2*X6*Z6*dq23*m_6*CC4*C5*S5*S6 + 8*Ixy6*dq11*C2*CC3*C4*C5*CC6*S2*S5 + 8*Ixy6*dq11*CC2*C3*C4*C5*CC6*S3*S5 + 8*Ixy6*dq11*CC2*CC3*C4*C5*C6*S4*S6 + 2*X6*d6*dq23*m_6*CC4*C5*S5*S6 + 2*Y6*a3*dq11*m_6*CC2*CC3*C4*C5*C6 - 4*XX6*dq11*m_6*C2*CC3*CC6*S2*S4*S5 - 4*XX6*dq11*m_6*CC2*C3*CC6*S3*S4*S5 + 4*YY6*dq11*m_6*C2*CC3*CC6*S2*S4*S5 + 4*YY6*dq11*m_6*CC2*C3*CC6*S3*S4*S5 + 2*Y6*Z6*dq11*m_6*CC2*CC3*C5*C6*S5 - Y6*Z6*dq11*m_6*CC2*CC4*C5*C6*S5 - Y6*Z6*dq11*m_6*CC3*CC4*C5*C6*S5 + 2*X6*a3*dq11*m_6*CC2*CC3*C4*C5*S6 + 4*XX6*dq12*m_6*C2*CC4*C5*CC6*S3 + 4*XX6*dq12*m_6*C3*CC4*C5*CC6*S2 + 4*XX6*dq13*m_6*C2*CC4*C5*CC6*S3 + 4*XX6*dq13*m_6*C3*CC4*C5*CC6*S2 + 2*Y6*d6*dq11*m_6*CC2*CC3*C5*C6*S5 - Y6*d6*dq11*m_6*CC2*CC4*C5*C6*S5 - Y6*d6*dq11*m_6*CC3*CC4*C5*C6*S5 - 4*YY6*dq12*m_6*C2*CC4*C5*CC6*S3 - 4*YY6*dq12*m_6*C3*CC4*C5*CC6*S2 - 4*YY6*dq13*m_6*C2*CC4*C5*CC6*S3 - 4*YY6*dq13*m_6*C3*CC4*C5*CC6*S2 + 4*X6*Y6*dq11*m_6*CC2*CC3*CC4*CC5*CC6 + 2*X6*Z6*dq11*m_6*CC2*CC3*C5*S5*S6 - X6*Z6*dq11*m_6*CC2*CC4*C5*S5*S6 - X6*Z6*dq11*m_6*CC3*CC4*C5*S5*S6 + 4*Ixy6*dq12*C2*C4*CC5*CC6*S3*S4 + 4*Ixy6*dq12*C3*C4*CC5*CC6*S2*S4 + 4*Ixy6*dq13*C2*C4*CC5*CC6*S3*S4 + 4*Ixy6*dq13*C3*C4*CC5*CC6*S2*S4 + 2*X6*d6*dq11*m_6*CC2*CC3*C5*S5*S6 - X6*d6*dq11*m_6*CC2*CC4*C5*S5*S6 - X6*d6*dq11*m_6*CC3*CC4*C5*S5*S6 - 4*X6*Y6*dq14*m_6*C2*C3*CC5*CC6 - 2*Ixx6*dq11*C2*C3*C4*C5*S2*S3*S4 - 2*Ixx6*dq11*C2*C4*C5*C6*S2*S5*S6 - 2*Ixx6*dq11*C3*C4*C5*C6*S3*S5*S6 + 2*Iyy6*dq11*C2*C3*C4*C5*S2*S3*S4 + 2*Iyy6*dq11*C2*C4*C5*C6*S2*S5*S6 + 2*Iyy6*dq11*C3*C4*C5*C6*S3*S5*S6 + 2*Iyz6*dq11*C2*C3*C5*C6*S2*S3*S5 + Y6*a1*dq11*m_6*C2*C3*C4*C5*C6 + 4*XX6*dq11*m_6*CC2*CC3*C4*C5*CC6*S4 - 4*YY6*dq11*m_6*CC2*CC3*C4*C5*CC6*S4 + 4*XX6*dq11*m_6*C2*C3*C6*S2*S3*S6 - 4*YY6*dq11*m_6*C2*C3*C6*S2*S3*S6 + 4*X6*Y6*dq14*m_6*CC5*CC6*S2*S3 + 4*Ixy6*dq11*C2*C3*CC4*CC5*CC6*S2*S3 + 2*Ixz6*dq11*C2*C3*C5*S2*S3*S5*S6 + X6*a1*dq11*m_6*C2*C3*C4*C5*S6 - Y6*d4*dq11*m_6*C2*C4*C5*C6*S2 - Y6*d4*dq11*m_6*C3*C4*C5*C6*S3 - 2*X6*Y6*dq11*m_6*C2*C4*C5*S2*S5 - 2*X6*Y6*dq11*m_6*C3*C4*C5*S3*S5 - 4*X6*Y6*dq22*m_6*C4*C5*C6*S4*S6 - 4*X6*Y6*dq33*m_6*C4*C5*C6*S4*S6 - X6*Z6*dq11*m_6*C2*C5*C6*S2*S4 - X6*Z6*dq11*m_6*C3*C5*C6*S3*S4 + 4*Ixy6*dq12*C2*C3*C4*C6*S5*S6 + 4*Ixy6*dq13*C2*C3*C4*C6*S5*S6 + 4*Ixy6*dq15*C2*C4*C5*C6*S3*S6 + 4*Ixy6*dq15*C3*C4*C5*C6*S2*S6 - Y6*a2*dq11*m_6*C2*C3*C6*S2*S5 - Y6*a1*dq11*m_6*C4*C5*C6*S2*S3 - X6*d4*dq11*m_6*C2*C4*C5*S2*S6 - X6*d4*dq11*m_6*C3*C4*C5*S3*S6 - X6*d6*dq11*m_6*C2*C5*C6*S2*S4 - X6*d6*dq11*m_6*C3*C5*C6*S3*S4 - 2*X6*Z6*dq15*m_6*C2*C3*C5*C6 + Y6*Z6*dq11*m_6*C2*C5*S2*S4*S6 + Y6*Z6*dq11*m_6*C3*C5*S3*S4*S6 + 2*Ixx6*dq12*C2*C4*C6*S3*S4*S6 + 2*Ixx6*dq12*C3*C4*C6*S2*S4*S6 + 2*Ixx6*dq13*C2*C4*C6*S3*S4*S6 + 2*Ixx6*dq13*C3*C4*C6*S2*S4*S6 - 2*Iyy6*dq12*C2*C4*C6*S3*S4*S6 - 2*Iyy6*dq12*C3*C4*C6*S2*S4*S6 - 2*Iyy6*dq13*C2*C4*C6*S3*S4*S6 - 2*Iyy6*dq13*C3*C4*C6*S2*S4*S6 - X6*a2*dq11*m_6*C2*C6*S2*S3*S4 - X6*a2*dq11*m_6*C2*C3*S2*S5*S6 - X6*a1*dq11*m_6*C4*C5*S2*S3*S6 - 2*XX6*dq15*m_6*C2*C6*S3*S4*S6 - 2*XX6*dq15*m_6*C3*C6*S2*S4*S6 + 2*XX6*dq24*m_6*C5*C6*S4*S5*S6 + 2*XX6*dq34*m_6*C5*C6*S4*S5*S6 - 2*X6*d4*dq12*m_6*C2*C3*C4*C6 - 2*X6*d4*dq13*m_6*C2*C3*C4*C6 - 2*X6*d6*dq15*m_6*C2*C3*C5*C6 + Y6*d6*dq11*m_6*C2*C5*S2*S4*S6 + Y6*d6*dq11*m_6*C3*C5*S3*S4*S6 + 2*YY6*dq15*m_6*C2*C6*S3*S4*S6 + 2*YY6*dq15*m_6*C3*C6*S2*S4*S6 - 2*YY6*dq24*m_6*C5*C6*S4*S5*S6 - 2*YY6*dq34*m_6*C5*C6*S4*S5*S6 + 2*Y6*Z6*dq14*m_6*C2*C4*C6*S3 + 2*Y6*Z6*dq14*m_6*C3*C4*C6*S2 + 2*Y6*Z6*dq15*m_6*C2*C3*C5*S6 - 4*Ixy6*dq12*C4*C6*S2*S3*S5*S6 - 4*Ixy6*dq13*C4*C6*S2*S3*S5*S6 + 4*Ixy6*dq14*C2*C6*S3*S4*S5*S6 + 4*Ixy6*dq14*C3*C6*S2*S4*S5*S6 + 2*X6*a3*dq12*m_6*C2*C4*C6*S3 + 2*X6*a3*dq12*m_6*C3*C4*C6*S2 + 2*X6*a3*dq13*m_6*C2*C4*C6*S3 + 2*X6*a3*dq13*m_6*C3*C4*C6*S2 + Y6*a2*dq11*m_6*C2*S2*S3*S4*S6 + 2*Y6*d4*dq12*m_6*C2*C3*C4*S6 + 2*Y6*d4*dq13*m_6*C2*C3*C4*S6 + 2*Y6*d6*dq14*m_6*C2*C4*C6*S3 + 2*Y6*d6*dq14*m_6*C3*C4*C6*S2 + 2*Y6*d6*dq15*m_6*C2*C3*C5*S6 + 2*X6*Y6*dq12*m_6*C2*C4*S3*S4 + 2*X6*Y6*dq12*m_6*C3*C4*S2*S4 + 2*X6*Y6*dq13*m_6*C2*C4*S3*S4 + 2*X6*Y6*dq13*m_6*C3*C4*S2*S4 + 4*X6*Y6*dq24*m_6*C4*C6*S5*S6 - 4*X6*Y6*dq25*m_6*C5*C6*S4*S6 + 4*X6*Y6*dq34*m_6*C4*C6*S5*S6 - 4*X6*Y6*dq35*m_6*C5*C6*S4*S6 + 2*X6*Z6*dq14*m_6*C2*C4*S3*S6 + 2*X6*Z6*dq14*m_6*C3*C4*S2*S6 + 2*X6*Z6*dq15*m_6*C5*C6*S2*S3 + 2*X6*Z6*dq23*m_6*C4*C6*S4*S5 - 2*Y6*a3*dq12*m_6*C2*C4*S3*S6 - 2*Y6*a3*dq12*m_6*C3*C4*S2*S6 - 2*Y6*a2*dq12*m_6*C5*C6*S2*S4 - 2*Y6*a3*dq13*m_6*C2*C4*S3*S6 - 2*Y6*a3*dq13*m_6*C3*C4*S2*S6 + 2*X6*d4*dq12*m_6*C4*C6*S2*S3 + 2*X6*d4*dq13*m_6*C4*C6*S2*S3 + 2*X6*d6*dq14*m_6*C2*C4*S3*S6 + 2*X6*d6*dq14*m_6*C3*C4*S2*S6 + 2*X6*d6*dq15*m_6*C5*C6*S2*S3 + 2*X6*d6*dq23*m_6*C4*C6*S4*S5 - 2*Y6*Z6*dq15*m_6*C5*S2*S3*S6 - 2*Y6*Z6*dq23*m_6*C4*S4*S5*S6 + 2*Ixx6*dq11*C2*C3*CC4*C6*S2*S3*S6 + 2*Ixx6*dq11*C2*C3*CC5*C6*S2*S3*S6 - 2*Iyy6*dq11*C2*C3*CC4*C6*S2*S3*S6 - 2*Iyy6*dq11*C2*C3*CC5*C6*S2*S3*S6 + Y6*a2*dq11*m_6*CC2*C3*C4*C5*C6 - 2*X6*a2*dq12*m_6*C5*S2*S4*S6 + 2*XX6*dq11*m_6*CC2*CC3*CC4*CC5*C6*S6 - 2*YY6*dq11*m_6*CC2*CC3*CC4*CC5*C6*S6 - 2*Y6*d4*dq12*m_6*C4*S2*S3*S6 - 2*Y6*d4*dq13*m_6*C4*S2*S3*S6 - 2*Y6*d6*dq15*m_6*C5*S2*S3*S6 - 2*Y6*d6*dq23*m_6*C4*S4*S5*S6 - 2*Y6*Z6*dq11*m_6*C2*CC3*C4*C6*S2 - 2*Y6*Z6*dq11*m_6*CC2*C3*C4*C6*S3 - 2*Y6*Z6*dq11*m_6*C2*C4*CC5*C6*S2 - 2*Y6*Z6*dq11*m_6*C3*C4*CC5*C6*S3 - 8*Ixy6*dq11*C2*CC3*C6*S2*S4*S5*S6 - 8*Ixy6*dq11*CC2*C3*C6*S3*S4*S5*S6 + X6*a2*dq11*m_6*CC2*C3*C4*C5*S6 + 2*XX6*dq12*m_6*C2*C3*C4*CC6*S5 + 2*XX6*dq13*m_6*C2*C3*C4*CC6*S5 + 2*XX6*dq15*m_6*C2*C4*C5*CC6*S3 + 2*XX6*dq15*m_6*C3*C4*C5*CC6*S2 - 2*XX6*dq14*m_6*C2*C3*CC5*C6*S6 - 2*Y6*d6*dq11*m_6*C2*CC3*C4*C6*S2 - 2*Y6*d6*dq11*m_6*CC2*C3*C4*C6*S3 - 2*Y6*d6*dq11*m_6*C2*C4*CC5*C6*S2 - 2*Y6*d6*dq11*m_6*C3*C4*CC5*C6*S3 - 2*YY6*dq12*m_6*C2*C3*C4*CC6*S5 - 2*YY6*dq13*m_6*C2*C3*C4*CC6*S5 - 2*YY6*dq15*m_6*C2*C4*C5*CC6*S3 - 2*YY6*dq15*m_6*C3*C4*C5*CC6*S2 + 2*YY6*dq14*m_6*C2*C3*CC5*C6*S6 + 2*X6*Y6*dq11*m_6*C2*C3*CC4*S2*S3 + 2*X6*Y6*dq11*m_6*C2*C3*CC5*S2*S3 + 8*X6*Y6*dq11*m_6*C2*C3*CC6*S2*S3 - 2*X6*Z6*dq11*m_6*C2*CC3*C4*S2*S6 - 2*X6*Z6*dq11*m_6*CC2*C3*C4*S3*S6 - 2*X6*Z6*dq11*m_6*C2*C4*CC5*S2*S6 - 2*X6*Z6*dq11*m_6*C3*C4*CC5*S3*S6 - X6*Z6*dq11*m_6*CC2*C4*C6*S4*S5 - X6*Z6*dq11*m_6*CC3*C4*C6*S4*S5 + 4*Ixy6*dq12*C2*C3*C5*CC6*S4*S5 + 8*Ixy6*dq12*C2*CC4*C5*C6*S3*S6 + 8*Ixy6*dq12*C3*CC4*C5*C6*S2*S6 + 4*Ixy6*dq13*C2*C3*C5*CC6*S4*S5 + 8*Ixy6*dq13*C2*CC4*C5*C6*S3*S6 + 8*Ixy6*dq13*C3*CC4*C5*C6*S2*S6 - 4*Ixy6*dq14*C2*C4*C5*CC6*S3*S5 - 4*Ixy6*dq14*C3*C4*C5*CC6*S2*S5 - 2*Y6*a3*dq11*m_6*C2*CC3*C6*S2*S5 - 2*Y6*a3*dq11*m_6*CC2*C3*C6*S3*S5 + 2*X6*d4*dq11*m_6*C2*CC3*C6*S2*S4 + 2*X6*d4*dq11*m_6*CC2*C3*C6*S3*S4 - 2*X6*d6*dq11*m_6*C2*CC3*C4*S2*S6 - 2*X6*d6*dq11*m_6*CC2*C3*C4*S3*S6 - 2*X6*d6*dq11*m_6*C2*C4*CC5*S2*S6 - 2*X6*d6*dq11*m_6*C3*C4*CC5*S3*S6 - X6*d6*dq11*m_6*CC2*C4*C6*S4*S5 - X6*d6*dq11*m_6*CC3*C4*C6*S4*S5 + Y6*Z6*dq11*m_6*CC2*C4*S4*S5*S6 + Y6*Z6*dq11*m_6*CC3*C4*S4*S5*S6 - 2*X6*a3*dq11*m_6*C2*CC3*S2*S5*S6 - 2*X6*a3*dq11*m_6*CC2*C3*S3*S5*S6 - 2*Y6*d6*dq12*m_6*C2*CC4*S3*S5*S6 - 2*Y6*d6*dq12*m_6*C3*CC4*S2*S5*S6 - 2*Y6*d6*dq12*m_6*CC5*C6*S2*S3*S4 - 2*Y6*d6*dq13*m_6*C2*CC4*S3*S5*S6 - 2*Y6*d6*dq13*m_6*C3*CC4*S2*S5*S6 - 2*Y6*d6*dq13*m_6*CC5*C6*S2*S3*S4 + 4*Y6*Z6*dq11*m_6*C2*CC3*C4*CC5*C6*S2
 + 4*Y6*Z6*dq11*m_6*CC2*C3*C4*CC5*C6*S3 - 2*X6*Z6*dq12*m_6*CC5*S2*S3*S4*S6 - 2*X6*Z6*dq13*m_6*CC5*S2*S3*S4*S6 + 4*Y6*d6*dq11*m_6*C2*CC3*C4*CC5*C6*S2 + 4*Y6*d6*dq11*m_6*CC2*C3*C4*CC5*C6*S3 - 2*X6*d6*dq12*m_6*CC5*S2*S3*S4*S6 - 2*X6*d6*dq13*m_6*CC5*S2*S3*S4*S6 + 2*X6*Y6*dq11*m_6*C2*C3*CC4*CC5*S2*S3 - 4*X6*Y6*dq11*m_6*C2*C3*CC4*CC6*S2*S3 - 4*X6*Y6*dq11*m_6*C2*C3*CC5*CC6*S2*S3 + 4*X6*Z6*dq11*m_6*C2*CC3*C4*CC5*S2*S6 + 4*X6*Z6*dq11*m_6*CC2*C3*C4*CC5*S3*S6 + 2*X6*Z6*dq11*m_6*CC2*CC3*C4*C6*S4*S5 + 4*X6*d6*dq11*m_6*C2*CC3*C4*CC5*S2*S6 + 4*X6*d6*dq11*m_6*CC2*C3*C4*CC5*S3*S6 + 2*X6*d6*dq11*m_6*CC2*CC3*C4*C6*S4*S5 - 2*Y6*Z6*dq11*m_6*CC2*CC3*C4*S4*S5*S6 - 2*Y6*d6*dq11*m_6*CC2*CC3*C4*S4*S5*S6 + 2*XX6*dq11*m_6*C2*C3*C4*C5*S2*S3*S4 + 2*XX6*dq11*m_6*C2*C4*C5*C6*S2*S5*S6 + 2*XX6*dq11*m_6*C3*C4*C5*C6*S3*S5*S6 - 2*YY6*dq11*m_6*C2*C3*C4*C5*S2*S3*S4 - 2*YY6*dq11*m_6*C2*C4*C5*C6*S2*S5*S6 - 2*YY6*dq11*m_6*C3*C4*C5*C6*S3*S5*S6 + 2*Ixz6*dq11*C2*C3*C4*C6*S2*S3*S4*S5 - 2*Iyz6*dq11*C2*C3*C4*S2*S3*S4*S5*S6 - Y6*a2*dq11*m_6*C2*C4*C5*C6*S2*S3 + 2*Y6*Z6*dq11*m_6*CC2*CC3*CC4*C5*C6*S5 - 2*X6*Z6*dq12*m_6*C2*C3*C4*C5*C6 - 2*X6*Z6*dq13*m_6*C2*C3*C4*C5*C6 + 2*Ixx6*dq12*C2*C3*C5*C6*S4*S5*S6 + 2*Ixx6*dq13*C2*C3*C5*C6*S4*S5*S6 - 2*Ixx6*dq14*C2*C4*C5*C6*S3*S5*S6 - 2*Ixx6*dq14*C3*C4*C5*C6*S2*S5*S6 - 2*Iyy6*dq12*C2*C3*C5*C6*S4*S5*S6 - 2*Iyy6*dq13*C2*C3*C5*C6*S4*S5*S6 + 2*Iyy6*dq14*C2*C4*C5*C6*S3*S5*S6 + 2*Iyy6*dq14*C3*C4*C5*C6*S2*S5*S6 + 2*Iyz6*dq12*C2*C4*C5*C6*S3*S4*S5 + 2*Iyz6*dq12*C3*C4*C5*C6*S2*S4*S5 + 2*Iyz6*dq13*C2*C4*C5*C6*S3*S4*S5 + 2*Iyz6*dq13*C3*C4*C5*C6*S2*S4*S5 - 2*X6*a3*dq11*m_6*C2*C3*C6*S2*S3*S4 - X6*a2*dq11*m_6*C2*C4*C5*S2*S3*S6 + 2*Y6*d6*dq11*m_6*CC2*CC3*CC4*C5*C6*S5 - 2*XX6*dq12*m_6*C2*C4*C6*S3*S4*S6 - 2*XX6*dq12*m_6*C3*C4*C6*S2*S4*S6 - 2*XX6*dq13*m_6*C2*C4*C6*S3*S4*S6 - 2*XX6*dq13*m_6*C3*C4*C6*S2*S4*S6 - 2*X6*d6*dq12*m_6*C2*C3*C4*C5*C6 - 2*X6*d6*dq13*m_6*C2*C3*C4*C5*C6 - 2*Y6*d4*dq11*m_6*C2*C3*C6*S2*S3*S5 + 2*YY6*dq12*m_6*C2*C4*C6*S3*S4*S6 + 2*YY6*dq12*m_6*C3*C4*C6*S2*S4*S6 + 2*YY6*dq13*m_6*C2*C4*C6*S3*S4*S6 + 2*YY6*dq13*m_6*C3*C4*C6*S2*S4*S6 + 2*X6*Z6*dq11*m_6*CC2*CC3*CC4*C5*S5*S6 - 4*X6*Y6*dq11*m_6*C2*C6*S2*S4*S5*S6 - 4*X6*Y6*dq11*m_6*C3*C6*S3*S4*S5*S6 + 2*Y6*Z6*dq12*m_6*C2*C3*C4*C5*S6 + 2*Y6*Z6*dq13*m_6*C2*C3*C4*C5*S6 - 2*Y6*Z6*dq14*m_6*C2*C3*C5*C6*S5 + 2*Ixz6*dq12*C2*C4*C5*S3*S4*S5*S6 + 2*Ixz6*dq12*C3*C4*C5*S2*S4*S5*S6 + 2*Ixz6*dq13*C2*C4*C5*S3*S4*S5*S6 + 2*Ixz6*dq13*C3*C4*C5*S2*S4*S5*S6 + 2*Y6*a3*dq11*m_6*C2*C3*S2*S3*S4*S6 + 2*X6*d6*dq11*m_6*CC2*CC3*CC4*C5*S5*S6 - 2*X6*d4*dq11*m_6*C2*C3*S2*S3*S5*S6 + 2*Y6*d4*dq12*m_6*C2*C3*C5*C6*S4 + 2*Y6*d4*dq13*m_6*C2*C3*C5*C6*S4 + 2*Y6*d6*dq12*m_6*C2*C3*C4*C5*S6 + 2*Y6*d6*dq13*m_6*C2*C3*C4*C5*S6 - 2*Y6*d6*dq14*m_6*C2*C3*C5*C6*S5 + 2*X6*Y6*dq12*m_6*C2*C3*C5*S4*S5 + 2*X6*Y6*dq13*m_6*C2*C3*C5*S4*S5 - 2*X6*Y6*dq14*m_6*C2*C4*C5*S3*S5 - 2*X6*Y6*dq14*m_6*C3*C4*C5*S2*S5 + 4*X6*Y6*dq12*m_6*C2*C5*C6*S3*S6 + 4*X6*Y6*dq12*m_6*C3*C5*C6*S2*S6 + 4*X6*Y6*dq13*m_6*C2*C5*C6*S3*S6 + 4*X6*Y6*dq13*m_6*C3*C5*C6*S2*S6 - 4*X6*Y6*dq15*m_6*C2*C3*C6*S5*S6 - 8*X6*Y6*dq23*m_6*C4*C5*C6*S4*S6 + 2*X6*Z6*dq12*m_6*C4*C5*C6*S2*S3 + 2*X6*Z6*dq13*m_6*C4*C5*C6*S2*S3 - 2*X6*Z6*dq14*m_6*C2*C3*C5*S5*S6 + 2*X6*Z6*dq15*m_6*C2*C4*C6*S3*S5 + 2*X6*Z6*dq15*m_6*C3*C4*C6*S2*S5 - 2*Ixx6*dq12*C5*C6*S2*S3*S4*S5*S6 - 2*Ixx6*dq13*C5*C6*S2*S3*S4*S5*S6 + 2*Iyy6*dq12*C5*C6*S2*S3*S4*S5*S6 + 2*Iyy6*dq13*C5*C6*S2*S3*S4*S5*S6 - 2*Y6*a3*dq12*m_6*C2*C5*C6*S3*S4 - 2*Y6*a3*dq12*m_6*C3*C5*C6*S2*S4 - 2*Y6*a3*dq13*m_6*C2*C5*C6*S3*S4 - 2*Y6*a3*dq13*m_6*C3*C5*C6*S2*S4 + 2*X6*d4*dq12*m_6*C2*C3*C5*S4*S6 + 2*X6*d4*dq13*m_6*C2*C3*C5*S4*S6 + 2*X6*d6*dq12*m_6*C4*C5*C6*S2*S3 + 2*X6*d6*dq13*m_6*C4*C5*C6*S2*S3 - 2*X6*d6*dq14*m_6*C2*C3*C5*S5*S6 + 2*X6*d6*dq15*m_6*C2*C4*C6*S3*S5 + 2*X6*d6*dq15*m_6*C3*C4*C6*S2*S5 - 2*Y6*Z6*dq12*m_6*C4*C5*S2*S3*S6 - 2*Y6*Z6*dq13*m_6*C4*C5*S2*S3*S6 + 2*Y6*Z6*dq14*m_6*C5*C6*S2*S3*S5 - 2*Y6*Z6*dq15*m_6*C2*C4*S3*S5*S6 - 2*Y6*Z6*dq15*m_6*C3*C4*S2*S5*S6 + 4*Ixx6*dq11*C2*C3*C4*C5*CC6*S2*S3*S4 + 4*Ixx6*dq11*C2*CC3*C4*C5*C6*S2*S5*S6 + 4*Ixx6*dq11*CC2*C3*C4*C5*C6*S3*S5*S6 - 4*Iyy6*dq11*C2*C3*C4*C5*CC6*S2*S3*S4 - 4*Iyy6*dq11*C2*CC3*C4*C5*C6*S2*S5*S6 - 4*Iyy6*dq11*CC2*C3*C4*C5*C6*S3*S5*S6 + 2*Iyz6*dq11*C2*C3*CC4*C5*C6*S2*S3*S5 - 2*X6*a3*dq12*m_6*C2*C5*S3*S4*S6 - 2*X6*a3*dq12*m_6*C3*C5*S2*S4*S6 - 2*X6*a3*dq13*m_6*C2*C5*S3*S4*S6 - 2*X6*a3*dq13*m_6*C3*C5*S2*S4*S6 - 2*XX6*dq11*m_6*C2*C3*CC4*C6*S2*S3*S6 - 2*XX6*dq11*m_6*C2*C3*CC5*C6*S2*S3*S6 + 2*YY6*dq11*m_6*C2*C3*CC4*C6*S2*S3*S6 + 2*YY6*dq11*m_6*C2*C3*CC5*C6*S2*S3*S6 - 2*Y6*d4*dq12*m_6*C5*C6*S2*S3*S4 - 2*Y6*d4*dq13*m_6*C5*C6*S2*S3*S4 - 2*Y6*d6*dq12*m_6*C4*C5*S2*S3*S6 - 2*Y6*d6*dq13*m_6*C4*C5*S2*S3*S6 + 2*Y6*d6*dq14*m_6*C5*C6*S2*S3*S5 - 2*Y6*d6*dq15*m_6*C2*C4*S3*S5*S6 - 2*Y6*d6*dq15*m_6*C3*C4*S2*S5*S6 - 2*X6*Y6*dq12*m_6*C5*S2*S3*S4*S5 - 2*X6*Y6*dq13*m_6*C5*S2*S3*S4*S5 + 4*X6*Y6*dq15*m_6*C6*S2*S3*S5*S6 + 2*X6*Z6*dq14*m_6*C5*S2*S3*S5*S6 + 2*Ixz6*dq11*C2*C3*CC4*C5*S2*S3*S5*S6 + 2*Y6*d4*dq11*m_6*C2*CC3*C4*C5*C6*S2 + 2*Y6*d4*dq11*m_6*CC2*C3*C4*C5*C6*S3 - 2*X6*d4*dq12*m_6*C5*S2*S3*S4*S6 - 2*X6*d4*dq13*m_6*C5*S2*S3*S4*S6 + 2*X6*d6*dq14*m_6*C5*S2*S3*S5*S6 + 4*X6*Y6*dq11*m_6*C2*CC3*C4*C5*S2*S5 + 4*X6*Y6*dq11*m_6*CC2*C3*C4*C5*S3*S5 + 4*X6*Y6*dq11*m_6*C2*C4*C5*CC6*S2*S5 + 4*X6*Y6*dq11*m_6*C3*C4*C5*CC6*S3*S5 + 4*X6*Y6*dq11*m_6*CC2*C4*C5*C6*S4*S6 + 4*X6*Y6*dq11*m_6*CC3*C4*C5*C6*S4*S6 + 2*X6*Z6*dq11*m_6*C2*CC3*C5*C6*S2*S4 + 2*X6*Z6*dq11*m_6*CC2*C3*C5*C6*S3*S4 + 2*X6*d4*dq11*m_6*C2*CC3*C4*C5*S2*S6 + 2*X6*d4*dq11*m_6*CC2*C3*C4*C5*S3*S6 + 2*X6*d6*dq11*m_6*C2*CC3*C5*C6*S2*S4 + 2*X6*d6*dq11*m_6*CC2*C3*C5*C6*S3*S4 - 2*Y6*Z6*dq11*m_6*C2*CC3*C5*S2*S4*S6 - 2*Y6*Z6*dq11*m_6*CC2*C3*C5*S3*S4*S6 + 2*Ixx6*dq12*C2*C4*CC5*C6*S3*S4*S6 + 2*Ixx6*dq12*C3*C4*CC5*C6*S2*S4*S6 + 2*Ixx6*dq13*C2*C4*CC5*C6*S3*S4*S6 + 2*Ixx6*dq13*C3*C4*CC5*C6*S2*S4*S6 - 2*Iyy6*dq12*C2*C4*CC5*C6*S3*S4*S6 - 2*Iyy6*dq12*C3*C4*CC5*C6*S2*S4*S6 - 2*Iyy6*dq13*C2*C4*CC5*C6*S3*S4*S6 - 2*Iyy6*dq13*C3*C4*CC5*C6*S2*S4*S6 - 2*Y6*d6*dq11*m_6*C2*CC3*C5*S2*S4*S6 - 2*Y6*d6*dq11*m_6*CC2*C3*C5*S3*S4*S6 + 2*Y6*Z6*dq12*m_6*C2*C3*CC5*C6*S4 + 2*Y6*Z6*dq13*m_6*C2*C3*CC5*C6*S4 - 2*Y6*Z6*dq14*m_6*C2*C4*CC5*C6*S3 - 2*Y6*Z6*dq14*m_6*C3*C4*CC5*C6*S2 + 2*Y6*d6*dq12*m_6*C2*C3*CC5*C6*S4 + 2*Y6*d6*dq13*m_6*C2*C3*CC5*C6*S4 - 2*Y6*d6*dq14*m_6*C2*C4*CC5*C6*S3 - 2*Y6*d6*dq14*m_6*C3*C4*CC5*C6*S2 + 2*X6*Y6*dq12*m_6*C2*C4*CC5*S3*S4 + 2*X6*Y6*dq12*m_6*C3*C4*CC5*S2*S4 - 4*X6*Y6*dq12*m_6*C2*C4*CC6*S3*S4 - 4*X6*Y6*dq12*m_6*C3*C4*CC6*S2*S4 + 2*X6*Y6*dq13*m_6*C2*C4*CC5*S3*S4 + 2*X6*Y6*dq13*m_6*C3*C4*CC5*S2*S4 - 4*X6*Y6*dq13*m_6*C2*C4*CC6*S3*S4 - 4*X6*Y6*dq13*m_6*C3*C4*CC6*S2*S4 + 2*X6*Z6*dq12*m_6*C2*C3*CC5*S4*S6 + 2*X6*Z6*dq12*m_6*C2*CC4*C6*S3*S5 + 2*X6*Z6*dq12*m_6*C3*CC4*C6*S2*S5 + 2*X6*Z6*dq13*m_6*C2*C3*CC5*S4*S6 + 2*X6*Z6*dq13*m_6*C2*CC4*C6*S3*S5 + 2*X6*Z6*dq13*m_6*C3*CC4*C6*S2*S5 - 2*X6*Z6*dq14*m_6*C2*C4*CC5*S3*S6 - 2*X6*Z6*dq14*m_6*C3*C4*CC5*S2*S6 + 2*X6*d6*dq12*m_6*C2*C3*CC5*S4*S6 + 2*X6*d6*dq12*m_6*C2*CC4*C6*S3*S5 + 2*X6*d6*dq12*m_6*C3*CC4*C6*S2*S5 + 2*X6*d6*dq13*m_6*C2*C3*CC5*S4*S6 + 2*X6*d6*dq13*m_6*C2*CC4*C6*S3*S5 + 2*X6*d6*dq13*m_6*C3*CC4*C6*S2*S5 - 2*X6*d6*dq14*m_6*C2*C4*CC5*S3*S6 - 2*X6*d6*dq14*m_6*C3*C4*CC5*S2*S6 - 2*Y6*Z6*dq12*m_6*C2*CC4*S3*S5*S6 - 2*Y6*Z6*dq12*m_6*C3*CC4*S2*S5*S6 - 2*Y6*Z6*dq12*m_6*CC5*C6*S2*S3*S4 - 2*Y6*Z6*dq13*m_6*C2*CC4*S3*S5*S6 - 2*Y6*Z6*dq13*m_6*C3*CC4*S2*S5*S6 - 2*Y6*Z6*dq13*m_6*CC5*C6*S2*S3*S4 + 2*Ixx6*dq11*C2*C3*CC4*CC5*C6*S2*S3*S6 - 2*Iyy6*dq11*C2*C3*CC4*CC5*C6*S2*S3*S6 - 4*X6*Y6*dq12*m_6*C2*C4*CC5*CC6*S3*S4 - 4*X6*Y6*dq12*m_6*C3*C4*CC5*CC6*S2*S4 - 4*X6*Y6*dq13*m_6*C2*C4*CC5*CC6*S3*S4 - 4*X6*Y6*dq13*m_6*C3*C4*CC5*CC6*S2*S4 - 8*Ixy6*dq11*C2*C3*C4*C5*C6*S2*S3*S4*S6 - 2*Y6*a3*dq11*m_6*C2*C3*C4*C5*C6*S2*S3 - 2*Y6*Z6*dq11*m_6*C2*C3*C5*C6*S2*S3*S5 - 2*X6*a3*dq11*m_6*C2*C3*C4*C5*S2*S3*S6 - 2*XX6*dq12*m_6*C2*C3*C5*C6*S4*S5*S6 - 2*XX6*dq13*m_6*C2*C3*C5*C6*S4*S5*S6 + 2*XX6*dq14*m_6*C2*C4*C5*C6*S3*S5*S6 + 2*XX6*dq14*m_6*C3*C4*C5*C6*S2*S5*S6 - 2*Y6*d6*dq11*m_6*C2*C3*C5*C6*S2*S3*S5 + 2*YY6*dq12*m_6*C2*C3*C5*C6*S4*S5*S6 + 2*YY6*dq13*m_6*C2*C3*C5*C6*S4*S5*S6 - 2*YY6*dq14*m_6*C2*C4*C5*C6*S3*S5*S6 - 2*YY6*dq14*m_6*C3*C4*C5*C6*S2*S5*S6 - 4*X6*Y6*dq11*m_6*C2*C3*CC4*CC5*CC6*S2*S3 - 2*X6*Z6*dq11*m_6*C2*C3*C5*S2*S3*S5*S6 - 2*X6*d6*dq11*m_6*C2*C3*C5*S2*S3*S5*S6 - 4*X6*Y6*dq12*m_6*C2*C3*C4*C6*S5*S6 - 4*X6*Y6*dq13*m_6*C2*C3*C4*C6*S5*S6 - 4*X6*Y6*dq15*m_6*C2*C4*C5*C6*S3*S6 - 4*X6*Y6*dq15*m_6*C3*C4*C5*C6*S2*S6 + 2*XX6*dq12*m_6*C5*C6*S2*S3*S4*S5*S6 + 2*XX6*dq13*m_6*C5*C6*S2*S3*S4*S5*S6 - 2*YY6*dq12*m_6*C5*C6*S2*S3*S4*S5*S6 - 2*YY6*dq13*m_6*C5*C6*S2*S3*S4*S5*S6 - 4*XX6*dq11*m_6*C2*C3*C4*C5*CC6*S2*S3*S4 - 4*XX6*dq11*m_6*C2*CC3*C4*C5*C6*S2*S5*S6 - 4*XX6*dq11*m_6*CC2*C3*C4*C5*C6*S3*S5*S6 + 4*YY6*dq11*m_6*C2*C3*C4*C5*CC6*S2*S3*S4 + 4*YY6*dq11*m_6*C2*CC3*C4*C5*C6*S2*S5*S6 + 4*YY6*dq11*m_6*CC2*C3*C4*C5*C6*S3*S5*S6 + 4*X6*Y6*dq12*m_6*C4*C6*S2*S3*S5*S6 + 4*X6*Y6*dq13*m_6*C4*C6*S2*S3*S5*S6 - 4*X6*Y6*dq14*m_6*C2*C6*S3*S4*S5*S6 - 4*X6*Y6*dq14*m_6*C3*C6*S2*S4*S5*S6 - 2*XX6*dq12*m_6*C2*C4*CC5*C6*S3*S4*S6 - 2*XX6*dq12*m_6*C3*C4*CC5*C6*S2*S4*S6 - 2*XX6*dq13*m_6*C2*C4*CC5*C6*S3*S4*S6 - 2*XX6*dq13*m_6*C3*C4*CC5*C6*S2*S4*S6 + 2*YY6*dq12*m_6*C2*C4*CC5*C6*S3*S4*S6 + 2*YY6*dq12*m_6*C3*C4*CC5*C6*S2*S4*S6 + 2*YY6*dq13*m_6*C2*C4*CC5*C6*S3*S4*S6 + 2*YY6*dq13*m_6*C3*C4*CC5*C6*S2*S4*S6 + 8*X6*Y6*dq11*m_6*C2*CC3*C6*S2*S4*S5*S6 + 8*X6*Y6*dq11*m_6*CC2*C3*C6*S3*S4*S5*S6 - 4*X6*Y6*dq12*m_6*C2*C3*C5*CC6*S4*S5 - 8*X6*Y6*dq12*m_6*C2*CC4*C5*C6*S3*S6 - 8*X6*Y6*dq12*m_6*C3*CC4*C5*C6*S2*S6 - 4*X6*Y6*dq13*m_6*C2*C3*C5*CC6*S4*S5 - 8*X6*Y6*dq13*m_6*C2*CC4*C5*C6*S3*S6 - 8*X6*Y6*dq13*m_6*C3*CC4*C5*C6*S2*S6 + 4*X6*Y6*dq14*m_6*C2*C4*C5*CC6*S3*S5 + 4*X6*Y6*dq14*m_6*C3*C4*C5*CC6*S2*S5 - 2*XX6*dq11*m_6*C2*C3*CC4*CC5*C6*S2*S3*S6 + 2*YY6*dq11*m_6*C2*C3*CC4*CC5*C6*S2*S3*S6 + 4*X6*Y6*dq12*m_6*C5*CC6*S2*S3*S4*S5 + 4*X6*Y6*dq13*m_6*C5*CC6*S2*S3*S4*S5 - 8*X6*Y6*dq11*m_6*C2*CC3*C4*C5*CC6*S2*S5 - 8*X6*Y6*dq11*m_6*CC2*C3*C4*C5*CC6*S3*S5 - 8*X6*Y6*dq11*m_6*CC2*CC3*C4*C5*C6*S4*S6 - 2*X6*Z6*dq11*m_6*C2*C3*C4*C6*S2*S3*S4*S5 - 2*X6*d6*dq11*m_6*C2*C3*C4*C6*S2*S3*S4*S5
 + 2*Y6*Z6*dq11*m_6*C2*C3*C4*S2*S3*S4*S5*S6 + 2*Y6*d6*dq11*m_6*C2*C3*C4*S2*S3*S4*S5*S6 - 2*Y6*Z6*dq12*m_6*C2*C4*C5*C6*S3*S4*S5 - 2*Y6*Z6*dq12*m_6*C3*C4*C5*C6*S2*S4*S5 - 2*Y6*Z6*dq13*m_6*C2*C4*C5*C6*S3*S4*S5 - 2*Y6*Z6*dq13*m_6*C3*C4*C5*C6*S2*S4*S5 - 2*Y6*d6*dq12*m_6*C2*C4*C5*C6*S3*S4*S5 - 2*Y6*d6*dq12*m_6*C3*C4*C5*C6*S2*S4*S5 - 2*Y6*d6*dq13*m_6*C2*C4*C5*C6*S3*S4*S5 - 2*Y6*d6*dq13*m_6*C3*C4*C5*C6*S2*S4*S5 - 2*X6*Z6*dq12*m_6*C2*C4*C5*S3*S4*S5*S6 - 2*X6*Z6*dq12*m_6*C3*C4*C5*S2*S4*S5*S6 - 2*X6*Z6*dq13*m_6*C2*C4*C5*S3*S4*S5*S6 - 2*X6*Z6*dq13*m_6*C3*C4*C5*S2*S4*S5*S6 - 2*X6*d6*dq12*m_6*C2*C4*C5*S3*S4*S5*S6 - 2*X6*d6*dq12*m_6*C3*C4*C5*S2*S4*S5*S6 - 2*X6*d6*dq13*m_6*C2*C4*C5*S3*S4*S5*S6 - 2*X6*d6*dq13*m_6*C3*C4*C5*S2*S4*S5*S6 - 2*Y6*Z6*dq11*m_6*C2*C3*CC4*C5*C6*S2*S3*S5 - 2*Y6*d6*dq11*m_6*C2*C3*CC4*C5*C6*S2*S3*S5 - 2*X6*Z6*dq11*m_6*C2*C3*CC4*C5*S2*S3*S5*S6 - 2*X6*d6*dq11*m_6*C2*C3*CC4*C5*S2*S3*S5*S6 + 8*X6*Y6*dq11*m_6*C2*C3*C4*C5*C6*S2*S3*S4*S6;

return(coriolis);
}


